__BRYTHON__.VFS_timestamp = 1533849808545
__BRYTHON__.use_VFS = true
__BRYTHON__.VFS = {"heapq": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__about__=\"\"\"Heap queues\n\n[explanation by Fran\u00e7ois Pinard]\n\nHeaps are arrays for which a[k] <= a[2*k+1] and a[k] <= a[2*k+2] for\nall k, counting elements from 0.  For the sake of comparison,\nnon-existing elements are considered to be infinite.  The interesting\nproperty of a heap is that a[0] is always its smallest element.\n\nThe strange invariant above is meant to be an efficient memory\nrepresentation for a tournament.  The numbers below are `k', not a[k]:\n\n                                   0\n\n                  1                                 2\n\n          3               4                5               6\n\n      7       8       9       10      11      12      13      14\n\n    15 16   17 18   19 20   21 22   23 24   25 26   27 28   29 30\n\n\nIn the tree above, each cell `k' is topping `2*k+1' and `2*k+2'.  In\nan usual binary tournament we see in sports, each cell is the winner\nover the two cells it tops, and we can trace the winner down the tree\nto see all opponents s/he had.  However, in many computer applications\nof such tournaments, we do not need to trace the history of a winner.\nTo be more memory efficient, when a winner is promoted, we try to\nreplace it by something else at a lower level, and the rule becomes\nthat a cell and the two cells it tops contain three different items,\nbut the top cell \"wins\" over the two topped cells.\n\nIf this heap invariant is protected at all time, index 0 is clearly\nthe overall winner.  The simplest algorithmic way to remove it and\nfind the \"next\" winner is to move some loser (let's say cell 30 in the\ndiagram above) into the 0 position, and then percolate this new 0 down\nthe tree, exchanging values, until the invariant is re-established.\nThis is clearly logarithmic on the total number of items in the tree.\nBy iterating over all items, you get an O(n ln n) sort.\n\nA nice feature of this sort is that you can efficiently insert new\nitems while the sort is going on, provided that the inserted items are\nnot \"better\" than the last 0'th element you extracted.  This is\nespecially useful in simulation contexts, where the tree holds all\nincoming events, and the \"win\" condition means the smallest scheduled\ntime.  When an event schedule other events for execution, they are\nscheduled into the future, so they can easily go into the heap.  So, a\nheap is a good structure for implementing schedulers (this is what I\nused for my MIDI sequencer :-).\n\nVarious structures for implementing schedulers have been extensively\nstudied, and heaps are good for this, as they are reasonably speedy,\nthe speed is almost constant, and the worst case is not much different\nthan the average case.  However, there are other representations which\nare more efficient overall, yet the worst cases might be terrible.\n\nHeaps are also very useful in big disk sorts.  You most probably all\nknow that a big sort implies producing \"runs\" (which are pre-sorted\nsequences, which size is usually related to the amount of CPU memory),\nfollowed by a merging passes for these runs, which merging is often\nvery cleverly organised[1].  It is very important that the initial\nsort produces the longest runs possible.  Tournaments are a good way\nto that.  If, using all the memory available to hold a tournament, you\nreplace and percolate items that happen to fit the current run, you'll\nproduce runs which are twice the size of the memory for random input,\nand much better for input fuzzily ordered.\n\nMoreover, if you output the 0'th item on disk and get an input which\nmay not fit in the current tournament (because the value \"wins\" over\nthe last output value), it cannot fit in the heap, so the size of the\nheap decreases.  The freed memory could be cleverly reused immediately\nfor progressively building a second heap, which grows at exactly the\nsame rate the first heap is melting.  When the first heap completely\nvanishes, you switch heaps and start a new run.  Clever and quite\neffective!\n\nIn a word, heaps are useful memory structures to know.  I use them in\na few applications, and I think it is good to keep a `heap' module\naround. :-)\n\n--------------------\n[1] The disk balancing algorithms which are current, nowadays, are\nmore annoying than clever, and this is a consequence of the seeking\ncapabilities of the disks.  On devices which cannot seek, like big\ntape drives, the story was quite different, and one had to be very\nclever to ensure (far in advance) that each tape movement will be the\nmost effective possible (that is, will best participate at\n\"progressing\" the merge).  Some tapes were even able to read\nbackwards, and this was also used to avoid the rewinding time.\nBelieve me, real good tape sorts were quite spectacular to watch!\nFrom all times, sorting has always been a Great Art! :-)\n\"\"\"\n\n__all__=['heappush','heappop','heapify','heapreplace','merge',\n'nlargest','nsmallest','heappushpop']\n\nfrom itertools import islice,count,tee,chain\n\ndef heappush(heap,item):\n ''\n heap. append(item)\n _siftdown(heap,0,len(heap)-1)\n \ndef heappop(heap):\n ''\n lastelt=heap. pop()\n if heap:\n  returnitem=heap[0]\n  heap[0]=lastelt\n  _siftup(heap,0)\n else :\n  returnitem=lastelt\n return returnitem\n \ndef heapreplace(heap,item):\n ''\n\n\n\n\n\n\n\n\n \n returnitem=heap[0]\n heap[0]=item\n _siftup(heap,0)\n return returnitem\n \ndef heappushpop(heap,item):\n ''\n if heap and heap[0]<item:\n  item,heap[0]=heap[0],item\n  _siftup(heap,0)\n return item\n \ndef heapify(x):\n ''\n n=len(x)\n \n \n \n \n \n for i in reversed(range(n //2)):\n  _siftup(x,i)\n  \ndef _heappushpop_max(heap,item):\n ''\n if heap and item <heap[0]:\n  item,heap[0]=heap[0],item\n  _siftup_max(heap,0)\n return item\n \ndef _heapify_max(x):\n ''\n n=len(x)\n for i in reversed(range(n //2)):\n  _siftup_max(x,i)\n  \ndef nlargest(n,iterable):\n ''\n\n\n \n if n <0:\n  return []\n it=iter(iterable)\n result=list(islice(it,n))\n if not result:\n  return result\n heapify(result)\n _heappushpop=heappushpop\n for elem in it:\n  _heappushpop(result,elem)\n result. sort(reverse=True )\n return result\n \ndef nsmallest(n,iterable):\n ''\n\n\n \n if n <0:\n  return []\n it=iter(iterable)\n result=list(islice(it,n))\n if not result:\n  return result\n _heapify_max(result)\n _heappushpop=_heappushpop_max\n for elem in it:\n  _heappushpop(result,elem)\n result. sort()\n return result\n \n \n \n \ndef _siftdown(heap,startpos,pos):\n newitem=heap[pos]\n \n \n while pos >startpos:\n  parentpos=(pos -1)>>1\n  parent=heap[parentpos]\n  if newitem <parent:\n   heap[pos]=parent\n   pos=parentpos\n   continue\n  break\n heap[pos]=newitem\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \ndef _siftup(heap,pos):\n endpos=len(heap)\n startpos=pos\n newitem=heap[pos]\n \n childpos=2 *pos+1\n while childpos <endpos:\n \n  rightpos=childpos+1\n  if rightpos <endpos and not heap[childpos]<heap[rightpos]:\n   childpos=rightpos\n   \n  heap[pos]=heap[childpos]\n  pos=childpos\n  childpos=2 *pos+1\n  \n  \n heap[pos]=newitem\n _siftdown(heap,startpos,pos)\n \ndef _siftdown_max(heap,startpos,pos):\n ''\n newitem=heap[pos]\n \n \n while pos >startpos:\n  parentpos=(pos -1)>>1\n  parent=heap[parentpos]\n  if parent <newitem:\n   heap[pos]=parent\n   pos=parentpos\n   continue\n  break\n heap[pos]=newitem\n \ndef _siftup_max(heap,pos):\n ''\n endpos=len(heap)\n startpos=pos\n newitem=heap[pos]\n \n childpos=2 *pos+1\n while childpos <endpos:\n \n  rightpos=childpos+1\n  if rightpos <endpos and not heap[rightpos]<heap[childpos]:\n   childpos=rightpos\n   \n  heap[pos]=heap[childpos]\n  pos=childpos\n  childpos=2 *pos+1\n  \n  \n heap[pos]=newitem\n _siftdown_max(heap,startpos,pos)\n \n \n \n \n \n \n \n \ndef merge(*iterables):\n ''\n\n\n\n\n\n\n\n\n \n _heappop,_heapreplace,_StopIteration=heappop,heapreplace,StopIteration\n _len=len\n \n h=[]\n h_append=h. append\n for itnum,it in enumerate(map(iter,iterables)):\n  try :\n   next=it. __next__\n   h_append([next(),itnum,next])\n  except _StopIteration:\n   pass\n heapify(h)\n \n while _len(h)>1:\n  try :\n   while True :\n    v,itnum,next=s=h[0]\n    yield v\n    s[0]=next()\n    _heapreplace(h,s)\n  except _StopIteration:\n   _heappop(h)\n if h:\n \n  v,itnum,next=h[0]\n  yield v\n  yield from next. __self__\n  \n  \n_nsmallest=nsmallest\ndef nsmallest(n,iterable,key=None ):\n ''\n\n\n \n \n if n ==1:\n  it=iter(iterable)\n  head=list(islice(it,1))\n  if not head:\n   return []\n  if key is None :\n   return [min(chain(head,it))]\n  return [min(chain(head,it),key=key)]\n  \n  \n try :\n  size=len(iterable)\n except (TypeError,AttributeError):\n  pass\n else :\n  if n >=size:\n   return sorted(iterable,key=key)[:n]\n   \n   \n if key is None :\n  it=zip(iterable,count())\n  result=_nsmallest(n,it)\n  return [r[0]for r in result]\n  \n  \n in1,in2=tee(iterable)\n it=zip(map(key,in1),count(),in2)\n result=_nsmallest(n,it)\n return [r[2]for r in result]\n \n_nlargest=nlargest\ndef nlargest(n,iterable,key=None ):\n ''\n\n\n \n \n \n if n ==1:\n  it=iter(iterable)\n  head=list(islice(it,1))\n  if not head:\n   return []\n  if key is None :\n   return [max(chain(head,it))]\n  return [max(chain(head,it),key=key)]\n  \n  \n try :\n  size=len(iterable)\n except (TypeError,AttributeError):\n  pass\n else :\n  if n >=size:\n   return sorted(iterable,key=key,reverse=True )[:n]\n   \n   \n if key is None :\n  it=zip(iterable,count(0,-1))\n  result=_nlargest(n,it)\n  return [r[0]for r in result]\n  \n  \n in1,in2=tee(iterable)\n it=zip(map(key,in1),count(0,-1),in2)\n result=_nlargest(n,it)\n return [r[2]for r in result]\n \nif __name__ ==\"__main__\":\n\n heap=[]\n data=[1,3,5,7,9,2,4,6,8,0]\n for item in data:\n  heappush(heap,item)\n sort=[]\n while heap:\n  sort. append(heappop(heap))\n print(sort)\n \n import doctest\n doctest. testmod()\n", ["doctest", "itertools"]], "_strptime": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\nimport time\nimport locale\nimport calendar\nfrom re import compile as re_compile\nfrom re import IGNORECASE\nfrom re import escape as re_escape\nfrom datetime import (date as datetime_date,\ntimedelta as datetime_timedelta,\ntimezone as datetime_timezone)\ntry :\n from _thread import allocate_lock as _thread_allocate_lock\nexcept ImportError:\n from _dummy_thread import allocate_lock as _thread_allocate_lock\n \n__all__=[]\n\ndef _getlang():\n\n return locale. getlocale(locale. LC_TIME)\n \nclass LocaleTime(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. lang=_getlang()\n  self. __calc_weekday()\n  self. __calc_month()\n  self. __calc_am_pm()\n  self. __calc_timezone()\n  self. __calc_date_time()\n  if _getlang()!=self. lang:\n   raise ValueError(\"locale changed during initialization\")\n   \n def __pad(self,seq,front):\n \n  seq=list(seq)\n  if front:\n   seq. insert(0,'')\n  else :\n   seq. append('')\n  return seq\n  \n def __calc_weekday(self):\n \n \n  a_weekday=[calendar. day_abbr[i]. lower()for i in range(7)]\n  f_weekday=[calendar. day_name[i]. lower()for i in range(7)]\n  self. a_weekday=a_weekday\n  self. f_weekday=f_weekday\n  \n def __calc_month(self):\n \n  a_month=[calendar. month_abbr[i]. lower()for i in range(13)]\n  f_month=[calendar. month_name[i]. lower()for i in range(13)]\n  self. a_month=a_month\n  self. f_month=f_month\n  \n def __calc_am_pm(self):\n \n \n \n \n \n  am_pm=[]\n  for hour in (1,22):\n   time_tuple=time. struct_time((1999,3,17,hour,44,55,2,76,0))\n   am_pm. append(time. strftime(\"%p\",time_tuple). lower())\n  self. am_pm=am_pm\n  \n def __calc_date_time(self):\n \n \n \n \n \n \n \n  time_tuple=time. struct_time((1999,3,17,22,44,55,2,76,0))\n  date_time=[None ,None ,None ]\n  date_time[0]=time. strftime(\"%c\",time_tuple). lower()\n  date_time[1]=time. strftime(\"%x\",time_tuple). lower()\n  date_time[2]=time. strftime(\"%X\",time_tuple). lower()\n  replacement_pairs=[('%','%%'),(self. f_weekday[2],'%A'),\n  (self. f_month[3],'%B'),(self. a_weekday[2],'%a'),\n  (self. a_month[3],'%b'),(self. am_pm[1],'%p'),\n  ('1999','%Y'),('99','%y'),('22','%H'),\n  ('44','%M'),('55','%S'),('76','%j'),\n  ('17','%d'),('03','%m'),('3','%m'),\n  \n  ('2','%w'),('10','%I')]\n  replacement_pairs. extend([(tz,\"%Z\")for tz_values in self. timezone\n  for tz in tz_values])\n  for offset,directive in ((0,'%c'),(1,'%x'),(2,'%X')):\n   current_format=date_time[offset]\n   for old,new in replacement_pairs:\n   \n   \n   \n   \n    if old:\n     current_format=current_format. replace(old,new)\n     \n     \n     \n   time_tuple=time. struct_time((1999,1,3,1,1,1,6,3,0))\n   if'00'in time. strftime(directive,time_tuple):\n    U_W='%W'\n   else :\n    U_W='%U'\n   date_time[offset]=current_format. replace('11',U_W)\n  self. LC_date_time=date_time[0]\n  self. LC_date=date_time[1]\n  self. LC_time=date_time[2]\n  \n def __calc_timezone(self):\n \n \n \n \n \n \n \n  no_saving=frozenset([\"utc\",\"gmt\",time. tzname[0]. lower()])\n  if time. daylight:\n   has_saving=frozenset([time. tzname[1]. lower()])\n  else :\n   has_saving=frozenset()\n  self. timezone=(no_saving,has_saving)\n  \n  \nclass TimeRE(dict):\n ''\n \n def __init__(self,locale_time=None ):\n  ''\n\n\n\n  \n  if locale_time:\n   self. locale_time=locale_time\n  else :\n   self. locale_time=LocaleTime()\n  base=super()\n  base. __init__({\n  \n  'd':r\"(?P<d>3[0-1]|[1-2]\\d|0[1-9]|[1-9]| [1-9])\",\n  'f':r\"(?P<f>[0-9]{1,6})\",\n  'H':r\"(?P<H>2[0-3]|[0-1]\\d|\\d)\",\n  'I':r\"(?P<I>1[0-2]|0[1-9]|[1-9])\",\n  'j':r\"(?P<j>36[0-6]|3[0-5]\\d|[1-2]\\d\\d|0[1-9]\\d|00[1-9]|[1-9]\\d|0[1-9]|[1-9])\",\n  'm':r\"(?P<m>1[0-2]|0[1-9]|[1-9])\",\n  'M':r\"(?P<M>[0-5]\\d|\\d)\",\n  'S':r\"(?P<S>6[0-1]|[0-5]\\d|\\d)\",\n  'U':r\"(?P<U>5[0-3]|[0-4]\\d|\\d)\",\n  'w':r\"(?P<w>[0-6])\",\n  \n  'y':r\"(?P<y>\\d\\d)\",\n  \n  \n  'Y':r\"(?P<Y>\\d\\d\\d\\d)\",\n  'z':r\"(?P<z>[+-]\\d\\d[0-5]\\d)\",\n  'A':self. __seqToRE(self. locale_time. f_weekday,'A'),\n  'a':self. __seqToRE(self. locale_time. a_weekday,'a'),\n  'B':self. __seqToRE(self. locale_time. f_month[1:],'B'),\n  'b':self. __seqToRE(self. locale_time. a_month[1:],'b'),\n  'p':self. __seqToRE(self. locale_time. am_pm,'p'),\n  'Z':self. __seqToRE((tz for tz_names in self. locale_time. timezone\n  for tz in tz_names),\n  'Z'),\n  '%':'%'})\n  base. __setitem__('W',base. __getitem__('U'). replace('U','W'))\n  base. __setitem__('c',self. pattern(self. locale_time. LC_date_time))\n  base. __setitem__('x',self. pattern(self. locale_time. LC_date))\n  base. __setitem__('X',self. pattern(self. locale_time. LC_time))\n  \n def __seqToRE(self,to_convert,directive):\n  ''\n\n\n\n\n\n\n  \n  to_convert=sorted(to_convert,key=len,reverse=True )\n  for value in to_convert:\n   if value !='':\n    break\n  else :\n   return''\n  regex='|'. join(re_escape(stuff)for stuff in to_convert)\n  regex='(?P<%s>%s'%(directive,regex)\n  return'%s)'%regex\n  \n def pattern(self,format):\n  ''\n\n\n\n\n  \n  processed_format=''\n  \n  \n  \n  regex_chars=re_compile(r\"([\\\\.^$*+?\\(\\){}\\[\\]|])\")\n  format=regex_chars. sub(r\"\\\\\\1\",format)\n  whitespace_replacement=re_compile('\\s+')\n  format=whitespace_replacement. sub('\\s+',format)\n  while'%'in format:\n   directive_index=format. index('%')+1\n   processed_format=\"%s%s%s\"%(processed_format,\n   format[:directive_index -1],\n   self[format[directive_index]])\n   format=format[directive_index+1:]\n  return\"%s%s\"%(processed_format,format)\n  \n def compile(self,format):\n  ''\n  return re_compile(self. pattern(format),IGNORECASE)\n  \n_cache_lock=_thread_allocate_lock()\n\n\n_TimeRE_cache=TimeRE()\n_CACHE_MAX_SIZE=5\n_regex_cache={}\n\ndef _calc_julian_from_U_or_W(year,week_of_year,day_of_week,week_starts_Mon):\n ''\n\n \n first_weekday=datetime_date(year,1,1). weekday()\n \n \n \n if not week_starts_Mon:\n  first_weekday=(first_weekday+1)%7\n  day_of_week=(day_of_week+1)%7\n  \n  \n week_0_length=(7 -first_weekday)%7\n if week_of_year ==0:\n  return 1+day_of_week -first_weekday\n else :\n  days_to_week=week_0_length+(7 *(week_of_year -1))\n  return 1+days_to_week+day_of_week\n  \n  \ndef _strptime(data_string,format=\"%a %b %d %H:%M:%S %Y\"):\n ''\n\n \n \n for index,arg in enumerate([data_string,format]):\n  if not isinstance(arg,str):\n   msg=\"strptime() argument {} must be str, not {}\"\n   raise TypeError(msg. format(index,type(arg)))\n   \n global _TimeRE_cache,_regex_cache\n with _cache_lock:\n \n  if _getlang()!=_TimeRE_cache. locale_time. lang:\n   _TimeRE_cache=TimeRE()\n   _regex_cache. clear()\n  if len(_regex_cache)>_CACHE_MAX_SIZE:\n   _regex_cache. clear()\n  locale_time=_TimeRE_cache. locale_time\n  format_regex=_regex_cache. get(format)\n  if not format_regex:\n   try :\n    format_regex=_TimeRE_cache. compile(format)\n    \n    \n   except KeyError as err:\n    bad_directive=err. args[0]\n    if bad_directive ==\"\\\\\":\n     bad_directive=\"%\"\n    del err\n    raise ValueError(\"'%s' is a bad directive in format '%s'\"%\n    (bad_directive,format))from None\n    \n   except IndexError:\n    raise ValueError(\"stray %% in format '%s'\"%format)from None\n   _regex_cache[format]=format_regex\n found=format_regex. match(data_string)\n if not found:\n  raise ValueError(\"time data %r does not match format %r\"%\n  (data_string,format))\n if len(data_string)!=found. end():\n  raise ValueError(\"unconverted data remains: %s\"%\n  data_string[found. end():])\n  \n year=None\n month=day=1\n hour=minute=second=fraction=0\n tz=-1\n tzoffset=None\n \n \n week_of_year=-1\n week_of_year_start=-1\n \n \n weekday=julian=-1\n found_dict=found. groupdict()\n for group_key in found_dict. keys():\n \n \n \n \n \n  if group_key =='y':\n   year=int(found_dict['y'])\n   \n   \n   \n   if year <=68:\n    year +=2000\n   else :\n    year +=1900\n  elif group_key =='Y':\n   year=int(found_dict['Y'])\n  elif group_key =='m':\n   month=int(found_dict['m'])\n  elif group_key =='B':\n   month=locale_time. f_month. index(found_dict['B']. lower())\n  elif group_key =='b':\n   month=locale_time. a_month. index(found_dict['b']. lower())\n  elif group_key =='d':\n   day=int(found_dict['d'])\n  elif group_key =='H':\n   hour=int(found_dict['H'])\n  elif group_key =='I':\n   hour=int(found_dict['I'])\n   ampm=found_dict. get('p',''). lower()\n   \n   if ampm in ('',locale_time. am_pm[0]):\n   \n   \n   \n    if hour ==12:\n     hour=0\n   elif ampm ==locale_time. am_pm[1]:\n   \n   \n   \n    if hour !=12:\n     hour +=12\n  elif group_key =='M':\n   minute=int(found_dict['M'])\n  elif group_key =='S':\n   second=int(found_dict['S'])\n  elif group_key =='f':\n   s=found_dict['f']\n   \n   s +=\"0\"*(6 -len(s))\n   fraction=int(s)\n  elif group_key =='A':\n   weekday=locale_time. f_weekday. index(found_dict['A']. lower())\n  elif group_key =='a':\n   weekday=locale_time. a_weekday. index(found_dict['a']. lower())\n  elif group_key =='w':\n   weekday=int(found_dict['w'])\n   if weekday ==0:\n    weekday=6\n   else :\n    weekday -=1\n  elif group_key =='j':\n   julian=int(found_dict['j'])\n  elif group_key in ('U','W'):\n   week_of_year=int(found_dict[group_key])\n   if group_key =='U':\n   \n    week_of_year_start=6\n   else :\n   \n    week_of_year_start=0\n  elif group_key =='z':\n   z=found_dict['z']\n   tzoffset=int(z[1:3])*60+int(z[3:5])\n   if z. startswith(\"-\"):\n    tzoffset=-tzoffset\n  elif group_key =='Z':\n  \n  \n   found_zone=found_dict['Z']. lower()\n   for value,tz_values in enumerate(locale_time. timezone):\n    if found_zone in tz_values:\n    \n    \n    \n     if (time. tzname[0]==time. tzname[1]and\n     time. daylight and found_zone not in (\"utc\",\"gmt\")):\n      break\n     else :\n      tz=value\n      break\n leap_year_fix=False\n if year is None and month ==2 and day ==29:\n  year=1904\n  leap_year_fix=True\n elif year is None :\n  year=1900\n  \n  \n if julian ==-1 and week_of_year !=-1 and weekday !=-1:\n  week_starts_Mon=True if week_of_year_start ==0 else False\n  julian=_calc_julian_from_U_or_W(year,week_of_year,weekday,\n  week_starts_Mon)\n  \n  \n  \n if julian ==-1:\n \n  julian=datetime_date(year,month,day). toordinal()-  datetime_date(year,1,1). toordinal()+1\n else :\n \n  datetime_result=datetime_date. fromordinal((julian -1)+datetime_date(year,1,1). toordinal())\n  year=datetime_result. year\n  month=datetime_result. month\n  day=datetime_result. day\n if weekday ==-1:\n  weekday=datetime_date(year,month,day). weekday()\n  \n tzname=found_dict. get(\"Z\")\n if tzoffset is not None :\n  gmtoff=tzoffset *60\n else :\n  gmtoff=None\n  \n if leap_year_fix:\n \n \n \n  year=1900\n  \n return (year,month,day,\n hour,minute,second,\n weekday,julian,tz,tzname,gmtoff),fraction\n \ndef _strptime_time(data_string,format=\"%a %b %d %H:%M:%S %Y\"):\n ''\n \n tt=_strptime(data_string,format)[0]\n return time. struct_time(tt[:time. _STRUCT_TM_ITEMS])\n \ndef _strptime_datetime(cls,data_string,format=\"%a %b %d %H:%M:%S %Y\"):\n ''\n \n tt,fraction=_strptime(data_string,format)\n tzname,gmtoff=tt[-2:]\n args=tt[:6]+(fraction,)\n if gmtoff is not None :\n  tzdelta=datetime_timedelta(seconds=gmtoff)\n  if tzname:\n   tz=datetime_timezone(tzdelta,tzname)\n  else :\n   tz=datetime_timezone(tzdelta)\n  args +=(tz,)\n return cls(*args)\n", ["_dummy_thread", "_thread", "calendar", "datetime", "locale", "re", "time"]], "io": [".py", "import builtins\n\nopen=builtins. open\n\n\nSEEK_SET=0\nSEEK_CUR=1\nSEEK_END=2\n\nr\"\"\"File-like objects that read from or write to a string buffer.\n\nThis implements (nearly) all stdio methods.\n\nf = StringIO()      # ready for writing\nf = StringIO(buf)   # ready for reading\nf.close()           # explicitly release resources held\nflag = f.isatty()   # always false\npos = f.tell()      # get current position\nf.seek(pos)         # set current position\nf.seek(pos, mode)   # mode 0: absolute; 1: relative; 2: relative to EOF\nbuf = f.read()      # read until EOF\nbuf = f.read(n)     # read up to n bytes\nbuf = f.readline()  # read until end of line ('\\n') or EOF\nlist = f.readlines()# list of f.readline() results until EOF\nf.truncate([size])  # truncate file at to at most size (default: current pos)\nf.write(buf)        # write at current position\nf.writelines(list)  # for line in list: f.write(line)\nf.getvalue()        # return whole file's contents as a string\n\nNotes:\n- Using a real file is often faster (but less convenient).\n- There's also a much faster implementation in C, called cStringIO, but\n  it's not subclassable.\n- fileno() is left unimplemented so that code which uses it triggers\n  an exception early.\n- Seeking far beyond EOF and then writing will insert real null\n  bytes that occupy space in the buffer.\n- There's a simple test set (see end of this file).\n\"\"\"\n\nEINVAL=22\n\n__all__=[\"StringIO\"]\n\ndef _complain_ifclosed(closed):\n if closed:\n  raise ValueError(\"I/O operation on closed file\")\n  \nclass IOBase:\n ''\n\n\n\n\n\n\n\n\n\n \n def __init__(self,buf=''):\n  self. buf=buf\n  self. len=len(buf)\n  self. buflist=[]\n  self. pos=0\n  self. closed=False\n  self. softspace=0\n  self. empty_char=''\n  self. zero_char='\\0'\n  self. newline='\\n'\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  ''\n\n\n\n\n  \n  _complain_ifclosed(self. closed)\n  r=self. readline()\n  if not r:\n   raise StopIteration\n  return r\n  \n def close(self):\n  ''\n  \n  if not self. closed:\n   self. closed=True\n   del self. buf,self. pos\n   \n def isatty(self):\n  ''\n\n  \n  _complain_ifclosed(self. closed)\n  return False\n  \n def seek(self,pos,mode=0):\n  ''\n\n\n\n\n\n\n  \n  _complain_ifclosed(self. closed)\n  if self. buflist:\n   self. buf +=self. empty_char. join(self. buflist)\n   self. buflist=[]\n  if mode ==1:\n   pos +=self. pos\n  elif mode ==2:\n   pos +=self. len\n  self. pos=max(0,pos)\n  \n def tell(self):\n  ''\n  _complain_ifclosed(self. closed)\n  return self. pos\n  \n def read(self,n=-1):\n  ''\n\n\n\n\n\n  \n  _complain_ifclosed(self. closed)\n  if self. buflist:\n   self. buf +=self. empty_char. join(self. buflist)\n   self. buflist=[]\n  if n is None or n <0:\n   newpos=self. len\n  else :\n   newpos=min(self. pos+n,self. len)\n  r=self. buf[self. pos:newpos]\n  self. pos=newpos\n  return r\n  \n def readline(self,length=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  _complain_ifclosed(self. closed)\n  if self. buflist:\n   self. buf +=self. empty_char. join(self. buflist)\n   self. buflist=[]\n  i=self. buf. find(self. newline,self. pos)\n  if i <0:\n   newpos=self. len\n  else :\n   newpos=i+1\n  if length is not None and length >=0:\n   if self. pos+length <newpos:\n    newpos=self. pos+length\n  r=self. buf[self. pos:newpos]\n  self. pos=newpos\n  return r\n  \n def readlines(self,sizehint=0):\n  ''\n\n\n\n\n\n  \n  total=0\n  lines=[]\n  line=self. readline()\n  while line:\n   lines. append(line)\n   total +=len(line)\n   if 0 <sizehint <=total:\n    break\n   line=self. readline()\n  return lines\n  \n def truncate(self,size=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  _complain_ifclosed(self. closed)\n  if size is None :\n   size=self. pos\n  elif size <0:\n   raise IOError(EINVAL,\"Negative size not allowed\")\n  elif size <self. pos:\n   self. pos=size\n  self. buf=self. getvalue()[:size]\n  self. len=size\n  \n def write(self,s):\n  ''\n\n\n  \n  _complain_ifclosed(self. closed)\n  if not s:return\n  spos=self. pos\n  slen=self. len\n  if spos ==slen:\n   self. buflist. append(s)\n   self. len=self. pos=spos+len(s)\n   return\n  if spos >slen:\n   self. buflist. append(self. zero_char *(spos -slen))\n   slen=spos\n  newpos=spos+len(s)\n  if spos <slen:\n   if self. buflist:\n    self. buf +=self. empty_char. join(self. buflist)\n   self. buflist=[self. buf[:spos],s,self. buf[newpos:]]\n   self. buf=self. empty_char\n   if newpos >slen:\n    slen=newpos\n  else :\n   self. buflist. append(s)\n   slen=newpos\n  self. len=slen\n  self. pos=newpos\n  \n def writelines(self,iterable):\n  ''\n\n\n\n\n\n  \n  write=self. write\n  for line in iterable:\n   write(line)\n   \n def flush(self):\n  ''\n  \n  _complain_ifclosed(self. closed)\n  \n def getvalue(self):\n  ''\n\n\n\n\n\n\n\n\n  \n  _complain_ifclosed(self. closed)\n  if self. buflist:\n   self. buf +=self. empty_char. join(self. buflist)\n   self. buflist=[]\n  return self. buf\n  \nclass TextIOBase(IOBase):\n pass\n \nclass StringIO(TextIOBase):\n pass\n \nTextIOWrapper=StringIO\n\n\nclass RawIOBase:\n\n def read(self,n=-1):\n  pass\n def readall(self):\n  pass\n def readinto(self,b):\n  pass\n def write(self,b):\n  pass\n  \n  \nBufferedIOBase=RawIOBase\nBufferedReader=RawIOBase\n\nclass BytesIO(IOBase):\n\n def __init__(self,buf=b''):\n  super(). __init__(buf)\n  self. empty_char=b''\n  self. zero_char=b'\\0'\n  self. newline=b'\\n'\n  \n  \n  \n", ["builtins"]], "_codecs": [".py", "\ndef ascii_decode(*args,**kw):\n pass\n \ndef ascii_encode(*args,**kw):\n pass\n \ndef charbuffer_encode(*args,**kw):\n pass\n \ndef charmap_build(*args,**kw):\n pass\n \ndef charmap_decode(*args,**kw):\n pass\n \ndef charmap_encode(*args,**kw):\n pass\n \ndef decode(*args,**kw):\n ''\n\n\n\n\n\n \n pass\n \ndef encode(*args,**kw):\n ''\n\n\n\n\n\n \n obj=args[0]\n if len(args)==2:\n  encoding=args[1]\n else :\n  encoding='utf-8'\n if isinstance(obj,str):\n  return obj. encode(encoding)\n  \ndef escape_decode(*args,**kw):\n pass\n \ndef escape_encode(*args,**kw):\n pass\n \ndef latin_1_decode(*args,**kw):\n pass\n \ndef latin_1_encode(*args,**kw):\n pass\n \ndef lookup(encoding):\n ''\n\n \n \n if encoding in ('utf-8','utf_8'):\n  from browser import console\n  console. log('encoding',encoding)\n  import encodings. utf_8\n  return encodings. utf_8. getregentry()\n  \n LookupError(encoding)\n \ndef lookup_error(*args,**kw):\n ''\n\n \n pass\n \ndef mbcs_decode(*args,**kw):\n pass\n \ndef mbcs_encode(*args,**kw):\n pass\n \ndef raw_unicode_escape_decode(*args,**kw):\n pass\n \ndef raw_unicode_escape_encode(*args,**kw):\n pass\n \ndef readbuffer_encode(*args,**kw):\n pass\n \ndef register(*args,**kw):\n ''\n\n\n\n \n pass\n \ndef register_error(*args,**kw):\n ''\n\n\n\n\n \n pass\n \ndef unicode_escape_decode(*args,**kw):\n pass\n \ndef unicode_escape_encode(*args,**kw):\n pass\n \ndef unicode_internal_decode(*args,**kw):\n pass\n \ndef unicode_internal_encode(*args,**kw):\n pass\n \ndef utf_16_be_decode(*args,**kw):\n pass\n \ndef utf_16_be_encode(*args,**kw):\n pass\n \ndef utf_16_decode(*args,**kw):\n pass\n \ndef utf_16_encode(*args,**kw):\n pass\n \ndef utf_16_ex_decode(*args,**kw):\n pass\n \ndef utf_16_le_decode(*args,**kw):\n pass\n \ndef utf_16_le_encode(*args,**kw):\n pass\n \ndef utf_32_be_decode(*args,**kw):\n pass\n \ndef utf_32_be_encode(*args,**kw):\n pass\n \ndef utf_32_decode(*args,**kw):\n pass\n \ndef utf_32_encode(*args,**kw):\n pass\n \ndef utf_32_ex_decode(*args,**kw):\n pass\n \ndef utf_32_le_decode(*args,**kw):\n pass\n \ndef utf_32_le_encode(*args,**kw):\n pass\n \ndef utf_7_decode(*args,**kw):\n pass\n \ndef utf_7_encode(*args,**kw):\n pass\n \ndef utf_8_decode(*args,**kw):\n pass\n \ndef utf_8_encode(*args,**kw):\n input=args[0]\n if len(args)==2:\n  errors=args[1]\n else :\n  errors=kw. get('errors','strict')\n  \n  \n  \n return (bytes([_f for _f in input],'utf-8'),len(input))\n", ["browser", "encodings.utf_8"]], "_ajax": [".js", "// ajax\nvar $module = (function($B){\n\neval($B.InjectBuiltins())\nvar $N = $B.builtins.None\n\nvar ajax1 = $B.make_class(\"ajax1\",\n    function(){\n        if(window.XMLHttpRequest){// code for IE7+, Firefox, Chrome, Opera, Safari\n            var xmlhttp = new XMLHttpRequest()\n        }else{// code for IE6, IE5\n            var xmlhttp = new ActiveXObject(\"Microsoft.XMLHTTP\")\n        }\n        xmlhttp.onreadystatechange = function(){\n            // here, \"this\" refers to xmlhttp\n            var state = this.readyState\n            var timer = this.$requestTimer\n            if(state == 0 && this.onuninitialized){this.onuninitialized()}\n            else if(state == 1 && this.onloading){this.onloading()}\n            else if(state == 2 && this.onloaded){this.onloaded()}\n            else if(state == 3 && this.oninteractive){this.oninteractive()}\n            else if(state == 4 && this.oncomplete){\n                if(timer !== null){window.clearTimeout(timer)}\n                this.oncomplete()\n            }\n        }\n        return {\n            __class__: ajax,\n            js: xmlhttp,\n            headers: {}\n        }\n    }\n)\n\nvar add_to_res = function(res, key, val) {\n    if(isinstance(val, list)){\n        for (j = 0; j < val.length; j++) {\n            add_to_res(res, key, val[j])\n        }\n    }else if (val instanceof File || val instanceof Blob){\n        res.append(key, val)\n    }else{res.append(key,str.$factory(val))}\n}\n\nvar ajax = {\n    __class__: _b_.type,\n    __mro__: [$B.JSObject, _b_.object],\n    __name__: 'ajax',\n\n    __getattribute__ : function(self, attr){\n        // Special case for send : accept dict as parameters\n        if(attr == 'send'){\n            return function(params){\n                return ajax.send(self, params)\n            }\n        }\n        // Otherwise default to JSObject method\n        return $B.JSObject.__getattribute__(self, attr)\n    },\n\n    __repr__ : function(self){return '<object Ajax>'},\n    __str__ : function(self){return '<object Ajax>'},\n\n    bind : function(self, evt, func){\n        // req.bind(evt,func) is the same as req.onevt = func\n        self.js['on' + evt] = function(){\n            try{\n                return func.apply(null, arguments)\n            }catch(err){\n                if(err.__class__ !== undefined){\n                    var msg = _b_.getattr(err, 'info') +\n                        '\\n' + err.__class__.__name__\n                    if(err.args){msg += ': ' + err.args[0]}\n                    try{getattr($B.stderr, \"write\")(msg)}\n                    catch(err){console.log(msg)}\n                }else{\n                    try{getattr($B.stderr, \"write\")(err)}\n                    catch(err1){console.log(err)}\n                }\n            }\n        }\n        return $N\n    },\n\n    send : function(self,params){\n        // params can be Python dictionary or string\n        //self.js.onreadystatechange = function(ev){console.log(ev.target)}\n        var res = ''\n        if(!params){\n            self.js.send()\n            return $N\n        }else if(isinstance(params, str)){\n            res = params\n        }else if(isinstance(params, dict)){\n            if(self.headers['content-type'] == 'multipart/form-data'){\n                // The FormData object serializes the data in the 'multipart/form-data'\n                // content-type so we may as well override that header if it was set\n                // by the user.\n                res = new FormData()\n                var items = _b_.list.$factory(_b_.dict.items(params))\n                for(var i = 0, len = items.length; i < len; i++){\n                    add_to_res(res, str.$factory(items[i][0]), items[i][1])\n                }\n            }else{\n                var items = _b_.list.$factory(_b_.dict.items(params))\n                for(var i = 0, len = items.length; i < len; i++){\n                    var key = encodeURIComponent(str.$factory(items[i][0]));\n                    if(isinstance(items[i][1], list)){\n                        for (j = 0; j < items[i][1].length; j++) {\n                            res += key +'=' +\n                                encodeURIComponent(str.$factory(items[i][1][j])) + '&'\n                        }\n                    }else{\n                        res += key + '=' +\n                            encodeURIComponent(str.$factory(items[i][1])) + '&'\n                    }\n                }\n                res = res.substr(0, res.length - 1)\n            }\n        }else{\n            throw _b_.TypeError(\"send() argument must be string or dictionary, not '\" +\n                str.$factory(params.__class__) + \"'\")\n        }\n        self.js.send(res)\n        return $N\n    },\n\n    set_header : function(self,key,value){\n        self.js.setRequestHeader(key,value)\n        self.headers[key.toLowerCase()] = value.toLowerCase()\n    },\n\n    set_timeout : function(self,seconds,func){\n        self.js.$requestTimer = setTimeout(\n            function() {self.js.abort();func()},\n            seconds * 1000)\n    }\n}\n\najax.$factory = function(){\n\n    if(window.XMLHttpRequest){// code for IE7+, Firefox, Chrome, Opera, Safari\n        var xmlhttp = new XMLHttpRequest()\n    }else{// code for IE6, IE5\n        var xmlhttp = new ActiveXObject(\"Microsoft.XMLHTTP\")\n    }\n    xmlhttp.onreadystatechange = function(){\n        // here, \"this\" refers to xmlhttp\n        var state = this.readyState\n        if(this.responseType == \"\" || this.responseType == \"text\"){\n            res.js.text = this.responseText\n        }\n        var timer = this.$requestTimer\n        if(state == 0 && this.onuninitialized){this.onuninitialized(res)}\n        else if(state == 1 && this.onloading){this.onloading(res)}\n        else if(state == 2 && this.onloaded){this.onloaded(res)}\n        else if(state == 3 && this.oninteractive){this.oninteractive(res)}\n        else if(state == 4 && this.oncomplete){\n            if(timer !== null){window.clearTimeout(timer)}\n            this.oncomplete(res)\n        }\n    }\n    var res = {\n        __class__: ajax,\n        js: xmlhttp,\n        headers: {}\n    }\n    return res\n}\n\n\n$B.set_func_names(ajax)\n\nreturn {ajax: ajax, ajax1: ajax1}\n\n})(__BRYTHON__)\n"], "argparse": [".py", "\n\n\"\"\"Command-line parsing library\n\nThis module is an optparse-inspired command-line parsing library that:\n\n    - handles both optional and positional arguments\n    - produces highly informative usage messages\n    - supports parsers that dispatch to sub-parsers\n\nThe following is a simple usage example that sums integers from the\ncommand-line and writes the result to a file::\n\n    parser = argparse.ArgumentParser(\n        description='sum the integers at the command line')\n    parser.add_argument(\n        'integers', metavar='int', nargs='+', type=int,\n        help='an integer to be summed')\n    parser.add_argument(\n        '--log', default=sys.stdout, type=argparse.FileType('w'),\n        help='the file where the sum should be written')\n    args = parser.parse_args()\n    args.log.write('%s' % sum(args.integers))\n    args.log.close()\n\nThe module contains the following public classes:\n\n    - ArgumentParser -- The main entry point for command-line parsing. As the\n        example above shows, the add_argument() method is used to populate\n        the parser with actions for optional and positional arguments. Then\n        the parse_args() method is invoked to convert the args at the\n        command-line into an object with attributes.\n\n    - ArgumentError -- The exception raised by ArgumentParser objects when\n        there are errors with the parser's actions. Errors raised while\n        parsing the command-line are caught by ArgumentParser and emitted\n        as command-line messages.\n\n    - FileType -- A factory for defining types of files to be created. As the\n        example above shows, instances of FileType are typically passed as\n        the type= argument of add_argument() calls.\n\n    - Action -- The base class for parser actions. Typically actions are\n        selected by passing strings like 'store_true' or 'append_const' to\n        the action= argument of add_argument(). However, for greater\n        customization of ArgumentParser actions, subclasses of Action may\n        be defined and passed as the action= argument.\n\n    - HelpFormatter, RawDescriptionHelpFormatter, RawTextHelpFormatter,\n        ArgumentDefaultsHelpFormatter -- Formatter classes which\n        may be passed as the formatter_class= argument to the\n        ArgumentParser constructor. HelpFormatter is the default,\n        RawDescriptionHelpFormatter and RawTextHelpFormatter tell the parser\n        not to change the formatting for help text, and\n        ArgumentDefaultsHelpFormatter adds information about argument defaults\n        to the help.\n\nAll other classes in this module are considered implementation details.\n(Also note that HelpFormatter and RawDescriptionHelpFormatter are only\nconsidered public as object names -- the API of the formatter objects is\nstill considered an implementation detail.)\n\"\"\"\n\n__version__='1.1'\n__all__=[\n'ArgumentParser',\n'ArgumentError',\n'ArgumentTypeError',\n'FileType',\n'HelpFormatter',\n'ArgumentDefaultsHelpFormatter',\n'RawDescriptionHelpFormatter',\n'RawTextHelpFormatter',\n'MetavarTypeHelpFormatter',\n'Namespace',\n'Action',\n'ONE_OR_MORE',\n'OPTIONAL',\n'PARSER',\n'REMAINDER',\n'SUPPRESS',\n'ZERO_OR_MORE',\n]\n\n\nimport collections as _collections\nimport copy as _copy\nimport os as _os\nimport re as _re\nimport sys as _sys\nimport textwrap as _textwrap\n\nfrom gettext import gettext as _,ngettext\n\n\nSUPPRESS='==SUPPRESS=='\n\nOPTIONAL='?'\nZERO_OR_MORE='*'\nONE_OR_MORE='+'\nPARSER='A...'\nREMAINDER='...'\n_UNRECOGNIZED_ARGS_ATTR='_unrecognized_args'\n\n\n\n\n\nclass _AttributeHolder(object):\n ''\n\n\n\n\n\n \n \n def __repr__(self):\n  type_name=type(self). __name__\n  arg_strings=[]\n  for arg in self. _get_args():\n   arg_strings. append(repr(arg))\n  for name,value in self. _get_kwargs():\n   arg_strings. append('%s=%r'%(name,value))\n  return'%s(%s)'%(type_name,', '. join(arg_strings))\n  \n def _get_kwargs(self):\n  return sorted(self. __dict__. items())\n  \n def _get_args(self):\n  return []\n  \n  \ndef _ensure_value(namespace,name,value):\n if getattr(namespace,name,None )is None :\n  setattr(namespace,name,value)\n return getattr(namespace,name)\n \n \n \n \n \n \nclass HelpFormatter(object):\n ''\n\n\n\n \n \n def __init__(self,\n prog,\n indent_increment=2,\n max_help_position=24,\n width=None ):\n \n \n  if width is None :\n   try :\n    width=int(_os. environ['COLUMNS'])\n   except (KeyError,ValueError):\n    width=80\n   width -=2\n   \n  self. _prog=prog\n  self. _indent_increment=indent_increment\n  self. _max_help_position=max_help_position\n  self. _max_help_position=min(max_help_position,\n  max(width -20,indent_increment *2))\n  self. _width=width\n  \n  self. _current_indent=0\n  self. _level=0\n  self. _action_max_length=0\n  \n  self. _root_section=self. _Section(self,None )\n  self. _current_section=self. _root_section\n  \n  self. _whitespace_matcher=_re. compile(r'\\s+')\n  self. _long_break_matcher=_re. compile(r'\\n\\n\\n+')\n  \n  \n  \n  \n def _indent(self):\n  self. _current_indent +=self. _indent_increment\n  self. _level +=1\n  \n def _dedent(self):\n  self. _current_indent -=self. _indent_increment\n  assert self. _current_indent >=0,'Indent decreased below 0.'\n  self. _level -=1\n  \n class _Section(object):\n \n  def __init__(self,formatter,parent,heading=None ):\n   self. formatter=formatter\n   self. parent=parent\n   self. heading=heading\n   self. items=[]\n   \n  def format_help(self):\n  \n   if self. parent is not None :\n    self. formatter. _indent()\n   join=self. formatter. _join_parts\n   for func,args in self. items:\n    func(*args)\n   item_help=join([func(*args)for func,args in self. items])\n   if self. parent is not None :\n    self. formatter. _dedent()\n    \n    \n   if not item_help:\n    return''\n    \n    \n   if self. heading is not SUPPRESS and self. heading is not None :\n    current_indent=self. formatter. _current_indent\n    heading='%*s%s:\\n'%(current_indent,'',self. heading)\n   else :\n    heading=''\n    \n    \n   return join(['\\n',heading,item_help,'\\n'])\n   \n def _add_item(self,func,args):\n  self. _current_section. items. append((func,args))\n  \n  \n  \n  \n def start_section(self,heading):\n  self. _indent()\n  section=self. _Section(self,self. _current_section,heading)\n  self. _add_item(section. format_help,[])\n  self. _current_section=section\n  \n def end_section(self):\n  self. _current_section=self. _current_section. parent\n  self. _dedent()\n  \n def add_text(self,text):\n  if text is not SUPPRESS and text is not None :\n   self. _add_item(self. _format_text,[text])\n   \n def add_usage(self,usage,actions,groups,prefix=None ):\n  if usage is not SUPPRESS:\n   args=usage,actions,groups,prefix\n   self. _add_item(self. _format_usage,args)\n   \n def add_argument(self,action):\n  if action. help is not SUPPRESS:\n  \n  \n   get_invocation=self. _format_action_invocation\n   invocations=[get_invocation(action)]\n   for subaction in self. _iter_indented_subactions(action):\n    invocations. append(get_invocation(subaction))\n    \n    \n   invocation_length=max([len(s)for s in invocations])\n   action_length=invocation_length+self. _current_indent\n   self. _action_max_length=max(self. _action_max_length,\n   action_length)\n   \n   \n   self. _add_item(self. _format_action,[action])\n   \n def add_arguments(self,actions):\n  for action in actions:\n   self. add_argument(action)\n   \n   \n   \n   \n def format_help(self):\n  help=self. _root_section. format_help()\n  if help:\n   help=self. _long_break_matcher. sub('\\n\\n',help)\n   help=help. strip('\\n')+'\\n'\n  return help\n  \n def _join_parts(self,part_strings):\n  return''. join([part\n  for part in part_strings\n  if part and part is not SUPPRESS])\n  \n def _format_usage(self,usage,actions,groups,prefix):\n  if prefix is None :\n   prefix=_('usage: ')\n   \n   \n  if usage is not None :\n   usage=usage %dict(prog=self. _prog)\n   \n   \n  elif usage is None and not actions:\n   usage='%(prog)s'%dict(prog=self. _prog)\n   \n   \n  elif usage is None :\n   prog='%(prog)s'%dict(prog=self. _prog)\n   \n   \n   optionals=[]\n   positionals=[]\n   for action in actions:\n    if action. option_strings:\n     optionals. append(action)\n    else :\n     positionals. append(action)\n     \n     \n   format=self. _format_actions_usage\n   action_usage=format(optionals+positionals,groups)\n   usage=' '. join([s for s in [prog,action_usage]if s])\n   \n   \n   text_width=self. _width -self. _current_indent\n   if len(prefix)+len(usage)>text_width:\n   \n   \n    part_regexp=r'\\(.*?\\)+|\\[.*?\\]+|\\S+'\n    opt_usage=format(optionals,groups)\n    pos_usage=format(positionals,groups)\n    opt_parts=_re. findall(part_regexp,opt_usage)\n    pos_parts=_re. findall(part_regexp,pos_usage)\n    assert' '. join(opt_parts)==opt_usage\n    assert' '. join(pos_parts)==pos_usage\n    \n    \n    def get_lines(parts,indent,prefix=None ):\n     lines=[]\n     line=[]\n     if prefix is not None :\n      line_len=len(prefix)-1\n     else :\n      line_len=len(indent)-1\n     for part in parts:\n      if line_len+1+len(part)>text_width and line:\n       lines. append(indent+' '. join(line))\n       line=[]\n       line_len=len(indent)-1\n      line. append(part)\n      line_len +=len(part)+1\n     if line:\n      lines. append(indent+' '. join(line))\n     if prefix is not None :\n      lines[0]=lines[0][len(indent):]\n     return lines\n     \n     \n    if len(prefix)+len(prog)<=0.75 *text_width:\n     indent=' '*(len(prefix)+len(prog)+1)\n     if opt_parts:\n      lines=get_lines([prog]+opt_parts,indent,prefix)\n      lines. extend(get_lines(pos_parts,indent))\n     elif pos_parts:\n      lines=get_lines([prog]+pos_parts,indent,prefix)\n     else :\n      lines=[prog]\n      \n      \n    else :\n     indent=' '*len(prefix)\n     parts=opt_parts+pos_parts\n     lines=get_lines(parts,indent)\n     if len(lines)>1:\n      lines=[]\n      lines. extend(get_lines(opt_parts,indent))\n      lines. extend(get_lines(pos_parts,indent))\n     lines=[prog]+lines\n     \n     \n    usage='\\n'. join(lines)\n    \n    \n  return'%s%s\\n\\n'%(prefix,usage)\n  \n def _format_actions_usage(self,actions,groups):\n \n  group_actions=set()\n  inserts={}\n  for group in groups:\n   try :\n    start=actions. index(group. _group_actions[0])\n   except ValueError:\n    continue\n   else :\n    end=start+len(group. _group_actions)\n    if actions[start:end]==group. _group_actions:\n     for action in group. _group_actions:\n      group_actions. add(action)\n     if not group. required:\n      if start in inserts:\n       inserts[start]+=' ['\n      else :\n       inserts[start]='['\n      inserts[end]=']'\n     else :\n      if start in inserts:\n       inserts[start]+=' ('\n      else :\n       inserts[start]='('\n      inserts[end]=')'\n     for i in range(start+1,end):\n      inserts[i]='|'\n      \n      \n  parts=[]\n  for i,action in enumerate(actions):\n  \n  \n  \n   if action. help is SUPPRESS:\n    parts. append(None )\n    if inserts. get(i)=='|':\n     inserts. pop(i)\n    elif inserts. get(i+1)=='|':\n     inserts. pop(i+1)\n     \n     \n   elif not action. option_strings:\n    default=self. _get_default_metavar_for_positional(action)\n    part=self. _format_args(action,default)\n    \n    \n    if action in group_actions:\n     if part[0]=='['and part[-1]==']':\n      part=part[1:-1]\n      \n      \n    parts. append(part)\n    \n    \n   else :\n    option_string=action. option_strings[0]\n    \n    \n    \n    if action. nargs ==0:\n     part='%s'%option_string\n     \n     \n     \n    else :\n     default=self. _get_default_metavar_for_optional(action)\n     args_string=self. _format_args(action,default)\n     part='%s %s'%(option_string,args_string)\n     \n     \n    if not action. required and action not in group_actions:\n     part='[%s]'%part\n     \n     \n    parts. append(part)\n    \n    \n  for i in sorted(inserts,reverse=True ):\n   parts[i:i]=[inserts[i]]\n   \n   \n  text=' '. join([item for item in parts if item is not None ])\n  \n  \n  open=r'[\\[(]'\n  close=r'[\\])]'\n  text=_re. sub(r'(%s) '%open,r'\\1',text)\n  text=_re. sub(r' (%s)'%close,r'\\1',text)\n  text=_re. sub(r'%s *%s'%(open,close),r'',text)\n  text=_re. sub(r'\\(([^|]*)\\)',r'\\1',text)\n  text=text. strip()\n  \n  \n  return text\n  \n def _format_text(self,text):\n  if'%(prog)'in text:\n   text=text %dict(prog=self. _prog)\n  text_width=max(self. _width -self. _current_indent,11)\n  indent=' '*self. _current_indent\n  return self. _fill_text(text,text_width,indent)+'\\n\\n'\n  \n def _format_action(self,action):\n \n  help_position=min(self. _action_max_length+2,\n  self. _max_help_position)\n  help_width=max(self. _width -help_position,11)\n  action_width=help_position -self. _current_indent -2\n  action_header=self. _format_action_invocation(action)\n  \n  \n  if not action. help:\n   tup=self. _current_indent,'',action_header\n   action_header='%*s%s\\n'%tup\n   \n   \n  elif len(action_header)<=action_width:\n   tup=self. _current_indent,'',action_width,action_header\n   action_header='%*s%-*s  '%tup\n   indent_first=0\n   \n   \n  else :\n   tup=self. _current_indent,'',action_header\n   action_header='%*s%s\\n'%tup\n   indent_first=help_position\n   \n   \n  parts=[action_header]\n  \n  \n  if action. help:\n   help_text=self. _expand_help(action)\n   help_lines=self. _split_lines(help_text,help_width)\n   parts. append('%*s%s\\n'%(indent_first,'',help_lines[0]))\n   for line in help_lines[1:]:\n    parts. append('%*s%s\\n'%(help_position,'',line))\n    \n    \n  elif not action_header. endswith('\\n'):\n   parts. append('\\n')\n   \n   \n  for subaction in self. _iter_indented_subactions(action):\n   parts. append(self. _format_action(subaction))\n   \n   \n  return self. _join_parts(parts)\n  \n def _format_action_invocation(self,action):\n  if not action. option_strings:\n   default=self. _get_default_metavar_for_positional(action)\n   metavar,=self. _metavar_formatter(action,default)(1)\n   return metavar\n   \n  else :\n   parts=[]\n   \n   \n   \n   if action. nargs ==0:\n    parts. extend(action. option_strings)\n    \n    \n    \n   else :\n    default=self. _get_default_metavar_for_optional(action)\n    args_string=self. _format_args(action,default)\n    for option_string in action. option_strings:\n     parts. append('%s %s'%(option_string,args_string))\n     \n   return', '. join(parts)\n   \n def _metavar_formatter(self,action,default_metavar):\n  if action. metavar is not None :\n   result=action. metavar\n  elif action. choices is not None :\n   choice_strs=[str(choice)for choice in action. choices]\n   result='{%s}'%','. join(choice_strs)\n  else :\n   result=default_metavar\n   \n  def format(tuple_size):\n   if isinstance(result,tuple):\n    return result\n   else :\n    return (result,)*tuple_size\n  return format\n  \n def _format_args(self,action,default_metavar):\n  get_metavar=self. _metavar_formatter(action,default_metavar)\n  if action. nargs is None :\n   result='%s'%get_metavar(1)\n  elif action. nargs ==OPTIONAL:\n   result='[%s]'%get_metavar(1)\n  elif action. nargs ==ZERO_OR_MORE:\n   result='[%s [%s ...]]'%get_metavar(2)\n  elif action. nargs ==ONE_OR_MORE:\n   result='%s [%s ...]'%get_metavar(2)\n  elif action. nargs ==REMAINDER:\n   result='...'\n  elif action. nargs ==PARSER:\n   result='%s ...'%get_metavar(1)\n  else :\n   formats=['%s'for _ in range(action. nargs)]\n   result=' '. join(formats)%get_metavar(action. nargs)\n  return result\n  \n def _expand_help(self,action):\n  params=dict(vars(action),prog=self. _prog)\n  for name in list(params):\n   if params[name]is SUPPRESS:\n    del params[name]\n  for name in list(params):\n   if hasattr(params[name],'__name__'):\n    params[name]=params[name]. __name__\n  if params. get('choices')is not None :\n   choices_str=', '. join([str(c)for c in params['choices']])\n   params['choices']=choices_str\n  return self. _get_help_string(action)%params\n  \n def _iter_indented_subactions(self,action):\n  try :\n   get_subactions=action. _get_subactions\n  except AttributeError:\n   pass\n  else :\n   self. _indent()\n   yield from get_subactions()\n   self. _dedent()\n   \n def _split_lines(self,text,width):\n  text=self. _whitespace_matcher. sub(' ',text). strip()\n  return _textwrap. wrap(text,width)\n  \n def _fill_text(self,text,width,indent):\n  text=self. _whitespace_matcher. sub(' ',text). strip()\n  return _textwrap. fill(text,width,initial_indent=indent,\n  subsequent_indent=indent)\n  \n def _get_help_string(self,action):\n  return action. help\n  \n def _get_default_metavar_for_optional(self,action):\n  return action. dest. upper()\n  \n def _get_default_metavar_for_positional(self,action):\n  return action. dest\n  \n  \nclass RawDescriptionHelpFormatter(HelpFormatter):\n ''\n\n\n\n \n \n def _fill_text(self,text,width,indent):\n  return''. join(indent+line for line in text. splitlines(keepends=True ))\n  \n  \nclass RawTextHelpFormatter(RawDescriptionHelpFormatter):\n ''\n\n\n\n \n \n def _split_lines(self,text,width):\n  return text. splitlines()\n  \n  \nclass ArgumentDefaultsHelpFormatter(HelpFormatter):\n ''\n\n\n\n \n \n def _get_help_string(self,action):\n  help=action. help\n  if'%(default)'not in action. help:\n   if action. default is not SUPPRESS:\n    defaulting_nargs=[OPTIONAL,ZERO_OR_MORE]\n    if action. option_strings or action. nargs in defaulting_nargs:\n     help +=' (default: %(default)s)'\n  return help\n  \n  \nclass MetavarTypeHelpFormatter(HelpFormatter):\n ''\n\n\n\n\n \n \n def _get_default_metavar_for_optional(self,action):\n  return action. type. __name__\n  \n def _get_default_metavar_for_positional(self,action):\n  return action. type. __name__\n  \n  \n  \n  \n  \n  \n  \ndef _get_action_name(argument):\n if argument is None :\n  return None\n elif argument. option_strings:\n  return'/'. join(argument. option_strings)\n elif argument. metavar not in (None ,SUPPRESS):\n  return argument. metavar\n elif argument. dest not in (None ,SUPPRESS):\n  return argument. dest\n else :\n  return None\n  \n  \nclass ArgumentError(Exception):\n ''\n\n\n\n \n \n def __init__(self,argument,message):\n  self. argument_name=_get_action_name(argument)\n  self. message=message\n  \n def __str__(self):\n  if self. argument_name is None :\n   format='%(message)s'\n  else :\n   format='argument %(argument_name)s: %(message)s'\n  return format %dict(message=self. message,\n  argument_name=self. argument_name)\n  \n  \nclass ArgumentTypeError(Exception):\n ''\n pass\n \n \n \n \n \n \nclass Action(_AttributeHolder):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,\n option_strings,\n dest,\n nargs=None ,\n const=None ,\n default=None ,\n type=None ,\n choices=None ,\n required=False ,\n help=None ,\n metavar=None ):\n  self. option_strings=option_strings\n  self. dest=dest\n  self. nargs=nargs\n  self. const=const\n  self. default=default\n  self. type=type\n  self. choices=choices\n  self. required=required\n  self. help=help\n  self. metavar=metavar\n  \n def _get_kwargs(self):\n  names=[\n  'option_strings',\n  'dest',\n  'nargs',\n  'const',\n  'default',\n  'type',\n  'choices',\n  'help',\n  'metavar',\n  ]\n  return [(name,getattr(self,name))for name in names]\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  raise NotImplementedError(_('.__call__() not defined'))\n  \n  \nclass _StoreAction(Action):\n\n def __init__(self,\n option_strings,\n dest,\n nargs=None ,\n const=None ,\n default=None ,\n type=None ,\n choices=None ,\n required=False ,\n help=None ,\n metavar=None ):\n  if nargs ==0:\n   raise ValueError('nargs for store actions must be > 0; if you '\n   'have nothing to store, actions such as store '\n   'true or store const may be more appropriate')\n  if const is not None and nargs !=OPTIONAL:\n   raise ValueError('nargs must be %r to supply const'%OPTIONAL)\n  super(_StoreAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  nargs=nargs,\n  const=const,\n  default=default,\n  type=type,\n  choices=choices,\n  required=required,\n  help=help,\n  metavar=metavar)\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  setattr(namespace,self. dest,values)\n  \n  \nclass _StoreConstAction(Action):\n\n def __init__(self,\n option_strings,\n dest,\n const,\n default=None ,\n required=False ,\n help=None ,\n metavar=None ):\n  super(_StoreConstAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  nargs=0,\n  const=const,\n  default=default,\n  required=required,\n  help=help)\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  setattr(namespace,self. dest,self. const)\n  \n  \nclass _StoreTrueAction(_StoreConstAction):\n\n def __init__(self,\n option_strings,\n dest,\n default=False ,\n required=False ,\n help=None ):\n  super(_StoreTrueAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  const=True ,\n  default=default,\n  required=required,\n  help=help)\n  \n  \nclass _StoreFalseAction(_StoreConstAction):\n\n def __init__(self,\n option_strings,\n dest,\n default=True ,\n required=False ,\n help=None ):\n  super(_StoreFalseAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  const=False ,\n  default=default,\n  required=required,\n  help=help)\n  \n  \nclass _AppendAction(Action):\n\n def __init__(self,\n option_strings,\n dest,\n nargs=None ,\n const=None ,\n default=None ,\n type=None ,\n choices=None ,\n required=False ,\n help=None ,\n metavar=None ):\n  if nargs ==0:\n   raise ValueError('nargs for append actions must be > 0; if arg '\n   'strings are not supplying the value to append, '\n   'the append const action may be more appropriate')\n  if const is not None and nargs !=OPTIONAL:\n   raise ValueError('nargs must be %r to supply const'%OPTIONAL)\n  super(_AppendAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  nargs=nargs,\n  const=const,\n  default=default,\n  type=type,\n  choices=choices,\n  required=required,\n  help=help,\n  metavar=metavar)\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  items=_copy. copy(_ensure_value(namespace,self. dest,[]))\n  items. append(values)\n  setattr(namespace,self. dest,items)\n  \n  \nclass _AppendConstAction(Action):\n\n def __init__(self,\n option_strings,\n dest,\n const,\n default=None ,\n required=False ,\n help=None ,\n metavar=None ):\n  super(_AppendConstAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  nargs=0,\n  const=const,\n  default=default,\n  required=required,\n  help=help,\n  metavar=metavar)\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  items=_copy. copy(_ensure_value(namespace,self. dest,[]))\n  items. append(self. const)\n  setattr(namespace,self. dest,items)\n  \n  \nclass _CountAction(Action):\n\n def __init__(self,\n option_strings,\n dest,\n default=None ,\n required=False ,\n help=None ):\n  super(_CountAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  nargs=0,\n  default=default,\n  required=required,\n  help=help)\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  new_count=_ensure_value(namespace,self. dest,0)+1\n  setattr(namespace,self. dest,new_count)\n  \n  \nclass _HelpAction(Action):\n\n def __init__(self,\n option_strings,\n dest=SUPPRESS,\n default=SUPPRESS,\n help=None ):\n  super(_HelpAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  default=default,\n  nargs=0,\n  help=help)\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  parser. print_help()\n  parser. exit()\n  \n  \nclass _VersionAction(Action):\n\n def __init__(self,\n option_strings,\n version=None ,\n dest=SUPPRESS,\n default=SUPPRESS,\n help=\"show program's version number and exit\"):\n  super(_VersionAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  default=default,\n  nargs=0,\n  help=help)\n  self. version=version\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  version=self. version\n  if version is None :\n   version=parser. version\n  formatter=parser. _get_formatter()\n  formatter. add_text(version)\n  parser. _print_message(formatter. format_help(),_sys. stdout)\n  parser. exit()\n  \n  \nclass _SubParsersAction(Action):\n\n class _ChoicesPseudoAction(Action):\n \n  def __init__(self,name,aliases,help):\n   metavar=dest=name\n   if aliases:\n    metavar +=' (%s)'%', '. join(aliases)\n   sup=super(_SubParsersAction. _ChoicesPseudoAction,self)\n   sup. __init__(option_strings=[],dest=dest,help=help,\n   metavar=metavar)\n   \n def __init__(self,\n option_strings,\n prog,\n parser_class,\n dest=SUPPRESS,\n help=None ,\n metavar=None ):\n \n  self. _prog_prefix=prog\n  self. _parser_class=parser_class\n  self. _name_parser_map=_collections. OrderedDict()\n  self. _choices_actions=[]\n  \n  super(_SubParsersAction,self). __init__(\n  option_strings=option_strings,\n  dest=dest,\n  nargs=PARSER,\n  choices=self. _name_parser_map,\n  help=help,\n  metavar=metavar)\n  \n def add_parser(self,name,**kwargs):\n \n  if kwargs. get('prog')is None :\n   kwargs['prog']='%s %s'%(self. _prog_prefix,name)\n   \n  aliases=kwargs. pop('aliases',())\n  \n  \n  if'help'in kwargs:\n   help=kwargs. pop('help')\n   choice_action=self. _ChoicesPseudoAction(name,aliases,help)\n   self. _choices_actions. append(choice_action)\n   \n   \n  parser=self. _parser_class(**kwargs)\n  self. _name_parser_map[name]=parser\n  \n  \n  for alias in aliases:\n   self. _name_parser_map[alias]=parser\n   \n  return parser\n  \n def _get_subactions(self):\n  return self. _choices_actions\n  \n def __call__(self,parser,namespace,values,option_string=None ):\n  parser_name=values[0]\n  arg_strings=values[1:]\n  \n  \n  if self. dest is not SUPPRESS:\n   setattr(namespace,self. dest,parser_name)\n   \n   \n  try :\n   parser=self. _name_parser_map[parser_name]\n  except KeyError:\n   args={'parser_name':parser_name,\n   'choices':', '. join(self. _name_parser_map)}\n   msg=_('unknown parser %(parser_name)r (choices: %(choices)s)')%args\n   raise ArgumentError(self,msg)\n   \n   \n   \n   \n   \n   \n   \n   \n  subnamespace,arg_strings=parser. parse_known_args(arg_strings,None )\n  for key,value in vars(subnamespace). items():\n   setattr(namespace,key,value)\n   \n  if arg_strings:\n   vars(namespace). setdefault(_UNRECOGNIZED_ARGS_ATTR,[])\n   getattr(namespace,_UNRECOGNIZED_ARGS_ATTR). extend(arg_strings)\n   \n   \n   \n   \n   \n   \nclass FileType(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,mode='r',bufsize=-1,encoding=None ,errors=None ):\n  self. _mode=mode\n  self. _bufsize=bufsize\n  self. _encoding=encoding\n  self. _errors=errors\n  \n def __call__(self,string):\n \n  if string =='-':\n   if'r'in self. _mode:\n    return _sys. stdin\n   elif'w'in self. _mode:\n    return _sys. stdout\n   else :\n    msg=_('argument \"-\" with mode %r')%self. _mode\n    raise ValueError(msg)\n    \n    \n  try :\n   return open(string,self. _mode,self. _bufsize,self. _encoding,\n   self. _errors)\n  except OSError as e:\n   message=_(\"can't open '%s': %s\")\n   raise ArgumentTypeError(message %(string,e))\n   \n def __repr__(self):\n  args=self. _mode,self. _bufsize\n  kwargs=[('encoding',self. _encoding),('errors',self. _errors)]\n  args_str=', '. join([repr(arg)for arg in args if arg !=-1]+\n  ['%s=%r'%(kw,arg)for kw,arg in kwargs\n  if arg is not None ])\n  return'%s(%s)'%(type(self). __name__,args_str)\n  \n  \n  \n  \n  \nclass Namespace(_AttributeHolder):\n ''\n\n\n\n \n \n def __init__(self,**kwargs):\n  for name in kwargs:\n   setattr(self,name,kwargs[name])\n   \n def __eq__(self,other):\n  if not isinstance(other,Namespace):\n   return NotImplemented\n  return vars(self)==vars(other)\n  \n def __ne__(self,other):\n  if not isinstance(other,Namespace):\n   return NotImplemented\n  return not (self ==other)\n  \n def __contains__(self,key):\n  return key in self. __dict__\n  \n  \nclass _ActionsContainer(object):\n\n def __init__(self,\n description,\n prefix_chars,\n argument_default,\n conflict_handler):\n  super(_ActionsContainer,self). __init__()\n  \n  self. description=description\n  self. argument_default=argument_default\n  self. prefix_chars=prefix_chars\n  self. conflict_handler=conflict_handler\n  \n  \n  self. _registries={}\n  \n  \n  self. register('action',None ,_StoreAction)\n  self. register('action','store',_StoreAction)\n  self. register('action','store_const',_StoreConstAction)\n  self. register('action','store_true',_StoreTrueAction)\n  self. register('action','store_false',_StoreFalseAction)\n  self. register('action','append',_AppendAction)\n  self. register('action','append_const',_AppendConstAction)\n  self. register('action','count',_CountAction)\n  self. register('action','help',_HelpAction)\n  self. register('action','version',_VersionAction)\n  self. register('action','parsers',_SubParsersAction)\n  \n  \n  self. _get_handler()\n  \n  \n  self. _actions=[]\n  self. _option_string_actions={}\n  \n  \n  self. _action_groups=[]\n  self. _mutually_exclusive_groups=[]\n  \n  \n  self. _defaults={}\n  \n  \n  self. _negative_number_matcher=_re. compile(r'^-\\d+$|^-\\d*\\.\\d+$')\n  \n  \n  \n  self. _has_negative_number_optionals=[]\n  \n  \n  \n  \n def register(self,registry_name,value,object):\n  registry=self. _registries. setdefault(registry_name,{})\n  registry[value]=object\n  \n def _registry_get(self,registry_name,value,default=None ):\n  return self. _registries[registry_name]. get(value,default)\n  \n  \n  \n  \n def set_defaults(self,**kwargs):\n  self. _defaults. update(kwargs)\n  \n  \n  \n  for action in self. _actions:\n   if action. dest in kwargs:\n    action. default=kwargs[action. dest]\n    \n def get_default(self,dest):\n  for action in self. _actions:\n   if action. dest ==dest and action. default is not None :\n    return action. default\n  return self. _defaults. get(dest,None )\n  \n  \n  \n  \n  \n def add_argument(self,*args,**kwargs):\n  ''\n\n\n  \n  \n  \n  \n  \n  chars=self. prefix_chars\n  if not args or len(args)==1 and args[0][0]not in chars:\n   if args and'dest'in kwargs:\n    raise ValueError('dest supplied twice for positional argument')\n   kwargs=self. _get_positional_kwargs(*args,**kwargs)\n   \n   \n  else :\n   kwargs=self. _get_optional_kwargs(*args,**kwargs)\n   \n   \n  if'default'not in kwargs:\n   dest=kwargs['dest']\n   if dest in self. _defaults:\n    kwargs['default']=self. _defaults[dest]\n   elif self. argument_default is not None :\n    kwargs['default']=self. argument_default\n    \n    \n  action_class=self. _pop_action_class(kwargs)\n  if not callable(action_class):\n   raise ValueError('unknown action \"%s\"'%(action_class,))\n  action=action_class(**kwargs)\n  \n  \n  type_func=self. _registry_get('type',action. type,action. type)\n  if not callable(type_func):\n   raise ValueError('%r is not callable'%(type_func,))\n   \n   \n  if hasattr(self,\"_get_formatter\"):\n   try :\n    self. _get_formatter(). _format_args(action,None )\n   except TypeError:\n    raise ValueError(\"length of metavar tuple does not match nargs\")\n    \n  return self. _add_action(action)\n  \n def add_argument_group(self,*args,**kwargs):\n  group=_ArgumentGroup(self,*args,**kwargs)\n  self. _action_groups. append(group)\n  return group\n  \n def add_mutually_exclusive_group(self,**kwargs):\n  group=_MutuallyExclusiveGroup(self,**kwargs)\n  self. _mutually_exclusive_groups. append(group)\n  return group\n  \n def _add_action(self,action):\n \n  self. _check_conflict(action)\n  \n  \n  self. _actions. append(action)\n  action. container=self\n  \n  \n  for option_string in action. option_strings:\n   self. _option_string_actions[option_string]=action\n   \n   \n  for option_string in action. option_strings:\n   if self. _negative_number_matcher. match(option_string):\n    if not self. _has_negative_number_optionals:\n     self. _has_negative_number_optionals. append(True )\n     \n     \n  return action\n  \n def _remove_action(self,action):\n  self. _actions. remove(action)\n  \n def _add_container_actions(self,container):\n \n  title_group_map={}\n  for group in self. _action_groups:\n   if group. title in title_group_map:\n    msg=_('cannot merge actions - two groups are named %r')\n    raise ValueError(msg %(group. title))\n   title_group_map[group. title]=group\n   \n   \n  group_map={}\n  for group in container. _action_groups:\n  \n  \n  \n   if group. title not in title_group_map:\n    title_group_map[group. title]=self. add_argument_group(\n    title=group. title,\n    description=group. description,\n    conflict_handler=group. conflict_handler)\n    \n    \n   for action in group. _group_actions:\n    group_map[action]=title_group_map[group. title]\n    \n    \n    \n    \n  for group in container. _mutually_exclusive_groups:\n   mutex_group=self. add_mutually_exclusive_group(\n   required=group. required)\n   \n   \n   for action in group. _group_actions:\n    group_map[action]=mutex_group\n    \n    \n  for action in container. _actions:\n   group_map. get(action,self). _add_action(action)\n   \n def _get_positional_kwargs(self,dest,**kwargs):\n \n  if'required'in kwargs:\n   msg=_(\"'required' is an invalid argument for positionals\")\n   raise TypeError(msg)\n   \n   \n   \n  if kwargs. get('nargs')not in [OPTIONAL,ZERO_OR_MORE]:\n   kwargs['required']=True\n  if kwargs. get('nargs')==ZERO_OR_MORE and'default'not in kwargs:\n   kwargs['required']=True\n   \n   \n  return dict(kwargs,dest=dest,option_strings=[])\n  \n def _get_optional_kwargs(self,*args,**kwargs):\n \n  option_strings=[]\n  long_option_strings=[]\n  for option_string in args:\n  \n   if not option_string[0]in self. prefix_chars:\n    args={'option':option_string,\n    'prefix_chars':self. prefix_chars}\n    msg=_('invalid option string %(option)r: '\n    'must start with a character %(prefix_chars)r')\n    raise ValueError(msg %args)\n    \n    \n   option_strings. append(option_string)\n   if option_string[0]in self. prefix_chars:\n    if len(option_string)>1:\n     if option_string[1]in self. prefix_chars:\n      long_option_strings. append(option_string)\n      \n      \n  dest=kwargs. pop('dest',None )\n  if dest is None :\n   if long_option_strings:\n    dest_option_string=long_option_strings[0]\n   else :\n    dest_option_string=option_strings[0]\n   dest=dest_option_string. lstrip(self. prefix_chars)\n   if not dest:\n    msg=_('dest= is required for options like %r')\n    raise ValueError(msg %option_string)\n   dest=dest. replace('-','_')\n   \n   \n  return dict(kwargs,dest=dest,option_strings=option_strings)\n  \n def _pop_action_class(self,kwargs,default=None ):\n  action=kwargs. pop('action',default)\n  return self. _registry_get('action',action,action)\n  \n def _get_handler(self):\n \n  handler_func_name='_handle_conflict_%s'%self. conflict_handler\n  try :\n   return getattr(self,handler_func_name)\n  except AttributeError:\n   msg=_('invalid conflict_resolution value: %r')\n   raise ValueError(msg %self. conflict_handler)\n   \n def _check_conflict(self,action):\n \n \n  confl_optionals=[]\n  for option_string in action. option_strings:\n   if option_string in self. _option_string_actions:\n    confl_optional=self. _option_string_actions[option_string]\n    confl_optionals. append((option_string,confl_optional))\n    \n    \n  if confl_optionals:\n   conflict_handler=self. _get_handler()\n   conflict_handler(action,confl_optionals)\n   \n def _handle_conflict_error(self,action,conflicting_actions):\n  message=ngettext('conflicting option string: %s',\n  'conflicting option strings: %s',\n  len(conflicting_actions))\n  conflict_string=', '. join([option_string\n  for option_string,action\n  in conflicting_actions])\n  raise ArgumentError(action,message %conflict_string)\n  \n def _handle_conflict_resolve(self,action,conflicting_actions):\n \n \n  for option_string,action in conflicting_actions:\n  \n  \n   action. option_strings. remove(option_string)\n   self. _option_string_actions. pop(option_string,None )\n   \n   \n   \n   if not action. option_strings:\n    action. container. _remove_action(action)\n    \n    \nclass _ArgumentGroup(_ActionsContainer):\n\n def __init__(self,container,title=None ,description=None ,**kwargs):\n \n  update=kwargs. setdefault\n  update('conflict_handler',container. conflict_handler)\n  update('prefix_chars',container. prefix_chars)\n  update('argument_default',container. argument_default)\n  super_init=super(_ArgumentGroup,self). __init__\n  super_init(description=description,**kwargs)\n  \n  \n  self. title=title\n  self. _group_actions=[]\n  \n  \n  self. _registries=container. _registries\n  self. _actions=container. _actions\n  self. _option_string_actions=container. _option_string_actions\n  self. _defaults=container. _defaults\n  self. _has_negative_number_optionals=  container. _has_negative_number_optionals\n  self. _mutually_exclusive_groups=container. _mutually_exclusive_groups\n  \n def _add_action(self,action):\n  action=super(_ArgumentGroup,self). _add_action(action)\n  self. _group_actions. append(action)\n  return action\n  \n def _remove_action(self,action):\n  super(_ArgumentGroup,self). _remove_action(action)\n  self. _group_actions. remove(action)\n  \n  \nclass _MutuallyExclusiveGroup(_ArgumentGroup):\n\n def __init__(self,container,required=False ):\n  super(_MutuallyExclusiveGroup,self). __init__(container)\n  self. required=required\n  self. _container=container\n  \n def _add_action(self,action):\n  if action. required:\n   msg=_('mutually exclusive arguments must be optional')\n   raise ValueError(msg)\n  action=self. _container. _add_action(action)\n  self. _group_actions. append(action)\n  return action\n  \n def _remove_action(self,action):\n  self. _container. _remove_action(action)\n  self. _group_actions. remove(action)\n  \n  \nclass ArgumentParser(_AttributeHolder,_ActionsContainer):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,\n prog=None ,\n usage=None ,\n description=None ,\n epilog=None ,\n parents=[],\n formatter_class=HelpFormatter,\n prefix_chars='-',\n fromfile_prefix_chars=None ,\n argument_default=None ,\n conflict_handler='error',\n add_help=True ):\n \n  superinit=super(ArgumentParser,self). __init__\n  superinit(description=description,\n  prefix_chars=prefix_chars,\n  argument_default=argument_default,\n  conflict_handler=conflict_handler)\n  \n  \n  if prog is None :\n   prog=_os. path. basename(_sys. argv[0])\n   \n  self. prog=prog\n  self. usage=usage\n  self. epilog=epilog\n  self. formatter_class=formatter_class\n  self. fromfile_prefix_chars=fromfile_prefix_chars\n  self. add_help=add_help\n  \n  add_group=self. add_argument_group\n  self. _positionals=add_group(_('positional arguments'))\n  self. _optionals=add_group(_('optional arguments'))\n  self. _subparsers=None\n  \n  \n  def identity(string):\n   return string\n  self. register('type',None ,identity)\n  \n  \n  \n  default_prefix='-'if'-'in prefix_chars else prefix_chars[0]\n  if self. add_help:\n   self. add_argument(\n   default_prefix+'h',default_prefix *2+'help',\n   action='help',default=SUPPRESS,\n   help=_('show this help message and exit'))\n   \n   \n  for parent in parents:\n   self. _add_container_actions(parent)\n   try :\n    defaults=parent. _defaults\n   except AttributeError:\n    pass\n   else :\n    self. _defaults. update(defaults)\n    \n    \n    \n    \n def _get_kwargs(self):\n  names=[\n  'prog',\n  'usage',\n  'description',\n  'formatter_class',\n  'conflict_handler',\n  'add_help',\n  ]\n  return [(name,getattr(self,name))for name in names]\n  \n  \n  \n  \n def add_subparsers(self,**kwargs):\n  if self. _subparsers is not None :\n   self. error(_('cannot have multiple subparser arguments'))\n   \n   \n  kwargs. setdefault('parser_class',type(self))\n  \n  if'title'in kwargs or'description'in kwargs:\n   title=_(kwargs. pop('title','subcommands'))\n   description=_(kwargs. pop('description',None ))\n   self. _subparsers=self. add_argument_group(title,description)\n  else :\n   self. _subparsers=self. _positionals\n   \n   \n   \n  if kwargs. get('prog')is None :\n   formatter=self. _get_formatter()\n   positionals=self. _get_positional_actions()\n   groups=self. _mutually_exclusive_groups\n   formatter. add_usage(self. usage,positionals,groups,'')\n   kwargs['prog']=formatter. format_help(). strip()\n   \n   \n  parsers_class=self. _pop_action_class(kwargs,'parsers')\n  action=parsers_class(option_strings=[],**kwargs)\n  self. _subparsers. _add_action(action)\n  \n  \n  return action\n  \n def _add_action(self,action):\n  if action. option_strings:\n   self. _optionals. _add_action(action)\n  else :\n   self. _positionals. _add_action(action)\n  return action\n  \n def _get_optional_actions(self):\n  return [action\n  for action in self. _actions\n  if action. option_strings]\n  \n def _get_positional_actions(self):\n  return [action\n  for action in self. _actions\n  if not action. option_strings]\n  \n  \n  \n  \n def parse_args(self,args=None ,namespace=None ):\n  args,argv=self. parse_known_args(args,namespace)\n  if argv:\n   msg=_('unrecognized arguments: %s')\n   self. error(msg %' '. join(argv))\n  return args\n  \n def parse_known_args(self,args=None ,namespace=None ):\n  if args is None :\n  \n   args=_sys. argv[1:]\n  else :\n  \n   args=list(args)\n   \n   \n  if namespace is None :\n   namespace=Namespace()\n   \n   \n  for action in self. _actions:\n   if action. dest is not SUPPRESS:\n    if not hasattr(namespace,action. dest):\n     if action. default is not SUPPRESS:\n      setattr(namespace,action. dest,action. default)\n      \n      \n  for dest in self. _defaults:\n   if not hasattr(namespace,dest):\n    setattr(namespace,dest,self. _defaults[dest])\n    \n    \n  try :\n   namespace,args=self. _parse_known_args(args,namespace)\n   if hasattr(namespace,_UNRECOGNIZED_ARGS_ATTR):\n    args. extend(getattr(namespace,_UNRECOGNIZED_ARGS_ATTR))\n    delattr(namespace,_UNRECOGNIZED_ARGS_ATTR)\n   return namespace,args\n  except ArgumentError:\n   err=_sys. exc_info()[1]\n   self. error(str(err))\n   \n def _parse_known_args(self,arg_strings,namespace):\n \n  if self. fromfile_prefix_chars is not None :\n   arg_strings=self. _read_args_from_files(arg_strings)\n   \n   \n   \n  action_conflicts={}\n  for mutex_group in self. _mutually_exclusive_groups:\n   group_actions=mutex_group. _group_actions\n   for i,mutex_action in enumerate(mutex_group. _group_actions):\n    conflicts=action_conflicts. setdefault(mutex_action,[])\n    conflicts. extend(group_actions[:i])\n    conflicts. extend(group_actions[i+1:])\n    \n    \n    \n    \n  option_string_indices={}\n  arg_string_pattern_parts=[]\n  arg_strings_iter=iter(arg_strings)\n  for i,arg_string in enumerate(arg_strings_iter):\n  \n  \n   if arg_string =='--':\n    arg_string_pattern_parts. append('-')\n    for arg_string in arg_strings_iter:\n     arg_string_pattern_parts. append('A')\n     \n     \n     \n   else :\n    option_tuple=self. _parse_optional(arg_string)\n    if option_tuple is None :\n     pattern='A'\n    else :\n     option_string_indices[i]=option_tuple\n     pattern='O'\n    arg_string_pattern_parts. append(pattern)\n    \n    \n  arg_strings_pattern=''. join(arg_string_pattern_parts)\n  \n  \n  seen_actions=set()\n  seen_non_default_actions=set()\n  \n  def take_action(action,argument_strings,option_string=None ):\n   seen_actions. add(action)\n   argument_values=self. _get_values(action,argument_strings)\n   \n   \n   \n   \n   if argument_values is not action. default:\n    seen_non_default_actions. add(action)\n    for conflict_action in action_conflicts. get(action,[]):\n     if conflict_action in seen_non_default_actions:\n      msg=_('not allowed with argument %s')\n      action_name=_get_action_name(conflict_action)\n      raise ArgumentError(action,msg %action_name)\n      \n      \n      \n   if argument_values is not SUPPRESS:\n    action(self,namespace,argument_values,option_string)\n    \n    \n  def consume_optional(start_index):\n  \n  \n   option_tuple=option_string_indices[start_index]\n   action,option_string,explicit_arg=option_tuple\n   \n   \n   \n   match_argument=self. _match_argument\n   action_tuples=[]\n   while True :\n   \n   \n    if action is None :\n     extras. append(arg_strings[start_index])\n     return start_index+1\n     \n     \n     \n    if explicit_arg is not None :\n     arg_count=match_argument(action,'A')\n     \n     \n     \n     \n     chars=self. prefix_chars\n     if arg_count ==0 and option_string[1]not in chars:\n      action_tuples. append((action,[],option_string))\n      char=option_string[0]\n      option_string=char+explicit_arg[0]\n      new_explicit_arg=explicit_arg[1:]or None\n      optionals_map=self. _option_string_actions\n      if option_string in optionals_map:\n       action=optionals_map[option_string]\n       explicit_arg=new_explicit_arg\n      else :\n       msg=_('ignored explicit argument %r')\n       raise ArgumentError(action,msg %explicit_arg)\n       \n       \n       \n     elif arg_count ==1:\n      stop=start_index+1\n      args=[explicit_arg]\n      action_tuples. append((action,args,option_string))\n      break\n      \n      \n      \n     else :\n      msg=_('ignored explicit argument %r')\n      raise ArgumentError(action,msg %explicit_arg)\n      \n      \n      \n      \n    else :\n     start=start_index+1\n     selected_patterns=arg_strings_pattern[start:]\n     arg_count=match_argument(action,selected_patterns)\n     stop=start+arg_count\n     args=arg_strings[start:stop]\n     action_tuples. append((action,args,option_string))\n     break\n     \n     \n     \n   assert action_tuples\n   for action,args,option_string in action_tuples:\n    take_action(action,args,option_string)\n   return stop\n   \n   \n   \n  positionals=self. _get_positional_actions()\n  \n  \n  def consume_positionals(start_index):\n  \n   match_partial=self. _match_arguments_partial\n   selected_pattern=arg_strings_pattern[start_index:]\n   arg_counts=match_partial(positionals,selected_pattern)\n   \n   \n   \n   for action,arg_count in zip(positionals,arg_counts):\n    args=arg_strings[start_index:start_index+arg_count]\n    start_index +=arg_count\n    take_action(action,args)\n    \n    \n    \n   positionals[:]=positionals[len(arg_counts):]\n   return start_index\n   \n   \n   \n  extras=[]\n  start_index=0\n  if option_string_indices:\n   max_option_string_index=max(option_string_indices)\n  else :\n   max_option_string_index=-1\n  while start_index <=max_option_string_index:\n  \n  \n   next_option_string_index=min([\n   index\n   for index in option_string_indices\n   if index >=start_index])\n   if start_index !=next_option_string_index:\n    positionals_end_index=consume_positionals(start_index)\n    \n    \n    \n    if positionals_end_index >start_index:\n     start_index=positionals_end_index\n     continue\n    else :\n     start_index=positionals_end_index\n     \n     \n     \n   if start_index not in option_string_indices:\n    strings=arg_strings[start_index:next_option_string_index]\n    extras. extend(strings)\n    start_index=next_option_string_index\n    \n    \n   start_index=consume_optional(start_index)\n   \n   \n  stop_index=consume_positionals(start_index)\n  \n  \n  extras. extend(arg_strings[stop_index:])\n  \n  \n  \n  required_actions=[]\n  for action in self. _actions:\n   if action not in seen_actions:\n    if action. required:\n     required_actions. append(_get_action_name(action))\n    else :\n    \n    \n    \n    \n     if (action. default is not None and\n     isinstance(action. default,str)and\n     hasattr(namespace,action. dest)and\n     action. default is getattr(namespace,action. dest)):\n      setattr(namespace,action. dest,\n      self. _get_value(action,action. default))\n      \n  if required_actions:\n   self. error(_('the following arguments are required: %s')%\n   ', '. join(required_actions))\n   \n   \n  for group in self. _mutually_exclusive_groups:\n   if group. required:\n    for action in group. _group_actions:\n     if action in seen_non_default_actions:\n      break\n      \n      \n    else :\n     names=[_get_action_name(action)\n     for action in group. _group_actions\n     if action. help is not SUPPRESS]\n     msg=_('one of the arguments %s is required')\n     self. error(msg %' '. join(names))\n     \n     \n  return namespace,extras\n  \n def _read_args_from_files(self,arg_strings):\n \n  new_arg_strings=[]\n  for arg_string in arg_strings:\n  \n  \n   if not arg_string or arg_string[0]not in self. fromfile_prefix_chars:\n    new_arg_strings. append(arg_string)\n    \n    \n   else :\n    try :\n     with open(arg_string[1:])as args_file:\n      arg_strings=[]\n      for arg_line in args_file. read(). splitlines():\n       for arg in self. convert_arg_line_to_args(arg_line):\n        arg_strings. append(arg)\n      arg_strings=self. _read_args_from_files(arg_strings)\n      new_arg_strings. extend(arg_strings)\n    except OSError:\n     err=_sys. exc_info()[1]\n     self. error(str(err))\n     \n     \n  return new_arg_strings\n  \n def convert_arg_line_to_args(self,arg_line):\n  return [arg_line]\n  \n def _match_argument(self,action,arg_strings_pattern):\n \n  nargs_pattern=self. _get_nargs_pattern(action)\n  match=_re. match(nargs_pattern,arg_strings_pattern)\n  \n  \n  if match is None :\n   nargs_errors={\n   None :_('expected one argument'),\n   OPTIONAL:_('expected at most one argument'),\n   ONE_OR_MORE:_('expected at least one argument'),\n   }\n   default=ngettext('expected %s argument',\n   'expected %s arguments',\n   action. nargs)%action. nargs\n   msg=nargs_errors. get(action. nargs,default)\n   raise ArgumentError(action,msg)\n   \n   \n  return len(match. group(1))\n  \n def _match_arguments_partial(self,actions,arg_strings_pattern):\n \n \n  result=[]\n  for i in range(len(actions),0,-1):\n   actions_slice=actions[:i]\n   pattern=''. join([self. _get_nargs_pattern(action)\n   for action in actions_slice])\n   match=_re. match(pattern,arg_strings_pattern)\n   if match is not None :\n    result. extend([len(string)for string in match. groups()])\n    break\n    \n    \n  return result\n  \n def _parse_optional(self,arg_string):\n \n  if not arg_string:\n   return None\n   \n   \n  if not arg_string[0]in self. prefix_chars:\n   return None\n   \n   \n  if arg_string in self. _option_string_actions:\n   action=self. _option_string_actions[arg_string]\n   return action,arg_string,None\n   \n   \n  if len(arg_string)==1:\n   return None\n   \n   \n  if'='in arg_string:\n   option_string,explicit_arg=arg_string. split('=',1)\n   if option_string in self. _option_string_actions:\n    action=self. _option_string_actions[option_string]\n    return action,option_string,explicit_arg\n    \n    \n    \n  option_tuples=self. _get_option_tuples(arg_string)\n  \n  \n  if len(option_tuples)>1:\n   options=', '. join([option_string\n   for action,option_string,explicit_arg in option_tuples])\n   args={'option':arg_string,'matches':options}\n   msg=_('ambiguous option: %(option)s could match %(matches)s')\n   self. error(msg %args)\n   \n   \n   \n  elif len(option_tuples)==1:\n   option_tuple,=option_tuples\n   return option_tuple\n   \n   \n   \n   \n  if self. _negative_number_matcher. match(arg_string):\n   if not self. _has_negative_number_optionals:\n    return None\n    \n    \n  if' 'in arg_string:\n   return None\n   \n   \n   \n  return None ,arg_string,None\n  \n def _get_option_tuples(self,option_string):\n  result=[]\n  \n  \n  \n  chars=self. prefix_chars\n  if option_string[0]in chars and option_string[1]in chars:\n   if'='in option_string:\n    option_prefix,explicit_arg=option_string. split('=',1)\n   else :\n    option_prefix=option_string\n    explicit_arg=None\n   for option_string in self. _option_string_actions:\n    if option_string. startswith(option_prefix):\n     action=self. _option_string_actions[option_string]\n     tup=action,option_string,explicit_arg\n     result. append(tup)\n     \n     \n     \n     \n  elif option_string[0]in chars and option_string[1]not in chars:\n   option_prefix=option_string\n   explicit_arg=None\n   short_option_prefix=option_string[:2]\n   short_explicit_arg=option_string[2:]\n   \n   for option_string in self. _option_string_actions:\n    if option_string ==short_option_prefix:\n     action=self. _option_string_actions[option_string]\n     tup=action,option_string,short_explicit_arg\n     result. append(tup)\n    elif option_string. startswith(option_prefix):\n     action=self. _option_string_actions[option_string]\n     tup=action,option_string,explicit_arg\n     result. append(tup)\n     \n     \n  else :\n   self. error(_('unexpected option string: %s')%option_string)\n   \n   \n  return result\n  \n def _get_nargs_pattern(self,action):\n \n \n  nargs=action. nargs\n  \n  \n  if nargs is None :\n   nargs_pattern='(-*A-*)'\n   \n   \n  elif nargs ==OPTIONAL:\n   nargs_pattern='(-*A?-*)'\n   \n   \n  elif nargs ==ZERO_OR_MORE:\n   nargs_pattern='(-*[A-]*)'\n   \n   \n  elif nargs ==ONE_OR_MORE:\n   nargs_pattern='(-*A[A-]*)'\n   \n   \n  elif nargs ==REMAINDER:\n   nargs_pattern='([-AO]*)'\n   \n   \n  elif nargs ==PARSER:\n   nargs_pattern='(-*A[-AO]*)'\n   \n   \n  else :\n   nargs_pattern='(-*%s-*)'%'-*'. join('A'*nargs)\n   \n   \n  if action. option_strings:\n   nargs_pattern=nargs_pattern. replace('-*','')\n   nargs_pattern=nargs_pattern. replace('-','')\n   \n   \n  return nargs_pattern\n  \n  \n  \n  \n def _get_values(self,action,arg_strings):\n \n  if action. nargs not in [PARSER,REMAINDER]:\n   try :\n    arg_strings. remove('--')\n   except ValueError:\n    pass\n    \n    \n  if not arg_strings and action. nargs ==OPTIONAL:\n   if action. option_strings:\n    value=action. const\n   else :\n    value=action. default\n   if isinstance(value,str):\n    value=self. _get_value(action,value)\n    self. _check_value(action,value)\n    \n    \n    \n  elif (not arg_strings and action. nargs ==ZERO_OR_MORE and\n  not action. option_strings):\n   if action. default is not None :\n    value=action. default\n   else :\n    value=arg_strings\n   self. _check_value(action,value)\n   \n   \n  elif len(arg_strings)==1 and action. nargs in [None ,OPTIONAL]:\n   arg_string,=arg_strings\n   value=self. _get_value(action,arg_string)\n   self. _check_value(action,value)\n   \n   \n  elif action. nargs ==REMAINDER:\n   value=[self. _get_value(action,v)for v in arg_strings]\n   \n   \n  elif action. nargs ==PARSER:\n   value=[self. _get_value(action,v)for v in arg_strings]\n   self. _check_value(action,value[0])\n   \n   \n  else :\n   value=[self. _get_value(action,v)for v in arg_strings]\n   for v in value:\n    self. _check_value(action,v)\n    \n    \n  return value\n  \n def _get_value(self,action,arg_string):\n  type_func=self. _registry_get('type',action. type,action. type)\n  if not callable(type_func):\n   msg=_('%r is not callable')\n   raise ArgumentError(action,msg %type_func)\n   \n   \n  try :\n   result=type_func(arg_string)\n   \n   \n  except ArgumentTypeError:\n   name=getattr(action. type,'__name__',repr(action. type))\n   msg=str(_sys. exc_info()[1])\n   raise ArgumentError(action,msg)\n   \n   \n  except (TypeError,ValueError):\n   name=getattr(action. type,'__name__',repr(action. type))\n   args={'type':name,'value':arg_string}\n   msg=_('invalid %(type)s value: %(value)r')\n   raise ArgumentError(action,msg %args)\n   \n   \n  return result\n  \n def _check_value(self,action,value):\n \n  if action. choices is not None and value not in action. choices:\n   args={'value':value,\n   'choices':', '. join(map(repr,action. choices))}\n   msg=_('invalid choice: %(value)r (choose from %(choices)s)')\n   raise ArgumentError(action,msg %args)\n   \n   \n   \n   \n def format_usage(self):\n  formatter=self. _get_formatter()\n  formatter. add_usage(self. usage,self. _actions,\n  self. _mutually_exclusive_groups)\n  return formatter. format_help()\n  \n def format_help(self):\n  formatter=self. _get_formatter()\n  \n  \n  formatter. add_usage(self. usage,self. _actions,\n  self. _mutually_exclusive_groups)\n  \n  \n  formatter. add_text(self. description)\n  \n  \n  for action_group in self. _action_groups:\n   formatter. start_section(action_group. title)\n   formatter. add_text(action_group. description)\n   formatter. add_arguments(action_group. _group_actions)\n   formatter. end_section()\n   \n   \n  formatter. add_text(self. epilog)\n  \n  \n  return formatter. format_help()\n  \n def _get_formatter(self):\n  return self. formatter_class(prog=self. prog)\n  \n  \n  \n  \n def print_usage(self,file=None ):\n  if file is None :\n   file=_sys. stdout\n  self. _print_message(self. format_usage(),file)\n  \n def print_help(self,file=None ):\n  if file is None :\n   file=_sys. stdout\n  self. _print_message(self. format_help(),file)\n  \n def _print_message(self,message,file=None ):\n  if message:\n   if file is None :\n    file=_sys. stderr\n   file. write(message)\n   \n   \n   \n   \n def exit(self,status=0,message=None ):\n  if message:\n   self. _print_message(message,_sys. stderr)\n  _sys. exit(status)\n  \n def error(self,message):\n  ''\n\n\n\n\n\n\n  \n  self. print_usage(_sys. stderr)\n  args={'prog':self. prog,'message':message}\n  self. exit(2,_('%(prog)s: error: %(message)s\\n')%args)\n", ["collections", "copy", "gettext", "os", "re", "sys", "textwrap"]], "cmd": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nimport string,sys\n\n__all__=[\"Cmd\"]\n\nPROMPT='(Cmd) '\nIDENTCHARS=string. ascii_letters+string. digits+'_'\n\nclass Cmd:\n ''\n\n\n\n\n\n\n\n\n\n \n prompt=PROMPT\n identchars=IDENTCHARS\n ruler='='\n lastcmd=''\n intro=None\n doc_leader=\"\"\n doc_header=\"Documented commands (type help <topic>):\"\n misc_header=\"Miscellaneous help topics:\"\n undoc_header=\"Undocumented commands:\"\n nohelp=\"*** No help on %s\"\n use_rawinput=1\n \n def __init__(self,completekey='tab',stdin=None ,stdout=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  if stdin is not None :\n   self. stdin=stdin\n  else :\n   self. stdin=sys. stdin\n  if stdout is not None :\n   self. stdout=stdout\n  else :\n   self. stdout=sys. stdout\n  self. cmdqueue=[]\n  self. completekey=completekey\n  \n def cmdloop(self,intro=None ):\n  ''\n\n\n\n  \n  \n  self. preloop()\n  if self. use_rawinput and self. completekey:\n   try :\n    import readline\n    self. old_completer=readline. get_completer()\n    readline. set_completer(self. complete)\n    readline. parse_and_bind(self. completekey+\": complete\")\n   except ImportError:\n    pass\n  try :\n   if intro is not None :\n    self. intro=intro\n   if self. intro:\n    self. stdout. write(str(self. intro)+\"\\n\")\n   stop=None\n   while not stop:\n    if self. cmdqueue:\n     line=self. cmdqueue. pop(0)\n    else :\n     if self. use_rawinput:\n      try :\n       line=input(self. prompt)\n      except EOFError:\n       line='EOF'\n     else :\n      self. stdout. write(self. prompt)\n      self. stdout. flush()\n      line=self. stdin. readline()\n      if not len(line):\n       line='EOF'\n      else :\n       line=line. rstrip('\\r\\n')\n    line=self. precmd(line)\n    stop=self. onecmd(line)\n    stop=self. postcmd(stop,line)\n   self. postloop()\n  finally :\n   if self. use_rawinput and self. completekey:\n    try :\n     import readline\n     readline. set_completer(self. old_completer)\n    except ImportError:\n     pass\n     \n     \n def precmd(self,line):\n  ''\n\n\n  \n  return line\n  \n def postcmd(self,stop,line):\n  ''\n  return stop\n  \n def preloop(self):\n  ''\n  pass\n  \n def postloop(self):\n  ''\n\n\n  \n  pass\n  \n def parseline(self,line):\n  ''\n\n\n  \n  line=line. strip()\n  if not line:\n   return None ,None ,line\n  elif line[0]=='?':\n   line='help '+line[1:]\n  elif line[0]=='!':\n   if hasattr(self,'do_shell'):\n    line='shell '+line[1:]\n   else :\n    return None ,None ,line\n  i,n=0,len(line)\n  while i <n and line[i]in self. identchars:i=i+1\n  cmd,arg=line[:i],line[i:]. strip()\n  return cmd,arg,line\n  \n def onecmd(self,line):\n  ''\n\n\n\n\n\n\n\n  \n  cmd,arg,line=self. parseline(line)\n  if not line:\n   return self. emptyline()\n  if cmd is None :\n   return self. default(line)\n  self. lastcmd=line\n  if line =='EOF':\n   self. lastcmd=''\n  if cmd =='':\n   return self. default(line)\n  else :\n   try :\n    func=getattr(self,'do_'+cmd)\n   except AttributeError:\n    return self. default(line)\n   return func(arg)\n   \n def emptyline(self):\n  ''\n\n\n\n\n  \n  if self. lastcmd:\n   return self. onecmd(self. lastcmd)\n   \n def default(self,line):\n  ''\n\n\n\n\n  \n  self. stdout. write('*** Unknown syntax: %s\\n'%line)\n  \n def completedefault(self,*ignored):\n  ''\n\n\n\n\n  \n  return []\n  \n def completenames(self,text,*ignored):\n  dotext='do_'+text\n  return [a[3:]for a in self. get_names()if a. startswith(dotext)]\n  \n def complete(self,text,state):\n  ''\n\n\n\n  \n  if state ==0:\n   import readline\n   origline=readline. get_line_buffer()\n   line=origline. lstrip()\n   stripped=len(origline)-len(line)\n   begidx=readline. get_begidx()-stripped\n   endidx=readline. get_endidx()-stripped\n   if begidx >0:\n    cmd,args,foo=self. parseline(line)\n    if cmd =='':\n     compfunc=self. completedefault\n    else :\n     try :\n      compfunc=getattr(self,'complete_'+cmd)\n     except AttributeError:\n      compfunc=self. completedefault\n   else :\n    compfunc=self. completenames\n   self. completion_matches=compfunc(text,line,begidx,endidx)\n  try :\n   return self. completion_matches[state]\n  except IndexError:\n   return None\n   \n def get_names(self):\n \n \n  return dir(self. __class__)\n  \n def complete_help(self,*args):\n  commands=set(self. completenames(*args))\n  topics=set(a[5:]for a in self. get_names()\n  if a. startswith('help_'+args[0]))\n  return list(commands |topics)\n  \n def do_help(self,arg):\n  ''\n  if arg:\n  \n   try :\n    func=getattr(self,'help_'+arg)\n   except AttributeError:\n    try :\n     doc=getattr(self,'do_'+arg). __doc__\n     if doc:\n      self. stdout. write(\"%s\\n\"%str(doc))\n      return\n    except AttributeError:\n     pass\n    self. stdout. write(\"%s\\n\"%str(self. nohelp %(arg,)))\n    return\n   func()\n  else :\n   names=self. get_names()\n   cmds_doc=[]\n   cmds_undoc=[]\n   help={}\n   for name in names:\n    if name[:5]=='help_':\n     help[name[5:]]=1\n   names. sort()\n   \n   prevname=''\n   for name in names:\n    if name[:3]=='do_':\n     if name ==prevname:\n      continue\n     prevname=name\n     cmd=name[3:]\n     if cmd in help:\n      cmds_doc. append(cmd)\n      del help[cmd]\n     elif getattr(self,name). __doc__:\n      cmds_doc. append(cmd)\n     else :\n      cmds_undoc. append(cmd)\n   self. stdout. write(\"%s\\n\"%str(self. doc_leader))\n   self. print_topics(self. doc_header,cmds_doc,15,80)\n   self. print_topics(self. misc_header,list(help. keys()),15,80)\n   self. print_topics(self. undoc_header,cmds_undoc,15,80)\n   \n def print_topics(self,header,cmds,cmdlen,maxcol):\n  if cmds:\n   self. stdout. write(\"%s\\n\"%str(header))\n   if self. ruler:\n    self. stdout. write(\"%s\\n\"%str(self. ruler *len(header)))\n   self. columnize(cmds,maxcol -1)\n   self. stdout. write(\"\\n\")\n   \n def columnize(self,list,displaywidth=80):\n  ''\n\n\n\n  \n  if not list:\n   self. stdout. write(\"<empty>\\n\")\n   return\n   \n  nonstrings=[i for i in range(len(list))\n  if not isinstance(list[i],str)]\n  if nonstrings:\n   raise TypeError(\"list[i] not a string for i in %s\"\n   %\", \". join(map(str,nonstrings)))\n  size=len(list)\n  if size ==1:\n   self. stdout. write('%s\\n'%str(list[0]))\n   return\n   \n  for nrows in range(1,len(list)):\n   ncols=(size+nrows -1)//nrows\n   colwidths=[]\n   totwidth=-2\n   for col in range(ncols):\n    colwidth=0\n    for row in range(nrows):\n     i=row+nrows *col\n     if i >=size:\n      break\n     x=list[i]\n     colwidth=max(colwidth,len(x))\n    colwidths. append(colwidth)\n    totwidth +=colwidth+2\n    if totwidth >displaywidth:\n     break\n   if totwidth <=displaywidth:\n    break\n  else :\n   nrows=len(list)\n   ncols=1\n   colwidths=[0]\n  for row in range(nrows):\n   texts=[]\n   for col in range(ncols):\n    i=row+nrows *col\n    if i >=size:\n     x=\"\"\n    else :\n     x=list[i]\n    texts. append(x)\n   while texts and not texts[-1]:\n    del texts[-1]\n   for col in range(len(texts)):\n    texts[col]=texts[col]. ljust(colwidths[col])\n   self. stdout. write(\"%s\\n\"%str(\"  \". join(texts)))\n", ["readline", "string", "sys"]], "time": [".py", "from browser import window\n\n\ndate=window. Date. new\n\nnow=window. Date. now\n\n\n\n\n\n\n\n_STRUCT_TM_ITEMS=9\n\n\n\n\n\ndef _get_day_of_year(arg):\n ''\n\n\n\n\n\n\n\n\n\n \n ml=[31,28,31,30,31,30,31,31,30,31,30,31]\n if arg[0]%4 ==0:\n  ml[1]+=1\n i=1\n yday=0\n while i <arg[1]:\n  yday +=ml[i -1]\n  i +=1\n yday +=arg[2]\n return yday\n \ndef _get_week_of_year(arg):\n ''\n\n\n\n\n\n\n\n\n\n\n \n d1=date(arg[0],arg[1]-1,arg[2])\n d0=date(arg[0],0,1)\n firstday=d0. getDay()\n if firstday ==0:firstday=7\n firstweek=8 -firstday\n doy=arg[7]\n if firstday !=1:\n  doy=doy -firstweek\n if doy %7 ==0:\n  week_number=doy //7\n else :\n  week_number=doy //7+1\n return week_number\n \ndef _check_struct_time(t):\n mm=t[1]\n if mm ==0:mm=1\n if -1 >mm >13:raise ValueError(\"month out of range\")\n \n dd=t[2]\n if dd ==0:dd=1\n if -1 >dd >32:raise ValueError(\"day of month out of range\")\n \n hh=t[3]\n if -1 >hh >24:raise ValueError(\"hour out of range\")\n \n minu=t[4]\n if -1 >minu >60:raise ValueError(\"minute out of range\")\n \n ss=t[5]\n if -1 >ss >62:raise ValueError(\"seconds out of range\")\n \n wd=t[6]%7\n if wd <-2:raise ValueError(\"day of week out of range\")\n \n dy=t[7]\n if dy ==0:dy=1\n if -1 >dy >367:raise ValueError(\"day of year out of range\")\n \n return t[0],mm,dd,hh,minu,ss,wd,dy,t[-1]\n \n \ndef _is_dst(secs=None ):\n ''\n d=date()\n if secs is not None :\n  d=date(secs *1000)\n  \n  \n jan=date(d. getFullYear(),0,1)\n jul=date(d. getFullYear(),6,1)\n dst=int(d. getTimezoneOffset()<max(abs(jan. getTimezoneOffset()),abs(jul. getTimezoneOffset())))\n return dst\n \ndef _get_tzname():\n ''\n d=date()\n d=d. toTimeString()\n try :\n  d=d. split('(')[1]. split(')')[0]\n  return (d,'NotAvailable')\n except :\n  return ('','')\n  \ndef _set_altzone():\n d=date()\n jan=date(d. getFullYear(),0,1)\n jul=date(d. getFullYear(),6,1)\n result=timezone -(jan. getTimezoneOffset()-jul. getTimezoneOffset())*60\n return result\n \ndef _check_input(t):\n if t and isinstance(t,struct_time)and len(t. args)==9:\n  t=t. args\n elif t and isinstance(t,tuple)and len(t)==9:\n  t=t\n elif t and isinstance(t,struct_time)and len(t. args)!=9:\n  raise TypeError(\"function takes exactly 9 arguments ({} given)\". format(len(t. args)))\n elif t and isinstance(t,tuple)and len(t)!=9:\n  raise TypeError(\"function takes exactly 9 arguments ({} given)\". format(len(t)))\n elif t and not isinstance(t,(tuple,struct_time)):\n  raise TypeError(\"Tuple or struct_time argument required\")\n else :\n  t=localtime(). args\n return t\n \n \n \n \n \ndaylight=_is_dst()\ntimezone=date(). getTimezoneOffset()*60\ntzname=_get_tzname()\naltzone=_set_altzone()if daylight else timezone\n\n\ndef asctime(t=None ):\n weekdays={0:\"Mon\",1:\"Tue\",2:\"Wed\",3:\"Thu\",\n 4:\"Fri\",5:\"Sat\",6:\"Sun\"}\n months={1:'Jan',2:'Feb',3:'Mar',4:'Apr',5:'May',6:'Jun',\n 7:'Jul',8:'Aug',9:'Sep',10:'Oct',11:'Nov',12:'Dec'}\n \n t=_check_input(t)\n t=_check_struct_time(t)\n \n result=\"%s %s %2d %02d:%02d:%02d %d\"%(\n weekdays[t[6]],months[t[1]],t[2],t[3],t[4],t[5],t[0])\n return result\n \ndef ctime(timestamp=None ):\n return asctime(localtime(timestamp))\n \ndef gmtime(secs=None ):\n d=date()\n if secs is not None :\n  d=date(secs *1000)\n wday=d. getUTCDay()-1 if d. getUTCDay()-1 >=0 else 6\n tmp=struct_time([d. getUTCFullYear(),\n d. getUTCMonth()+1,d. getUTCDate(),\n d. getUTCHours(),d. getUTCMinutes(),d. getUTCSeconds(),\n wday,0,0])\n tmp. args[7]=_get_day_of_year(tmp. args)\n return tmp\n \ndef localtime(secs=None ):\n d=date()\n if secs is not None :\n  d=date(secs *1000)\n dst=_is_dst(secs)\n wday=d. getDay()-1 if d. getDay()-1 >=0 else 6\n tmp=struct_time([d. getFullYear(),\n d. getMonth()+1,d. getDate(),\n d. getHours(),d. getMinutes(),d. getSeconds(),\n wday,0,dst])\n tmp. args[7]=_get_day_of_year(tmp. args)\n return tmp\n \ndef mktime(t):\n if isinstance(t,struct_time):\n  d1=date(t. tm_year,t. tm_mon -1,t. tm_mday,\n  t. tm_hour,t. tm_min,t. tm_sec,0). getTime()\n elif isinstance(t,tuple):\n  d1=date(t[0],t[1]-1,t[2],t[3],t[4],t[5],0). getTime()\n else :\n  raise ValueError(\"Tuple or struct_time argument required\")\n d2=date(0). getTime()\n return (d1 -d2)/1000.\n \ndef monotonic():\n return now()/1000.\n \ndef perf_counter():\n return now()/1000.\n \ndef process_time():\n return now()/1000.\n \ndef time():\n return float(date(). getTime()/1000)\n \ndef sleep(secs):\n ''\n\n \n \n \n \n raise NotImplementedError(\"Blocking functions like time.sleep() are not \"\n \"supported in the browser. Use functions in module browser.timer \"\n \"instead.\")\n \ndef strftime(_format,t=None ):\n\n def ns(t,nb):\n \n  res=str(t)\n  while len(res)<nb:\n   res='0'+res\n  return res\n  \n t=_check_input(t)\n t=_check_struct_time(t)\n \n YY=ns(t[0],4)\n yy=ns(t[0],4)[2:]\n mm=ns(t[1],2)\n dd=ns(t[2],2)\n HH=t[3]\n HH24=ns(HH,2)\n HH12=ns(HH %12,2)\n if HH12 ==0:HH12=12\n AMPM='AM'if 0 <=HH <12 else'PM'\n MM=ns(t[4],2)\n SS=ns(t[5],2)\n DoY=ns(t[7],3)\n w=t[6]+1 if t[6]<6 else 0\n W=ns(_get_week_of_year(t),2)\n \n abb_weekdays=['Sun','Mon','Tue','Wed','Thu','Fri','Sat']\n full_weekdays=['Sunday','Monday','Tuesday','Wednesday',\n 'Thursday','Friday','Saturday']\n abb_months=['Jan','Feb','Mar','Apr','May','Jun',\n 'Jul','Aug','Sep','Oct','Nov','Dec']\n full_months=['January','February','March','April','May','June',\n 'July','August','September','October','November','December']\n \n res=_format\n res=res. replace(\"%H\",HH24)\n res=res. replace(\"%I\",HH12)\n res=res. replace(\"%p\",AMPM)\n res=res. replace(\"%M\",MM)\n res=res. replace(\"%S\",SS)\n res=res. replace(\"%Y\",YY)\n res=res. replace(\"%y\",yy)\n res=res. replace(\"%m\",mm)\n res=res. replace(\"%d\",dd)\n res=res. replace(\"%a\",abb_weekdays[w])\n res=res. replace(\"%A\",full_weekdays[w])\n res=res. replace(\"%b\",abb_months[int(mm)-1])\n res=res. replace(\"%B\",full_months[int(mm)-1])\n res=res. replace(\"%j\",DoY)\n res=res. replace(\"%w\",str(w))\n res=res. replace(\"%W\",W)\n res=res. replace(\"%x\",mm+'/'+dd+'/'+yy)\n res=res. replace(\"%X\",HH24+':'+MM+':'+SS)\n res=res. replace(\"%c\",abb_weekdays[w]+' '+abb_months[int(mm)-1]+\n ' '+dd+' '+HH24+':'+MM+':'+SS+' '+YY)\n res=res. replace(\"%%\",'%')\n \n return res\n \nclass struct_time:\n\n def __init__(self,args):\n \n  if len(args)!=9:\n   raise TypeError(\"time.struct_time() takes a 9-sequence (%s-sequence given)\"%len(args))\n   \n  self. args=args\n  \n @property\n def tm_year(self):\n  return self. args[0]\n  \n @property\n def tm_mon(self):\n  return self. args[1]\n  \n @property\n def tm_mday(self):\n  return self. args[2]\n  \n @property\n def tm_hour(self):\n  return self. args[3]\n  \n @property\n def tm_min(self):\n  return self. args[4]\n  \n @property\n def tm_sec(self):\n  return self. args[5]\n  \n @property\n def tm_wday(self):\n  return self. args[6]\n  \n @property\n def tm_yday(self):\n  return self. args[7]\n  \n @property\n def tm_isdst(self):\n  return self. args[8]\n  \n def __getitem__(self,i):\n  return self. args[i]\n  \n def __iter__(self):\n  return iter(self. args)\n  \n def __repr__(self):\n  return (\"time.structime(tm_year={}, tm_mon={}, tm_day={}, \"+  \"tm_hour={}, tm_min={}, tm_sec={}, tm_wday={}, \"+  \"tm_yday={}, tm_isdst={})\"). format(*self. args)\n  \n def __str__(self):\n  return self. __repr__()\n  \ndef to_struct_time(*arg):\n arg=list(arg)\n \n \n ml=[31,28,31,30,31,30,31,31,30,31,30,31]\n if arg[0]%4 ==0:\n  ml[1]+=1\n  \n i=1\n yday=0\n while i <arg[1]:\n  yday +=ml[i -1]\n  i +=1\n yday +=arg[2]\n arg. append(yday)\n arg. append(-1)\n return struct_time(tuple(arg))\n \ndef wait(secs):\n\n pass\n \ndef strptime(string,_format):\n import _strptime\n return _strptime. _strptime_datetime(to_struct_time,string,_format)\n \n \n \n_clock_msg=\"\"\"Browser cannot access CPU. See '%s'\"\"\"\ndef _clock_xx(url):\n raise NotImplementedError(_clock_msg %url)\nclock=time\nclock_getres=lambda :_clock_xx(\"https://docs.python.org/3/library/time.html#time.clock_getres\")\nclock_gettime=lambda :_clock_xx(\"https://docs.python.org/3/library/time.html#time.clock_gettime\")\nclock_settime=lambda :_clock_xx(\"https://docs.python.org/3/library/time.html#time.clock_settime\")\nCLOCK_HIGHRES=_clock_msg %\"https://docs.python.org/3/library/time.html#time.CLOCK_HIGHRES\"\nCLOCK_MONOTONIC=_clock_msg %\"https://docs.python.org/3/library/time.html#time.CLOCK_MONOTONIC\"\nCLOCK_MONOTONIC_RAW=_clock_msg %\"https://docs.python.org/3/library/time.html#time.CLOCK_MONOTONIC_RAW\"\nCLOCK_PROCESS_CPUTIME_ID=_clock_msg %\"https://docs.python.org/3/library/time.html#time.CLOCK_PROCESS_CPUTIME_ID\"\nCLOCK_REALTIME=_clock_msg %\"https://docs.python.org/3/library/time.html#time.CLOCK_REALTIME\"\nCLOCK_THREAD_CPUTIME_ID=_clock_msg %\"https://docs.python.org/3/library/time.html#time.CLOCK_THREAD_CPUTIME_ID\"\n\n\ndef get_clock_info(cl):\n from collections import namedtuple\n ClockInfo=namedtuple('ClockInfo',['adjustable','implementation','monotonic','resolution'])\n \n if cl =='monotonic':\n  return ClockInfo(adjustable=False ,\n  implementation='window.performance.now',\n  monotonic=True ,\n  resolution=0.000001)\n elif cl =='perf_counter'or cl =='process_time':\n  return ClockInfo(adjustable=False ,\n  implementation='date.getTime',\n  monotonic=False ,\n  resolution=0.001)\n else :\n  _clock_xx(\"https://docs.python.org/3/library/time.html#time.get_clock_info\")\n  \ndef tzset():\n raise NotImplementedError()\n", ["_strptime", "browser", "collections"]], "types": [".py", "''\n\n\nimport sys\n\n\n\n\n\n\ndef _f():pass\nFunctionType=type(_f)\nLambdaType=type(lambda :None )\nCodeType=type(_f. __code__)\nMappingProxyType=type(type. __dict__)\nSimpleNamespace=type(sys. implementation)\n\ndef _g():\n yield 1\nGeneratorType=type(_g())\n\nclass _C:\n def _m(self):pass\nMethodType=type(_C(). _m)\n\nBuiltinFunctionType=type(len)\nBuiltinMethodType=type([]. append)\n\nModuleType=type(sys)\n\ntry :\n raise TypeError\nexcept TypeError:\n tb=sys. exc_info()[2]\n TracebackType=type(tb)\n FrameType=type(tb. tb_frame)\n tb=None ;del tb\n \n \nGetSetDescriptorType=type(FunctionType. __code__)\nMemberDescriptorType=type(FunctionType. __globals__)\n\ndel sys,_f,_g,_C,\n\n\n\ndef new_class(name,bases=(),kwds=None ,exec_body=None ):\n ''\n meta,ns,kwds=prepare_class(name,bases,kwds)\n if exec_body is not None :\n  exec_body(ns)\n return meta(name,bases,ns,**kwds)\n \ndef prepare_class(name,bases=(),kwds=None ):\n ''\n\n\n\n\n\n\n\n\n \n if kwds is None :\n  kwds={}\n else :\n  kwds=dict(kwds)\n if'metaclass'in kwds:\n  meta=kwds. pop('metaclass')\n else :\n  if bases:\n   meta=type(bases[0])\n  else :\n   meta=type\n if isinstance(meta,type):\n \n \n  meta=_calculate_meta(meta,bases)\n if hasattr(meta,'__prepare__'):\n  ns=meta. __prepare__(name,bases,**kwds)\n else :\n  ns={}\n return meta,ns,kwds\n \ndef _calculate_meta(meta,bases):\n ''\n winner=meta\n for base in bases:\n  base_meta=type(base)\n  if issubclass(winner,base_meta):\n   continue\n  if issubclass(base_meta,winner):\n   winner=base_meta\n   continue\n   \n  raise TypeError(\"metaclass conflict: \"\n  \"the metaclass of a derived class \"\n  \"must be a (non-strict) subclass \"\n  \"of the metaclasses of all its bases\")\n return winner\n", ["sys"]], "copyreg": [".py", "''\n\n\n\n\n\n__all__=[\"pickle\",\"constructor\",\n\"add_extension\",\"remove_extension\",\"clear_extension_cache\"]\n\ndispatch_table={}\n\ndef pickle(ob_type,pickle_function,constructor_ob=None ):\n if not callable(pickle_function):\n  raise TypeError(\"reduction functions must be callable\")\n dispatch_table[ob_type]=pickle_function\n \n \n \n if constructor_ob is not None :\n  constructor(constructor_ob)\n  \ndef constructor(object):\n if not callable(object):\n  raise TypeError(\"constructors must be callable\")\n  \n  \n  \ntry :\n complex\nexcept NameError:\n pass\nelse :\n\n def pickle_complex(c):\n  return complex,(c. real,c. imag)\n  \n pickle(complex,pickle_complex,complex)\n \n \n \ndef _reconstructor(cls,base,state):\n if base is object:\n  obj=object. __new__(cls)\n else :\n  obj=base. __new__(cls,state)\n  if base. __init__ !=object. __init__:\n   base. __init__(obj,state)\n return obj\n \n_HEAPTYPE=1 <<9\n\n\n\ndef _reduce_ex(self,proto):\n assert proto <2\n for base in self. __class__. __mro__:\n  if hasattr(base,'__flags__')and not base. __flags__&_HEAPTYPE:\n   break\n else :\n  base=object\n if base is object:\n  state=None\n else :\n  if base is self. __class__:\n   raise TypeError(\"can't pickle %s objects\"%base. __name__)\n  state=base(self)\n args=(self. __class__,base,state)\n try :\n  getstate=self. __getstate__\n except AttributeError:\n  if getattr(self,\"__slots__\",None ):\n   raise TypeError(\"a class that defines __slots__ without \"\n   \"defining __getstate__ cannot be pickled\")\n  try :\n   dict=self. __dict__\n  except AttributeError:\n   dict=None\n else :\n  dict=getstate()\n if dict:\n  return _reconstructor,args,dict\n else :\n  return _reconstructor,args\n  \n  \n  \ndef __newobj__(cls,*args):\n return cls. __new__(cls,*args)\n \ndef _slotnames(cls):\n ''\n\n\n\n\n\n\n\n \n \n \n names=cls. __dict__. get(\"__slotnames__\")\n if names is not None :\n  return names\n  \n  \n names=[]\n if not hasattr(cls,\"__slots__\"):\n \n  pass\n else :\n \n  for c in cls. __mro__:\n   if\"__slots__\"in c. __dict__:\n    slots=c. __dict__['__slots__']\n    \n    if isinstance(slots,str):\n     slots=(slots,)\n    for name in slots:\n    \n     if name in (\"__dict__\",\"__weakref__\"):\n      continue\n      \n     elif name. startswith('__')and not name. endswith('__'):\n      names. append('_%s%s'%(c. __name__,name))\n     else :\n      names. append(name)\n      \n      \n try :\n  cls. __slotnames__=names\n except :\n  pass\n  \n return names\n \n \n \n \n \n \n \n \n \n \n_extension_registry={}\n_inverted_registry={}\n_extension_cache={}\n\n\n\ndef add_extension(module,name,code):\n ''\n code=int(code)\n if not 1 <=code <=0x7fffffff:\n  raise ValueError(\"code out of range\")\n key=(module,name)\n if (_extension_registry. get(key)==code and\n _inverted_registry. get(code)==key):\n  return\n if key in _extension_registry:\n  raise ValueError(\"key %s is already registered with code %s\"%\n  (key,_extension_registry[key]))\n if code in _inverted_registry:\n  raise ValueError(\"code %s is already in use for key %s\"%\n  (code,_inverted_registry[code]))\n _extension_registry[key]=code\n _inverted_registry[code]=key\n \ndef remove_extension(module,name,code):\n ''\n key=(module,name)\n if (_extension_registry. get(key)!=code or\n _inverted_registry. get(code)!=key):\n  raise ValueError(\"key %s is not registered with code %s\"%\n  (key,code))\n del _extension_registry[key]\n del _inverted_registry[code]\n if code in _extension_cache:\n  del _extension_cache[code]\n  \ndef clear_extension_cache():\n _extension_cache. clear()\n \n \n \n \n \n \n \n \n \n \n \n \n \n", []], "_sys": [".js", "var $module=(function($B){\n    var _b_ = $B.builtins\n    return {\n        // Called \"Getframe\" because \"_getframe\" wouldn't be imported in\n        // sys.py with \"from _sys import *\"\n        Getframe : function(depth){\n            return $B._frame.$factory($B.frames_stack, depth)\n        },\n        modules :\n            {'__get__':function(){\n                console.log(\"get sys.modules\")\n                return $B.obj_dict($B.imported)\n            },\n             '__set__':function(self, obj, value){ throw _b_.TypeError(\"Read only property 'sys.modules'\") }\n            },\n        path:\n            {'__get__':function(){return $B.path},\n             '__set__':function(self, obj, value){ $B.path = value }\n            },\n        meta_path:\n            {'__get__':function(){return $B.meta_path},\n             '__set__':function(self, obj, value){ $B.meta_path = value }\n            },\n        path_hooks:\n            {'__get__':function(){return $B.path_hooks},\n             '__set__':function(self, obj, value){ $B.path_hooks = value }\n            },\n        path_importer_cache:\n            {'__get__':function(){\n                return _b_.dict.$factory($B.JSObject.$factory($B.path_importer_cache))\n            },\n             '__set__':function(self, obj, value){\n                 throw _b_.TypeError(\"Read only property 'sys.path_importer_cache'\")\n            }\n        },\n        stderr : {\n            __get__:function(){return $B.stderr},\n            __set__:function(self, obj, value){$B.stderr = value},\n            write:function(data){_b_.getattr($B.stderr,\"write\")(data)}\n            },\n        stdout : {\n            __get__:function(){return $B.stdout},\n            __set__:function(self, obj, value){$B.stdout = value},\n            write:function(data){_b_.getattr($B.stdout,\"write\")(data)}\n            },\n        stdin : $B.stdin\n    }\n})(__BRYTHON__)\n"], "unittest.result": [".py", "''\n\nimport io\nimport sys\nimport traceback\n\nfrom . import util\nfrom functools import wraps\n\n__unittest=True\n\ndef failfast(method):\n @wraps(method)\n def inner(self,*args,**kw):\n  if getattr(self,'failfast',False ):\n   self. stop()\n  return method(self,*args,**kw)\n return inner\n \nSTDOUT_LINE='\\nStdout:\\n%s'\nSTDERR_LINE='\\nStderr:\\n%s'\n\n\nclass TestResult(object):\n ''\n\n\n\n\n\n\n\n\n \n _previousTestClass=None\n _testRunEntered=False\n _moduleSetUpFailed=False\n def __init__(self,stream=None ,descriptions=None ,verbosity=None ):\n  self. failfast=False\n  self. failures=[]\n  self. errors=[]\n  self. testsRun=0\n  self. skipped=[]\n  self. expectedFailures=[]\n  self. unexpectedSuccesses=[]\n  self. shouldStop=False\n  self. buffer=False\n  self. _stdout_buffer=None\n  self. _stderr_buffer=None\n  self. _original_stdout=sys. stdout\n  self. _original_stderr=sys. stderr\n  self. _mirrorOutput=False\n  \n def printErrors(self):\n  ''\n  \n  pass\n  \n def startTest(self,test):\n  ''\n  self. testsRun +=1\n  self. _mirrorOutput=False\n  self. _setupStdout()\n  \n def _setupStdout(self):\n  if self. buffer:\n   if self. _stderr_buffer is None :\n    self. _stderr_buffer=io. StringIO()\n    self. _stdout_buffer=io. StringIO()\n   sys. stdout=self. _stdout_buffer\n   sys. stderr=self. _stderr_buffer\n   \n def startTestRun(self):\n  ''\n\n\n  \n  \n def stopTest(self,test):\n  ''\n  self. _restoreStdout()\n  self. _mirrorOutput=False\n  \n def _restoreStdout(self):\n  if self. buffer:\n   if self. _mirrorOutput:\n    output=sys. stdout. getvalue()\n    error=sys. stderr. getvalue()\n    if output:\n     if not output. endswith('\\n'):\n      output +='\\n'\n     self. _original_stdout. write(STDOUT_LINE %output)\n    if error:\n     if not error. endswith('\\n'):\n      error +='\\n'\n     self. _original_stderr. write(STDERR_LINE %error)\n     \n   sys. stdout=self. _original_stdout\n   sys. stderr=self. _original_stderr\n   self. _stdout_buffer. seek(0)\n   self. _stdout_buffer. truncate()\n   self. _stderr_buffer. seek(0)\n   self. _stderr_buffer. truncate()\n   \n def stopTestRun(self):\n  ''\n\n\n  \n  \n @failfast\n def addError(self,test,err):\n  ''\n\n  \n  self. errors. append((test,self. _exc_info_to_string(err,test)))\n  self. _mirrorOutput=True\n  \n @failfast\n def addFailure(self,test,err):\n  ''\n  \n  self. failures. append((test,self. _exc_info_to_string(err,test)))\n  self. _mirrorOutput=True\n  \n def addSuccess(self,test):\n  ''\n  pass\n  \n def addSkip(self,test,reason):\n  ''\n  self. skipped. append((test,reason))\n  \n def addExpectedFailure(self,test,err):\n  ''\n  self. expectedFailures. append(\n  (test,self. _exc_info_to_string(err,test)))\n  \n @failfast\n def addUnexpectedSuccess(self,test):\n  ''\n  self. unexpectedSuccesses. append(test)\n  \n def wasSuccessful(self):\n  ''\n  return len(self. failures)==len(self. errors)==0\n  \n def stop(self):\n  ''\n  self. shouldStop=True\n  \n def _exc_info_to_string(self,err,test):\n  ''\n  exctype,value,tb=err\n  \n  while tb and self. _is_relevant_tb_level(tb):\n   tb=tb. tb_next\n   \n  if exctype is test. failureException:\n  \n   length=self. _count_relevant_tb_levels(tb)\n   msgLines=traceback. format_exception(exctype,value,tb,length)\n  else :\n   msgLines=traceback. format_exception(exctype,value,tb)\n   \n  if self. buffer:\n   output=sys. stdout. getvalue()\n   error=sys. stderr. getvalue()\n   if output:\n    if not output. endswith('\\n'):\n     output +='\\n'\n    msgLines. append(STDOUT_LINE %output)\n   if error:\n    if not error. endswith('\\n'):\n     error +='\\n'\n    msgLines. append(STDERR_LINE %error)\n  return''. join(msgLines)\n  \n  \n def _is_relevant_tb_level(self,tb):\n \n \n  return False\n  \n def _count_relevant_tb_levels(self,tb):\n  length=0\n  while tb and not self. _is_relevant_tb_level(tb):\n   length +=1\n   tb=tb. tb_next\n  return length\n  \n def __repr__(self):\n  return (\"<%s run=%i errors=%i failures=%i>\"%\n  (util. strclass(self. __class__),self. testsRun,len(self. errors),\n  len(self. failures)))\n", ["functools", "io", "sys", "traceback", "unittest", "unittest.util"]], "unittest": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__all__=['TestResult','TestCase','TestSuite',\n'TextTestRunner','TestLoader','FunctionTestCase','main',\n'defaultTestLoader','SkipTest','skip','skipIf','skipUnless',\n'expectedFailure','TextTestResult','installHandler',\n'registerResult','removeResult','removeHandler']\n\n\n__all__. extend(['getTestCaseNames','makeSuite','findTestCases'])\n\n__unittest=True\n\nfrom . result import TestResult\nfrom . case import (TestCase,FunctionTestCase,SkipTest,skip,skipIf,\nskipUnless,expectedFailure)\nfrom . suite import BaseTestSuite,TestSuite\nfrom . loader import (TestLoader,defaultTestLoader,makeSuite,getTestCaseNames,\nfindTestCases)\nfrom . main import TestProgram,main\nfrom . runner import TextTestRunner,TextTestResult\nfrom . signals import installHandler,registerResult,removeResult,removeHandler\n\n\n_TextTestResult=TextTestResult\n", ["unittest.case", "unittest.loader", "unittest.main", "unittest.result", "unittest.runner", "unittest.signals", "unittest.suite"], 1], "itertools": [".py", "import operator\n\nclass accumulate:\n def __init__(self,iterable,func=operator. add):\n  self. it=iter(iterable)\n  self. _total=None\n  self. func=func\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  if not self. _total:\n   self. _total=next(self. it)\n   return self. _total\n  else :\n   element=next(self. it)\n   try :\n    self. _total=self. func(self. _total,element)\n   except :\n    raise TypeError(\"unsupported operand type\")\n   return self. _total\n   \n   \n   \nclass chain:\n def __init__(self,*iterables):\n  self. _iterables_iter=iter(map(iter,iterables))\n  \n  self. _cur_iterable_iter=iter([])\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  while True :\n   try :\n    return next(self. _cur_iterable_iter)\n   except StopIteration:\n    self. _cur_iterable_iter=next(self. _iterables_iter)\n    \n @classmethod\n def from_iterable(cls,iterable):\n  for it in iterable:\n   for element in it:\n    yield element\n    \nclass combinations:\n def __init__(self,iterable,r):\n  self. pool=tuple(iterable)\n  self. n=len(self. pool)\n  self. r=r\n  self. indices=list(range(self. r))\n  self. zero=False\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  if self. r >self. n:\n   raise StopIteration\n  if not self. zero:\n   self. zero=True\n   return tuple(self. pool[i]for i in self. indices)\n  else :\n   try :\n    for i in reversed(range(self. r)):\n     if self. indices[i]!=i+self. n -self. r:\n      break\n    self. indices[i]+=1\n    for j in range(i+1,self. r):\n     self. indices[j]=self. indices[j -1]+1\n    return tuple(self. pool[i]for i in self. indices)\n   except :\n    raise StopIteration\n    \nclass combinations_with_replacement:\n def __init__(self,iterable,r):\n  self. pool=tuple(iterable)\n  self. n=len(self. pool)\n  self. r=r\n  self. indices=[0]*self. r\n  self. zero=False\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  if not self. n and self. r:\n   raise StopIteration\n  if not self. zero:\n   self. zero=True\n   return tuple(self. pool[i]for i in self. indices)\n  else :\n   try :\n    for i in reversed(range(self. r)):\n     if self. indices[i]!=self. n -1:\n      break\n    self. indices[i:]=[self. indices[i]+1]*(self. r -i)\n    return tuple(self. pool[i]for i in self. indices)\n   except :\n    raise StopIteration\n    \n    \n    \nclass compress:\n def __init__(self,data,selectors):\n  self. data=iter(data)\n  self. selectors=iter(selectors)\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  while True :\n   next_item=next(self. data)\n   next_selector=next(self. selectors)\n   if bool(next_selector):\n    return next_item\n    \n    \n    \n    \nclass count:\n ''\n\n\n\n \n def __init__(self,start=0,step=1):\n  if not isinstance(start,(int,float)):\n   raise TypeError('a number is required')\n  self. times=start -step\n  self. step=step\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  self. times +=self. step\n  return self. times\n  \n def __repr__(self):\n  return'count(%d)'%(self. times+self. step)\n  \n  \n  \nclass cycle:\n def __init__(self,iterable):\n  self. _cur_iter=iter(iterable)\n  self. _saved=[]\n  self. _must_save=True\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  try :\n   next_elt=next(self. _cur_iter)\n   if self. _must_save:\n    self. _saved. append(next_elt)\n  except StopIteration:\n   self. _cur_iter=iter(self. _saved)\n   next_elt=next(self. _cur_iter)\n   self. _must_save=False\n  return next_elt\n  \n  \n  \nclass dropwhile:\n def __init__(self,predicate,iterable):\n  self. _predicate=predicate\n  self. _iter=iter(iterable)\n  self. _dropped=False\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  value=next(self. _iter)\n  if self. _dropped:\n   return value\n  while self. _predicate(value):\n   value=next(self. _iter)\n  self. _dropped=True\n  return value\n  \n  \n  \nclass filterfalse:\n def __init__(self,predicate,iterable):\n \n  self. _iter=iter(iterable)\n  if predicate is None :\n   self. _predicate=bool\n  else :\n   self. _predicate=predicate\n   \n def __iter__(self):\n  return self\n def __next__(self):\n  next_elt=next(self. _iter)\n  while True :\n   if not self. _predicate(next_elt):\n    return next_elt\n   next_elt=next(self. _iter)\n   \nclass groupby:\n\n\n def __init__(self,iterable,key=None ):\n  if key is None :\n   key=lambda x:x\n  self. keyfunc=key\n  self. it=iter(iterable)\n  self. tgtkey=self. currkey=self. currvalue=object()\n def __iter__(self):\n  return self\n def __next__(self):\n  while self. currkey ==self. tgtkey:\n   self. currvalue=next(self. it)\n   self. currkey=self. keyfunc(self. currvalue)\n  self. tgtkey=self. currkey\n  return (self. currkey,self. _grouper(self. tgtkey))\n def _grouper(self,tgtkey):\n  while self. currkey ==tgtkey:\n   yield self. currvalue\n   self. currvalue=next(self. it)\n   self. currkey=self. keyfunc(self. currvalue)\n   \n   \n   \nclass islice:\n def __init__(self,iterable,*args):\n  s=slice(*args)\n  self. start,self. stop,self. step=s. start or 0,s. stop,s. step\n  if not isinstance(self. start,int):\n   raise ValueError(\"Start argument must be an integer\")\n  if self. stop !=None and not isinstance(self. stop,int):\n   raise ValueError(\"Stop argument must be an integer or None\")\n  if self. step is None :\n   self. step=1\n  if self. start <0 or (self. stop !=None and self. stop <0\n  )or self. step <=0:\n   raise ValueError(\"indices for islice() must be positive\")\n  self. it=iter(iterable)\n  self. donext=None\n  self. cnt=0\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  nextindex=self. start\n  if self. stop !=None and nextindex >=self. stop:\n   raise StopIteration\n  while self. cnt <=nextindex:\n   nextitem=next(self. it)\n   self. cnt +=1\n  self. start +=self. step\n  return nextitem\n  \nclass permutations:\n def __init__(self,iterable,r=None ):\n  self. pool=tuple(iterable)\n  self. n=len(self. pool)\n  self. r=self. n if r is None else r\n  self. indices=list(range(self. n))\n  self. cycles=list(range(self. n,self. n -self. r,-1))\n  self. zero=False\n  self. stop=False\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  indices=self. indices\n  if self. r >self. n:\n   raise StopIteration\n  if not self. zero:\n   self. zero=True\n   return tuple(self. pool[i]for i in indices[:self. r])\n   \n  i=self. r -1\n  while i >=0:\n   j=self. cycles[i]-1\n   if j >0:\n    self. cycles[i]=j\n    indices[i],indices[-j]=indices[-j],indices[i]\n    return tuple(self. pool[i]for i in indices[:self. r])\n   self. cycles[i]=len(indices)-i\n   n1=len(indices)-1\n   assert n1 >=0\n   num=indices[i]\n   for k in range(i,n1):\n    indices[k]=indices[k+1]\n   indices[n1]=num\n   i -=1\n  raise StopIteration\n  \n  \ndef product(*args,repeat=1):\n\n\n pools=[tuple(pool)for pool in args]*repeat\n result=[[]]\n for pool in pools:\n  result=[x+[y]for x in result for y in pool]\n for prod in result:\n  yield tuple(prod)\n  \n  \n  \n  \n  \n  \n  \n  \nclass _product:\n def __init__(self,*args,**kw):\n  if len(kw)>1:\n   raise TypeError(\"product() takes at most 1 argument (%d given)\"%\n   len(kw))\n  self. repeat=kw. get('repeat',1)\n  if not isinstance(self. repeat,int):\n   raise TypeError(\"integer argument expected, got %s\"%\n   type(self. repeat))\n  self. gears=[x for x in args]*self. repeat\n  self. num_gears=len(self. gears)\n  \n  self. indicies=[(0,len(self. gears[x]))\n  for x in range(0,self. num_gears)]\n  self. cont=True\n  self. zero=False\n  \n def roll_gears(self):\n \n \n \n  should_carry=True\n  for n in range(0,self. num_gears):\n   nth_gear=self. num_gears -n -1\n   if should_carry:\n    count,lim=self. indicies[nth_gear]\n    count +=1\n    if count ==lim and nth_gear ==0:\n     self. cont=False\n    if count ==lim:\n     should_carry=True\n     count=0\n    else :\n     should_carry=False\n    self. indicies[nth_gear]=(count,lim)\n   else :\n    break\n    \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  if self. zero:\n   raise StopIteration\n  if self. repeat >0:\n   if not self. cont:\n    raise StopIteration\n   l=[]\n   for x in range(0,self. num_gears):\n    index,limit=self. indicies[x]\n    print('itertools 353',self. gears,x,index)\n    l. append(self. gears[x][index])\n   self. roll_gears()\n   return tuple(l)\n  elif self. repeat ==0:\n   self. zero=True\n   return ()\n  else :\n   raise ValueError(\"repeat argument cannot be negative\")\n   \n   \n   \nclass repeat:\n def __init__(self,obj,times=None ):\n  self. _obj=obj\n  if times is not None :\n   range(times)\n   if times <0:\n    times=0\n  self. _times=times\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n \n  if self. _times is not None :\n   if self. _times <=0:\n    raise StopIteration()\n   self. _times -=1\n  return self. _obj\n  \n def __repr__(self):\n  if self. _times is not None :\n   return'repeat(%r, %r)'%(self. _obj,self. _times)\n  else :\n   return'repeat(%r)'%(self. _obj,)\n   \n def __len__(self):\n  if self. _times ==-1 or self. _times is None :\n   raise TypeError(\"len() of uniszed object\")\n  return self. _times\n  \n  \n  \nclass starmap(object):\n def __init__(self,function,iterable):\n  self. _func=function\n  self. _iter=iter(iterable)\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  t=next(self. _iter)\n  return self. _func(*t)\n  \n  \n  \nclass takewhile(object):\n def __init__(self,predicate,iterable):\n  self. _predicate=predicate\n  self. _iter=iter(iterable)\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  value=next(self. _iter)\n  if not self. _predicate(value):\n   raise StopIteration()\n  return value\n  \n  \n  \nclass TeeData(object):\n def __init__(self,iterator):\n  self. data=[]\n  self. _iter=iterator\n  \n def __getitem__(self,i):\n \n  while i >=len(self. data):\n   self. data. append(next(self. _iter))\n  return self. data[i]\n  \n  \nclass TeeObject(object):\n def __init__(self,iterable=None ,tee_data=None ):\n  if tee_data:\n   self. tee_data=tee_data\n   self. pos=0\n   \n  elif isinstance(iterable,TeeObject):\n   self. tee_data=iterable. tee_data\n   self. pos=iterable. pos\n  else :\n   self. tee_data=TeeData(iter(iterable))\n   self. pos=0\n   \n def __next__(self):\n  data=self. tee_data[self. pos]\n  self. pos +=1\n  return data\n  \n def __iter__(self):\n  return self\n  \n  \ndef tee(iterable,n=2):\n if isinstance(iterable,TeeObject):\n  return tuple([iterable]+\n  [TeeObject(tee_data=iterable. tee_data)for i in range(n -1)])\n tee_data=TeeData(iter(iterable))\n return tuple([TeeObject(tee_data=tee_data)for i in range(n)])\n \nclass zip_longest:\n def __init__(self,*args,fillvalue=None ):\n  self. args=[iter(arg)for arg in args]\n  self. fillvalue=fillvalue\n  self. units=len(args)\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  temp=[]\n  nb=0\n  for i in range(self. units):\n   try :\n    temp. append(next(self. args[i]))\n    nb +=1\n   except StopIteration:\n    temp. append(self. fillvalue)\n  if nb ==0:\n   raise StopIteration\n  return tuple(temp)\n", ["operator"]], "importlib._bootstrap": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n_CASE_INSENSITIVE_PLATFORMS='win','cygwin','darwin'\n\n\ndef _make_relax_case():\n if sys. platform. startswith(_CASE_INSENSITIVE_PLATFORMS):\n  def _relax_case():\n   ''\n   return b'PYTHONCASEOK'in _os. environ\n else :\n  def _relax_case():\n   ''\n   return False\n return _relax_case\n \n \n \ndef _w_long(x):\n ''\n\n\n\n \n x=int(x)\n int_bytes=[]\n int_bytes. append(x&0xFF)\n int_bytes. append((x >>8)&0xFF)\n int_bytes. append((x >>16)&0xFF)\n int_bytes. append((x >>24)&0xFF)\n return bytearray(int_bytes)\n \n \n \ndef _r_long(int_bytes):\n ''\n\n\n\n \n x=int_bytes[0]\n x |=int_bytes[1]<<8\n x |=int_bytes[2]<<16\n x |=int_bytes[3]<<24\n return x\n \n \ndef _path_join(*path_parts):\n ''\n new_parts=[]\n for part in path_parts:\n  if not part:\n   continue\n  new_parts. append(part)\n  if part[-1]not in path_separators:\n   new_parts. append(path_sep)\n return''. join(new_parts[:-1])\n \n \ndef _path_split(path):\n ''\n for x in reversed(path):\n  if x in path_separators:\n   sep=x\n   break\n else :\n  sep=path_sep\n front,_,tail=path. rpartition(sep)\n return front,tail\n \n \ndef _path_is_mode_type(path,mode):\n ''\n try :\n  stat_info=_os. stat(path)\n except OSError:\n  return False\n return (stat_info. st_mode&0o170000)==mode\n \n \n \ndef _path_isfile(path):\n ''\n return _path_is_mode_type(path,0o100000)\n \n \n \ndef _path_isdir(path):\n ''\n if not path:\n  path=_os. getcwd()\n return _path_is_mode_type(path,0o040000)\n \n \ndef _write_atomic(path,data,mode=0o666):\n ''\n\n \n \n path_tmp='{}.{}'. format(path,id(path))\n fd=_os. open(path_tmp,\n _os. O_EXCL |_os. O_CREAT |_os. O_WRONLY,mode&0o666)\n try :\n \n \n  with _io. FileIO(fd,'wb')as file:\n   file. write(data)\n  _os. replace(path_tmp,path)\n except OSError:\n  try :\n   _os. unlink(path_tmp)\n  except OSError:\n   pass\n  raise\n  \n  \ndef _wrap(new,old):\n ''\n for replace in ['__module__','__name__','__qualname__','__doc__']:\n  if hasattr(old,replace):\n   setattr(new,replace,getattr(old,replace))\n new. __dict__. update(old. __dict__)\n \n \n_code_type=type(_wrap. __code__)\n\n\ndef new_module(name):\n ''\n\n\n\n \n return type(_io)(name)\n \n \n \n \n \n_module_locks={}\n\n_blocking_on={}\n\n\nclass _DeadlockError(RuntimeError):\n pass\n \n \nclass _ModuleLock:\n ''\n\n\n \n \n def __init__(self,name):\n  self. lock=_thread. allocate_lock()\n  self. wakeup=_thread. allocate_lock()\n  self. name=name\n  self. owner=None\n  self. count=0\n  self. waiters=0\n  \n def has_deadlock(self):\n \n  me=_thread. get_ident()\n  tid=self. owner\n  while True :\n   lock=_blocking_on. get(tid)\n   if lock is None :\n    return False\n   tid=lock. owner\n   if tid ==me:\n    return True\n    \n def acquire(self):\n  ''\n\n\n\n  \n  tid=_thread. get_ident()\n  _blocking_on[tid]=self\n  try :\n   while True :\n    with self. lock:\n     if self. count ==0 or self. owner ==tid:\n      self. owner=tid\n      self. count +=1\n      return True\n     if self. has_deadlock():\n      raise _DeadlockError(\"deadlock detected by %r\"%self)\n     if self. wakeup. acquire(False ):\n      self. waiters +=1\n      \n    self. wakeup. acquire()\n    self. wakeup. release()\n  finally :\n   del _blocking_on[tid]\n   \n def release(self):\n  tid=_thread. get_ident()\n  with self. lock:\n   if self. owner !=tid:\n    raise RuntimeError(\"cannot release un-acquired lock\")\n   assert self. count >0\n   self. count -=1\n   if self. count ==0:\n    self. owner=None\n    if self. waiters:\n     self. waiters -=1\n     self. wakeup. release()\n     \n def __repr__(self):\n  return\"_ModuleLock(%r) at %d\"%(self. name,id(self))\n  \n  \nclass _DummyModuleLock:\n ''\n \n \n def __init__(self,name):\n  self. name=name\n  self. count=0\n  \n def acquire(self):\n  self. count +=1\n  return True\n  \n def release(self):\n  if self. count ==0:\n   raise RuntimeError(\"cannot release un-acquired lock\")\n  self. count -=1\n  \n def __repr__(self):\n  return\"_DummyModuleLock(%r) at %d\"%(self. name,id(self))\n  \n  \n  \n  \ndef _get_module_lock(name):\n ''\n\n \n lock=None\n try :\n  lock=_module_locks[name]()\n except KeyError:\n  pass\n if lock is None :\n  if _thread is None :\n   lock=_DummyModuleLock(name)\n  else :\n   lock=_ModuleLock(name)\n  def cb(_):\n   del _module_locks[name]\n  _module_locks[name]=_weakref. ref(lock,cb)\n return lock\n \ndef _lock_unlock_module(name):\n ''\n\n\n\n\n \n lock=_get_module_lock(name)\n _imp. release_lock()\n try :\n  lock. acquire()\n except _DeadlockError:\n \n \n  pass\n else :\n  lock. release()\n  \n  \n  \ndef _call_with_frames_removed(f,*args,**kwds):\n ''\n\n\n\n\n\n \n return f(*args,**kwds)\n \n \n \n \n\"\"\"Magic word to reject .pyc files generated by other Python versions.\nIt should change for each incompatible change to the bytecode.\n\nThe value of CR and LF is incorporated so if you ever read or write\na .pyc file in text mode the magic number will be wrong; also, the\nApple MPW compiler swaps their values, botching string constants.\n\nThe magic numbers must be spaced apart at least 2 values, as the\n-U interpeter flag will cause MAGIC+1 being used. They have been\nodd numbers for some time now.\n\nThere were a variety of old schemes for setting the magic number.\nThe current working scheme is to increment the previous value by\n10.\n\nStarting with the adoption of PEP 3147 in Python 3.2, every bump in magic\nnumber also includes a new \"magic tag\", i.e. a human readable string used\nto represent the magic number in __pycache__ directories.  When you change\nthe magic number, you must also set a new unique magic tag.  Generally this\ncan be named after the Python major version of the magic number bump, but\nit can really be anything, as long as it's different than anything else\nthat's come before.  The tags are included in the following table, starting\nwith Python 3.2a0.\n\nKnown values:\n Python 1.5:   20121\n Python 1.5.1: 20121\n    Python 1.5.2: 20121\n    Python 1.6:   50428\n    Python 2.0:   50823\n    Python 2.0.1: 50823\n    Python 2.1:   60202\n    Python 2.1.1: 60202\n    Python 2.1.2: 60202\n    Python 2.2:   60717\n    Python 2.3a0: 62011\n    Python 2.3a0: 62021\n    Python 2.3a0: 62011 (!)\n    Python 2.4a0: 62041\n    Python 2.4a3: 62051\n    Python 2.4b1: 62061\n    Python 2.5a0: 62071\n    Python 2.5a0: 62081 (ast-branch)\n    Python 2.5a0: 62091 (with)\n    Python 2.5a0: 62092 (changed WITH_CLEANUP opcode)\n    Python 2.5b3: 62101 (fix wrong code: for x, in ...)\n    Python 2.5b3: 62111 (fix wrong code: x += yield)\n    Python 2.5c1: 62121 (fix wrong lnotab with for loops and\n                         storing constants that should have been removed)\n    Python 2.5c2: 62131 (fix wrong code: for x, in ... in listcomp/genexp)\n    Python 2.6a0: 62151 (peephole optimizations and STORE_MAP opcode)\n    Python 2.6a1: 62161 (WITH_CLEANUP optimization)\n    Python 3000:   3000\n                   3010 (removed UNARY_CONVERT)\n                   3020 (added BUILD_SET)\n                   3030 (added keyword-only parameters)\n                   3040 (added signature annotations)\n                   3050 (print becomes a function)\n                   3060 (PEP 3115 metaclass syntax)\n                   3061 (string literals become unicode)\n                   3071 (PEP 3109 raise changes)\n                   3081 (PEP 3137 make __file__ and __name__ unicode)\n                   3091 (kill str8 interning)\n                   3101 (merge from 2.6a0, see 62151)\n                   3103 (__file__ points to source file)\n    Python 3.0a4: 3111 (WITH_CLEANUP optimization).\n    Python 3.0a5: 3131 (lexical exception stacking, including POP_EXCEPT)\n    Python 3.1a0: 3141 (optimize list, set and dict comprehensions:\n            change LIST_APPEND and SET_ADD, add MAP_ADD)\n    Python 3.1a0: 3151 (optimize conditional branches:\n            introduce POP_JUMP_IF_FALSE and POP_JUMP_IF_TRUE)\n    Python 3.2a0: 3160 (add SETUP_WITH)\n                  tag: cpython-32\n    Python 3.2a1: 3170 (add DUP_TOP_TWO, remove DUP_TOPX and ROT_FOUR)\n                  tag: cpython-32\n    Python 3.2a2  3180 (add DELETE_DEREF)\n    Python 3.3a0  3190 __class__ super closure changed\n    Python 3.3a0  3200 (__qualname__ added)\n                     3210 (added size modulo 2**32 to the pyc header)\n    Python 3.3a1  3220 (changed PEP 380 implementation)\n    Python 3.3a4  3230 (revert changes to implicit __class__ closure)\n\nMAGIC must change whenever the bytecode emitted by the compiler may no\nlonger be understood by older implementations of the eval loop (usually\ndue to the addition of new opcodes).\n\n\"\"\"\n_RAW_MAGIC_NUMBER=3230 |ord('\\r')<<16 |ord('\\n')<<24\n_MAGIC_BYTES=bytes(_RAW_MAGIC_NUMBER >>n&0xff for n in range(0,25,8))\n\n_PYCACHE='__pycache__'\n\nSOURCE_SUFFIXES=['.py']\n\nDEBUG_BYTECODE_SUFFIXES=['.pyc']\nOPTIMIZED_BYTECODE_SUFFIXES=['.pyo']\n\ndef cache_from_source(path,debug_override=None ):\n ''\n\n\n\n\n\n\n\n\n\n\n \n debug=not sys. flags. optimize if debug_override is None else debug_override\n if debug:\n  suffixes=DEBUG_BYTECODE_SUFFIXES\n else :\n  suffixes=OPTIMIZED_BYTECODE_SUFFIXES\n head,tail=_path_split(path)\n base_filename,sep,_=tail. partition('.')\n tag=sys. implementation. cache_tag\n if tag is None :\n  raise NotImplementedError('sys.implementation.cache_tag is None')\n filename=''. join([base_filename,sep,tag,suffixes[0]])\n return _path_join(head,_PYCACHE,filename)\n \n \ndef source_from_cache(path):\n ''\n\n\n\n\n\n\n \n if sys. implementation. cache_tag is None :\n  raise NotImplementedError('sys.implementation.cache_tag is None')\n head,pycache_filename=_path_split(path)\n head,pycache=_path_split(head)\n if pycache !=_PYCACHE:\n  raise ValueError('{} not bottom-level directory in '\n  '{!r}'. format(_PYCACHE,path))\n if pycache_filename. count('.')!=2:\n  raise ValueError('expected only 2 dots in '\n  '{!r}'. format(pycache_filename))\n base_filename=pycache_filename. partition('.')[0]\n return _path_join(head,base_filename+SOURCE_SUFFIXES[0])\n \n \ndef _get_sourcefile(bytecode_path):\n ''\n\n\n\n\n \n if len(bytecode_path)==0:\n  return None\n rest,_,extension=bytecode_path. rpartition('.')\n if not rest or extension. lower()[-3:-1]!='py':\n  return bytecode_path\n try :\n  source_path=source_from_cache(bytecode_path)\n except (NotImplementedError,ValueError):\n  source_path=bytecode_path[:-1]\n return source_path if _path_isfile(source_path)else bytecode_path\n \n \ndef _verbose_message(message,*args,verbosity=1):\n ''\n if sys. flags. verbose >=verbosity:\n  if not message. startswith(('#','import ')):\n   message='# '+message\n  print(message. format(*args),file=sys. stderr)\n  \n  \ndef set_package(fxn):\n ''\n def set_package_wrapper(*args,**kwargs):\n  module=fxn(*args,**kwargs)\n  if getattr(module,'__package__',None )is None :\n   module. __package__=module. __name__\n   if not hasattr(module,'__path__'):\n    module. __package__=module. __package__. rpartition('.')[0]\n  return module\n _wrap(set_package_wrapper,fxn)\n return set_package_wrapper\n \n \ndef set_loader(fxn):\n ''\n def set_loader_wrapper(self,*args,**kwargs):\n  module=fxn(self,*args,**kwargs)\n  if not hasattr(module,'__loader__'):\n   module. __loader__=self\n  return module\n _wrap(set_loader_wrapper,fxn)\n return set_loader_wrapper\n \n \ndef module_for_loader(fxn):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n def module_for_loader_wrapper(self,fullname,*args,**kwargs):\n  module=sys. modules. get(fullname)\n  is_reload=module is not None\n  if not is_reload:\n  \n  \n  \n   module=new_module(fullname)\n   \n   \n   module. __initializing__=True\n   sys. modules[fullname]=module\n   module. __loader__=self\n   try :\n    is_package=self. is_package(fullname)\n   except (ImportError,AttributeError):\n    pass\n   else :\n    if is_package:\n     module. __package__=fullname\n    else :\n     module. __package__=fullname. rpartition('.')[0]\n  else :\n   module. __initializing__=True\n  try :\n  \n   return fxn(self,module,*args,**kwargs)\n  except :\n   if not is_reload:\n    del sys. modules[fullname]\n   raise\n  finally :\n   module. __initializing__=False\n _wrap(module_for_loader_wrapper,fxn)\n return module_for_loader_wrapper\n \n \ndef _check_name(method):\n ''\n\n\n\n\n\n \n def _check_name_wrapper(self,name=None ,*args,**kwargs):\n  if name is None :\n   name=self. name\n  elif self. name !=name:\n   raise ImportError(\"loader cannot handle %s\"%name,name=name)\n  return method(self,name,*args,**kwargs)\n _wrap(_check_name_wrapper,method)\n return _check_name_wrapper\n \n \ndef _requires_builtin(fxn):\n ''\n def _requires_builtin_wrapper(self,fullname):\n  if fullname not in sys. builtin_module_names:\n   raise ImportError(\"{} is not a built-in module\". format(fullname),\n   name=fullname)\n  return fxn(self,fullname)\n _wrap(_requires_builtin_wrapper,fxn)\n return _requires_builtin_wrapper\n \n \ndef _requires_frozen(fxn):\n ''\n def _requires_frozen_wrapper(self,fullname):\n  if not _imp. is_frozen(fullname):\n   raise ImportError(\"{} is not a frozen module\". format(fullname),\n   name=fullname)\n  return fxn(self,fullname)\n _wrap(_requires_frozen_wrapper,fxn)\n return _requires_frozen_wrapper\n \n \ndef _find_module_shim(self,fullname):\n ''\n \n \n \n \n loader,portions=self. find_loader(fullname)\n if loader is None and len(portions):\n  msg=\"Not importing directory {}: missing __init__\"\n  _warnings. warn(msg. format(portions[0]),ImportWarning)\n return loader\n \n \n \n \n \n \nclass BuiltinImporter:\n\n ''\n\n\n\n\n \n \n @classmethod\n def module_repr(cls,module):\n  return\"<module '{}' (built-in)>\". format(module. __name__)\n  \n @classmethod\n def find_module(cls,fullname,path=None ):\n  ''\n\n\n\n  \n  if path is not None :\n   return None\n  return cls if _imp. is_builtin(fullname)else None\n  \n @classmethod\n @set_package\n @set_loader\n @_requires_builtin\n def load_module(cls,fullname):\n  ''\n  is_reload=fullname in sys. modules\n  try :\n   return _call_with_frames_removed(_imp. init_builtin,fullname)\n  except :\n   if not is_reload and fullname in sys. modules:\n    del sys. modules[fullname]\n   raise\n   \n @classmethod\n @_requires_builtin\n def get_code(cls,fullname):\n  ''\n  return None\n  \n @classmethod\n @_requires_builtin\n def get_source(cls,fullname):\n  ''\n  return None\n  \n @classmethod\n @_requires_builtin\n def is_package(cls,fullname):\n  ''\n  return False\n  \n  \nclass FrozenImporter:\n\n ''\n\n\n\n\n \n \n @classmethod\n def module_repr(cls,m):\n  return\"<module '{}' (frozen)>\". format(m. __name__)\n  \n @classmethod\n def find_module(cls,fullname,path=None ):\n  ''\n  return cls if _imp. is_frozen(fullname)else None\n  \n @classmethod\n @set_package\n @set_loader\n @_requires_frozen\n def load_module(cls,fullname):\n  ''\n  is_reload=fullname in sys. modules\n  try :\n   m=_call_with_frames_removed(_imp. init_frozen,fullname)\n   \n   del m. __file__\n   return m\n  except :\n   if not is_reload and fullname in sys. modules:\n    del sys. modules[fullname]\n   raise\n   \n @classmethod\n @_requires_frozen\n def get_code(cls,fullname):\n  ''\n  return _imp. get_frozen_object(fullname)\n  \n @classmethod\n @_requires_frozen\n def get_source(cls,fullname):\n  ''\n  return None\n  \n @classmethod\n @_requires_frozen\n def is_package(cls,fullname):\n  ''\n  return _imp. is_frozen_package(fullname)\n  \n  \nclass WindowsRegistryFinder:\n\n ''\n \n \n REGISTRY_KEY=(\n \"Software\\\\Python\\\\PythonCore\\\\{sys_version}\"\n \"\\\\Modules\\\\{fullname}\")\n REGISTRY_KEY_DEBUG=(\n \"Software\\\\Python\\\\PythonCore\\\\{sys_version}\"\n \"\\\\Modules\\\\{fullname}\\\\Debug\")\n DEBUG_BUILD=False\n \n @classmethod\n def _open_registry(cls,key):\n  try :\n   return _winreg. OpenKey(_winreg. HKEY_CURRENT_USER,key)\n  except WindowsError:\n   return _winreg. OpenKey(_winreg. HKEY_LOCAL_MACHINE,key)\n   \n @classmethod\n def _search_registry(cls,fullname):\n  if cls. DEBUG_BUILD:\n   registry_key=cls. REGISTRY_KEY_DEBUG\n  else :\n   registry_key=cls. REGISTRY_KEY\n  key=registry_key. format(fullname=fullname,\n  sys_version=sys. version[:3])\n  try :\n   with cls. _open_registry(key)as hkey:\n    filepath=_winreg. QueryValue(hkey,\"\")\n  except WindowsError:\n   return None\n  return filepath\n  \n @classmethod\n def find_module(cls,fullname,path=None ):\n  ''\n  filepath=cls. _search_registry(fullname)\n  if filepath is None :\n   return None\n  try :\n   _os. stat(filepath)\n  except OSError:\n   return None\n  for loader,suffixes in _get_supported_file_loaders():\n   if filepath. endswith(tuple(suffixes)):\n    return loader(fullname,filepath)\n    \n    \nclass _LoaderBasics:\n\n ''\n \n \n def is_package(self,fullname):\n  ''\n  \n  filename=_path_split(self. get_filename(fullname))[1]\n  filename_base=filename. rsplit('.',1)[0]\n  tail_name=fullname. rpartition('.')[2]\n  return filename_base =='__init__'and tail_name !='__init__'\n  \n def _bytes_from_bytecode(self,fullname,data,bytecode_path,source_stats):\n  ''\n\n\n\n\n  \n  magic=data[:4]\n  raw_timestamp=data[4:8]\n  raw_size=data[8:12]\n  if magic !=_MAGIC_BYTES:\n   msg='bad magic number in {!r}: {!r}'. format(fullname,magic)\n   _verbose_message(msg)\n   raise ImportError(msg,name=fullname,path=bytecode_path)\n  elif len(raw_timestamp)!=4:\n   message='bad timestamp in {}'. format(fullname)\n   _verbose_message(message)\n   raise EOFError(message)\n  elif len(raw_size)!=4:\n   message='bad size in {}'. format(fullname)\n   _verbose_message(message)\n   raise EOFError(message)\n  if source_stats is not None :\n   try :\n    source_mtime=int(source_stats['mtime'])\n   except KeyError:\n    pass\n   else :\n    if _r_long(raw_timestamp)!=source_mtime:\n     message='bytecode is stale for {}'. format(fullname)\n     _verbose_message(message)\n     raise ImportError(message,name=fullname,\n     path=bytecode_path)\n   try :\n    source_size=source_stats['size']&0xFFFFFFFF\n   except KeyError:\n    pass\n   else :\n    if _r_long(raw_size)!=source_size:\n     raise ImportError(\n     \"bytecode is stale for {}\". format(fullname),\n     name=fullname,path=bytecode_path)\n     \n     \n  return data[12:]\n  \n @module_for_loader\n def _load_module(self,module,*,sourceless=False ):\n  ''\n  \n  name=module. __name__\n  code_object=self. get_code(name)\n  module. __file__=self. get_filename(name)\n  if not sourceless:\n   try :\n    module. __cached__=cache_from_source(module. __file__)\n   except NotImplementedError:\n    module. __cached__=module. __file__\n  else :\n   module. __cached__=module. __file__\n  module. __package__=name\n  if self. is_package(name):\n   module. __path__=[_path_split(module. __file__)[0]]\n  else :\n   module. __package__=module. __package__. rpartition('.')[0]\n  module. __loader__=self\n  _call_with_frames_removed(exec,code_object,module. __dict__)\n  return module\n  \n  \nclass SourceLoader(_LoaderBasics):\n\n def path_mtime(self,path):\n  ''\n\n  \n  raise NotImplementedError\n  \n def path_stats(self,path):\n  ''\n\n\n\n\n\n\n\n  \n  return {'mtime':self. path_mtime(path)}\n  \n def _cache_bytecode(self,source_path,cache_path,data):\n  ''\n\n\n\n\n  \n  \n  return self. set_data(cache_path,data)\n  \n def set_data(self,path,data):\n  ''\n\n\n\n  \n  raise NotImplementedError\n  \n  \n def get_source(self,fullname):\n  ''\n  import tokenize\n  path=self. get_filename(fullname)\n  try :\n   source_bytes=self. get_data(path)\n  except IOError as exc:\n   raise ImportError(\"source not available through get_data()\",\n   name=fullname)from exc\n  readsource=_io. BytesIO(source_bytes). readline\n  try :\n   encoding=tokenize. detect_encoding(readsource)\n  except SyntaxError as exc:\n   raise ImportError(\"Failed to detect encoding\",\n   name=fullname)from exc\n  newline_decoder=_io. IncrementalNewlineDecoder(None ,True )\n  try :\n   return newline_decoder. decode(source_bytes. decode(encoding[0]))\n  except UnicodeDecodeError as exc:\n   raise ImportError(\"Failed to decode source file\",\n   name=fullname)from exc\n   \n def get_code(self,fullname):\n  ''\n\n\n\n\n  \n  source_path=self. get_filename(fullname)\n  source_mtime=None\n  try :\n   bytecode_path=cache_from_source(source_path)\n  except NotImplementedError:\n   bytecode_path=None\n  else :\n   try :\n    st=self. path_stats(source_path)\n   except NotImplementedError:\n    pass\n   else :\n    source_mtime=int(st['mtime'])\n    try :\n     data=self. get_data(bytecode_path)\n    except IOError:\n     pass\n    else :\n     try :\n      bytes_data=self. _bytes_from_bytecode(fullname,data,\n      bytecode_path,\n      st)\n     except (ImportError,EOFError):\n      pass\n     else :\n      _verbose_message('{} matches {}',bytecode_path,\n      source_path)\n      found=marshal. loads(bytes_data)\n      if isinstance(found,_code_type):\n       _imp. _fix_co_filename(found,source_path)\n       _verbose_message('code object from {}',\n       bytecode_path)\n       return found\n      else :\n       msg=\"Non-code object in {}\"\n       raise ImportError(msg. format(bytecode_path),\n       name=fullname,path=bytecode_path)\n  source_bytes=self. get_data(source_path)\n  code_object=_call_with_frames_removed(compile,\n  source_bytes,source_path,'exec',\n  dont_inherit=True )\n  _verbose_message('code object from {}',source_path)\n  if (not sys. dont_write_bytecode and bytecode_path is not None and\n  source_mtime is not None ):\n   data=bytearray(_MAGIC_BYTES)\n   data. extend(_w_long(source_mtime))\n   data. extend(_w_long(len(source_bytes)))\n   data. extend(marshal. dumps(code_object))\n   try :\n    self. _cache_bytecode(source_path,bytecode_path,data)\n    _verbose_message('wrote {!r}',bytecode_path)\n   except NotImplementedError:\n    pass\n  return code_object\n  \n def load_module(self,fullname):\n  ''\n\n\n\n\n\n  \n  return self. _load_module(fullname)\n  \n  \nclass FileLoader:\n\n ''\n \n \n def __init__(self,fullname,path):\n  ''\n  \n  self. name=fullname\n  self. path=path\n  \n @_check_name\n def load_module(self,fullname):\n  ''\n  \n  \n  return super(FileLoader,self). load_module(fullname)\n  \n @_check_name\n def get_filename(self,fullname):\n  ''\n  return self. path\n  \n def get_data(self,path):\n  ''\n  with _io. FileIO(path,'r')as file:\n   return file. read()\n   \n   \nclass SourceFileLoader(FileLoader,SourceLoader):\n\n ''\n \n def path_stats(self,path):\n  ''\n  st=_os. stat(path)\n  return {'mtime':st. st_mtime,'size':st. st_size}\n  \n def _cache_bytecode(self,source_path,bytecode_path,data):\n \n  try :\n   mode=_os. stat(source_path). st_mode\n  except OSError:\n   mode=0o666\n   \n   \n  mode |=0o200\n  return self. set_data(bytecode_path,data,_mode=mode)\n  \n def set_data(self,path,data,*,_mode=0o666):\n  ''\n  parent,filename=_path_split(path)\n  path_parts=[]\n  \n  while parent and not _path_isdir(parent):\n   parent,part=_path_split(parent)\n   path_parts. append(part)\n   \n  for part in reversed(path_parts):\n   parent=_path_join(parent,part)\n   try :\n    _os. mkdir(parent)\n   except FileExistsError:\n   \n    continue\n   except OSError as exc:\n   \n   \n    _verbose_message('could not create {!r}: {!r}',parent,exc)\n    return\n  try :\n   _write_atomic(path,data,_mode)\n   _verbose_message('created {!r}',path)\n  except OSError as exc:\n  \n   _verbose_message('could not create {!r}: {!r}',path,exc)\n   \n   \nclass SourcelessFileLoader(FileLoader,_LoaderBasics):\n\n ''\n \n def load_module(self,fullname):\n  return self. _load_module(fullname,sourceless=True )\n  \n def get_code(self,fullname):\n  path=self. get_filename(fullname)\n  data=self. get_data(path)\n  bytes_data=self. _bytes_from_bytecode(fullname,data,path,None )\n  found=marshal. loads(bytes_data)\n  if isinstance(found,_code_type):\n   _verbose_message('code object from {!r}',path)\n   return found\n  else :\n   raise ImportError(\"Non-code object in {}\". format(path),\n   name=fullname,path=path)\n   \n def get_source(self,fullname):\n  ''\n  return None\n  \n  \n  \nEXTENSION_SUFFIXES=[]\n\n\nclass ExtensionFileLoader:\n\n ''\n\n\n\n \n \n def __init__(self,name,path):\n  self. name=name\n  self. path=path\n  \n @_check_name\n @set_package\n @set_loader\n def load_module(self,fullname):\n  ''\n  is_reload=fullname in sys. modules\n  try :\n   module=_call_with_frames_removed(_imp. load_dynamic,\n   fullname,self. path)\n   _verbose_message('extension module loaded from {!r}',self. path)\n   if self. is_package(fullname)and not hasattr(module,'__path__'):\n    module. __path__=[_path_split(self. path)[0]]\n   return module\n  except :\n   if not is_reload and fullname in sys. modules:\n    del sys. modules[fullname]\n   raise\n   \n def is_package(self,fullname):\n  ''\n  file_name=_path_split(self. path)[1]\n  return any(file_name =='__init__'+suffix\n  for suffix in EXTENSION_SUFFIXES)\n  \n def get_code(self,fullname):\n  ''\n  return None\n  \n def get_source(self,fullname):\n  ''\n  return None\n  \n  \nclass _NamespacePath:\n ''\n\n\n\n \n \n def __init__(self,name,path,path_finder):\n  self. _name=name\n  self. _path=path\n  self. _last_parent_path=tuple(self. _get_parent_path())\n  self. _path_finder=path_finder\n  \n def _find_parent_path_names(self):\n  ''\n  parent,dot,me=self. _name. rpartition('.')\n  if dot =='':\n  \n   return'sys','path'\n   \n   \n  return parent,'__path__'\n  \n def _get_parent_path(self):\n  parent_module_name,path_attr_name=self. _find_parent_path_names()\n  return getattr(sys. modules[parent_module_name],path_attr_name)\n  \n def _recalculate(self):\n \n  parent_path=tuple(self. _get_parent_path())\n  if parent_path !=self. _last_parent_path:\n   loader,new_path=self. _path_finder(self. _name,parent_path)\n   \n   \n   if loader is None :\n    self. _path=new_path\n   self. _last_parent_path=parent_path\n  return self. _path\n  \n def __iter__(self):\n  return iter(self. _recalculate())\n  \n def __len__(self):\n  return len(self. _recalculate())\n  \n def __repr__(self):\n  return\"_NamespacePath({!r})\". format(self. _path)\n  \n def __contains__(self,item):\n  return item in self. _recalculate()\n  \n def append(self,item):\n  self. _path. append(item)\n  \n  \nclass NamespaceLoader:\n def __init__(self,name,path,path_finder):\n  self. _path=_NamespacePath(name,path,path_finder)\n  \n @classmethod\n def module_repr(cls,module):\n  return\"<module '{}' (namespace)>\". format(module. __name__)\n  \n @module_for_loader\n def load_module(self,module):\n  ''\n  _verbose_message('namespace module loaded with path {!r}',self. _path)\n  module. __path__=self. _path\n  return module\n  \n  \n  \n  \nclass PathFinder:\n\n ''\n \n @classmethod\n def invalidate_caches(cls):\n  ''\n  \n  for finder in sys. path_importer_cache. values():\n   if hasattr(finder,'invalidate_caches'):\n    finder. invalidate_caches()\n    \n @classmethod\n def _path_hooks(cls,path):\n  ''\n\n\n\n  \n  if not sys. path_hooks:\n   _warnings. warn('sys.path_hooks is empty',ImportWarning)\n  for hook in sys. path_hooks:\n   try :\n    return hook(path)\n   except ImportError:\n    continue\n  else :\n   return None\n   \n @classmethod\n def _path_importer_cache(cls,path):\n  ''\n\n\n\n\n  \n  if path =='':\n   path='.'\n  try :\n   finder=sys. path_importer_cache[path]\n  except KeyError:\n   finder=cls. _path_hooks(path)\n   sys. path_importer_cache[path]=finder\n  return finder\n  \n @classmethod\n def _get_loader(cls,fullname,path):\n  ''\n  \n  \n  namespace_path=[]\n  for entry in path:\n   if not isinstance(entry,(str,bytes)):\n    continue\n   finder=cls. _path_importer_cache(entry)\n   if finder is not None :\n    if hasattr(finder,'find_loader'):\n     loader,portions=finder. find_loader(fullname)\n    else :\n     loader=finder. find_module(fullname)\n     portions=[]\n    if loader is not None :\n    \n     return loader,namespace_path\n     \n     \n     \n     \n    namespace_path. extend(portions)\n  else :\n   return None ,namespace_path\n   \n @classmethod\n def find_module(cls,fullname,path=None ):\n  ''\n  \n  if path is None :\n   path=sys. path\n  loader,namespace_path=cls. _get_loader(fullname,path)\n  if loader is not None :\n   return loader\n  else :\n   if namespace_path:\n   \n   \n    return NamespaceLoader(fullname,namespace_path,cls. _get_loader)\n   else :\n    return None\n    \n    \nclass FileFinder:\n\n ''\n\n\n\n\n \n \n def __init__(self,path,*loader_details):\n  ''\n\n  \n  loaders=[]\n  for loader,suffixes in loader_details:\n   loaders. extend((suffix,loader)for suffix in suffixes)\n  self. _loaders=loaders\n  \n  self. path=path or'.'\n  self. _path_mtime=-1\n  self. _path_cache=set()\n  self. _relaxed_path_cache=set()\n  \n def invalidate_caches(self):\n  ''\n  self. _path_mtime=-1\n  \n find_module=_find_module_shim\n \n def find_loader(self,fullname):\n  ''\n  \n  is_namespace=False\n  tail_module=fullname. rpartition('.')[2]\n  try :\n   mtime=_os. stat(self. path). st_mtime\n  except OSError:\n   mtime=-1\n  if mtime !=self. _path_mtime:\n   self. _fill_cache()\n   self. _path_mtime=mtime\n   \n  if _relax_case():\n   cache=self. _relaxed_path_cache\n   cache_module=tail_module. lower()\n  else :\n   cache=self. _path_cache\n   cache_module=tail_module\n   \n  if cache_module in cache:\n   base_path=_path_join(self. path,tail_module)\n   if _path_isdir(base_path):\n    for suffix,loader in self. _loaders:\n     init_filename='__init__'+suffix\n     full_path=_path_join(base_path,init_filename)\n     if _path_isfile(full_path):\n      return (loader(fullname,full_path),[base_path])\n    else :\n    \n    \n     is_namespace=True\n     \n  for suffix,loader in self. _loaders:\n   full_path=_path_join(self. path,tail_module+suffix)\n   _verbose_message('trying {}'. format(full_path),verbosity=2)\n   if cache_module+suffix in cache:\n    if _path_isfile(full_path):\n     return (loader(fullname,full_path),[])\n  if is_namespace:\n   _verbose_message('possible namespace for {}'. format(base_path))\n   return (None ,[base_path])\n  return (None ,[])\n  \n def _fill_cache(self):\n  ''\n  path=self. path\n  try :\n   contents=_os. listdir(path)\n  except (FileNotFoundError,PermissionError,NotADirectoryError):\n  \n  \n   contents=[]\n   \n   \n  if not sys. platform. startswith('win'):\n   self. _path_cache=set(contents)\n  else :\n  \n  \n  \n  \n  \n   lower_suffix_contents=set()\n   for item in contents:\n    name,dot,suffix=item. partition('.')\n    if dot:\n     new_name='{}.{}'. format(name,suffix. lower())\n    else :\n     new_name=name\n    lower_suffix_contents. add(new_name)\n   self. _path_cache=lower_suffix_contents\n  if sys. platform. startswith(_CASE_INSENSITIVE_PLATFORMS):\n   self. _relaxed_path_cache=set(fn. lower()for fn in contents)\n   \n @classmethod\n def path_hook(cls,*loader_details):\n  ''\n\n\n\n\n\n\n  \n  def path_hook_for_FileFinder(path):\n   ''\n   if not _path_isdir(path):\n    raise ImportError(\"only directories are supported\",path=path)\n   return cls(path,*loader_details)\n   \n  return path_hook_for_FileFinder\n  \n def __repr__(self):\n  return\"FileFinder(%r)\"%(self. path,)\n  \n  \n  \n  \nclass _ImportLockContext:\n\n ''\n \n def __enter__(self):\n  ''\n  _imp. acquire_lock()\n  \n def __exit__(self,exc_type,exc_value,exc_traceback):\n  ''\n  _imp. release_lock()\n  \n  \ndef _resolve_name(name,package,level):\n ''\n bits=package. rsplit('.',level -1)\n if len(bits)<level:\n  raise ValueError('attempted relative import beyond top-level package')\n base=bits[0]\n return'{}.{}'. format(base,name)if name else base\n \n \ndef _find_module(name,path):\n ''\n if not sys. meta_path:\n  _warnings. warn('sys.meta_path is empty',ImportWarning)\n for finder in sys. meta_path:\n \n \n  loader=finder. find_module(name,path)\n  \n  if loader is not None :\n  \n   if name not in sys. modules:\n    return loader\n   else :\n    return sys. modules[name]. __loader__\n else :\n  return None\n  \n  \ndef _sanity_check(name,package,level):\n ''\n if not isinstance(name,str):\n  raise TypeError(\"module name must be str, not {}\". format(type(name)))\n if level <0:\n  raise ValueError('level must be >= 0')\n if package:\n  if not isinstance(package,str):\n   raise TypeError(\"__package__ not set to a string\")\n  elif package not in sys. modules:\n   msg=(\"Parent module {!r} not loaded, cannot perform relative \"\n   \"import\")\n   raise SystemError(msg. format(package))\n if not name and level ==0:\n  raise ValueError(\"Empty module name\")\n  \n  \n_ERR_MSG='No module named {!r}'\n\ndef _find_and_load_unlocked(name,import_):\n path=None\n parent=name. rpartition('.')[0]\n if parent:\n  if parent not in sys. modules:\n   _call_with_frames_removed(import_,parent)\n   \n  if name in sys. modules:\n   return sys. modules[name]\n   \n  parent_module=sys. modules[parent]\n  try :\n   path=parent_module. __path__\n  except AttributeError:\n   msg=(_ERR_MSG+'; {} is not a package'). format(name,parent)\n   raise ImportError(msg,name=name)\n loader=_find_module(name,path)\n if loader is None :\n  exc=ImportError(_ERR_MSG. format(name),name=name)\n  \n  \n  exc. _not_found=True\n  raise exc\n elif name not in sys. modules:\n \n  loader. load_module(name)\n  _verbose_message('import {!r} # {!r}',name,loader)\n  \n module=sys. modules[name]\n if parent:\n \n  parent_module=sys. modules[parent]\n  setattr(parent_module,name. rpartition('.')[2],module)\n  \n if getattr(module,'__package__',None )is None :\n  try :\n   module. __package__=module. __name__\n   if not hasattr(module,'__path__'):\n    module. __package__=module. __package__. rpartition('.')[0]\n  except AttributeError:\n   pass\n   \n if not hasattr(module,'__loader__'):\n  try :\n   module. __loader__=loader\n  except AttributeError:\n   pass\n return module\n \n \ndef _find_and_load(name,import_):\n ''\n try :\n  lock=_get_module_lock(name)\n finally :\n  _imp. release_lock()\n lock. acquire()\n try :\n  return _find_and_load_unlocked(name,import_)\n finally :\n  lock. release()\n  \n  \ndef _gcd_import(name,package=None ,level=0):\n ''\n\n\n\n\n\n\n \n _sanity_check(name,package,level)\n if level >0:\n  name=_resolve_name(name,package,level)\n _imp. acquire_lock()\n if name not in sys. modules:\n  return _find_and_load(name,_gcd_import)\n module=sys. modules[name]\n if module is None :\n  _imp. release_lock()\n  message=(\"import of {} halted; \"\n  \"None in sys.modules\". format(name))\n  raise ImportError(message,name=name)\n _lock_unlock_module(name)\n return module\n \ndef _handle_fromlist(module,fromlist,import_):\n ''\n\n\n\n\n\n \n \n \n if hasattr(module,'__path__'):\n  if'*'in fromlist:\n   fromlist=list(fromlist)\n   fromlist. remove('*')\n   if hasattr(module,'__all__'):\n    fromlist. extend(module. __all__)\n  for x in fromlist:\n   if not hasattr(module,x):\n    from_name='{}.{}'. format(module. __name__,x)\n    try :\n     _call_with_frames_removed(import_,from_name)\n    except ImportError as exc:\n    \n    \n    \n    \n    \n     if getattr(exc,'_not_found',False ):\n      if exc. name ==from_name:\n       continue\n     raise\n return module\n \n \ndef _calc___package__(globals):\n ''\n\n\n\n\n \n package=globals. get('__package__')\n if package is None :\n  package=globals['__name__']\n  if'__path__'not in globals:\n   package=package. rpartition('.')[0]\n return package\n \n \ndef _get_supported_file_loaders():\n ''\n\n\n \n extensions=ExtensionFileLoader,_imp. extension_suffixes()\n source=SourceFileLoader,SOURCE_SUFFIXES\n bytecode=SourcelessFileLoader,BYTECODE_SUFFIXES\n return [extensions,source,bytecode]\n \n \ndef __import__(name,globals=None ,locals=None ,fromlist=(),level=0,blocking=True ):\n ''\n\n\n\n\n\n\n\n\n \n if level ==0:\n  module=_gcd_import(name)\n else :\n  globals_=globals if globals is not None else {}\n  package=_calc___package__(globals_)\n  module=_gcd_import(name,package,level)\n if not fromlist:\n \n \n  if level ==0:\n   return _gcd_import(name. partition('.')[0])\n  elif not name:\n   return module\n  else :\n  \n  \n   cut_off=len(name)-len(name. partition('.')[0])\n   \n   \n   return sys. modules[module. __name__[:len(module. __name__)-cut_off]]\n else :\n  return _handle_fromlist(module,fromlist,_gcd_import)\n  \n  \n  \ndef _setup(sys_module,_imp_module):\n ''\n\n\n\n\n\n \n \n global _imp,sys,BYTECODE_SUFFIXES\n _imp=_imp_module\n sys=sys_module\n \n if sys. flags. optimize:\n  BYTECODE_SUFFIXES=OPTIMIZED_BYTECODE_SUFFIXES\n else :\n  BYTECODE_SUFFIXES=DEBUG_BYTECODE_SUFFIXES\n  \n module_type=type(sys)\n for name,module in sys. modules. items():\n  if isinstance(module,module_type):\n   if not hasattr(module,'__loader__'):\n    if name in sys. builtin_module_names:\n     module. __loader__=BuiltinImporter\n     \n     \n     \n     \n self_module=sys. modules[__name__]\n for builtin_name in ('_io','_warnings','builtins'):\n  if builtin_name not in sys. modules:\n   builtin_module=BuiltinImporter. load_module(builtin_name)\n  else :\n   builtin_module=sys. modules[builtin_name]\n  setattr(self_module,builtin_name,builtin_module)\n  \n os_details=('posix',['/']),('nt',['\\\\','/']),('os2',['\\\\','/'])\n for builtin_os,path_separators in os_details:\n \n  assert all(len(sep)==1 for sep in path_separators)\n  path_sep=path_separators[0]\n  if builtin_os in sys. modules:\n   os_module=sys. modules[builtin_os]\n   break\n  else :\n   try :\n    os_module=BuiltinImporter. load_module(builtin_os)\n    \n    if builtin_os =='os2'and'EMX GCC'in sys. version:\n     path_sep=path_separators[1]\n    break\n   except ImportError:\n    continue\n else :\n  raise ImportError('importlib requires posix or nt')\n  \n try :\n  thread_module=BuiltinImporter. load_module('_thread')\n except ImportError:\n \n  thread_module=None\n weakref_module=BuiltinImporter. load_module('_weakref')\n \n if builtin_os =='nt':\n  winreg_module=BuiltinImporter. load_module('winreg')\n  setattr(self_module,'_winreg',winreg_module)\n  \n setattr(self_module,'_os',os_module)\n setattr(self_module,'_thread',thread_module)\n setattr(self_module,'_weakref',weakref_module)\n setattr(self_module,'path_sep',path_sep)\n setattr(self_module,'path_separators',set(path_separators))\n \n setattr(self_module,'_relax_case',_make_relax_case())\n EXTENSION_SUFFIXES. extend(_imp. extension_suffixes())\n if builtin_os =='nt':\n  SOURCE_SUFFIXES. append('.pyw')\n  if'_d.pyd'in EXTENSION_SUFFIXES:\n   WindowsRegistryFinder. DEBUG_BUILD=True\n   \ndef _install(sys_module,_imp_module):\n ''\n _setup(sys_module,_imp_module)\n supported_loaders=_get_supported_file_loaders()\n sys. path_hooks. extend([FileFinder. path_hook(*supported_loaders)])\n sys. meta_path. append(BuiltinImporter)\n sys. meta_path. append(FrozenImporter)\n if _os. __name__ =='nt':\n  sys. meta_path. append(WindowsRegistryFinder)\n sys. meta_path. append(PathFinder)\n", ["tokenize"]], "importlib": [".py", "''\n__all__=['__import__','import_module','invalidate_caches']\n\n\n\n\n\n\n\n\n\nimport _imp\nimport sys\n\nfrom . import machinery\nfrom . import _bootstrap\n_bootstrap. _setup(sys,_imp)\n\n\n_w_long=_bootstrap. _w_long\n_r_long=_bootstrap. _r_long\n\n\n\n\n\n\nfrom . _bootstrap import __import__\n\n\ndef invalidate_caches():\n ''\n \n for finder in sys. meta_path:\n  if hasattr(finder,'invalidate_caches'):\n   finder. invalidate_caches()\n   \n   \ndef find_loader(name,path=None ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n try :\n  loader=sys. modules[name]. __loader__\n  if loader is None :\n   raise ValueError('{}.__loader__ is None'. format(name))\n  else :\n   return loader\n except KeyError:\n  pass\n return _bootstrap. _find_module(name,path)\n \n \ndef import_module(name,package=None ):\n ''\n\n\n\n\n\n \n level=0\n if name. startswith('.'):\n  if not package:\n   raise TypeError(\"relative imports require the 'package' argument\")\n  for character in name:\n   if character !='.':\n    break\n   level +=1\n return _bootstrap. _gcd_import(name[level:],package,level)\n \n \n \nfrom . import basehook\nsys. meta_path. append(basehook. BaseHook())\n", ["_imp", "importlib", "importlib._bootstrap", "importlib.basehook", "importlib.machinery", "sys"], 1], "__future__": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nall_feature_names=[\n\"nested_scopes\",\n\"generators\",\n\"division\",\n\"absolute_import\",\n\"with_statement\",\n\"print_function\",\n\"unicode_literals\",\n\"barry_as_FLUFL\",\n]\n\n__all__=[\"all_feature_names\"]+all_feature_names\n\n\n\n\n\nCO_NESTED=0x0010\nCO_GENERATOR_ALLOWED=0\nCO_FUTURE_DIVISION=0x2000\nCO_FUTURE_ABSOLUTE_IMPORT=0x4000\nCO_FUTURE_WITH_STATEMENT=0x8000\nCO_FUTURE_PRINT_FUNCTION=0x10000\nCO_FUTURE_UNICODE_LITERALS=0x20000\nCO_FUTURE_BARRY_AS_BDFL=0x40000\n\nclass _Feature:\n def __init__(self,optionalRelease,mandatoryRelease,compiler_flag):\n  self. optional=optionalRelease\n  self. mandatory=mandatoryRelease\n  self. compiler_flag=compiler_flag\n  \n def getOptionalRelease(self):\n  ''\n\n\n  \n  \n  return self. optional\n  \n def getMandatoryRelease(self):\n  ''\n\n\n\n  \n  \n  return self. mandatory\n  \n def __repr__(self):\n  return\"_Feature\"+repr((self. optional,\n  self. mandatory,\n  self. compiler_flag))\n  \nnested_scopes=_Feature((2,1,0,\"beta\",1),\n(2,2,0,\"alpha\",0),\nCO_NESTED)\n\ngenerators=_Feature((2,2,0,\"alpha\",1),\n(2,3,0,\"final\",0),\nCO_GENERATOR_ALLOWED)\n\ndivision=_Feature((2,2,0,\"alpha\",2),\n(3,0,0,\"alpha\",0),\nCO_FUTURE_DIVISION)\n\nabsolute_import=_Feature((2,5,0,\"alpha\",1),\n(3,0,0,\"alpha\",0),\nCO_FUTURE_ABSOLUTE_IMPORT)\n\nwith_statement=_Feature((2,5,0,\"alpha\",1),\n(2,6,0,\"alpha\",0),\nCO_FUTURE_WITH_STATEMENT)\n\nprint_function=_Feature((2,6,0,\"alpha\",2),\n(3,0,0,\"alpha\",0),\nCO_FUTURE_PRINT_FUNCTION)\n\nunicode_literals=_Feature((2,6,0,\"alpha\",2),\n(3,0,0,\"alpha\",0),\nCO_FUTURE_UNICODE_LITERALS)\n\nbarry_as_FLUFL=_Feature((3,1,0,\"alpha\",2),\n(3,9,0,\"alpha\",0),\nCO_FUTURE_BARRY_AS_BDFL)\n", []], "locale": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\nimport sys\nimport encodings\nimport encodings. aliases\nimport re\nimport collections\nfrom builtins import str as _builtin_str\nimport functools\n\n\n\n\n\n\n\n__all__=[\"getlocale\",\"getdefaultlocale\",\"getpreferredencoding\",\"Error\",\n\"setlocale\",\"resetlocale\",\"localeconv\",\"strcoll\",\"strxfrm\",\n\"str\",\"atof\",\"atoi\",\"format\",\"format_string\",\"currency\",\n\"normalize\",\"LC_CTYPE\",\"LC_COLLATE\",\"LC_TIME\",\"LC_MONETARY\",\n\"LC_NUMERIC\",\"LC_ALL\",\"CHAR_MAX\"]\n\ndef _strcoll(a,b):\n ''\n\n \n return (a >b)-(a <b)\n \ndef _strxfrm(s):\n ''\n\n \n return s\n \n \n \n \n \nCHAR_MAX=127\nLC_ALL=6\nLC_COLLATE=3\nLC_CTYPE=0\nLC_MESSAGES=5\nLC_MONETARY=4\nLC_NUMERIC=1\nLC_TIME=2\nError=ValueError\n\ndef localeconv():\n ''\n\n \n \n return {'grouping':[127],\n 'currency_symbol':'',\n 'n_sign_posn':127,\n 'p_cs_precedes':127,\n 'n_cs_precedes':127,\n 'mon_grouping':[],\n 'n_sep_by_space':127,\n 'decimal_point':'.',\n 'negative_sign':'',\n 'positive_sign':'',\n 'p_sep_by_space':127,\n 'int_curr_symbol':'',\n 'p_sign_posn':127,\n 'thousands_sep':'',\n 'mon_thousands_sep':'',\n 'frac_digits':127,\n 'mon_decimal_point':'',\n 'int_frac_digits':127}\n \ndef setlocale(category,value=None ):\n ''\n\n \n if value not in (None ,'','C'):\n  raise Error('_locale emulation only supports \"C\" locale')\n return'C'\n \n \nif'strxfrm'not in globals():\n strxfrm=_strxfrm\nif'strcoll'not in globals():\n strcoll=_strcoll\n \n \n_localeconv=localeconv\n\n\n\n_override_localeconv={}\n\n@functools. wraps(_localeconv)\ndef localeconv():\n d=_localeconv()\n if _override_localeconv:\n  d. update(_override_localeconv)\n return d\n \n \n \n \n \n \n \n \ndef _grouping_intervals(grouping):\n last_interval=None\n for interval in grouping:\n \n  if interval ==CHAR_MAX:\n   return\n   \n  if interval ==0:\n   if last_interval is None :\n    raise ValueError(\"invalid grouping\")\n   while True :\n    yield last_interval\n  yield interval\n  last_interval=interval\n  \n  \ndef _group(s,monetary=False ):\n conv=localeconv()\n thousands_sep=conv[monetary and'mon_thousands_sep'or'thousands_sep']\n grouping=conv[monetary and'mon_grouping'or'grouping']\n if not grouping:\n  return (s,0)\n if s[-1]==' ':\n  stripped=s. rstrip()\n  right_spaces=s[len(stripped):]\n  s=stripped\n else :\n  right_spaces=''\n left_spaces=''\n groups=[]\n for interval in _grouping_intervals(grouping):\n  if not s or s[-1]not in\"0123456789\":\n  \n   left_spaces=s\n   s=''\n   break\n  groups. append(s[-interval:])\n  s=s[:-interval]\n if s:\n  groups. append(s)\n groups. reverse()\n return (\n left_spaces+thousands_sep. join(groups)+right_spaces,\n len(thousands_sep)*(len(groups)-1)\n )\n \n \ndef _strip_padding(s,amount):\n lpos=0\n while amount and s[lpos]==' ':\n  lpos +=1\n  amount -=1\n rpos=len(s)-1\n while amount and s[rpos]==' ':\n  rpos -=1\n  amount -=1\n return s[lpos:rpos+1]\n \n_percent_re=re. compile(r'%(?:\\((?P<key>.*?)\\))?'\nr'(?P<modifiers>[-#0-9 +*.hlL]*?)[eEfFgGdiouxXcrs%]')\n\ndef format(percent,value,grouping=False ,monetary=False ,*additional):\n ''\n\n\n\n \n \n match=_percent_re. match(percent)\n if not match or len(match. group())!=len(percent):\n  raise ValueError((\"format() must be given exactly one %%char \"\n  \"format specifier, %s not valid\")%repr(percent))\n return _format(percent,value,grouping,monetary,*additional)\n \ndef _format(percent,value,grouping=False ,monetary=False ,*additional):\n if additional:\n  formatted=percent %((value,)+additional)\n else :\n  formatted=percent %value\n  \n if percent[-1]in'eEfFgG':\n  seps=0\n  parts=formatted. split('.')\n  if grouping:\n   parts[0],seps=_group(parts[0],monetary=monetary)\n  decimal_point=localeconv()[monetary and'mon_decimal_point'\n  or'decimal_point']\n  formatted=decimal_point. join(parts)\n  if seps:\n   formatted=_strip_padding(formatted,seps)\n elif percent[-1]in'diu':\n  seps=0\n  if grouping:\n   formatted,seps=_group(formatted,monetary=monetary)\n  if seps:\n   formatted=_strip_padding(formatted,seps)\n return formatted\n \ndef format_string(f,val,grouping=False ):\n ''\n\n \n percents=list(_percent_re. finditer(f))\n new_f=_percent_re. sub('%s',f)\n \n if isinstance(val,collections. Mapping):\n  new_val=[]\n  for perc in percents:\n   if perc. group()[-1]=='%':\n    new_val. append('%')\n   else :\n    new_val. append(format(perc. group(),val,grouping))\n else :\n  if not isinstance(val,tuple):\n   val=(val,)\n  new_val=[]\n  i=0\n  for perc in percents:\n   if perc. group()[-1]=='%':\n    new_val. append('%')\n   else :\n    starcount=perc. group('modifiers'). count('*')\n    new_val. append(_format(perc. group(),\n    val[i],\n    grouping,\n    False ,\n    *val[i+1:i+1+starcount]))\n    i +=(1+starcount)\n val=tuple(new_val)\n \n return new_f %val\n \ndef currency(val,symbol=True ,grouping=False ,international=False ):\n ''\n \n conv=localeconv()\n \n \n digits=conv[international and'int_frac_digits'or'frac_digits']\n if digits ==127:\n  raise ValueError(\"Currency formatting is not possible using \"\n  \"the 'C' locale.\")\n  \n s=format('%%.%if'%digits,abs(val),grouping,monetary=True )\n \n s='<'+s+'>'\n \n if symbol:\n  smb=conv[international and'int_curr_symbol'or'currency_symbol']\n  precedes=conv[val <0 and'n_cs_precedes'or'p_cs_precedes']\n  separated=conv[val <0 and'n_sep_by_space'or'p_sep_by_space']\n  \n  if precedes:\n   s=smb+(separated and' 'or'')+s\n  else :\n   s=s+(separated and' 'or'')+smb\n   \n sign_pos=conv[val <0 and'n_sign_posn'or'p_sign_posn']\n sign=conv[val <0 and'negative_sign'or'positive_sign']\n \n if sign_pos ==0:\n  s='('+s+')'\n elif sign_pos ==1:\n  s=sign+s\n elif sign_pos ==2:\n  s=s+sign\n elif sign_pos ==3:\n  s=s. replace('<',sign)\n elif sign_pos ==4:\n  s=s. replace('>',sign)\n else :\n \n \n  s=sign+s\n  \n return s. replace('<',''). replace('>','')\n \ndef str(val):\n ''\n return format(\"%.12g\",val)\n \ndef atof(string,func=float):\n ''\n \n ts=localeconv()['thousands_sep']\n if ts:\n  string=string. replace(ts,'')\n  \n dd=localeconv()['decimal_point']\n if dd:\n  string=string. replace(dd,'.')\n  \n return func(string)\n \ndef atoi(str):\n ''\n return atof(str,int)\n \ndef _test():\n setlocale(LC_ALL,\"\")\n \n s1=format(\"%d\",123456789,1)\n print(s1,\"is\",atoi(s1))\n \n s1=str(3.14)\n print(s1,\"is\",atof(s1))\n \n \n \n \n \n \n \n \n_setlocale=setlocale\n\ndef _replace_encoding(code,encoding):\n if'.'in code:\n  langname=code[:code. index('.')]\n else :\n  langname=code\n  \n norm_encoding=encodings. normalize_encoding(encoding)\n \n norm_encoding=encodings. aliases. aliases. get(norm_encoding. lower(),\n norm_encoding)\n \n encoding=norm_encoding\n norm_encoding=norm_encoding. lower()\n if norm_encoding in locale_encoding_alias:\n  encoding=locale_encoding_alias[norm_encoding]\n else :\n  norm_encoding=norm_encoding. replace('_','')\n  norm_encoding=norm_encoding. replace('-','')\n  if norm_encoding in locale_encoding_alias:\n   encoding=locale_encoding_alias[norm_encoding]\n   \n return langname+'.'+encoding\n \ndef _append_modifier(code,modifier):\n if modifier =='euro':\n  if'.'not in code:\n   return code+'.ISO8859-15'\n  _,_,encoding=code. partition('.')\n  if encoding in ('ISO8859-15','UTF-8'):\n   return code\n  if encoding =='ISO8859-1':\n   return _replace_encoding(code,'ISO8859-15')\n return code+'@'+modifier\n \ndef normalize(localename):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n code=localename. lower()\n if':'in code:\n \n  code=code. replace(':','.')\n if'@'in code:\n  code,modifier=code. split('@',1)\n else :\n  modifier=''\n if'.'in code:\n  langname,encoding=code. split('.')[:2]\n else :\n  langname=code\n  encoding=''\n  \n  \n lang_enc=langname\n if encoding:\n  norm_encoding=encoding. replace('-','')\n  norm_encoding=norm_encoding. replace('_','')\n  lang_enc +='.'+norm_encoding\n lookup_name=lang_enc\n if modifier:\n  lookup_name +='@'+modifier\n code=locale_alias. get(lookup_name,None )\n if code is not None :\n  return code\n  \n  \n if modifier:\n \n  code=locale_alias. get(lang_enc,None )\n  if code is not None :\n  \n   if'@'not in code:\n    return _append_modifier(code,modifier)\n   if code. split('@',1)[1]. lower()==modifier:\n    return code\n    \n    \n if encoding:\n \n  lookup_name=langname\n  if modifier:\n   lookup_name +='@'+modifier\n  code=locale_alias. get(lookup_name,None )\n  if code is not None :\n  \n   if'@'not in code:\n    return _replace_encoding(code,encoding)\n   code,modifier=code. split('@',1)\n   return _replace_encoding(code,encoding)+'@'+modifier\n   \n  if modifier:\n  \n   code=locale_alias. get(langname,None )\n   if code is not None :\n   \n    if'@'not in code:\n     code=_replace_encoding(code,encoding)\n     return _append_modifier(code,modifier)\n    code,defmod=code. split('@',1)\n    if defmod. lower()==modifier:\n     return _replace_encoding(code,encoding)+'@'+defmod\n     \n return localename\n \ndef _parse_localename(localename):\n\n ''\n\n\n\n\n\n\n\n\n\n\n \n code=normalize(localename)\n if'@'in code:\n \n  code,modifier=code. split('@',1)\n  if modifier =='euro'and'.'not in code:\n  \n  \n  \n   return code,'iso-8859-15'\n   \n if'.'in code:\n  return tuple(code. split('.')[:2])\n elif code =='C':\n  return None ,None\n raise ValueError('unknown locale: %s'%localename)\n \ndef _build_localename(localetuple):\n\n ''\n\n\n\n\n \n try :\n  language,encoding=localetuple\n  \n  if language is None :\n   language='C'\n  if encoding is None :\n   return language\n  else :\n   return language+'.'+encoding\n except (TypeError,ValueError):\n  raise TypeError('Locale must be None, a string, or an iterable of two strings -- language code, encoding.')\n  \ndef getdefaultlocale(envvars=('LC_ALL','LC_CTYPE','LANG','LANGUAGE')):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n try :\n \n  import _locale\n  code,encoding=_locale. _getdefaultlocale()\n except (ImportError,AttributeError):\n  pass\n else :\n \n  if sys. platform ==\"win32\"and code and code[:2]==\"0x\":\n  \n   code=windows_locale. get(int(code,0))\n   \n   \n  return code,encoding\n  \n  \n import os\n lookup=os. environ. get\n for variable in envvars:\n  localename=lookup(variable,None )\n  if localename:\n   if variable =='LANGUAGE':\n    localename=localename. split(':')[0]\n   break\n else :\n  localename='C'\n return _parse_localename(localename)\n \n \ndef getlocale(category=LC_CTYPE):\n\n ''\n\n\n\n\n\n\n\n\n\n \n localename=_setlocale(category)\n if category ==LC_ALL and';'in localename:\n  raise TypeError('category LC_ALL is not supported')\n return _parse_localename(localename)\n \ndef setlocale(category,locale=None ):\n\n ''\n\n\n\n\n\n\n\n\n \n if locale and not isinstance(locale,_builtin_str):\n \n  locale=normalize(_build_localename(locale))\n return _setlocale(category,locale)\n \ndef resetlocale(category=LC_ALL):\n\n ''\n\n\n\n\n \n _setlocale(category,_build_localename(getdefaultlocale()))\n \nif sys. platform. startswith(\"win\"):\n\n def getpreferredencoding(do_setlocale=True ):\n  ''\n  import _bootlocale\n  return _bootlocale. getpreferredencoding(False )\nelse :\n\n try :\n  CODESET\n except NameError:\n \n  def getpreferredencoding(do_setlocale=True ):\n   ''\n   \n   res=getdefaultlocale()[1]\n   if res is None :\n   \n    res='ascii'\n   return res\n else :\n  def getpreferredencoding(do_setlocale=True ):\n   ''\n   \n   import _bootlocale\n   if do_setlocale:\n    oldloc=setlocale(LC_CTYPE)\n    try :\n     setlocale(LC_CTYPE,\"\")\n    except Error:\n     pass\n   result=_bootlocale. getpreferredencoding(False )\n   if do_setlocale:\n    setlocale(LC_CTYPE,oldloc)\n   return result\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \nlocale_encoding_alias={\n\n\n'437':'C',\n'c':'C',\n'en':'ISO8859-1',\n'jis':'JIS7',\n'jis7':'JIS7',\n'ajec':'eucJP',\n'koi8c':'KOI8-C',\n'microsoftcp1251':'CP1251',\n'microsoftcp1255':'CP1255',\n'microsoftcp1256':'CP1256',\n'88591':'ISO8859-1',\n'88592':'ISO8859-2',\n'88595':'ISO8859-5',\n'885915':'ISO8859-15',\n\n\n'ascii':'ISO8859-1',\n'latin_1':'ISO8859-1',\n'iso8859_1':'ISO8859-1',\n'iso8859_10':'ISO8859-10',\n'iso8859_11':'ISO8859-11',\n'iso8859_13':'ISO8859-13',\n'iso8859_14':'ISO8859-14',\n'iso8859_15':'ISO8859-15',\n'iso8859_16':'ISO8859-16',\n'iso8859_2':'ISO8859-2',\n'iso8859_3':'ISO8859-3',\n'iso8859_4':'ISO8859-4',\n'iso8859_5':'ISO8859-5',\n'iso8859_6':'ISO8859-6',\n'iso8859_7':'ISO8859-7',\n'iso8859_8':'ISO8859-8',\n'iso8859_9':'ISO8859-9',\n'iso2022_jp':'JIS7',\n'shift_jis':'SJIS',\n'tactis':'TACTIS',\n'euc_jp':'eucJP',\n'euc_kr':'eucKR',\n'utf_8':'UTF-8',\n'koi8_r':'KOI8-R',\n'koi8_u':'KOI8-U',\n'cp1251':'CP1251',\n'cp1255':'CP1255',\n'cp1256':'CP1256',\n\n\n\n}\n\nfor k,v in sorted(locale_encoding_alias. items()):\n k=k. replace('_','')\n locale_encoding_alias. setdefault(k,v)\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \nlocale_alias={\n'a3':'az_AZ.KOI8-C',\n'a3_az':'az_AZ.KOI8-C',\n'a3_az.koic':'az_AZ.KOI8-C',\n'aa_dj':'aa_DJ.ISO8859-1',\n'aa_er':'aa_ER.UTF-8',\n'aa_et':'aa_ET.UTF-8',\n'af':'af_ZA.ISO8859-1',\n'af_za':'af_ZA.ISO8859-1',\n'am':'am_ET.UTF-8',\n'am_et':'am_ET.UTF-8',\n'american':'en_US.ISO8859-1',\n'an_es':'an_ES.ISO8859-15',\n'ar':'ar_AA.ISO8859-6',\n'ar_aa':'ar_AA.ISO8859-6',\n'ar_ae':'ar_AE.ISO8859-6',\n'ar_bh':'ar_BH.ISO8859-6',\n'ar_dz':'ar_DZ.ISO8859-6',\n'ar_eg':'ar_EG.ISO8859-6',\n'ar_in':'ar_IN.UTF-8',\n'ar_iq':'ar_IQ.ISO8859-6',\n'ar_jo':'ar_JO.ISO8859-6',\n'ar_kw':'ar_KW.ISO8859-6',\n'ar_lb':'ar_LB.ISO8859-6',\n'ar_ly':'ar_LY.ISO8859-6',\n'ar_ma':'ar_MA.ISO8859-6',\n'ar_om':'ar_OM.ISO8859-6',\n'ar_qa':'ar_QA.ISO8859-6',\n'ar_sa':'ar_SA.ISO8859-6',\n'ar_sd':'ar_SD.ISO8859-6',\n'ar_sy':'ar_SY.ISO8859-6',\n'ar_tn':'ar_TN.ISO8859-6',\n'ar_ye':'ar_YE.ISO8859-6',\n'arabic':'ar_AA.ISO8859-6',\n'as':'as_IN.UTF-8',\n'as_in':'as_IN.UTF-8',\n'ast_es':'ast_ES.ISO8859-15',\n'ayc_pe':'ayc_PE.UTF-8',\n'az':'az_AZ.ISO8859-9E',\n'az_az':'az_AZ.ISO8859-9E',\n'az_az.iso88599e':'az_AZ.ISO8859-9E',\n'be':'be_BY.CP1251',\n'be@latin':'be_BY.UTF-8@latin',\n'be_bg.utf8':'bg_BG.UTF-8',\n'be_by':'be_BY.CP1251',\n'be_by@latin':'be_BY.UTF-8@latin',\n'bem_zm':'bem_ZM.UTF-8',\n'ber_dz':'ber_DZ.UTF-8',\n'ber_ma':'ber_MA.UTF-8',\n'bg':'bg_BG.CP1251',\n'bg_bg':'bg_BG.CP1251',\n'bho_in':'bho_IN.UTF-8',\n'bn_bd':'bn_BD.UTF-8',\n'bn_in':'bn_IN.UTF-8',\n'bo_cn':'bo_CN.UTF-8',\n'bo_in':'bo_IN.UTF-8',\n'bokmal':'nb_NO.ISO8859-1',\n'bokm\\xe5l':'nb_NO.ISO8859-1',\n'br':'br_FR.ISO8859-1',\n'br_fr':'br_FR.ISO8859-1',\n'brx_in':'brx_IN.UTF-8',\n'bs':'bs_BA.ISO8859-2',\n'bs_ba':'bs_BA.ISO8859-2',\n'bulgarian':'bg_BG.CP1251',\n'byn_er':'byn_ER.UTF-8',\n'c':'C',\n'c-french':'fr_CA.ISO8859-1',\n'c.ascii':'C',\n'c.en':'C',\n'c.iso88591':'en_US.ISO8859-1',\n'c.utf8':'en_US.UTF-8',\n'c_c':'C',\n'c_c.c':'C',\n'ca':'ca_ES.ISO8859-1',\n'ca_ad':'ca_AD.ISO8859-1',\n'ca_es':'ca_ES.ISO8859-1',\n'ca_es@valencia':'ca_ES.ISO8859-15@valencia',\n'ca_fr':'ca_FR.ISO8859-1',\n'ca_it':'ca_IT.ISO8859-1',\n'catalan':'ca_ES.ISO8859-1',\n'cextend':'en_US.ISO8859-1',\n'chinese-s':'zh_CN.eucCN',\n'chinese-t':'zh_TW.eucTW',\n'crh_ua':'crh_UA.UTF-8',\n'croatian':'hr_HR.ISO8859-2',\n'cs':'cs_CZ.ISO8859-2',\n'cs_cs':'cs_CZ.ISO8859-2',\n'cs_cz':'cs_CZ.ISO8859-2',\n'csb_pl':'csb_PL.UTF-8',\n'cv_ru':'cv_RU.UTF-8',\n'cy':'cy_GB.ISO8859-1',\n'cy_gb':'cy_GB.ISO8859-1',\n'cz':'cs_CZ.ISO8859-2',\n'cz_cz':'cs_CZ.ISO8859-2',\n'czech':'cs_CZ.ISO8859-2',\n'da':'da_DK.ISO8859-1',\n'da_dk':'da_DK.ISO8859-1',\n'danish':'da_DK.ISO8859-1',\n'dansk':'da_DK.ISO8859-1',\n'de':'de_DE.ISO8859-1',\n'de_at':'de_AT.ISO8859-1',\n'de_be':'de_BE.ISO8859-1',\n'de_ch':'de_CH.ISO8859-1',\n'de_de':'de_DE.ISO8859-1',\n'de_li.utf8':'de_LI.UTF-8',\n'de_lu':'de_LU.ISO8859-1',\n'deutsch':'de_DE.ISO8859-1',\n'doi_in':'doi_IN.UTF-8',\n'dutch':'nl_NL.ISO8859-1',\n'dutch.iso88591':'nl_BE.ISO8859-1',\n'dv_mv':'dv_MV.UTF-8',\n'dz_bt':'dz_BT.UTF-8',\n'ee':'ee_EE.ISO8859-4',\n'ee_ee':'ee_EE.ISO8859-4',\n'eesti':'et_EE.ISO8859-1',\n'el':'el_GR.ISO8859-7',\n'el_cy':'el_CY.ISO8859-7',\n'el_gr':'el_GR.ISO8859-7',\n'el_gr@euro':'el_GR.ISO8859-15',\n'en':'en_US.ISO8859-1',\n'en_ag':'en_AG.UTF-8',\n'en_au':'en_AU.ISO8859-1',\n'en_be':'en_BE.ISO8859-1',\n'en_bw':'en_BW.ISO8859-1',\n'en_ca':'en_CA.ISO8859-1',\n'en_dk':'en_DK.ISO8859-1',\n'en_dl.utf8':'en_DL.UTF-8',\n'en_gb':'en_GB.ISO8859-1',\n'en_hk':'en_HK.ISO8859-1',\n'en_ie':'en_IE.ISO8859-1',\n'en_in':'en_IN.ISO8859-1',\n'en_ng':'en_NG.UTF-8',\n'en_nz':'en_NZ.ISO8859-1',\n'en_ph':'en_PH.ISO8859-1',\n'en_sg':'en_SG.ISO8859-1',\n'en_uk':'en_GB.ISO8859-1',\n'en_us':'en_US.ISO8859-1',\n'en_us@euro@euro':'en_US.ISO8859-15',\n'en_za':'en_ZA.ISO8859-1',\n'en_zm':'en_ZM.UTF-8',\n'en_zw':'en_ZW.ISO8859-1',\n'en_zw.utf8':'en_ZS.UTF-8',\n'eng_gb':'en_GB.ISO8859-1',\n'english':'en_EN.ISO8859-1',\n'english_uk':'en_GB.ISO8859-1',\n'english_united-states':'en_US.ISO8859-1',\n'english_united-states.437':'C',\n'english_us':'en_US.ISO8859-1',\n'eo':'eo_XX.ISO8859-3',\n'eo.utf8':'eo.UTF-8',\n'eo_eo':'eo_EO.ISO8859-3',\n'eo_us.utf8':'eo_US.UTF-8',\n'eo_xx':'eo_XX.ISO8859-3',\n'es':'es_ES.ISO8859-1',\n'es_ar':'es_AR.ISO8859-1',\n'es_bo':'es_BO.ISO8859-1',\n'es_cl':'es_CL.ISO8859-1',\n'es_co':'es_CO.ISO8859-1',\n'es_cr':'es_CR.ISO8859-1',\n'es_cu':'es_CU.UTF-8',\n'es_do':'es_DO.ISO8859-1',\n'es_ec':'es_EC.ISO8859-1',\n'es_es':'es_ES.ISO8859-1',\n'es_gt':'es_GT.ISO8859-1',\n'es_hn':'es_HN.ISO8859-1',\n'es_mx':'es_MX.ISO8859-1',\n'es_ni':'es_NI.ISO8859-1',\n'es_pa':'es_PA.ISO8859-1',\n'es_pe':'es_PE.ISO8859-1',\n'es_pr':'es_PR.ISO8859-1',\n'es_py':'es_PY.ISO8859-1',\n'es_sv':'es_SV.ISO8859-1',\n'es_us':'es_US.ISO8859-1',\n'es_uy':'es_UY.ISO8859-1',\n'es_ve':'es_VE.ISO8859-1',\n'estonian':'et_EE.ISO8859-1',\n'et':'et_EE.ISO8859-15',\n'et_ee':'et_EE.ISO8859-15',\n'eu':'eu_ES.ISO8859-1',\n'eu_es':'eu_ES.ISO8859-1',\n'eu_fr':'eu_FR.ISO8859-1',\n'fa':'fa_IR.UTF-8',\n'fa_ir':'fa_IR.UTF-8',\n'fa_ir.isiri3342':'fa_IR.ISIRI-3342',\n'ff_sn':'ff_SN.UTF-8',\n'fi':'fi_FI.ISO8859-15',\n'fi_fi':'fi_FI.ISO8859-15',\n'fil_ph':'fil_PH.UTF-8',\n'finnish':'fi_FI.ISO8859-1',\n'fo':'fo_FO.ISO8859-1',\n'fo_fo':'fo_FO.ISO8859-1',\n'fr':'fr_FR.ISO8859-1',\n'fr_be':'fr_BE.ISO8859-1',\n'fr_ca':'fr_CA.ISO8859-1',\n'fr_ch':'fr_CH.ISO8859-1',\n'fr_fr':'fr_FR.ISO8859-1',\n'fr_lu':'fr_LU.ISO8859-1',\n'fran\\xe7ais':'fr_FR.ISO8859-1',\n'fre_fr':'fr_FR.ISO8859-1',\n'french':'fr_FR.ISO8859-1',\n'french.iso88591':'fr_CH.ISO8859-1',\n'french_france':'fr_FR.ISO8859-1',\n'fur_it':'fur_IT.UTF-8',\n'fy_de':'fy_DE.UTF-8',\n'fy_nl':'fy_NL.UTF-8',\n'ga':'ga_IE.ISO8859-1',\n'ga_ie':'ga_IE.ISO8859-1',\n'galego':'gl_ES.ISO8859-1',\n'galician':'gl_ES.ISO8859-1',\n'gd':'gd_GB.ISO8859-1',\n'gd_gb':'gd_GB.ISO8859-1',\n'ger_de':'de_DE.ISO8859-1',\n'german':'de_DE.ISO8859-1',\n'german.iso88591':'de_CH.ISO8859-1',\n'german_germany':'de_DE.ISO8859-1',\n'gez_er':'gez_ER.UTF-8',\n'gez_et':'gez_ET.UTF-8',\n'gl':'gl_ES.ISO8859-1',\n'gl_es':'gl_ES.ISO8859-1',\n'greek':'el_GR.ISO8859-7',\n'gu_in':'gu_IN.UTF-8',\n'gv':'gv_GB.ISO8859-1',\n'gv_gb':'gv_GB.ISO8859-1',\n'ha_ng':'ha_NG.UTF-8',\n'he':'he_IL.ISO8859-8',\n'he_il':'he_IL.ISO8859-8',\n'hebrew':'he_IL.ISO8859-8',\n'hi':'hi_IN.ISCII-DEV',\n'hi_in':'hi_IN.ISCII-DEV',\n'hi_in.isciidev':'hi_IN.ISCII-DEV',\n'hne':'hne_IN.UTF-8',\n'hne_in':'hne_IN.UTF-8',\n'hr':'hr_HR.ISO8859-2',\n'hr_hr':'hr_HR.ISO8859-2',\n'hrvatski':'hr_HR.ISO8859-2',\n'hsb_de':'hsb_DE.ISO8859-2',\n'ht_ht':'ht_HT.UTF-8',\n'hu':'hu_HU.ISO8859-2',\n'hu_hu':'hu_HU.ISO8859-2',\n'hungarian':'hu_HU.ISO8859-2',\n'hy_am':'hy_AM.UTF-8',\n'hy_am.armscii8':'hy_AM.ARMSCII_8',\n'ia':'ia.UTF-8',\n'ia_fr':'ia_FR.UTF-8',\n'icelandic':'is_IS.ISO8859-1',\n'id':'id_ID.ISO8859-1',\n'id_id':'id_ID.ISO8859-1',\n'ig_ng':'ig_NG.UTF-8',\n'ik_ca':'ik_CA.UTF-8',\n'in':'id_ID.ISO8859-1',\n'in_id':'id_ID.ISO8859-1',\n'is':'is_IS.ISO8859-1',\n'is_is':'is_IS.ISO8859-1',\n'iso-8859-1':'en_US.ISO8859-1',\n'iso-8859-15':'en_US.ISO8859-15',\n'iso8859-1':'en_US.ISO8859-1',\n'iso8859-15':'en_US.ISO8859-15',\n'iso_8859_1':'en_US.ISO8859-1',\n'iso_8859_15':'en_US.ISO8859-15',\n'it':'it_IT.ISO8859-1',\n'it_ch':'it_CH.ISO8859-1',\n'it_it':'it_IT.ISO8859-1',\n'italian':'it_IT.ISO8859-1',\n'iu':'iu_CA.NUNACOM-8',\n'iu_ca':'iu_CA.NUNACOM-8',\n'iu_ca.nunacom8':'iu_CA.NUNACOM-8',\n'iw':'he_IL.ISO8859-8',\n'iw_il':'he_IL.ISO8859-8',\n'iw_il.utf8':'iw_IL.UTF-8',\n'ja':'ja_JP.eucJP',\n'ja_jp':'ja_JP.eucJP',\n'ja_jp.euc':'ja_JP.eucJP',\n'ja_jp.mscode':'ja_JP.SJIS',\n'ja_jp.pck':'ja_JP.SJIS',\n'japan':'ja_JP.eucJP',\n'japanese':'ja_JP.eucJP',\n'japanese-euc':'ja_JP.eucJP',\n'japanese.euc':'ja_JP.eucJP',\n'jp_jp':'ja_JP.eucJP',\n'ka':'ka_GE.GEORGIAN-ACADEMY',\n'ka_ge':'ka_GE.GEORGIAN-ACADEMY',\n'ka_ge.georgianacademy':'ka_GE.GEORGIAN-ACADEMY',\n'ka_ge.georgianps':'ka_GE.GEORGIAN-PS',\n'ka_ge.georgianrs':'ka_GE.GEORGIAN-ACADEMY',\n'kk_kz':'kk_KZ.RK1048',\n'kl':'kl_GL.ISO8859-1',\n'kl_gl':'kl_GL.ISO8859-1',\n'km_kh':'km_KH.UTF-8',\n'kn':'kn_IN.UTF-8',\n'kn_in':'kn_IN.UTF-8',\n'ko':'ko_KR.eucKR',\n'ko_kr':'ko_KR.eucKR',\n'ko_kr.euc':'ko_KR.eucKR',\n'kok_in':'kok_IN.UTF-8',\n'korean':'ko_KR.eucKR',\n'korean.euc':'ko_KR.eucKR',\n'ks':'ks_IN.UTF-8',\n'ks_in':'ks_IN.UTF-8',\n'ks_in@devanagari.utf8':'ks_IN.UTF-8@devanagari',\n'ku_tr':'ku_TR.ISO8859-9',\n'kw':'kw_GB.ISO8859-1',\n'kw_gb':'kw_GB.ISO8859-1',\n'ky':'ky_KG.UTF-8',\n'ky_kg':'ky_KG.UTF-8',\n'lb_lu':'lb_LU.UTF-8',\n'lg_ug':'lg_UG.ISO8859-10',\n'li_be':'li_BE.UTF-8',\n'li_nl':'li_NL.UTF-8',\n'lij_it':'lij_IT.UTF-8',\n'lithuanian':'lt_LT.ISO8859-13',\n'lo':'lo_LA.MULELAO-1',\n'lo_la':'lo_LA.MULELAO-1',\n'lo_la.cp1133':'lo_LA.IBM-CP1133',\n'lo_la.ibmcp1133':'lo_LA.IBM-CP1133',\n'lo_la.mulelao1':'lo_LA.MULELAO-1',\n'lt':'lt_LT.ISO8859-13',\n'lt_lt':'lt_LT.ISO8859-13',\n'lv':'lv_LV.ISO8859-13',\n'lv_lv':'lv_LV.ISO8859-13',\n'mag_in':'mag_IN.UTF-8',\n'mai':'mai_IN.UTF-8',\n'mai_in':'mai_IN.UTF-8',\n'mg_mg':'mg_MG.ISO8859-15',\n'mhr_ru':'mhr_RU.UTF-8',\n'mi':'mi_NZ.ISO8859-1',\n'mi_nz':'mi_NZ.ISO8859-1',\n'mk':'mk_MK.ISO8859-5',\n'mk_mk':'mk_MK.ISO8859-5',\n'ml':'ml_IN.UTF-8',\n'ml_in':'ml_IN.UTF-8',\n'mn_mn':'mn_MN.UTF-8',\n'mni_in':'mni_IN.UTF-8',\n'mr':'mr_IN.UTF-8',\n'mr_in':'mr_IN.UTF-8',\n'ms':'ms_MY.ISO8859-1',\n'ms_my':'ms_MY.ISO8859-1',\n'mt':'mt_MT.ISO8859-3',\n'mt_mt':'mt_MT.ISO8859-3',\n'my_mm':'my_MM.UTF-8',\n'nan_tw@latin':'nan_TW.UTF-8@latin',\n'nb':'nb_NO.ISO8859-1',\n'nb_no':'nb_NO.ISO8859-1',\n'nds_de':'nds_DE.UTF-8',\n'nds_nl':'nds_NL.UTF-8',\n'ne_np':'ne_NP.UTF-8',\n'nhn_mx':'nhn_MX.UTF-8',\n'niu_nu':'niu_NU.UTF-8',\n'niu_nz':'niu_NZ.UTF-8',\n'nl':'nl_NL.ISO8859-1',\n'nl_aw':'nl_AW.UTF-8',\n'nl_be':'nl_BE.ISO8859-1',\n'nl_nl':'nl_NL.ISO8859-1',\n'nn':'nn_NO.ISO8859-1',\n'nn_no':'nn_NO.ISO8859-1',\n'no':'no_NO.ISO8859-1',\n'no@nynorsk':'ny_NO.ISO8859-1',\n'no_no':'no_NO.ISO8859-1',\n'no_no.iso88591@bokmal':'no_NO.ISO8859-1',\n'no_no.iso88591@nynorsk':'no_NO.ISO8859-1',\n'norwegian':'no_NO.ISO8859-1',\n'nr':'nr_ZA.ISO8859-1',\n'nr_za':'nr_ZA.ISO8859-1',\n'nso':'nso_ZA.ISO8859-15',\n'nso_za':'nso_ZA.ISO8859-15',\n'ny':'ny_NO.ISO8859-1',\n'ny_no':'ny_NO.ISO8859-1',\n'nynorsk':'nn_NO.ISO8859-1',\n'oc':'oc_FR.ISO8859-1',\n'oc_fr':'oc_FR.ISO8859-1',\n'om_et':'om_ET.UTF-8',\n'om_ke':'om_KE.ISO8859-1',\n'or':'or_IN.UTF-8',\n'or_in':'or_IN.UTF-8',\n'os_ru':'os_RU.UTF-8',\n'pa':'pa_IN.UTF-8',\n'pa_in':'pa_IN.UTF-8',\n'pa_pk':'pa_PK.UTF-8',\n'pap_an':'pap_AN.UTF-8',\n'pd':'pd_US.ISO8859-1',\n'pd_de':'pd_DE.ISO8859-1',\n'pd_us':'pd_US.ISO8859-1',\n'ph':'ph_PH.ISO8859-1',\n'ph_ph':'ph_PH.ISO8859-1',\n'pl':'pl_PL.ISO8859-2',\n'pl_pl':'pl_PL.ISO8859-2',\n'polish':'pl_PL.ISO8859-2',\n'portuguese':'pt_PT.ISO8859-1',\n'portuguese_brazil':'pt_BR.ISO8859-1',\n'posix':'C',\n'posix-utf2':'C',\n'pp':'pp_AN.ISO8859-1',\n'pp_an':'pp_AN.ISO8859-1',\n'ps_af':'ps_AF.UTF-8',\n'pt':'pt_PT.ISO8859-1',\n'pt_br':'pt_BR.ISO8859-1',\n'pt_pt':'pt_PT.ISO8859-1',\n'ro':'ro_RO.ISO8859-2',\n'ro_ro':'ro_RO.ISO8859-2',\n'romanian':'ro_RO.ISO8859-2',\n'ru':'ru_RU.UTF-8',\n'ru_ru':'ru_RU.UTF-8',\n'ru_ua':'ru_UA.KOI8-U',\n'rumanian':'ro_RO.ISO8859-2',\n'russian':'ru_RU.ISO8859-5',\n'rw':'rw_RW.ISO8859-1',\n'rw_rw':'rw_RW.ISO8859-1',\n'sa_in':'sa_IN.UTF-8',\n'sat_in':'sat_IN.UTF-8',\n'sc_it':'sc_IT.UTF-8',\n'sd':'sd_IN.UTF-8',\n'sd_in':'sd_IN.UTF-8',\n'sd_in@devanagari.utf8':'sd_IN.UTF-8@devanagari',\n'sd_pk':'sd_PK.UTF-8',\n'se_no':'se_NO.UTF-8',\n'serbocroatian':'sr_RS.UTF-8@latin',\n'sh':'sr_RS.UTF-8@latin',\n'sh_ba.iso88592@bosnia':'sr_CS.ISO8859-2',\n'sh_hr':'sh_HR.ISO8859-2',\n'sh_hr.iso88592':'hr_HR.ISO8859-2',\n'sh_sp':'sr_CS.ISO8859-2',\n'sh_yu':'sr_RS.UTF-8@latin',\n'shs_ca':'shs_CA.UTF-8',\n'si':'si_LK.UTF-8',\n'si_lk':'si_LK.UTF-8',\n'sid_et':'sid_ET.UTF-8',\n'sinhala':'si_LK.UTF-8',\n'sk':'sk_SK.ISO8859-2',\n'sk_sk':'sk_SK.ISO8859-2',\n'sl':'sl_SI.ISO8859-2',\n'sl_cs':'sl_CS.ISO8859-2',\n'sl_si':'sl_SI.ISO8859-2',\n'slovak':'sk_SK.ISO8859-2',\n'slovene':'sl_SI.ISO8859-2',\n'slovenian':'sl_SI.ISO8859-2',\n'so_dj':'so_DJ.ISO8859-1',\n'so_et':'so_ET.UTF-8',\n'so_ke':'so_KE.ISO8859-1',\n'so_so':'so_SO.ISO8859-1',\n'sp':'sr_CS.ISO8859-5',\n'sp_yu':'sr_CS.ISO8859-5',\n'spanish':'es_ES.ISO8859-1',\n'spanish_spain':'es_ES.ISO8859-1',\n'sq':'sq_AL.ISO8859-2',\n'sq_al':'sq_AL.ISO8859-2',\n'sq_mk':'sq_MK.UTF-8',\n'sr':'sr_RS.UTF-8',\n'sr@cyrillic':'sr_RS.UTF-8',\n'sr@latn':'sr_CS.UTF-8@latin',\n'sr_cs':'sr_CS.UTF-8',\n'sr_cs.iso88592@latn':'sr_CS.ISO8859-2',\n'sr_cs@latn':'sr_CS.UTF-8@latin',\n'sr_me':'sr_ME.UTF-8',\n'sr_rs':'sr_RS.UTF-8',\n'sr_rs@latn':'sr_RS.UTF-8@latin',\n'sr_sp':'sr_CS.ISO8859-2',\n'sr_yu':'sr_RS.UTF-8@latin',\n'sr_yu.cp1251@cyrillic':'sr_CS.CP1251',\n'sr_yu.iso88592':'sr_CS.ISO8859-2',\n'sr_yu.iso88595':'sr_CS.ISO8859-5',\n'sr_yu.iso88595@cyrillic':'sr_CS.ISO8859-5',\n'sr_yu.microsoftcp1251@cyrillic':'sr_CS.CP1251',\n'sr_yu.utf8':'sr_RS.UTF-8',\n'sr_yu.utf8@cyrillic':'sr_RS.UTF-8',\n'sr_yu@cyrillic':'sr_RS.UTF-8',\n'ss':'ss_ZA.ISO8859-1',\n'ss_za':'ss_ZA.ISO8859-1',\n'st':'st_ZA.ISO8859-1',\n'st_za':'st_ZA.ISO8859-1',\n'sv':'sv_SE.ISO8859-1',\n'sv_fi':'sv_FI.ISO8859-1',\n'sv_se':'sv_SE.ISO8859-1',\n'sw_ke':'sw_KE.UTF-8',\n'sw_tz':'sw_TZ.UTF-8',\n'swedish':'sv_SE.ISO8859-1',\n'szl_pl':'szl_PL.UTF-8',\n'ta':'ta_IN.TSCII-0',\n'ta_in':'ta_IN.TSCII-0',\n'ta_in.tscii':'ta_IN.TSCII-0',\n'ta_in.tscii0':'ta_IN.TSCII-0',\n'ta_lk':'ta_LK.UTF-8',\n'te':'te_IN.UTF-8',\n'te_in':'te_IN.UTF-8',\n'tg':'tg_TJ.KOI8-C',\n'tg_tj':'tg_TJ.KOI8-C',\n'th':'th_TH.ISO8859-11',\n'th_th':'th_TH.ISO8859-11',\n'th_th.tactis':'th_TH.TIS620',\n'th_th.tis620':'th_TH.TIS620',\n'thai':'th_TH.ISO8859-11',\n'ti_er':'ti_ER.UTF-8',\n'ti_et':'ti_ET.UTF-8',\n'tig_er':'tig_ER.UTF-8',\n'tk_tm':'tk_TM.UTF-8',\n'tl':'tl_PH.ISO8859-1',\n'tl_ph':'tl_PH.ISO8859-1',\n'tn':'tn_ZA.ISO8859-15',\n'tn_za':'tn_ZA.ISO8859-15',\n'tr':'tr_TR.ISO8859-9',\n'tr_cy':'tr_CY.ISO8859-9',\n'tr_tr':'tr_TR.ISO8859-9',\n'ts':'ts_ZA.ISO8859-1',\n'ts_za':'ts_ZA.ISO8859-1',\n'tt':'tt_RU.TATAR-CYR',\n'tt_ru':'tt_RU.TATAR-CYR',\n'tt_ru.tatarcyr':'tt_RU.TATAR-CYR',\n'tt_ru@iqtelif':'tt_RU.UTF-8@iqtelif',\n'turkish':'tr_TR.ISO8859-9',\n'ug_cn':'ug_CN.UTF-8',\n'uk':'uk_UA.KOI8-U',\n'uk_ua':'uk_UA.KOI8-U',\n'univ':'en_US.utf',\n'universal':'en_US.utf',\n'universal.utf8@ucs4':'en_US.UTF-8',\n'unm_us':'unm_US.UTF-8',\n'ur':'ur_PK.CP1256',\n'ur_in':'ur_IN.UTF-8',\n'ur_pk':'ur_PK.CP1256',\n'uz':'uz_UZ.UTF-8',\n'uz_uz':'uz_UZ.UTF-8',\n'uz_uz@cyrillic':'uz_UZ.UTF-8',\n've':'ve_ZA.UTF-8',\n've_za':'ve_ZA.UTF-8',\n'vi':'vi_VN.TCVN',\n'vi_vn':'vi_VN.TCVN',\n'vi_vn.tcvn':'vi_VN.TCVN',\n'vi_vn.tcvn5712':'vi_VN.TCVN',\n'vi_vn.viscii':'vi_VN.VISCII',\n'vi_vn.viscii111':'vi_VN.VISCII',\n'wa':'wa_BE.ISO8859-1',\n'wa_be':'wa_BE.ISO8859-1',\n'wae_ch':'wae_CH.UTF-8',\n'wal_et':'wal_ET.UTF-8',\n'wo_sn':'wo_SN.UTF-8',\n'xh':'xh_ZA.ISO8859-1',\n'xh_za':'xh_ZA.ISO8859-1',\n'yi':'yi_US.CP1255',\n'yi_us':'yi_US.CP1255',\n'yo_ng':'yo_NG.UTF-8',\n'yue_hk':'yue_HK.UTF-8',\n'zh':'zh_CN.eucCN',\n'zh_cn':'zh_CN.gb2312',\n'zh_cn.big5':'zh_TW.big5',\n'zh_cn.euc':'zh_CN.eucCN',\n'zh_hk':'zh_HK.big5hkscs',\n'zh_hk.big5hk':'zh_HK.big5hkscs',\n'zh_sg':'zh_SG.GB2312',\n'zh_sg.gbk':'zh_SG.GBK',\n'zh_tw':'zh_TW.big5',\n'zh_tw.euc':'zh_TW.eucTW',\n'zh_tw.euctw':'zh_TW.eucTW',\n'zu':'zu_ZA.ISO8859-1',\n'zu_za':'zu_ZA.ISO8859-1',\n}\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nwindows_locale={\n0x0436:\"af_ZA\",\n0x041c:\"sq_AL\",\n0x0484:\"gsw_FR\",\n0x045e:\"am_ET\",\n0x0401:\"ar_SA\",\n0x0801:\"ar_IQ\",\n0x0c01:\"ar_EG\",\n0x1001:\"ar_LY\",\n0x1401:\"ar_DZ\",\n0x1801:\"ar_MA\",\n0x1c01:\"ar_TN\",\n0x2001:\"ar_OM\",\n0x2401:\"ar_YE\",\n0x2801:\"ar_SY\",\n0x2c01:\"ar_JO\",\n0x3001:\"ar_LB\",\n0x3401:\"ar_KW\",\n0x3801:\"ar_AE\",\n0x3c01:\"ar_BH\",\n0x4001:\"ar_QA\",\n0x042b:\"hy_AM\",\n0x044d:\"as_IN\",\n0x042c:\"az_AZ\",\n0x082c:\"az_AZ\",\n0x046d:\"ba_RU\",\n0x042d:\"eu_ES\",\n0x0423:\"be_BY\",\n0x0445:\"bn_IN\",\n0x201a:\"bs_BA\",\n0x141a:\"bs_BA\",\n0x047e:\"br_FR\",\n0x0402:\"bg_BG\",\n\n0x0403:\"ca_ES\",\n0x0004:\"zh_CHS\",\n0x0404:\"zh_TW\",\n0x0804:\"zh_CN\",\n0x0c04:\"zh_HK\",\n0x1004:\"zh_SG\",\n0x1404:\"zh_MO\",\n0x7c04:\"zh_CHT\",\n0x0483:\"co_FR\",\n0x041a:\"hr_HR\",\n0x101a:\"hr_BA\",\n0x0405:\"cs_CZ\",\n0x0406:\"da_DK\",\n0x048c:\"gbz_AF\",\n0x0465:\"div_MV\",\n0x0413:\"nl_NL\",\n0x0813:\"nl_BE\",\n0x0409:\"en_US\",\n0x0809:\"en_GB\",\n0x0c09:\"en_AU\",\n0x1009:\"en_CA\",\n0x1409:\"en_NZ\",\n0x1809:\"en_IE\",\n0x1c09:\"en_ZA\",\n0x2009:\"en_JA\",\n0x2409:\"en_CB\",\n0x2809:\"en_BZ\",\n0x2c09:\"en_TT\",\n0x3009:\"en_ZW\",\n0x3409:\"en_PH\",\n0x4009:\"en_IN\",\n0x4409:\"en_MY\",\n0x4809:\"en_IN\",\n0x0425:\"et_EE\",\n0x0438:\"fo_FO\",\n0x0464:\"fil_PH\",\n0x040b:\"fi_FI\",\n0x040c:\"fr_FR\",\n0x080c:\"fr_BE\",\n0x0c0c:\"fr_CA\",\n0x100c:\"fr_CH\",\n0x140c:\"fr_LU\",\n0x180c:\"fr_MC\",\n0x0462:\"fy_NL\",\n0x0456:\"gl_ES\",\n0x0437:\"ka_GE\",\n0x0407:\"de_DE\",\n0x0807:\"de_CH\",\n0x0c07:\"de_AT\",\n0x1007:\"de_LU\",\n0x1407:\"de_LI\",\n0x0408:\"el_GR\",\n0x046f:\"kl_GL\",\n0x0447:\"gu_IN\",\n0x0468:\"ha_NG\",\n0x040d:\"he_IL\",\n0x0439:\"hi_IN\",\n0x040e:\"hu_HU\",\n0x040f:\"is_IS\",\n0x0421:\"id_ID\",\n0x045d:\"iu_CA\",\n0x085d:\"iu_CA\",\n0x083c:\"ga_IE\",\n0x0410:\"it_IT\",\n0x0810:\"it_CH\",\n0x0411:\"ja_JP\",\n0x044b:\"kn_IN\",\n0x043f:\"kk_KZ\",\n0x0453:\"kh_KH\",\n0x0486:\"qut_GT\",\n0x0487:\"rw_RW\",\n0x0457:\"kok_IN\",\n0x0412:\"ko_KR\",\n0x0440:\"ky_KG\",\n0x0454:\"lo_LA\",\n0x0426:\"lv_LV\",\n0x0427:\"lt_LT\",\n0x082e:\"dsb_DE\",\n0x046e:\"lb_LU\",\n0x042f:\"mk_MK\",\n0x043e:\"ms_MY\",\n0x083e:\"ms_BN\",\n0x044c:\"ml_IN\",\n0x043a:\"mt_MT\",\n0x0481:\"mi_NZ\",\n0x047a:\"arn_CL\",\n0x044e:\"mr_IN\",\n0x047c:\"moh_CA\",\n0x0450:\"mn_MN\",\n0x0850:\"mn_CN\",\n0x0461:\"ne_NP\",\n0x0414:\"nb_NO\",\n0x0814:\"nn_NO\",\n0x0482:\"oc_FR\",\n0x0448:\"or_IN\",\n0x0463:\"ps_AF\",\n0x0429:\"fa_IR\",\n0x0415:\"pl_PL\",\n0x0416:\"pt_BR\",\n0x0816:\"pt_PT\",\n0x0446:\"pa_IN\",\n0x046b:\"quz_BO\",\n0x086b:\"quz_EC\",\n0x0c6b:\"quz_PE\",\n0x0418:\"ro_RO\",\n0x0417:\"rm_CH\",\n0x0419:\"ru_RU\",\n0x243b:\"smn_FI\",\n0x103b:\"smj_NO\",\n0x143b:\"smj_SE\",\n0x043b:\"se_NO\",\n0x083b:\"se_SE\",\n0x0c3b:\"se_FI\",\n0x203b:\"sms_FI\",\n0x183b:\"sma_NO\",\n0x1c3b:\"sma_SE\",\n0x044f:\"sa_IN\",\n0x0c1a:\"sr_SP\",\n0x1c1a:\"sr_BA\",\n0x081a:\"sr_SP\",\n0x181a:\"sr_BA\",\n0x045b:\"si_LK\",\n0x046c:\"ns_ZA\",\n0x0432:\"tn_ZA\",\n0x041b:\"sk_SK\",\n0x0424:\"sl_SI\",\n0x040a:\"es_ES\",\n0x080a:\"es_MX\",\n0x0c0a:\"es_ES\",\n0x100a:\"es_GT\",\n0x140a:\"es_CR\",\n0x180a:\"es_PA\",\n0x1c0a:\"es_DO\",\n0x200a:\"es_VE\",\n0x240a:\"es_CO\",\n0x280a:\"es_PE\",\n0x2c0a:\"es_AR\",\n0x300a:\"es_EC\",\n0x340a:\"es_CL\",\n0x380a:\"es_UR\",\n0x3c0a:\"es_PY\",\n0x400a:\"es_BO\",\n0x440a:\"es_SV\",\n0x480a:\"es_HN\",\n0x4c0a:\"es_NI\",\n0x500a:\"es_PR\",\n0x540a:\"es_US\",\n\n0x0441:\"sw_KE\",\n0x041d:\"sv_SE\",\n0x081d:\"sv_FI\",\n0x045a:\"syr_SY\",\n0x0428:\"tg_TJ\",\n0x085f:\"tmz_DZ\",\n0x0449:\"ta_IN\",\n0x0444:\"tt_RU\",\n0x044a:\"te_IN\",\n0x041e:\"th_TH\",\n0x0851:\"bo_BT\",\n0x0451:\"bo_CN\",\n0x041f:\"tr_TR\",\n0x0442:\"tk_TM\",\n0x0480:\"ug_CN\",\n0x0422:\"uk_UA\",\n0x042e:\"wen_DE\",\n0x0420:\"ur_PK\",\n0x0820:\"ur_IN\",\n0x0443:\"uz_UZ\",\n0x0843:\"uz_UZ\",\n0x042a:\"vi_VN\",\n0x0452:\"cy_GB\",\n0x0488:\"wo_SN\",\n0x0434:\"xh_ZA\",\n0x0485:\"sah_RU\",\n0x0478:\"ii_CN\",\n0x046a:\"yo_NG\",\n0x0435:\"zu_ZA\",\n}\n\ndef _print_locale():\n\n ''\n \n categories={}\n def _init_categories(categories=categories):\n  for k,v in globals(). items():\n   if k[:3]=='LC_':\n    categories[k]=v\n _init_categories()\n del categories['LC_ALL']\n \n print('Locale defaults as determined by getdefaultlocale():')\n print('-'*72)\n lang,enc=getdefaultlocale()\n print('Language: ',lang or'(undefined)')\n print('Encoding: ',enc or'(undefined)')\n print()\n \n print('Locale settings on startup:')\n print('-'*72)\n for name,category in categories. items():\n  print(name,'...')\n  lang,enc=getlocale(category)\n  print('   Language: ',lang or'(undefined)')\n  print('   Encoding: ',enc or'(undefined)')\n  print()\n  \n print()\n print('Locale settings after calling resetlocale():')\n print('-'*72)\n resetlocale()\n for name,category in categories. items():\n  print(name,'...')\n  lang,enc=getlocale(category)\n  print('   Language: ',lang or'(undefined)')\n  print('   Encoding: ',enc or'(undefined)')\n  print()\n  \n try :\n  setlocale(LC_ALL,\"\")\n except :\n  print('NOTE:')\n  print('setlocale(LC_ALL, \"\") does not support the default locale')\n  print('given in the OS environment variables.')\n else :\n  print()\n  print('Locale settings after calling setlocale(LC_ALL, \"\"):')\n  print('-'*72)\n  for name,category in categories. items():\n   print(name,'...')\n   lang,enc=getlocale(category)\n   print('   Language: ',lang or'(undefined)')\n   print('   Encoding: ',enc or'(undefined)')\n   print()\n   \n   \n   \ntry :\n LC_MESSAGES\nexcept NameError:\n pass\nelse :\n __all__. append(\"LC_MESSAGES\")\n \nif __name__ =='__main__':\n print('Locale aliasing:')\n print()\n _print_locale()\n print()\n print('Number formatting:')\n print()\n _test()\n", ["_bootlocale", "_locale", "builtins", "collections", "encodings", "encodings.aliases", "functools", "os", "re", "sys"]], "doctest": [".py", "\n\n\n\n\n\n\n\nr\"\"\"Module doctest -- a framework for running examples in docstrings.\n\nIn simplest use, end each module M to be tested with:\n\ndef _test():\n    import doctest\n    doctest.testmod()\n\nif __name__ == \"__main__\":\n    _test()\n\nThen running the module as a script will cause the examples in the\ndocstrings to get executed and verified:\n\npython M.py\n\nThis won't display anything unless an example fails, in which case the\nfailing example(s) and the cause(s) of the failure(s) are printed to stdout\n(why not stderr? because stderr is a lame hack <0.2 wink>), and the final\nline of output is \"Test failed.\".\n\nRun it with the -v switch instead:\n\npython M.py -v\n\nand a detailed report of all examples tried is printed to stdout, along\nwith assorted summaries at the end.\n\nYou can force verbose mode by passing \"verbose=True\" to testmod, or prohibit\nit by passing \"verbose=False\".  In either of those cases, sys.argv is not\nexamined by testmod.\n\nThere are a variety of other ways to run doctests, including integration\nwith the unittest framework, and support for running non-Python text\nfiles containing doctests.  There are also many ways to override parts\nof doctest's default behaviors.  See the Library Reference Manual for\ndetails.\n\"\"\"\n\n__docformat__='reStructuredText en'\n\n__all__=[\n\n'register_optionflag',\n'DONT_ACCEPT_TRUE_FOR_1',\n'DONT_ACCEPT_BLANKLINE',\n'NORMALIZE_WHITESPACE',\n'ELLIPSIS',\n'SKIP',\n'IGNORE_EXCEPTION_DETAIL',\n'COMPARISON_FLAGS',\n'REPORT_UDIFF',\n'REPORT_CDIFF',\n'REPORT_NDIFF',\n'REPORT_ONLY_FIRST_FAILURE',\n'REPORTING_FLAGS',\n'FAIL_FAST',\n\n\n'Example',\n'DocTest',\n\n'DocTestParser',\n\n'DocTestFinder',\n\n'DocTestRunner',\n'OutputChecker',\n'DocTestFailure',\n'UnexpectedException',\n'DebugRunner',\n\n'testmod',\n'testfile',\n'run_docstring_examples',\n\n'DocTestSuite',\n'DocFileSuite',\n'set_unittest_reportflags',\n\n'script_from_examples',\n'testsource',\n'debug_src',\n'debug',\n]\n\nimport __future__\nimport argparse\nimport difflib\nimport inspect\nimport linecache\nimport os\nimport pdb\nimport re\nimport sys\nimport traceback\nimport unittest\nfrom io import StringIO\nfrom collections import namedtuple\n\nTestResults=namedtuple('TestResults','failed attempted')\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nOPTIONFLAGS_BY_NAME={}\ndef register_optionflag(name):\n\n return OPTIONFLAGS_BY_NAME. setdefault(name,1 <<len(OPTIONFLAGS_BY_NAME))\n \nDONT_ACCEPT_TRUE_FOR_1=register_optionflag('DONT_ACCEPT_TRUE_FOR_1')\nDONT_ACCEPT_BLANKLINE=register_optionflag('DONT_ACCEPT_BLANKLINE')\nNORMALIZE_WHITESPACE=register_optionflag('NORMALIZE_WHITESPACE')\nELLIPSIS=register_optionflag('ELLIPSIS')\nSKIP=register_optionflag('SKIP')\nIGNORE_EXCEPTION_DETAIL=register_optionflag('IGNORE_EXCEPTION_DETAIL')\n\nCOMPARISON_FLAGS=(DONT_ACCEPT_TRUE_FOR_1 |\nDONT_ACCEPT_BLANKLINE |\nNORMALIZE_WHITESPACE |\nELLIPSIS |\nSKIP |\nIGNORE_EXCEPTION_DETAIL)\n\nREPORT_UDIFF=register_optionflag('REPORT_UDIFF')\nREPORT_CDIFF=register_optionflag('REPORT_CDIFF')\nREPORT_NDIFF=register_optionflag('REPORT_NDIFF')\nREPORT_ONLY_FIRST_FAILURE=register_optionflag('REPORT_ONLY_FIRST_FAILURE')\nFAIL_FAST=register_optionflag('FAIL_FAST')\n\nREPORTING_FLAGS=(REPORT_UDIFF |\nREPORT_CDIFF |\nREPORT_NDIFF |\nREPORT_ONLY_FIRST_FAILURE |\nFAIL_FAST)\n\n\nBLANKLINE_MARKER='<BLANKLINE>'\nELLIPSIS_MARKER='...'\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\ndef _extract_future_flags(globs):\n ''\n\n\n \n flags=0\n for fname in __future__. all_feature_names:\n  feature=globs. get(fname,None )\n  if feature is getattr(__future__,fname):\n   flags |=feature. compiler_flag\n return flags\n \ndef _normalize_module(module,depth=2):\n ''\n\n\n\n\n\n\n\n \n if inspect. ismodule(module):\n  return module\n elif isinstance(module,str):\n  return __import__(module,globals(),locals(),[\"*\"])\n elif module is None :\n  return sys. modules[sys. _getframe(depth). f_globals['__name__']]\n else :\n  raise TypeError(\"Expected a module, string, or None\")\n  \ndef _load_testfile(filename,package,module_relative,encoding):\n if module_relative:\n  package=_normalize_module(package,3)\n  filename=_module_relative_path(package,filename)\n  if getattr(package,'__loader__',None )is not None :\n   if hasattr(package. __loader__,'get_data'):\n    file_contents=package. __loader__. get_data(filename)\n    file_contents=file_contents. decode(encoding)\n    \n    \n    return file_contents. replace(os. linesep,'\\n'),filename\n with open(filename,encoding=encoding)as f:\n  return f. read(),filename\n  \ndef _indent(s,indent=4):\n ''\n\n\n \n \n return re. sub('(?m)^(?!$)',indent *' ',s)\n \ndef _exception_traceback(exc_info):\n ''\n\n\n \n \n excout=StringIO()\n exc_type,exc_val,exc_tb=exc_info\n traceback. print_exception(exc_type,exc_val,exc_tb,file=excout)\n return excout. getvalue()\n \n \nclass _SpoofOut(StringIO):\n def getvalue(self):\n  result=StringIO. getvalue(self)\n  \n  \n  \n  if result and not result. endswith(\"\\n\"):\n   result +=\"\\n\"\n  return result\n  \n def truncate(self,size=None ):\n  self. seek(size)\n  StringIO. truncate(self)\n  \n  \ndef _ellipsis_match(want,got):\n ''\n\n\n\n \n if ELLIPSIS_MARKER not in want:\n  return want ==got\n  \n  \n ws=want. split(ELLIPSIS_MARKER)\n assert len(ws)>=2\n \n \n startpos,endpos=0,len(got)\n w=ws[0]\n if w:\n  if got. startswith(w):\n   startpos=len(w)\n   del ws[0]\n  else :\n   return False\n w=ws[-1]\n if w:\n  if got. endswith(w):\n   endpos -=len(w)\n   del ws[-1]\n  else :\n   return False\n   \n if startpos >endpos:\n \n \n  return False\n  \n  \n  \n  \n for w in ws:\n \n \n \n  startpos=got. find(w,startpos,endpos)\n  if startpos <0:\n   return False\n  startpos +=len(w)\n  \n return True\n \ndef _comment_line(line):\n ''\n line=line. rstrip()\n if line:\n  return'# '+line\n else :\n  return'#'\n  \ndef _strip_exception_details(msg):\n\n\n\n\n\n\n\n\n\n\n start,end=0,len(msg)\n \n i=msg. find(\"\\n\")\n if i >=0:\n  end=i\n  \n i=msg. find(':',0,end)\n if i >=0:\n  end=i\n  \n i=msg. rfind('.',0,end)\n if i >=0:\n  start=i+1\n return msg[start:end]\n \nclass _OutputRedirectingPdb(pdb. Pdb):\n ''\n\n\n\n \n def __init__(self,out):\n  self. __out=out\n  self. __debugger_used=False\n  \n  pdb. Pdb. __init__(self,stdout=out,nosigint=True )\n  \n  self. use_rawinput=1\n  \n def set_trace(self,frame=None ):\n  self. __debugger_used=True\n  if frame is None :\n   frame=sys. _getframe(). f_back\n  pdb. Pdb. set_trace(self,frame)\n  \n def set_continue(self):\n \n \n  if self. __debugger_used:\n   pdb. Pdb. set_continue(self)\n   \n def trace_dispatch(self,*args):\n \n  save_stdout=sys. stdout\n  sys. stdout=self. __out\n  \n  try :\n   return pdb. Pdb. trace_dispatch(self,*args)\n  finally :\n   sys. stdout=save_stdout\n   \n   \ndef _module_relative_path(module,path):\n if not inspect. ismodule(module):\n  raise TypeError('Expected a module: %r'%module)\n if path. startswith('/'):\n  raise ValueError('Module-relative files may not have absolute paths')\n  \n  \n if hasattr(module,'__file__'):\n \n  basedir=os. path. split(module. __file__)[0]\n elif module. __name__ =='__main__':\n \n  if len(sys. argv)>0 and sys. argv[0]!='':\n   basedir=os. path. split(sys. argv[0])[0]\n  else :\n   basedir=os. curdir\n else :\n \n  raise ValueError(\"Can't resolve paths relative to the module \"+\n  module+\" (it has no __file__)\")\n  \n  \n return os. path. join(basedir,*(path. split('/')))\n \n \n \n \n \n \n \n \n \n \n \n \n \nclass Example:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n def __init__(self,source,want,exc_msg=None ,lineno=0,indent=0,\n options=None ):\n \n  if not source. endswith('\\n'):\n   source +='\\n'\n  if want and not want. endswith('\\n'):\n   want +='\\n'\n  if exc_msg is not None and not exc_msg. endswith('\\n'):\n   exc_msg +='\\n'\n   \n  self. source=source\n  self. want=want\n  self. lineno=lineno\n  self. indent=indent\n  if options is None :options={}\n  self. options=options\n  self. exc_msg=exc_msg\n  \n def __eq__(self,other):\n  if type(self)is not type(other):\n   return NotImplemented\n   \n  return self. source ==other. source and  self. want ==other. want and  self. lineno ==other. lineno and  self. indent ==other. indent and  self. options ==other. options and  self. exc_msg ==other. exc_msg\n  \n def __hash__(self):\n  return hash((self. source,self. want,self. lineno,self. indent,\n  self. exc_msg))\n  \nclass DocTest:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n def __init__(self,examples,globs,name,filename,lineno,docstring):\n  ''\n\n\n  \n  assert not isinstance(examples,str),  \"DocTest no longer accepts str; use DocTestParser instead\"\n  self. examples=examples\n  self. docstring=docstring\n  self. globs=globs. copy()\n  self. name=name\n  self. filename=filename\n  self. lineno=lineno\n  \n def __repr__(self):\n  if len(self. examples)==0:\n   examples='no examples'\n  elif len(self. examples)==1:\n   examples='1 example'\n  else :\n   examples='%d examples'%len(self. examples)\n  return ('<DocTest %s from %s:%s (%s)>'%\n  (self. name,self. filename,self. lineno,examples))\n  \n def __eq__(self,other):\n  if type(self)is not type(other):\n   return NotImplemented\n   \n  return self. examples ==other. examples and  self. docstring ==other. docstring and  self. globs ==other. globs and  self. name ==other. name and  self. filename ==other. filename and  self. lineno ==other. lineno\n  \n def __hash__(self):\n  return hash((self. docstring,self. name,self. filename,self. lineno))\n  \n  \n def __lt__(self,other):\n  if not isinstance(other,DocTest):\n   return NotImplemented\n  return ((self. name,self. filename,self. lineno,id(self))\n  <\n  (other. name,other. filename,other. lineno,id(other)))\n  \n  \n  \n  \n  \nclass DocTestParser:\n ''\n\n \n \n \n \n \n \n _EXAMPLE_RE=re. compile(r'''\n        # Source consists of a PS1 line followed by zero or more PS2 lines.\n        (?P<source>\n            (?:^(?P<indent> [ ]*) >>>    .*)    # PS1 line\n            (?:\\n           [ ]*  \\.\\.\\. .*)*)  # PS2 lines\n        \\n?\n        # Want consists of any non-blank lines that do not start with PS1.\n        (?P<want> (?:(?![ ]*$)    # Not a blank line\n                     (?![ ]*>>>)  # Not a line starting with PS1\n                     .+$\\n?       # But any other line\n                  )*)\n        ''',re. MULTILINE |re. VERBOSE)\n \n \n \n \n \n \n \n \n \n \n _EXCEPTION_RE=re. compile(r\"\"\"\n        # Grab the traceback header.  Different versions of Python have\n        # said different things on the first traceback line.\n        ^(?P<hdr> Traceback\\ \\(\n            (?: most\\ recent\\ call\\ last\n            |   innermost\\ last\n            ) \\) :\n        )\n        \\s* $                # toss trailing whitespace on the header.\n        (?P<stack> .*?)      # don't blink: absorb stuff until...\n        ^ (?P<msg> \\w+ .*)   #     a line *starts* with alphanum.\n        \"\"\",re. VERBOSE |re. MULTILINE |re. DOTALL)\n \n \n \n _IS_BLANK_OR_COMMENT=re. compile(r'^[ ]*(#.*)?$'). match\n \n def parse(self,string,name='<string>'):\n  ''\n\n\n\n\n\n  \n  string=string. expandtabs()\n  \n  min_indent=self. _min_indent(string)\n  if min_indent >0:\n   string='\\n'. join([l[min_indent:]for l in string. split('\\n')])\n   \n  output=[]\n  charno,lineno=0,0\n  \n  for m in self. _EXAMPLE_RE. finditer(string):\n  \n   output. append(string[charno:m. start()])\n   \n   lineno +=string. count('\\n',charno,m. start())\n   \n   (source,options,want,exc_msg)=   self. _parse_example(m,name,lineno)\n   \n   if not self. _IS_BLANK_OR_COMMENT(source):\n    output. append(Example(source,want,exc_msg,\n    lineno=lineno,\n    indent=min_indent+len(m. group('indent')),\n    options=options))\n    \n   lineno +=string. count('\\n',m. start(),m. end())\n   \n   charno=m. end()\n   \n  output. append(string[charno:])\n  return output\n  \n def get_doctest(self,string,globs,name,filename,lineno):\n  ''\n\n\n\n\n\n\n  \n  return DocTest(self. get_examples(string,name),globs,\n  name,filename,lineno,string)\n  \n def get_examples(self,string,name='<string>'):\n  ''\n\n\n\n\n\n\n\n\n  \n  return [x for x in self. parse(string,name)\n  if isinstance(x,Example)]\n  \n def _parse_example(self,m,name,lineno):\n  ''\n\n\n\n\n\n\n\n\n  \n  \n  indent=len(m. group('indent'))\n  \n  \n  \n  source_lines=m. group('source'). split('\\n')\n  self. _check_prompt_blank(source_lines,indent,name,lineno)\n  self. _check_prefix(source_lines[1:],' '*indent+'.',name,lineno)\n  source='\\n'. join([sl[indent+4:]for sl in source_lines])\n  \n  \n  \n  \n  want=m. group('want')\n  want_lines=want. split('\\n')\n  if len(want_lines)>1 and re. match(r' *$',want_lines[-1]):\n   del want_lines[-1]\n  self. _check_prefix(want_lines,' '*indent,name,\n  lineno+len(source_lines))\n  want='\\n'. join([wl[indent:]for wl in want_lines])\n  \n  \n  m=self. _EXCEPTION_RE. match(want)\n  if m:\n   exc_msg=m. group('msg')\n  else :\n   exc_msg=None\n   \n   \n  options=self. _find_options(source,name,lineno)\n  \n  return source,options,want,exc_msg\n  \n  \n  \n  \n  \n  \n  \n  \n _OPTION_DIRECTIVE_RE=re. compile(r'#\\s*doctest:\\s*([^\\n\\'\"]*)$',\n re. MULTILINE)\n \n def _find_options(self,source,name,lineno):\n  ''\n\n\n\n\n\n  \n  options={}\n  \n  for m in self. _OPTION_DIRECTIVE_RE. finditer(source):\n   option_strings=m. group(1). replace(',',' '). split()\n   for option in option_strings:\n    if (option[0]not in'+-'or\n    option[1:]not in OPTIONFLAGS_BY_NAME):\n     raise ValueError('line %r of the doctest for %s '\n     'has an invalid option: %r'%\n     (lineno+1,name,option))\n    flag=OPTIONFLAGS_BY_NAME[option[1:]]\n    options[flag]=(option[0]=='+')\n  if options and self. _IS_BLANK_OR_COMMENT(source):\n   raise ValueError('line %r of the doctest for %s has an option '\n   'directive on a line with no example: %r'%\n   (lineno,name,source))\n  return options\n  \n  \n  \n _INDENT_RE=re. compile('^([ ]*)(?=\\S)',re. MULTILINE)\n \n def _min_indent(self,s):\n  ''\n  indents=[len(indent)for indent in self. _INDENT_RE. findall(s)]\n  if len(indents)>0:\n   return min(indents)\n  else :\n   return 0\n   \n def _check_prompt_blank(self,lines,indent,name,lineno):\n  ''\n\n\n\n\n  \n  for i,line in enumerate(lines):\n   if len(line)>=indent+4 and line[indent+3]!=' ':\n    raise ValueError('line %r of the docstring for %s '\n    'lacks blank after %s: %r'%\n    (lineno+i+1,name,\n    line[indent:indent+3],line))\n    \n def _check_prefix(self,lines,prefix,name,lineno):\n  ''\n\n\n  \n  for i,line in enumerate(lines):\n   if line and not line. startswith(prefix):\n    raise ValueError('line %r of the docstring for %s has '\n    'inconsistent leading whitespace: %r'%\n    (lineno+i+1,name,line))\n    \n    \n    \n    \n    \n    \nclass DocTestFinder:\n ''\n\n\n\n\n\n \n \n def __init__(self,verbose=False ,parser=DocTestParser(),\n recurse=True ,exclude_empty=True ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. _parser=parser\n  self. _verbose=verbose\n  self. _recurse=recurse\n  self. _exclude_empty=exclude_empty\n  \n def find(self,obj,name=None ,module=None ,globs=None ,extraglobs=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if name is None :\n   name=getattr(obj,'__name__',None )\n   if name is None :\n    raise ValueError(\"DocTestFinder.find: name must be given \"\n    \"when obj.__name__ doesn't exist: %r\"%\n    (type(obj),))\n    \n    \n    \n    \n  if module is False :\n   module=None\n  elif module is None :\n   module=inspect. getmodule(obj)\n   \n   \n   \n   \n  try :\n   file=inspect. getsourcefile(obj)\n  except TypeError:\n   source_lines=None\n  else :\n   if not file:\n   \n   \n    file=inspect. getfile(obj)\n    if not file[0]+file[-2:]=='<]>':file=None\n   if file is None :\n    source_lines=None\n   else :\n    if module is not None :\n    \n    \n    \n     source_lines=linecache. getlines(file,module. __dict__)\n    else :\n    \n    \n     source_lines=linecache. getlines(file)\n    if not source_lines:\n     source_lines=None\n     \n     \n  if globs is None :\n   if module is None :\n    globs={}\n   else :\n    globs=module. __dict__. copy()\n  else :\n   globs=globs. copy()\n  if extraglobs is not None :\n   globs. update(extraglobs)\n  if'__name__'not in globs:\n   globs['__name__']='__main__'\n   \n   \n  tests=[]\n  self. _find(tests,obj,name,module,source_lines,globs,{})\n  \n  \n  \n  \n  tests. sort()\n  return tests\n  \n def _from_module(self,module,object):\n  ''\n\n\n  \n  if module is None :\n   return True\n  elif inspect. getmodule(object)is not None :\n   return module is inspect. getmodule(object)\n  elif inspect. isfunction(object):\n   return module. __dict__ is object. __globals__\n  elif inspect. ismethoddescriptor(object):\n   if hasattr(object,'__objclass__'):\n    obj_mod=object. __objclass__. __module__\n   elif hasattr(object,'__module__'):\n    obj_mod=object. __module__\n   else :\n    return True\n   return module. __name__ ==obj_mod\n  elif inspect. isclass(object):\n   return module. __name__ ==object. __module__\n  elif hasattr(object,'__module__'):\n   return module. __name__ ==object. __module__\n  elif isinstance(object,property):\n   return True\n  else :\n   raise ValueError(\"object must be a class or function\")\n   \n def _find(self,tests,obj,name,module,source_lines,globs,seen):\n  ''\n\n\n  \n  if self. _verbose:\n   print('Finding tests in %s'%name)\n   \n   \n  if id(obj)in seen:\n   return\n  seen[id(obj)]=1\n  \n  \n  test=self. _get_test(obj,name,module,globs,source_lines)\n  if test is not None :\n   tests. append(test)\n   \n   \n  if inspect. ismodule(obj)and self. _recurse:\n   for valname,val in obj. __dict__. items():\n    valname='%s.%s'%(name,valname)\n    \n    if ((inspect. isroutine(val)or inspect. isclass(val))and\n    self. _from_module(module,val)):\n     self. _find(tests,val,valname,module,source_lines,\n     globs,seen)\n     \n     \n  if inspect. ismodule(obj)and self. _recurse:\n   for valname,val in getattr(obj,'__test__',{}). items():\n    if not isinstance(valname,str):\n     raise ValueError(\"DocTestFinder.find: __test__ keys \"\n     \"must be strings: %r\"%\n     (type(valname),))\n    if not (inspect. isroutine(val)or inspect. isclass(val)or\n    inspect. ismodule(val)or isinstance(val,str)):\n     raise ValueError(\"DocTestFinder.find: __test__ values \"\n     \"must be strings, functions, methods, \"\n     \"classes, or modules: %r\"%\n     (type(val),))\n    valname='%s.__test__.%s'%(name,valname)\n    self. _find(tests,val,valname,module,source_lines,\n    globs,seen)\n    \n    \n  if inspect. isclass(obj)and self. _recurse:\n   for valname,val in obj. __dict__. items():\n   \n    if isinstance(val,staticmethod):\n     val=getattr(obj,valname)\n    if isinstance(val,classmethod):\n     val=getattr(obj,valname). __func__\n     \n     \n    if ((inspect. isroutine(val)or inspect. isclass(val)or\n    isinstance(val,property))and\n    self. _from_module(module,val)):\n     valname='%s.%s'%(name,valname)\n     self. _find(tests,val,valname,module,source_lines,\n     globs,seen)\n     \n def _get_test(self,obj,name,module,globs,source_lines):\n  ''\n\n\n  \n  \n  \n  if isinstance(obj,str):\n   docstring=obj\n  else :\n   try :\n    if obj. __doc__ is None :\n     docstring=''\n    else :\n     docstring=obj. __doc__\n     if not isinstance(docstring,str):\n      docstring=str(docstring)\n   except (TypeError,AttributeError):\n    docstring=''\n    \n    \n  lineno=self. _find_lineno(obj,source_lines)\n  \n  \n  if self. _exclude_empty and not docstring:\n   return None\n   \n   \n  if module is None :\n   filename=None\n  else :\n   filename=getattr(module,'__file__',module. __name__)\n   if filename[-4:]in (\".pyc\",\".pyo\"):\n    filename=filename[:-1]\n  return self. _parser. get_doctest(docstring,globs,name,\n  filename,lineno)\n  \n def _find_lineno(self,obj,source_lines):\n  ''\n\n\n  \n  lineno=None\n  \n  \n  if inspect. ismodule(obj):\n   lineno=0\n   \n   \n   \n   \n  if inspect. isclass(obj):\n   if source_lines is None :\n    return None\n   pat=re. compile(r'^\\s*class\\s*%s\\b'%\n   getattr(obj,'__name__','-'))\n   for i,line in enumerate(source_lines):\n    if pat. match(line):\n     lineno=i\n     break\n     \n     \n  if inspect. ismethod(obj):obj=obj. __func__\n  if inspect. isfunction(obj):obj=obj. __code__\n  if inspect. istraceback(obj):obj=obj. tb_frame\n  if inspect. isframe(obj):obj=obj. f_code\n  if inspect. iscode(obj):\n   lineno=getattr(obj,'co_firstlineno',None )-1\n   \n   \n   \n   \n   \n   \n  if lineno is not None :\n   if source_lines is None :\n    return lineno+1\n   pat=re. compile('(^|.*:)\\s*\\w*(\"|\\')')\n   for lineno in range(lineno,len(source_lines)):\n    if pat. match(source_lines[lineno]):\n     return lineno\n     \n     \n  return None\n  \n  \n  \n  \n  \nclass DocTestRunner:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n DIVIDER=\"*\"*70\n \n def __init__(self,checker=None ,verbose=None ,optionflags=0):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. _checker=checker or OutputChecker()\n  if verbose is None :\n   verbose='-v'in sys. argv\n  self. _verbose=verbose\n  self. optionflags=optionflags\n  self. original_optionflags=optionflags\n  \n  \n  self. tries=0\n  self. failures=0\n  self. _name2ft={}\n  \n  \n  self. _fakeout=_SpoofOut()\n  \n  \n  \n  \n  \n def report_start(self,out,test,example):\n  ''\n\n\n  \n  if self. _verbose:\n   if example. want:\n    out('Trying:\\n'+_indent(example. source)+\n    'Expecting:\\n'+_indent(example. want))\n   else :\n    out('Trying:\\n'+_indent(example. source)+\n    'Expecting nothing\\n')\n    \n def report_success(self,out,test,example,got):\n  ''\n\n\n  \n  if self. _verbose:\n   out(\"ok\\n\")\n   \n def report_failure(self,out,test,example,got):\n  ''\n\n  \n  out(self. _failure_header(test,example)+\n  self. _checker. output_difference(example,got,self. optionflags))\n  \n def report_unexpected_exception(self,out,test,example,exc_info):\n  ''\n\n  \n  out(self. _failure_header(test,example)+\n  'Exception raised:\\n'+_indent(_exception_traceback(exc_info)))\n  \n def _failure_header(self,test,example):\n  out=[self. DIVIDER]\n  if test. filename:\n   if test. lineno is not None and example. lineno is not None :\n    lineno=test. lineno+example. lineno+1\n   else :\n    lineno='?'\n   out. append('File \"%s\", line %s, in %s'%\n   (test. filename,lineno,test. name))\n  else :\n   out. append('Line %s, in %s'%(example. lineno+1,test. name))\n  out. append('Failed example:')\n  source=example. source\n  out. append(_indent(source))\n  return'\\n'. join(out)\n  \n  \n  \n  \n  \n def __run(self,test,compileflags,out):\n  ''\n\n\n\n\n\n\n\n  \n  \n  failures=tries=0\n  \n  \n  \n  original_optionflags=self. optionflags\n  \n  SUCCESS,FAILURE,BOOM=range(3)\n  \n  check=self. _checker. check_output\n  \n  \n  for examplenum,example in enumerate(test. examples):\n  \n  \n  \n   quiet=(self. optionflags&REPORT_ONLY_FIRST_FAILURE and\n   failures >0)\n   \n   \n   self. optionflags=original_optionflags\n   if example. options:\n    for (optionflag,val)in example. options. items():\n     if val:\n      self. optionflags |=optionflag\n     else :\n      self. optionflags &=~optionflag\n      \n      \n   if self. optionflags&SKIP:\n    continue\n    \n    \n   tries +=1\n   if not quiet:\n    self. report_start(out,test,example)\n    \n    \n    \n    \n   filename='<doctest %s[%d]>'%(test. name,examplenum)\n   \n   \n   \n   \n   try :\n   \n    exec(compile(example. source,filename,\"single\",\n    compileflags,1),test. globs)\n    self. debugger. set_continue()\n    exception=None\n   except KeyboardInterrupt:\n    raise\n   except :\n    exception=sys. exc_info()\n    self. debugger. set_continue()\n    \n   got=self. _fakeout. getvalue()\n   self. _fakeout. truncate(0)\n   outcome=FAILURE\n   \n   \n   \n   if exception is None :\n    if check(example. want,got,self. optionflags):\n     outcome=SUCCESS\n     \n     \n   else :\n    exc_msg=traceback. format_exception_only(*exception[:2])[-1]\n    if not quiet:\n     got +=_exception_traceback(exception)\n     \n     \n     \n    if example. exc_msg is None :\n     outcome=BOOM\n     \n     \n    elif check(example. exc_msg,exc_msg,self. optionflags):\n     outcome=SUCCESS\n     \n     \n    elif self. optionflags&IGNORE_EXCEPTION_DETAIL:\n     if check(_strip_exception_details(example. exc_msg),\n     _strip_exception_details(exc_msg),\n     self. optionflags):\n      outcome=SUCCESS\n      \n      \n   if outcome is SUCCESS:\n    if not quiet:\n     self. report_success(out,test,example,got)\n   elif outcome is FAILURE:\n    if not quiet:\n     self. report_failure(out,test,example,got)\n    failures +=1\n   elif outcome is BOOM:\n    if not quiet:\n     self. report_unexpected_exception(out,test,example,\n     exception)\n    failures +=1\n   else :\n    assert False ,(\"unknown outcome\",outcome)\n    \n   if failures and self. optionflags&FAIL_FAST:\n    break\n    \n    \n  self. optionflags=original_optionflags\n  \n  \n  self. __record_outcome(test,failures,tries)\n  return TestResults(failures,tries)\n  \n def __record_outcome(self,test,f,t):\n  ''\n\n\n  \n  f2,t2=self. _name2ft. get(test. name,(0,0))\n  self. _name2ft[test. name]=(f+f2,t+t2)\n  self. failures +=f\n  self. tries +=t\n  \n __LINECACHE_FILENAME_RE=re. compile(r'<doctest '\n r'(?P<name>.+)'\n r'\\[(?P<examplenum>\\d+)\\]>$')\n def __patched_linecache_getlines(self,filename,module_globals=None ):\n  m=self. __LINECACHE_FILENAME_RE. match(filename)\n  if m and m. group('name')==self. test. name:\n   example=self. test. examples[int(m. group('examplenum'))]\n   return example. source. splitlines(keepends=True )\n  else :\n   return self. save_linecache_getlines(filename,module_globals)\n   \n def run(self,test,compileflags=None ,out=None ,clear_globs=True ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. test=test\n  \n  if compileflags is None :\n   compileflags=_extract_future_flags(test. globs)\n   \n  save_stdout=sys. stdout\n  if out is None :\n   encoding=save_stdout. encoding\n   if encoding is None or encoding. lower()=='utf-8':\n    out=save_stdout. write\n   else :\n   \n    def out(s):\n     s=str(s. encode(encoding,'backslashreplace'),encoding)\n     save_stdout. write(s)\n  sys. stdout=self. _fakeout\n  \n  \n  \n  \n  \n  \n  save_trace=sys. gettrace()\n  save_set_trace=pdb. set_trace\n  self. debugger=_OutputRedirectingPdb(save_stdout)\n  self. debugger. reset()\n  pdb. set_trace=self. debugger. set_trace\n  \n  \n  \n  self. save_linecache_getlines=linecache. getlines\n  linecache. getlines=self. __patched_linecache_getlines\n  \n  \n  save_displayhook=sys. displayhook\n  sys. displayhook=sys. __displayhook__\n  \n  try :\n   return self. __run(test,compileflags,out)\n  finally :\n   sys. stdout=save_stdout\n   pdb. set_trace=save_set_trace\n   sys. settrace(save_trace)\n   linecache. getlines=self. save_linecache_getlines\n   sys. displayhook=save_displayhook\n   if clear_globs:\n    test. globs. clear()\n    import builtins\n    builtins. _=None\n    \n    \n    \n    \n def summarize(self,verbose=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  if verbose is None :\n   verbose=self. _verbose\n  notests=[]\n  passed=[]\n  failed=[]\n  totalt=totalf=0\n  for x in self. _name2ft. items():\n   name,(f,t)=x\n   assert f <=t\n   totalt +=t\n   totalf +=f\n   if t ==0:\n    notests. append(name)\n   elif f ==0:\n    passed. append((name,t))\n   else :\n    failed. append(x)\n  if verbose:\n   if notests:\n    print(len(notests),\"items had no tests:\")\n    notests. sort()\n    for thing in notests:\n     print(\"   \",thing)\n   if passed:\n    print(len(passed),\"items passed all tests:\")\n    passed. sort()\n    for thing,count in passed:\n     print(\" %3d tests in %s\"%(count,thing))\n  if failed:\n   print(self. DIVIDER)\n   print(len(failed),\"items had failures:\")\n   failed. sort()\n   for thing,(f,t)in failed:\n    print(\" %3d of %3d in %s\"%(f,t,thing))\n  if verbose:\n   print(totalt,\"tests in\",len(self. _name2ft),\"items.\")\n   print(totalt -totalf,\"passed and\",totalf,\"failed.\")\n  if totalf:\n   print(\"***Test Failed***\",totalf,\"failures.\")\n  elif verbose:\n   print(\"Test passed.\")\n  return TestResults(totalf,totalt)\n  \n  \n  \n  \n def merge(self,other):\n  d=self. _name2ft\n  for name,(f,t)in other. _name2ft. items():\n   if name in d:\n   \n   \n   \n   \n    f2,t2=d[name]\n    f=f+f2\n    t=t+t2\n   d[name]=f,t\n   \nclass OutputChecker:\n ''\n\n\n\n\n\n \n def _toAscii(self,s):\n  ''\n\n  \n  return str(s. encode('ASCII','backslashreplace'),\"ASCII\")\n  \n def check_output(self,want,got,optionflags):\n  ''\n\n\n\n\n\n\n\n  \n  \n  \n  \n  \n  \n  \n  got=self. _toAscii(got)\n  want=self. _toAscii(want)\n  \n  \n  \n  if got ==want:\n   return True\n   \n   \n   \n  if not (optionflags&DONT_ACCEPT_TRUE_FOR_1):\n   if (got,want)==(\"True\\n\",\"1\\n\"):\n    return True\n   if (got,want)==(\"False\\n\",\"0\\n\"):\n    return True\n    \n    \n    \n  if not (optionflags&DONT_ACCEPT_BLANKLINE):\n  \n   want=re. sub('(?m)^%s\\s*?$'%re. escape(BLANKLINE_MARKER),\n   '',want)\n   \n   \n   got=re. sub('(?m)^\\s*?$','',got)\n   if got ==want:\n    return True\n    \n    \n    \n    \n  if optionflags&NORMALIZE_WHITESPACE:\n   got=' '. join(got. split())\n   want=' '. join(want. split())\n   if got ==want:\n    return True\n    \n    \n    \n  if optionflags&ELLIPSIS:\n   if _ellipsis_match(want,got):\n    return True\n    \n    \n  return False\n  \n  \n def _do_a_fancy_diff(self,want,got,optionflags):\n \n  if not optionflags&(REPORT_UDIFF |\n  REPORT_CDIFF |\n  REPORT_NDIFF):\n   return False\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n  if optionflags&REPORT_NDIFF:\n   return True\n   \n   \n  return want. count('\\n')>2 and got. count('\\n')>2\n  \n def output_difference(self,example,got,optionflags):\n  ''\n\n\n\n\n  \n  want=example. want\n  \n  \n  if not (optionflags&DONT_ACCEPT_BLANKLINE):\n   got=re. sub('(?m)^[ ]*(?=\\n)',BLANKLINE_MARKER,got)\n   \n   \n  if self. _do_a_fancy_diff(want,got,optionflags):\n  \n   want_lines=want. splitlines(keepends=True )\n   got_lines=got. splitlines(keepends=True )\n   \n   if optionflags&REPORT_UDIFF:\n    diff=difflib. unified_diff(want_lines,got_lines,n=2)\n    diff=list(diff)[2:]\n    kind='unified diff with -expected +actual'\n   elif optionflags&REPORT_CDIFF:\n    diff=difflib. context_diff(want_lines,got_lines,n=2)\n    diff=list(diff)[2:]\n    kind='context diff with expected followed by actual'\n   elif optionflags&REPORT_NDIFF:\n    engine=difflib. Differ(charjunk=difflib. IS_CHARACTER_JUNK)\n    diff=list(engine. compare(want_lines,got_lines))\n    kind='ndiff with -expected +actual'\n   else :\n    assert 0,'Bad diff option'\n    \n   diff=[line. rstrip()+'\\n'for line in diff]\n   return'Differences (%s):\\n'%kind+_indent(''. join(diff))\n   \n   \n   \n  if want and got:\n   return'Expected:\\n%sGot:\\n%s'%(_indent(want),_indent(got))\n  elif want:\n   return'Expected:\\n%sGot nothing\\n'%_indent(want)\n  elif got:\n   return'Expected nothing\\nGot:\\n%s'%_indent(got)\n  else :\n   return'Expected nothing\\nGot nothing\\n'\n   \nclass DocTestFailure(Exception):\n ''\n\n\n\n\n\n\n\n\n \n def __init__(self,test,example,got):\n  self. test=test\n  self. example=example\n  self. got=got\n  \n def __str__(self):\n  return str(self. test)\n  \nclass UnexpectedException(Exception):\n ''\n\n\n\n\n\n\n\n\n \n def __init__(self,test,example,exc_info):\n  self. test=test\n  self. example=example\n  self. exc_info=exc_info\n  \n def __str__(self):\n  return str(self. test)\n  \nclass DebugRunner(DocTestRunner):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def run(self,test,compileflags=None ,out=None ,clear_globs=True ):\n  r=DocTestRunner. run(self,test,compileflags,out,False )\n  if clear_globs:\n   test. globs. clear()\n  return r\n  \n def report_unexpected_exception(self,out,test,example,exc_info):\n  raise UnexpectedException(test,example,exc_info)\n  \n def report_failure(self,out,test,example,got):\n  raise DocTestFailure(test,example,got)\n  \n  \n  \n  \n  \n  \n  \n  \nmaster=None\n\ndef testmod(m=None ,name=None ,globs=None ,verbose=None ,\nreport=True ,optionflags=0,extraglobs=None ,\nraise_on_error=False ,exclude_empty=False ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n global master\n \n \n if m is None :\n \n \n \n  m=sys. modules. get('__main__')\n  \n  \n if not inspect. ismodule(m):\n  raise TypeError(\"testmod: module required; %r\"%(m,))\n  \n  \n if name is None :\n  name=m. __name__\n  \n  \n finder=DocTestFinder(exclude_empty=exclude_empty)\n \n if raise_on_error:\n  runner=DebugRunner(verbose=verbose,optionflags=optionflags)\n else :\n  runner=DocTestRunner(verbose=verbose,optionflags=optionflags)\n  \n for test in finder. find(m,name,globs=globs,extraglobs=extraglobs):\n  runner. run(test)\n  \n if report:\n  runner. summarize()\n  \n if master is None :\n  master=runner\n else :\n  master. merge(runner)\n  \n return TestResults(runner. failures,runner. tries)\n \ndef testfile(filename,module_relative=True ,name=None ,package=None ,\nglobs=None ,verbose=None ,report=True ,optionflags=0,\nextraglobs=None ,raise_on_error=False ,parser=DocTestParser(),\nencoding=None ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n global master\n \n if package and not module_relative:\n  raise ValueError(\"Package may only be specified for module-\"\n  \"relative paths.\")\n  \n  \n text,filename=_load_testfile(filename,package,module_relative,\n encoding or\"utf-8\")\n \n \n if name is None :\n  name=os. path. basename(filename)\n  \n  \n if globs is None :\n  globs={}\n else :\n  globs=globs. copy()\n if extraglobs is not None :\n  globs. update(extraglobs)\n if'__name__'not in globs:\n  globs['__name__']='__main__'\n  \n if raise_on_error:\n  runner=DebugRunner(verbose=verbose,optionflags=optionflags)\n else :\n  runner=DocTestRunner(verbose=verbose,optionflags=optionflags)\n  \n  \n test=parser. get_doctest(text,globs,name,filename,0)\n runner. run(test)\n \n if report:\n  runner. summarize()\n  \n if master is None :\n  master=runner\n else :\n  master. merge(runner)\n  \n return TestResults(runner. failures,runner. tries)\n \ndef run_docstring_examples(f,globs,verbose=False ,name=\"NoName\",\ncompileflags=None ,optionflags=0):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n finder=DocTestFinder(verbose=verbose,recurse=False )\n runner=DocTestRunner(verbose=verbose,optionflags=optionflags)\n for test in finder. find(f,name,globs=globs):\n  runner. run(test,compileflags=compileflags)\n  \n  \n  \n  \n  \n_unittest_reportflags=0\n\ndef set_unittest_reportflags(flags):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n global _unittest_reportflags\n \n if (flags&REPORTING_FLAGS)!=flags:\n  raise ValueError(\"Only reporting flags allowed\",flags)\n old=_unittest_reportflags\n _unittest_reportflags=flags\n return old\n \n \nclass DocTestCase(unittest. TestCase):\n\n def __init__(self,test,optionflags=0,setUp=None ,tearDown=None ,\n checker=None ):\n \n  unittest. TestCase. __init__(self)\n  self. _dt_optionflags=optionflags\n  self. _dt_checker=checker\n  self. _dt_test=test\n  self. _dt_setUp=setUp\n  self. _dt_tearDown=tearDown\n  \n def setUp(self):\n  test=self. _dt_test\n  \n  if self. _dt_setUp is not None :\n   self. _dt_setUp(test)\n   \n def tearDown(self):\n  test=self. _dt_test\n  \n  if self. _dt_tearDown is not None :\n   self. _dt_tearDown(test)\n   \n  test. globs. clear()\n  \n def runTest(self):\n  test=self. _dt_test\n  old=sys. stdout\n  new=StringIO()\n  optionflags=self. _dt_optionflags\n  \n  if not (optionflags&REPORTING_FLAGS):\n  \n  \n   optionflags |=_unittest_reportflags\n   \n  runner=DocTestRunner(optionflags=optionflags,\n  checker=self. _dt_checker,verbose=False )\n  \n  try :\n   runner. DIVIDER=\"-\"*70\n   failures,tries=runner. run(\n   test,out=new. write,clear_globs=False )\n  finally :\n   sys. stdout=old\n   \n  if failures:\n   raise self. failureException(self. format_failure(new. getvalue()))\n   \n def format_failure(self,err):\n  test=self. _dt_test\n  if test. lineno is None :\n   lineno='unknown line number'\n  else :\n   lineno='%s'%test. lineno\n  lname='.'. join(test. name. split('.')[-1:])\n  return ('Failed doctest test for %s\\n'\n  '  File \"%s\", line %s, in %s\\n\\n%s'\n  %(test. name,test. filename,lineno,lname,err)\n  )\n  \n def debug(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  self. setUp()\n  runner=DebugRunner(optionflags=self. _dt_optionflags,\n  checker=self. _dt_checker,verbose=False )\n  runner. run(self. _dt_test,clear_globs=False )\n  self. tearDown()\n  \n def id(self):\n  return self. _dt_test. name\n  \n def __eq__(self,other):\n  if type(self)is not type(other):\n   return NotImplemented\n   \n  return self. _dt_test ==other. _dt_test and  self. _dt_optionflags ==other. _dt_optionflags and  self. _dt_setUp ==other. _dt_setUp and  self. _dt_tearDown ==other. _dt_tearDown and  self. _dt_checker ==other. _dt_checker\n  \n def __hash__(self):\n  return hash((self. _dt_optionflags,self. _dt_setUp,self. _dt_tearDown,\n  self. _dt_checker))\n  \n def __repr__(self):\n  name=self. _dt_test. name. split('.')\n  return\"%s (%s)\"%(name[-1],'.'. join(name[:-1]))\n  \n __str__=__repr__\n \n def shortDescription(self):\n  return\"Doctest: \"+self. _dt_test. name\n  \nclass SkipDocTestCase(DocTestCase):\n def __init__(self,module):\n  self. module=module\n  DocTestCase. __init__(self,None )\n  \n def setUp(self):\n  self. skipTest(\"DocTestSuite will not work with -O2 and above\")\n  \n def test_skip(self):\n  pass\n  \n def shortDescription(self):\n  return\"Skipping tests from %s\"%self. module. __name__\n  \n __str__=shortDescription\n \n \nclass _DocTestSuite(unittest. TestSuite):\n\n def _removeTestAtIndex(self,index):\n  pass\n  \n  \ndef DocTestSuite(module=None ,globs=None ,extraglobs=None ,test_finder=None ,\n**options):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n if test_finder is None :\n  test_finder=DocTestFinder()\n  \n module=_normalize_module(module)\n tests=test_finder. find(module,globs=globs,extraglobs=extraglobs)\n \n if not tests and sys. flags. optimize >=2:\n \n  suite=_DocTestSuite()\n  suite. addTest(SkipDocTestCase(module))\n  return suite\n elif not tests:\n \n \n \n \n \n \n \n  raise ValueError(module,\"has no docstrings\")\n  \n tests. sort()\n suite=_DocTestSuite()\n \n for test in tests:\n  if len(test. examples)==0:\n   continue\n  if not test. filename:\n   filename=module. __file__\n   if filename[-4:]in (\".pyc\",\".pyo\"):\n    filename=filename[:-1]\n   test. filename=filename\n  suite. addTest(DocTestCase(test,**options))\n  \n return suite\n \nclass DocFileCase(DocTestCase):\n\n def id(self):\n  return'_'. join(self. _dt_test. name. split('.'))\n  \n def __repr__(self):\n  return self. _dt_test. filename\n __str__=__repr__\n \n def format_failure(self,err):\n  return ('Failed doctest test for %s\\n  File \"%s\", line 0\\n\\n%s'\n  %(self. _dt_test. name,self. _dt_test. filename,err)\n  )\n  \ndef DocFileTest(path,module_relative=True ,package=None ,\nglobs=None ,parser=DocTestParser(),\nencoding=None ,**options):\n if globs is None :\n  globs={}\n else :\n  globs=globs. copy()\n  \n if package and not module_relative:\n  raise ValueError(\"Package may only be specified for module-\"\n  \"relative paths.\")\n  \n  \n doc,path=_load_testfile(path,package,module_relative,\n encoding or\"utf-8\")\n \n if\"__file__\"not in globs:\n  globs[\"__file__\"]=path\n  \n  \n name=os. path. basename(path)\n \n \n test=parser. get_doctest(doc,globs,name,path,0)\n return DocFileCase(test,**options)\n \ndef DocFileSuite(*paths,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n suite=_DocTestSuite()\n \n \n \n \n if kw. get('module_relative',True ):\n  kw['package']=_normalize_module(kw. get('package'))\n  \n for path in paths:\n  suite. addTest(DocFileTest(path,**kw))\n  \n return suite\n \n \n \n \n \ndef script_from_examples(s):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n output=[]\n for piece in DocTestParser(). parse(s):\n  if isinstance(piece,Example):\n  \n   output. append(piece. source[:-1])\n   \n   want=piece. want\n   if want:\n    output. append('# Expected:')\n    output +=['## '+l for l in want. split('\\n')[:-1]]\n  else :\n  \n   output +=[_comment_line(l)\n   for l in piece. split('\\n')[:-1]]\n   \n   \n while output and output[-1]=='#':\n  output. pop()\n while output and output[0]=='#':\n  output. pop(0)\n  \n  \n return'\\n'. join(output)+'\\n'\n \ndef testsource(module,name):\n ''\n\n\n\n\n \n module=_normalize_module(module)\n tests=DocTestFinder(). find(module)\n test=[t for t in tests if t. name ==name]\n if not test:\n  raise ValueError(name,\"not found in tests\")\n test=test[0]\n testsrc=script_from_examples(test. docstring)\n return testsrc\n \ndef debug_src(src,pm=False ,globs=None ):\n ''\n testsrc=script_from_examples(src)\n debug_script(testsrc,pm,globs)\n \ndef debug_script(src,pm=False ,globs=None ):\n ''\n import pdb\n \n if globs:\n  globs=globs. copy()\n else :\n  globs={}\n  \n if pm:\n  try :\n   exec(src,globs,globs)\n  except :\n   print(sys. exc_info()[1])\n   p=pdb. Pdb(nosigint=True )\n   p. reset()\n   p. interaction(None ,sys. exc_info()[2])\n else :\n  pdb. Pdb(nosigint=True ). run(\"exec(%r)\"%src,globs,globs)\n  \ndef debug(module,name,pm=False ):\n ''\n\n\n\n\n \n module=_normalize_module(module)\n testsrc=testsource(module,name)\n debug_script(testsrc,pm,module. __dict__)\n \n \n \n \nclass _TestClass:\n ''\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,val):\n  ''\n\n\n\n\n  \n  \n  self. val=val\n  \n def square(self):\n  ''\n\n\n\n  \n  \n  self. val=self. val **2\n  return self\n  \n def get(self):\n  ''\n\n\n\n\n  \n  \n  return self. val\n  \n__test__={\"_TestClass\":_TestClass,\n\"string\":r\"\"\"\n                      Example of a string object, searched as-is.\n                      >>> x = 1; y = 2\n                      >>> x + y, x * y\n                      (3, 2)\n                      \"\"\",\n\n\"bool-int equivalence\":r\"\"\"\n                                    In 2.2, boolean expressions displayed\n                                    0 or 1.  By default, we still accept\n                                    them.  This can be disabled by passing\n                                    DONT_ACCEPT_TRUE_FOR_1 to the new\n                                    optionflags argument.\n                                    >>> 4 == 4\n                                    1\n                                    >>> 4 == 4\n                                    True\n                                    >>> 4 > 4\n                                    0\n                                    >>> 4 > 4\n                                    False\n                                    \"\"\",\n\n\"blank lines\":r\"\"\"\n                Blank lines can be marked with <BLANKLINE>:\n                    >>> print('foo\\n\\nbar\\n')\n                    foo\n                    <BLANKLINE>\n                    bar\n                    <BLANKLINE>\n            \"\"\",\n\n\"ellipsis\":r\"\"\"\n                If the ellipsis flag is used, then '...' can be used to\n                elide substrings in the desired output:\n                    >>> print(list(range(1000))) #doctest: +ELLIPSIS\n                    [0, 1, 2, ..., 999]\n            \"\"\",\n\n\"whitespace normalization\":r\"\"\"\n                If the whitespace normalization flag is used, then\n                differences in whitespace are ignored.\n                    >>> print(list(range(30))) #doctest: +NORMALIZE_WHITESPACE\n                    [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14,\n                     15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,\n                     27, 28, 29]\n            \"\"\",\n}\n\n\ndef _test():\n parser=argparse. ArgumentParser(description=\"doctest runner\")\n parser. add_argument('-v','--verbose',action='store_true',default=False ,\n help='print very verbose output for all tests')\n parser. add_argument('-o','--option',action='append',\n choices=OPTIONFLAGS_BY_NAME. keys(),default=[],\n help=('specify a doctest option flag to apply'\n ' to the test run; may be specified more'\n ' than once to apply multiple options'))\n parser. add_argument('-f','--fail-fast',action='store_true',\n help=('stop running tests after first failure (this'\n ' is a shorthand for -o FAIL_FAST, and is'\n ' in addition to any other -o options)'))\n parser. add_argument('file',nargs='+',\n help='file containing the tests to run')\n args=parser. parse_args()\n testfiles=args. file\n \n \n verbose=args. verbose\n options=0\n for option in args. option:\n  options |=OPTIONFLAGS_BY_NAME[option]\n if args. fail_fast:\n  options |=FAIL_FAST\n for filename in testfiles:\n  if filename. endswith(\".py\"):\n  \n  \n  \n   dirname,filename=os. path. split(filename)\n   sys. path. insert(0,dirname)\n   m=__import__(filename[:-3])\n   del sys. path[0]\n   failures,_=testmod(m,verbose=verbose,optionflags=options)\n  else :\n   failures,_=testfile(filename,module_relative=False ,\n   verbose=verbose,optionflags=options)\n  if failures:\n   return 1\n return 0\n \n \nif __name__ ==\"__main__\":\n sys. exit(_test())\n", ["__future__", "argparse", "builtins", "collections", "difflib", "inspect", "io", "linecache", "os", "pdb", "re", "sys", "traceback", "unittest"]], "signal": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nCTRL_BREAK_EVENT=1\nCTRL_C_EVENT=0\nNSIG=23\nSIGABRT=22\nSIGBREAK=21\nSIGFPE=8\nSIGILL=4\nSIGINT=2\nSIGSEGV=11\nSIGTERM=15\nSIG_DFL=0\nSIG_IGN=1\n\ndef signal(signalnum,handler):\n pass\n", []], "_functools": [".py", "def partial(func,*args,**keywords):\n def newfunc(*fargs,**fkeywords):\n  newkeywords=keywords. copy()\n  newkeywords. update(fkeywords)\n  return func(*(args+fargs),**newkeywords)\n newfunc. func=func\n newfunc. args=args\n newfunc. keywords=keywords\n return newfunc\n \ndef reduce(func,iterable,initializer=None ):\n args=iter(iterable)\n if initializer is not None :\n  res=initializer\n else :\n  res=next(args)\n while True :\n  try :\n   res=func(res,next(args))\n  except StopIteration:\n   return res\n", []], "token": [".py", "''\n\n__all__=['tok_name','ISTERMINAL','ISNONTERMINAL','ISEOF']\n\n\n\n\n\n\n\n\n\nENDMARKER=0\nNAME=1\nNUMBER=2\nSTRING=3\nNEWLINE=4\nINDENT=5\nDEDENT=6\nLPAR=7\nRPAR=8\nLSQB=9\nRSQB=10\nCOLON=11\nCOMMA=12\nSEMI=13\nPLUS=14\nMINUS=15\nSTAR=16\nSLASH=17\nVBAR=18\nAMPER=19\nLESS=20\nGREATER=21\nEQUAL=22\nDOT=23\nPERCENT=24\nLBRACE=25\nRBRACE=26\nEQEQUAL=27\nNOTEQUAL=28\nLESSEQUAL=29\nGREATEREQUAL=30\nTILDE=31\nCIRCUMFLEX=32\nLEFTSHIFT=33\nRIGHTSHIFT=34\nDOUBLESTAR=35\nPLUSEQUAL=36\nMINEQUAL=37\nSTAREQUAL=38\nSLASHEQUAL=39\nPERCENTEQUAL=40\nAMPEREQUAL=41\nVBAREQUAL=42\nCIRCUMFLEXEQUAL=43\nLEFTSHIFTEQUAL=44\nRIGHTSHIFTEQUAL=45\nDOUBLESTAREQUAL=46\nDOUBLESLASH=47\nDOUBLESLASHEQUAL=48\nAT=49\nRARROW=50\nELLIPSIS=51\nOP=52\nERRORTOKEN=53\nN_TOKENS=54\nNT_OFFSET=256\n\n\ntok_name={value:name\nfor name,value in globals(). items()\nif isinstance(value,int)and not name. startswith('_')}\n__all__. extend(tok_name. values())\n\ndef ISTERMINAL(x):\n return x <NT_OFFSET\n \ndef ISNONTERMINAL(x):\n return x >=NT_OFFSET\n \ndef ISEOF(x):\n return x ==ENDMARKER\n \n \ndef _main():\n import re\n import sys\n args=sys. argv[1:]\n inFileName=args and args[0]or\"Include/token.h\"\n outFileName=\"Lib/token.py\"\n if len(args)>1:\n  outFileName=args[1]\n try :\n  fp=open(inFileName)\n except IOError as err:\n  sys. stdout. write(\"I/O error: %s\\n\"%str(err))\n  sys. exit(1)\n lines=fp. read(). split(\"\\n\")\n fp. close()\n prog=re. compile(\n \"#define[ \\t][ \\t]*([A-Z0-9][A-Z0-9_]*)[ \\t][ \\t]*([0-9][0-9]*)\",\n re. IGNORECASE)\n tokens={}\n for line in lines:\n  match=prog. match(line)\n  if match:\n   name,val=match. group(1,2)\n   val=int(val)\n   tokens[val]=name\n keys=sorted(tokens. keys())\n \n try :\n  fp=open(outFileName)\n except IOError as err:\n  sys. stderr. write(\"I/O error: %s\\n\"%str(err))\n  sys. exit(2)\n format=fp. read(). split(\"\\n\")\n fp. close()\n try :\n  start=format. index(\"#--start constants--\")+1\n  end=format. index(\"#--end constants--\")\n except ValueError:\n  sys. stderr. write(\"target does not contain format markers\")\n  sys. exit(3)\n lines=[]\n for val in keys:\n  lines. append(\"%s = %d\"%(tokens[val],val))\n format[start:end]=lines\n try :\n  fp=open(outFileName,'w')\n except IOError as err:\n  sys. stderr. write(\"I/O error: %s\\n\"%str(err))\n  sys. exit(4)\n fp. write(\"\\n\". join(format))\n fp. close()\n \n \nif __name__ ==\"__main__\":\n _main()\n", ["re", "sys"]], "browser": [".py", "import javascript\n\nfrom _browser import *\n\nfrom . local_storage import LocalStorage\nfrom . session_storage import SessionStorage\nfrom . object_storage import ObjectStorage\n\nWebSocket=window. WebSocket. new", ["_browser", "browser.local_storage", "browser.object_storage", "browser.session_storage", "javascript"], 1], "fnmatch": [".py", "''\n\n\n\n\n\n\n\n\n\n\nimport os\nimport posixpath\nimport re\nimport functools\n\n__all__=[\"filter\",\"fnmatch\",\"fnmatchcase\",\"translate\"]\n\ndef fnmatch(name,pat):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n name=os. path. normcase(name)\n pat=os. path. normcase(pat)\n return fnmatchcase(name,pat)\n \n@functools. lru_cache(maxsize=256,typed=True )\ndef _compile_pattern(pat):\n if isinstance(pat,bytes):\n  pat_str=str(pat,'ISO-8859-1')\n  res_str=translate(pat_str)\n  res=bytes(res_str,'ISO-8859-1')\n else :\n  res=translate(pat)\n return re. compile(res). match\n \ndef filter(names,pat):\n ''\n result=[]\n pat=os. path. normcase(pat)\n match=_compile_pattern(pat)\n if os. path is posixpath:\n \n  for name in names:\n   if match(name):\n    result. append(name)\n else :\n  for name in names:\n   if match(os. path. normcase(name)):\n    result. append(name)\n return result\n \ndef fnmatchcase(name,pat):\n ''\n\n\n\n \n match=_compile_pattern(pat)\n return match(name)is not None\n \n \ndef translate(pat):\n ''\n\n\n \n \n i,n=0,len(pat)\n res=''\n while i <n:\n  c=pat[i]\n  i=i+1\n  if c =='*':\n   res=res+'.*'\n  elif c =='?':\n   res=res+'.'\n  elif c =='[':\n   j=i\n   if j <n and pat[j]=='!':\n    j=j+1\n   if j <n and pat[j]==']':\n    j=j+1\n   while j <n and pat[j]!=']':\n    j=j+1\n   if j >=n:\n    res=res+'\\\\['\n   else :\n    stuff=pat[i:j]. replace('\\\\','\\\\\\\\')\n    i=j+1\n    if stuff[0]=='!':\n     stuff='^'+stuff[1:]\n    elif stuff[0]=='^':\n     stuff='\\\\'+stuff\n    res='%s[%s]'%(res,stuff)\n  else :\n   res=res+re. escape(c)\n return res+'\\Z(?ms)'\n", ["functools", "os", "posixpath", "re"]], "warnings": [".py", "''\n\n\n\n\nimport linecache\nimport sys\n\n__all__=[\"warn\",\"showwarning\",\"formatwarning\",\"filterwarnings\",\n\"resetwarnings\",\"catch_warnings\"]\n\n\ndef showwarning(message,category,filename,lineno,file=None ,line=None ):\n ''\n if file is None :\n  file=sys. stderr\n try :\n  file. write(formatwarning(message,category,filename,lineno,line))\n except IOError:\n  pass\n  \ndef formatwarning(message,category,filename,lineno,line=None ):\n ''\n s=\"%s:%s: %s: %s\\n\"%(filename,lineno,category. __name__,message)\n line=linecache. getline(filename,lineno)if line is None else line\n if line:\n  line=line. strip()\n  s +=\"  %s\\n\"%line\n return s\n \ndef filterwarnings(action,message=\"\",category=Warning,module=\"\",lineno=0,\nappend=False ):\n ''\n\n\n\n\n\n\n\n\n \n import re\n assert action in (\"error\",\"ignore\",\"always\",\"default\",\"module\",\n \"once\"),\"invalid action: %r\"%(action,)\n assert isinstance(message,str),\"message must be a string\"\n assert isinstance(category,type),\"category must be a class\"\n assert issubclass(category,Warning),\"category must be a Warning subclass\"\n assert isinstance(module,str),\"module must be a string\"\n assert isinstance(lineno,int)and lineno >=0, \"lineno must be an int >= 0\"\n item=(action,re. compile(message,re. I),category,\n re. compile(module),lineno)\n if append:\n  filters. append(item)\n else :\n  filters. insert(0,item)\n  \ndef simplefilter(action,category=Warning,lineno=0,append=False ):\n ''\n\n\n\n\n\n\n\n \n assert action in (\"error\",\"ignore\",\"always\",\"default\",\"module\",\n \"once\"),\"invalid action: %r\"%(action,)\n assert isinstance(lineno,int)and lineno >=0, \"lineno must be an int >= 0\"\n item=(action,None ,category,None ,lineno)\n if append:\n  filters. append(item)\n else :\n  filters. insert(0,item)\n  \ndef resetwarnings():\n ''\n filters[:]=[]\n \nclass _OptionError(Exception):\n ''\n pass\n \n \ndef _processoptions(args):\n for arg in args:\n  try :\n   _setoption(arg)\n  except _OptionError as msg:\n   print(\"Invalid -W option ignored:\",msg,file=sys. stderr)\n   \n   \ndef _setoption(arg):\n import re\n parts=arg. split(':')\n if len(parts)>5:\n  raise _OptionError(\"too many fields (max 5): %r\"%(arg,))\n while len(parts)<5:\n  parts. append('')\n action,message,category,module,lineno=[s. strip()\n for s in parts]\n action=_getaction(action)\n message=re. escape(message)\n category=_getcategory(category)\n module=re. escape(module)\n if module:\n  module=module+'$'\n if lineno:\n  try :\n   lineno=int(lineno)\n   if lineno <0:\n    raise ValueError\n  except (ValueError,OverflowError):\n   raise _OptionError(\"invalid lineno %r\"%(lineno,))\n else :\n  lineno=0\n filterwarnings(action,message,category,module,lineno)\n \n \ndef _getaction(action):\n if not action:\n  return\"default\"\n if action ==\"all\":return\"always\"\n for a in ('default','always','ignore','module','once','error'):\n  if a. startswith(action):\n   return a\n raise _OptionError(\"invalid action: %r\"%(action,))\n \n \ndef _getcategory(category):\n import re\n if not category:\n  return Warning\n if re. match(\"^[a-zA-Z0-9_]+$\",category):\n  try :\n   cat=eval(category)\n  except NameError:\n   raise _OptionError(\"unknown warning category: %r\"%(category,))\n else :\n  i=category. rfind(\".\")\n  module=category[:i]\n  klass=category[i+1:]\n  try :\n   m=__import__(module,None ,None ,[klass])\n  except ImportError:\n   raise _OptionError(\"invalid module name: %r\"%(module,))\n  try :\n   cat=getattr(m,klass)\n  except AttributeError:\n   raise _OptionError(\"unknown warning category: %r\"%(category,))\n if not issubclass(cat,Warning):\n  raise _OptionError(\"invalid warning category: %r\"%(category,))\n return cat\n \n \n \ndef warn(message,category=None ,stacklevel=1):\n ''\n \n if isinstance(message,Warning):\n  category=message. __class__\n  \n if category is None :\n  category=UserWarning\n assert issubclass(category,Warning)\n \n try :\n  caller=sys. _getframe(stacklevel)\n except ValueError:\n  globals=sys. __dict__\n  lineno=1\n else :\n  globals=caller. f_globals\n  lineno=caller. f_lineno\n if'__name__'in globals:\n  module=globals['__name__']\n else :\n  module=\"<string>\"\n filename=globals. get('__file__')\n if filename:\n  fnl=filename. lower()\n  if fnl. endswith((\".pyc\",\".pyo\")):\n   filename=filename[:-1]\n else :\n  if module ==\"__main__\":\n   try :\n    filename=sys. argv[0]\n   except AttributeError:\n   \n    filename='__main__'\n  if not filename:\n   filename=module\n registry=globals. setdefault(\"__warningregistry__\",{})\n warn_explicit(message,category,filename,lineno,module,registry,\n globals)\n \ndef warn_explicit(message,category,filename,lineno,\nmodule=None ,registry=None ,module_globals=None ):\n lineno=int(lineno)\n if module is None :\n  module=filename or\"<unknown>\"\n  if module[-3:]. lower()==\".py\":\n   module=module[:-3]\n if registry is None :\n  registry={}\n if isinstance(message,Warning):\n  text=str(message)\n  category=message. __class__\n else :\n  text=message\n  message=category(message)\n key=(text,category,lineno)\n \n if registry. get(key):\n  return\n  \n for item in filters:\n  action,msg,cat,mod,ln=item\n  if ((msg is None or msg. match(text))and\n  issubclass(category,cat)and\n  (mod is None or mod. match(module))and\n  (ln ==0 or lineno ==ln)):\n   break\n else :\n  action=defaultaction\n  \n if action ==\"ignore\":\n  registry[key]=1\n  return\n  \n  \n  \n linecache. getlines(filename,module_globals)\n \n if action ==\"error\":\n  raise message\n  \n if action ==\"once\":\n  registry[key]=1\n  oncekey=(text,category)\n  if onceregistry. get(oncekey):\n   return\n  onceregistry[oncekey]=1\n elif action ==\"always\":\n  pass\n elif action ==\"module\":\n  registry[key]=1\n  altkey=(text,category,0)\n  if registry. get(altkey):\n   return\n  registry[altkey]=1\n elif action ==\"default\":\n  registry[key]=1\n else :\n \n  raise RuntimeError(\n  \"Unrecognized action (%r) in warnings.filters:\\n %s\"%\n  (action,item))\n if not callable(showwarning):\n  raise TypeError(\"warnings.showwarning() must be set to a \"\n  \"function or method\")\n  \n showwarning(message,category,filename,lineno)\n \n \nclass WarningMessage(object):\n\n ''\n \n _WARNING_DETAILS=(\"message\",\"category\",\"filename\",\"lineno\",\"file\",\n \"line\")\n \n def __init__(self,message,category,filename,lineno,file=None ,\n line=None ):\n  local_values=locals()\n  for attr in self. _WARNING_DETAILS:\n   setattr(self,attr,local_values[attr])\n  self. _category_name=category. __name__ if category else None\n  \n def __str__(self):\n  return (\"{message : %r, category : %r, filename : %r, lineno : %s, \"\n  \"line : %r}\"%(self. message,self. _category_name,\n  self. filename,self. lineno,self. line))\n  \n  \nclass catch_warnings(object):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,*,record=False ,module=None ):\n  ''\n\n\n\n\n\n  \n  self. _record=record\n  self. _module=sys. modules['warnings']if module is None else module\n  self. _entered=False\n  \n def __repr__(self):\n  args=[]\n  if self. _record:\n   args. append(\"record=True\")\n  if self. _module is not sys. modules['warnings']:\n   args. append(\"module=%r\"%self. _module)\n  name=type(self). __name__\n  return\"%s(%s)\"%(name,\", \". join(args))\n  \n def __enter__(self):\n  if self. _entered:\n   raise RuntimeError(\"Cannot enter %r twice\"%self)\n  self. _entered=True\n  self. _filters=self. _module. filters\n  self. _module. filters=self. _filters[:]\n  self. _showwarning=self. _module. showwarning\n  if self. _record:\n   log=[]\n   def showwarning(*args,**kwargs):\n    log. append(WarningMessage(*args,**kwargs))\n   self. _module. showwarning=showwarning\n   return log\n  else :\n   return None\n   \n def __exit__(self,*exc_info):\n  if not self. _entered:\n   raise RuntimeError(\"Cannot exit %r without entering first\"%self)\n  self. _module. filters=self. _filters\n  self. _module. showwarning=self. _showwarning\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n_warnings_defaults=False\ntry :\n from _warnings import (filters,_defaultaction,_onceregistry,\n warn,warn_explicit)\n defaultaction=_defaultaction\n onceregistry=_onceregistry\n _warnings_defaults=True\nexcept ImportError:\n filters=[]\n defaultaction=\"default\"\n onceregistry={}\n \n \n \n_processoptions(sys. warnoptions)\nif not _warnings_defaults:\n silence=[ImportWarning,PendingDeprecationWarning]\n silence. append(DeprecationWarning)\n for cls in silence:\n  simplefilter(\"ignore\",category=cls)\n bytes_warning=sys. flags. bytes_warning\n if bytes_warning >1:\n  bytes_action=\"error\"\n elif bytes_warning:\n  bytes_action=\"default\"\n else :\n  bytes_action=\"ignore\"\n simplefilter(bytes_action,category=BytesWarning,append=1)\n \n if hasattr(sys,'gettotalrefcount'):\n  resource_action=\"always\"\n else :\n  resource_action=\"ignore\"\n simplefilter(resource_action,category=ResourceWarning,append=1)\n \ndel _warnings_defaults\n", ["_warnings", "linecache", "re", "sys"]], "encodings.aliases": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\naliases={\n\n\n\n\n'646':'ascii',\n'ansi_x3.4_1968':'ascii',\n'ansi_x3_4_1968':'ascii',\n'ansi_x3.4_1986':'ascii',\n'cp367':'ascii',\n'csascii':'ascii',\n'ibm367':'ascii',\n'iso646_us':'ascii',\n'iso_646.irv_1991':'ascii',\n'iso_ir_6':'ascii',\n'us':'ascii',\n'us_ascii':'ascii',\n\n\n'base64':'base64_codec',\n'base_64':'base64_codec',\n\n\n'big5_tw':'big5',\n'csbig5':'big5',\n\n\n'big5_hkscs':'big5hkscs',\n'hkscs':'big5hkscs',\n\n\n'bz2':'bz2_codec',\n\n\n'037':'cp037',\n'csibm037':'cp037',\n'ebcdic_cp_ca':'cp037',\n'ebcdic_cp_nl':'cp037',\n'ebcdic_cp_us':'cp037',\n'ebcdic_cp_wt':'cp037',\n'ibm037':'cp037',\n'ibm039':'cp037',\n\n\n'1026':'cp1026',\n'csibm1026':'cp1026',\n'ibm1026':'cp1026',\n\n\n'1125':'cp1125',\n'ibm1125':'cp1125',\n'cp866u':'cp1125',\n'ruscii':'cp1125',\n\n\n'1140':'cp1140',\n'ibm1140':'cp1140',\n\n\n'1250':'cp1250',\n'windows_1250':'cp1250',\n\n\n'1251':'cp1251',\n'windows_1251':'cp1251',\n\n\n'1252':'cp1252',\n'windows_1252':'cp1252',\n\n\n'1253':'cp1253',\n'windows_1253':'cp1253',\n\n\n'1254':'cp1254',\n'windows_1254':'cp1254',\n\n\n'1255':'cp1255',\n'windows_1255':'cp1255',\n\n\n'1256':'cp1256',\n'windows_1256':'cp1256',\n\n\n'1257':'cp1257',\n'windows_1257':'cp1257',\n\n\n'1258':'cp1258',\n'windows_1258':'cp1258',\n\n\n'273':'cp273',\n'ibm273':'cp273',\n'csibm273':'cp273',\n\n\n'424':'cp424',\n'csibm424':'cp424',\n'ebcdic_cp_he':'cp424',\n'ibm424':'cp424',\n\n\n'437':'cp437',\n'cspc8codepage437':'cp437',\n'ibm437':'cp437',\n\n\n'500':'cp500',\n'csibm500':'cp500',\n'ebcdic_cp_be':'cp500',\n'ebcdic_cp_ch':'cp500',\n'ibm500':'cp500',\n\n\n'775':'cp775',\n'cspc775baltic':'cp775',\n'ibm775':'cp775',\n\n\n'850':'cp850',\n'cspc850multilingual':'cp850',\n'ibm850':'cp850',\n\n\n'852':'cp852',\n'cspcp852':'cp852',\n'ibm852':'cp852',\n\n\n'855':'cp855',\n'csibm855':'cp855',\n'ibm855':'cp855',\n\n\n'857':'cp857',\n'csibm857':'cp857',\n'ibm857':'cp857',\n\n\n'858':'cp858',\n'csibm858':'cp858',\n'ibm858':'cp858',\n\n\n'860':'cp860',\n'csibm860':'cp860',\n'ibm860':'cp860',\n\n\n'861':'cp861',\n'cp_is':'cp861',\n'csibm861':'cp861',\n'ibm861':'cp861',\n\n\n'862':'cp862',\n'cspc862latinhebrew':'cp862',\n'ibm862':'cp862',\n\n\n'863':'cp863',\n'csibm863':'cp863',\n'ibm863':'cp863',\n\n\n'864':'cp864',\n'csibm864':'cp864',\n'ibm864':'cp864',\n\n\n'865':'cp865',\n'csibm865':'cp865',\n'ibm865':'cp865',\n\n\n'866':'cp866',\n'csibm866':'cp866',\n'ibm866':'cp866',\n\n\n'869':'cp869',\n'cp_gr':'cp869',\n'csibm869':'cp869',\n'ibm869':'cp869',\n\n\n'932':'cp932',\n'ms932':'cp932',\n'mskanji':'cp932',\n'ms_kanji':'cp932',\n\n\n'949':'cp949',\n'ms949':'cp949',\n'uhc':'cp949',\n\n\n'950':'cp950',\n'ms950':'cp950',\n\n\n'jisx0213':'euc_jis_2004',\n'eucjis2004':'euc_jis_2004',\n'euc_jis2004':'euc_jis_2004',\n\n\n'eucjisx0213':'euc_jisx0213',\n\n\n'eucjp':'euc_jp',\n'ujis':'euc_jp',\n'u_jis':'euc_jp',\n\n\n'euckr':'euc_kr',\n'korean':'euc_kr',\n'ksc5601':'euc_kr',\n'ks_c_5601':'euc_kr',\n'ks_c_5601_1987':'euc_kr',\n'ksx1001':'euc_kr',\n'ks_x_1001':'euc_kr',\n\n\n'gb18030_2000':'gb18030',\n\n\n'chinese':'gb2312',\n'csiso58gb231280':'gb2312',\n'euc_cn':'gb2312',\n'euccn':'gb2312',\n'eucgb2312_cn':'gb2312',\n'gb2312_1980':'gb2312',\n'gb2312_80':'gb2312',\n'iso_ir_58':'gb2312',\n\n\n'936':'gbk',\n'cp936':'gbk',\n'ms936':'gbk',\n\n\n'hex':'hex_codec',\n\n\n'roman8':'hp_roman8',\n'r8':'hp_roman8',\n'csHPRoman8':'hp_roman8',\n\n\n'hzgb':'hz',\n'hz_gb':'hz',\n'hz_gb_2312':'hz',\n\n\n'csiso2022jp':'iso2022_jp',\n'iso2022jp':'iso2022_jp',\n'iso_2022_jp':'iso2022_jp',\n\n\n'iso2022jp_1':'iso2022_jp_1',\n'iso_2022_jp_1':'iso2022_jp_1',\n\n\n'iso2022jp_2':'iso2022_jp_2',\n'iso_2022_jp_2':'iso2022_jp_2',\n\n\n'iso_2022_jp_2004':'iso2022_jp_2004',\n'iso2022jp_2004':'iso2022_jp_2004',\n\n\n'iso2022jp_3':'iso2022_jp_3',\n'iso_2022_jp_3':'iso2022_jp_3',\n\n\n'iso2022jp_ext':'iso2022_jp_ext',\n'iso_2022_jp_ext':'iso2022_jp_ext',\n\n\n'csiso2022kr':'iso2022_kr',\n'iso2022kr':'iso2022_kr',\n'iso_2022_kr':'iso2022_kr',\n\n\n'csisolatin6':'iso8859_10',\n'iso_8859_10':'iso8859_10',\n'iso_8859_10_1992':'iso8859_10',\n'iso_ir_157':'iso8859_10',\n'l6':'iso8859_10',\n'latin6':'iso8859_10',\n\n\n'thai':'iso8859_11',\n'iso_8859_11':'iso8859_11',\n'iso_8859_11_2001':'iso8859_11',\n\n\n'iso_8859_13':'iso8859_13',\n'l7':'iso8859_13',\n'latin7':'iso8859_13',\n\n\n'iso_8859_14':'iso8859_14',\n'iso_8859_14_1998':'iso8859_14',\n'iso_celtic':'iso8859_14',\n'iso_ir_199':'iso8859_14',\n'l8':'iso8859_14',\n'latin8':'iso8859_14',\n\n\n'iso_8859_15':'iso8859_15',\n'l9':'iso8859_15',\n'latin9':'iso8859_15',\n\n\n'iso_8859_16':'iso8859_16',\n'iso_8859_16_2001':'iso8859_16',\n'iso_ir_226':'iso8859_16',\n'l10':'iso8859_16',\n'latin10':'iso8859_16',\n\n\n'csisolatin2':'iso8859_2',\n'iso_8859_2':'iso8859_2',\n'iso_8859_2_1987':'iso8859_2',\n'iso_ir_101':'iso8859_2',\n'l2':'iso8859_2',\n'latin2':'iso8859_2',\n\n\n'csisolatin3':'iso8859_3',\n'iso_8859_3':'iso8859_3',\n'iso_8859_3_1988':'iso8859_3',\n'iso_ir_109':'iso8859_3',\n'l3':'iso8859_3',\n'latin3':'iso8859_3',\n\n\n'csisolatin4':'iso8859_4',\n'iso_8859_4':'iso8859_4',\n'iso_8859_4_1988':'iso8859_4',\n'iso_ir_110':'iso8859_4',\n'l4':'iso8859_4',\n'latin4':'iso8859_4',\n\n\n'csisolatincyrillic':'iso8859_5',\n'cyrillic':'iso8859_5',\n'iso_8859_5':'iso8859_5',\n'iso_8859_5_1988':'iso8859_5',\n'iso_ir_144':'iso8859_5',\n\n\n'arabic':'iso8859_6',\n'asmo_708':'iso8859_6',\n'csisolatinarabic':'iso8859_6',\n'ecma_114':'iso8859_6',\n'iso_8859_6':'iso8859_6',\n'iso_8859_6_1987':'iso8859_6',\n'iso_ir_127':'iso8859_6',\n\n\n'csisolatingreek':'iso8859_7',\n'ecma_118':'iso8859_7',\n'elot_928':'iso8859_7',\n'greek':'iso8859_7',\n'greek8':'iso8859_7',\n'iso_8859_7':'iso8859_7',\n'iso_8859_7_1987':'iso8859_7',\n'iso_ir_126':'iso8859_7',\n\n\n'csisolatinhebrew':'iso8859_8',\n'hebrew':'iso8859_8',\n'iso_8859_8':'iso8859_8',\n'iso_8859_8_1988':'iso8859_8',\n'iso_ir_138':'iso8859_8',\n\n\n'csisolatin5':'iso8859_9',\n'iso_8859_9':'iso8859_9',\n'iso_8859_9_1989':'iso8859_9',\n'iso_ir_148':'iso8859_9',\n'l5':'iso8859_9',\n'latin5':'iso8859_9',\n\n\n'cp1361':'johab',\n'ms1361':'johab',\n\n\n'cskoi8r':'koi8_r',\n\n\n\n\n\n\n\n\n'8859':'latin_1',\n'cp819':'latin_1',\n'csisolatin1':'latin_1',\n'ibm819':'latin_1',\n'iso8859':'latin_1',\n'iso8859_1':'latin_1',\n'iso_8859_1':'latin_1',\n'iso_8859_1_1987':'latin_1',\n'iso_ir_100':'latin_1',\n'l1':'latin_1',\n'latin':'latin_1',\n'latin1':'latin_1',\n\n\n'maccyrillic':'mac_cyrillic',\n\n\n'macgreek':'mac_greek',\n\n\n'maciceland':'mac_iceland',\n\n\n'maccentraleurope':'mac_latin2',\n'maclatin2':'mac_latin2',\n\n\n'macintosh':'mac_roman',\n'macroman':'mac_roman',\n\n\n'macturkish':'mac_turkish',\n\n\n'dbcs':'mbcs',\n\n\n'csptcp154':'ptcp154',\n'pt154':'ptcp154',\n'cp154':'ptcp154',\n'cyrillic_asian':'ptcp154',\n\n\n'quopri':'quopri_codec',\n'quoted_printable':'quopri_codec',\n'quotedprintable':'quopri_codec',\n\n\n'rot13':'rot_13',\n\n\n'csshiftjis':'shift_jis',\n'shiftjis':'shift_jis',\n'sjis':'shift_jis',\n's_jis':'shift_jis',\n\n\n'shiftjis2004':'shift_jis_2004',\n'sjis_2004':'shift_jis_2004',\n's_jis_2004':'shift_jis_2004',\n\n\n'shiftjisx0213':'shift_jisx0213',\n'sjisx0213':'shift_jisx0213',\n's_jisx0213':'shift_jisx0213',\n\n\n'tis260':'tactis',\n\n\n'tis620':'tis_620',\n'tis_620_0':'tis_620',\n'tis_620_2529_0':'tis_620',\n'tis_620_2529_1':'tis_620',\n'iso_ir_166':'tis_620',\n\n\n'u16':'utf_16',\n'utf16':'utf_16',\n\n\n'unicodebigunmarked':'utf_16_be',\n'utf_16be':'utf_16_be',\n\n\n'unicodelittleunmarked':'utf_16_le',\n'utf_16le':'utf_16_le',\n\n\n'u32':'utf_32',\n'utf32':'utf_32',\n\n\n'utf_32be':'utf_32_be',\n\n\n'utf_32le':'utf_32_le',\n\n\n'u7':'utf_7',\n'utf7':'utf_7',\n'unicode_1_1_utf_7':'utf_7',\n\n\n'u8':'utf_8',\n'utf':'utf_8',\n'utf8':'utf_8',\n'utf8_ucs2':'utf_8',\n'utf8_ucs4':'utf_8',\n\n\n'uu':'uu_codec',\n\n\n'zip':'zlib_codec',\n'zlib':'zlib_codec',\n\n\n'x_mac_japanese':'shift_jis',\n'x_mac_korean':'euc_kr',\n'x_mac_simp_chinese':'gb2312',\n'x_mac_trad_chinese':'big5',\n}\n", []], "encodings": [".py", "", [], 1], "operator": [".py", "#!/usr/bin/env python3\n''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\ndef lt(a,b):\n ''\n return a <b\n__lt__=lt\n\ndef le(a,b):\n ''\n return a <=b\n__le__=le\n\ndef eq(a,b):\n ''\n return a ==b\n__eq__=eq\n\ndef ne(a,b):\n ''\n return a !=b\n__ne__=ne\n\ndef ge(a,b):\n ''\n return a >=b\n__ge__=ge\n\ndef gt(a,b):\n ''\n return a >b\n__gt__=gt\n\ndef not_(a):\n ''\n return not a\n__not__=not_\n\ndef truth(a):\n ''\n \n return bool(a)\n \ndef is_(a,b):\n ''\n return a is b\n \n \n \n \n \n \n \n \n \n \n \n__abs__=abs\nabs=abs\n\n\ndef add(a,b):\n ''\n return a+b\n__add__=add\n\ndef and_(a,b):\n ''\n return a&b\n__and__=and_\n\ndef floordiv(a,b):\n ''\n return a //b\n__floordiv__=floordiv\n\ndef index(a):\n ''\n return a. __index__()\n__index__=index\n\ndef inv(a):\n ''\n return ~a\n \ninvert=__inv__=__invert__=inv\n\ndef lshift(a,b):\n ''\n return a <<b\n__lshift__=lshift\n\ndef mod(a,b):\n ''\n return a %b\n__mod__=mod\n\ndef mul(a,b):\n ''\n return a *b\n__mul__=mul\n\ndef neg(a):\n ''\n return -a\n__neg__=neg\n\ndef or_(a,b):\n ''\n return a |b\n__or__=or_\n\ndef pos(a):\n ''\n return +a\n \n__pos__=pos\n\ndef pow(a,b):\n ''\n return a **b\n__pow__=pow\n\ndef rshift(a,b):\n ''\n return a >>b\n__rshift__=rshift\n\ndef sub(a,b):\n ''\n return a -b\n__sub__=sub\n\ndef truediv(a,b):\n ''\n return a /b\n__truediv__=truediv\n\ndef xor(a,b):\n ''\n return a ^b\n__xor__=xor\n\ndef concat(a,b):\n ''\n if not (hasattr(a,'__getitem__')and hasattr(b,'__getitem__')):\n  raise TypeError('a and b must be sequences')\n return a+b\n__concat__=concat\n\ndef contains(a,b):\n ''\n return b in a\n__contains__=contains\n\ndef countOf(a,b):\n ''\n count=0\n for i in a:\n  if i ==b:\n   count +=1\n return count\n \ndef delitem(a,b):\n ''\n del a[b]\n__delitem__=delitem\n\ndef getitem(a,b):\n ''\n return a[b]\n__getitem__=getitem\n\n\ndef indexOf(a,b):\n ''\n \n for i,j in enumerate(a):\n  if j ==b:\n   return i\n else :\n  raise ValueError('b not found in a')\n  \ndef setitem(a,b,c):\n ''\n a[b]=c\n__setitem__=setitem\n\n\n\nclass attrgetter:\n ''\n\n\n\n\n\n \n def __init__(self,attr,*attrs):\n  self. _attrs=(attr,)\n  self. _attrs +=attrs\n  if any(not isinstance(attr,str)for attr in self. _attrs):\n   raise TypeError('attribute name must be a string')\n   \n @staticmethod\n def _resolve_attr(obj,attr):\n  for name in attr. split('.'):\n  \n   obj=getattr(obj,name)\n  return obj\n  \n def __call__(self,obj):\n  if len(self. _attrs)==1:\n   return self. _resolve_attr(obj,self. _attrs[0])\n  return tuple(self. _resolve_attr(obj,attr)for attr in self. _attrs)\n  \nclass itemgetter:\n ''\n\n\n\n \n def __init__(self,item,*items):\n  self. _items=(item,)\n  self. _items +=items\n  \n def __call__(self,obj):\n  if len(self. _items)==1:\n   return obj[self. _items[0]]\n  return tuple(obj[item]for item in self. _items)\n  \nclass methodcaller:\n ''\n\n\n\n\n \n \n def __init__(self,name,*args,**kwargs):\n  self. _name=name\n  self. _args=args\n  self. _kwargs=kwargs\n  \n def __call__(self,obj):\n  return getattr(obj,self. _name)(*self. _args,**self. _kwargs)\n  \n  \ndef iadd(a,b):\n ''\n a +=b\n return a\n__iadd__=iadd\n\ndef iand(a,b):\n ''\n a &=b\n return a\n__iand__=iand\n\ndef iconcat(a,b):\n ''\n if not (hasattr(a,'__getitem__')and hasattr(b,'__getitem__')):\n  raise TypeError('a and b must be sequences')\n a +=b\n return a\n__iconcat__=iconcat\n\ndef ifloordiv(a,b):\n ''\n a //=b\n return a\n__ifloordiv__=ifloordiv\n\ndef ilshift(a,b):\n ''\n a <<=b\n return a\n__ilshift__=ilshift\n\ndef imod(a,b):\n ''\n a %=b\n return a\n__imod__=imod\n\ndef imul(a,b):\n ''\n a *=b\n return a\n__imul__=imul\n\ndef ior(a,b):\n ''\n a |=b\n return a\n__ior__=ior\n\ndef ipow(a,b):\n ''\n a **=b\n return a\n__ipow__=ipow\n\ndef irshift(a,b):\n ''\n a >>=b\n return a\n__irshift__=irshift\n\ndef isub(a,b):\n ''\n a -=b\n return a\n__isub__=isub\n\ndef itruediv(a,b):\n ''\n a /=b\n return a\n__itruediv__=itruediv\n\ndef ixor(a,b):\n ''\n a ^=b\n return a\n__ixor__=ixor\n\ndef length_hint(obj,default=0):\n ''\n\n\n\n\n\n\n \n try :\n  return len(obj)\n except TypeError:\n  try :\n   val=obj. __length_hint__()\n   if val is NotImplemented:\n    raise TypeError\n  except (AttributeError,TypeError):\n   return default\n  else :\n   if not val >0:\n    raise ValueError('default must be > 0')\n   return val\n   \n   \n   \n   \n   \n   \n", []], "optparse": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__version__=\"1.5.3\"\n\n__all__=['Option',\n'make_option',\n'SUPPRESS_HELP',\n'SUPPRESS_USAGE',\n'Values',\n'OptionContainer',\n'OptionGroup',\n'OptionParser',\n'HelpFormatter',\n'IndentedHelpFormatter',\n'TitledHelpFormatter',\n'OptParseError',\n'OptionError',\n'OptionConflictError',\n'OptionValueError',\n'BadOptionError']\n\n__copyright__=\"\"\"\nCopyright (c) 2001-2006 Gregory P. Ward.  All rights reserved.\nCopyright (c) 2002-2006 Python Software Foundation.  All rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are\nmet:\n\n  * Redistributions of source code must retain the above copyright\n    notice, this list of conditions and the following disclaimer.\n\n  * Redistributions in binary form must reproduce the above copyright\n    notice, this list of conditions and the following disclaimer in the\n    documentation and/or other materials provided with the distribution.\n\n  * Neither the name of the author nor the names of its\n    contributors may be used to endorse or promote products derived from\n    this software without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS\nIS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED\nTO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A\nPARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR\nCONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\nEXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\nPROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\nPROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\nLIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\nNEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\nSOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\"\"\"\n\nimport sys,os\nimport textwrap\n\ndef _repr(self):\n return\"<%s at 0x%x: %s>\"%(self. __class__. __name__,id(self),self)\n \n \n \n \n \n \n \n \ntry :\n from gettext import gettext,ngettext\nexcept ImportError:\n def gettext(message):\n  return message\n  \n def ngettext(singular,plural,n):\n  if n ==1:\n   return singular\n  return plural\n  \n_=gettext\n\n\nclass OptParseError(Exception):\n def __init__(self,msg):\n  self. msg=msg\n  \n def __str__(self):\n  return self. msg\n  \n  \nclass OptionError(OptParseError):\n ''\n\n\n \n \n def __init__(self,msg,option):\n  self. msg=msg\n  self. option_id=str(option)\n  \n def __str__(self):\n  if self. option_id:\n   return\"option %s: %s\"%(self. option_id,self. msg)\n  else :\n   return self. msg\n   \nclass OptionConflictError(OptionError):\n ''\n\n \n \nclass OptionValueError(OptParseError):\n ''\n\n\n \n \nclass BadOptionError(OptParseError):\n ''\n\n \n def __init__(self,opt_str):\n  self. opt_str=opt_str\n  \n def __str__(self):\n  return _(\"no such option: %s\")%self. opt_str\n  \nclass AmbiguousOptionError(BadOptionError):\n ''\n\n \n def __init__(self,opt_str,possibilities):\n  BadOptionError. __init__(self,opt_str)\n  self. possibilities=possibilities\n  \n def __str__(self):\n  return (_(\"ambiguous option: %s (%s?)\")\n  %(self. opt_str,\", \". join(self. possibilities)))\n  \n  \nclass HelpFormatter:\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n NO_DEFAULT_VALUE=\"none\"\n \n def __init__(self,\n indent_increment,\n max_help_position,\n width,\n short_first):\n  self. parser=None\n  self. indent_increment=indent_increment\n  self. help_position=self. max_help_position=max_help_position\n  if width is None :\n   try :\n    width=int(os. environ['COLUMNS'])\n   except (KeyError,ValueError):\n    width=80\n   width -=2\n  self. width=width\n  self. current_indent=0\n  self. level=0\n  self. help_width=None\n  self. short_first=short_first\n  self. default_tag=\"%default\"\n  self. option_strings={}\n  self. _short_opt_fmt=\"%s %s\"\n  self. _long_opt_fmt=\"%s=%s\"\n  \n def set_parser(self,parser):\n  self. parser=parser\n  \n def set_short_opt_delimiter(self,delim):\n  if delim not in (\"\",\" \"):\n   raise ValueError(\n   \"invalid metavar delimiter for short options: %r\"%delim)\n  self. _short_opt_fmt=\"%s\"+delim+\"%s\"\n  \n def set_long_opt_delimiter(self,delim):\n  if delim not in (\"=\",\" \"):\n   raise ValueError(\n   \"invalid metavar delimiter for long options: %r\"%delim)\n  self. _long_opt_fmt=\"%s\"+delim+\"%s\"\n  \n def indent(self):\n  self. current_indent +=self. indent_increment\n  self. level +=1\n  \n def dedent(self):\n  self. current_indent -=self. indent_increment\n  assert self. current_indent >=0,\"Indent decreased below 0.\"\n  self. level -=1\n  \n def format_usage(self,usage):\n  raise NotImplementedError(\"subclasses must implement\")\n  \n def format_heading(self,heading):\n  raise NotImplementedError(\"subclasses must implement\")\n  \n def _format_text(self,text):\n  ''\n\n\n  \n  text_width=self. width -self. current_indent\n  indent=\" \"*self. current_indent\n  return textwrap. fill(text,\n  text_width,\n  initial_indent=indent,\n  subsequent_indent=indent)\n  \n def format_description(self,description):\n  if description:\n   return self. _format_text(description)+\"\\n\"\n  else :\n   return\"\"\n   \n def format_epilog(self,epilog):\n  if epilog:\n   return\"\\n\"+self. _format_text(epilog)+\"\\n\"\n  else :\n   return\"\"\n   \n   \n def expand_default(self,option):\n  if self. parser is None or not self. default_tag:\n   return option. help\n   \n  default_value=self. parser. defaults. get(option. dest)\n  if default_value is NO_DEFAULT or default_value is None :\n   default_value=self. NO_DEFAULT_VALUE\n   \n  return option. help. replace(self. default_tag,str(default_value))\n  \n def format_option(self,option):\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n  result=[]\n  opts=self. option_strings[option]\n  opt_width=self. help_position -self. current_indent -2\n  if len(opts)>opt_width:\n   opts=\"%*s%s\\n\"%(self. current_indent,\"\",opts)\n   indent_first=self. help_position\n  else :\n   opts=\"%*s%-*s  \"%(self. current_indent,\"\",opt_width,opts)\n   indent_first=0\n  result. append(opts)\n  if option. help:\n   help_text=self. expand_default(option)\n   help_lines=textwrap. wrap(help_text,self. help_width)\n   result. append(\"%*s%s\\n\"%(indent_first,\"\",help_lines[0]))\n   result. extend([\"%*s%s\\n\"%(self. help_position,\"\",line)\n   for line in help_lines[1:]])\n  elif opts[-1]!=\"\\n\":\n   result. append(\"\\n\")\n  return\"\". join(result)\n  \n def store_option_strings(self,parser):\n  self. indent()\n  max_len=0\n  for opt in parser. option_list:\n   strings=self. format_option_strings(opt)\n   self. option_strings[opt]=strings\n   max_len=max(max_len,len(strings)+self. current_indent)\n  self. indent()\n  for group in parser. option_groups:\n   for opt in group. option_list:\n    strings=self. format_option_strings(opt)\n    self. option_strings[opt]=strings\n    max_len=max(max_len,len(strings)+self. current_indent)\n  self. dedent()\n  self. dedent()\n  self. help_position=min(max_len+2,self. max_help_position)\n  self. help_width=self. width -self. help_position\n  \n def format_option_strings(self,option):\n  ''\n  if option. takes_value():\n   metavar=option. metavar or option. dest. upper()\n   short_opts=[self. _short_opt_fmt %(sopt,metavar)\n   for sopt in option. _short_opts]\n   long_opts=[self. _long_opt_fmt %(lopt,metavar)\n   for lopt in option. _long_opts]\n  else :\n   short_opts=option. _short_opts\n   long_opts=option. _long_opts\n   \n  if self. short_first:\n   opts=short_opts+long_opts\n  else :\n   opts=long_opts+short_opts\n   \n  return\", \". join(opts)\n  \nclass IndentedHelpFormatter(HelpFormatter):\n ''\n \n \n def __init__(self,\n indent_increment=2,\n max_help_position=24,\n width=None ,\n short_first=1):\n  HelpFormatter. __init__(\n  self,indent_increment,max_help_position,width,short_first)\n  \n def format_usage(self,usage):\n  return _(\"Usage: %s\\n\")%usage\n  \n def format_heading(self,heading):\n  return\"%*s%s:\\n\"%(self. current_indent,\"\",heading)\n  \n  \nclass TitledHelpFormatter(HelpFormatter):\n ''\n \n \n def __init__(self,\n indent_increment=0,\n max_help_position=24,\n width=None ,\n short_first=0):\n  HelpFormatter. __init__(\n  self,indent_increment,max_help_position,width,short_first)\n  \n def format_usage(self,usage):\n  return\"%s  %s\\n\"%(self. format_heading(_(\"Usage\")),usage)\n  \n def format_heading(self,heading):\n  return\"%s\\n%s\\n\"%(heading,\"=-\"[self. level]*len(heading))\n  \n  \ndef _parse_num(val,type):\n if val[:2]. lower()==\"0x\":\n  radix=16\n elif val[:2]. lower()==\"0b\":\n  radix=2\n  val=val[2:]or\"0\"\n elif val[:1]==\"0\":\n  radix=8\n else :\n  radix=10\n  \n return type(val,radix)\n \ndef _parse_int(val):\n return _parse_num(val,int)\n \n_builtin_cvt={\"int\":(_parse_int,_(\"integer\")),\n\"long\":(_parse_int,_(\"integer\")),\n\"float\":(float,_(\"floating-point\")),\n\"complex\":(complex,_(\"complex\"))}\n\ndef check_builtin(option,opt,value):\n (cvt,what)=_builtin_cvt[option. type]\n try :\n  return cvt(value)\n except ValueError:\n  raise OptionValueError(\n  _(\"option %s: invalid %s value: %r\")%(opt,what,value))\n  \ndef check_choice(option,opt,value):\n if value in option. choices:\n  return value\n else :\n  choices=\", \". join(map(repr,option. choices))\n  raise OptionValueError(\n  _(\"option %s: invalid choice: %r (choose from %s)\")\n  %(opt,value,choices))\n  \n  \n  \nNO_DEFAULT=(\"NO\",\"DEFAULT\")\n\n\nclass Option:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n \n ATTRS=['action',\n 'type',\n 'dest',\n 'default',\n 'nargs',\n 'const',\n 'choices',\n 'callback',\n 'callback_args',\n 'callback_kwargs',\n 'help',\n 'metavar']\n \n \n \n ACTIONS=(\"store\",\n \"store_const\",\n \"store_true\",\n \"store_false\",\n \"append\",\n \"append_const\",\n \"count\",\n \"callback\",\n \"help\",\n \"version\")\n \n \n \n \n STORE_ACTIONS=(\"store\",\n \"store_const\",\n \"store_true\",\n \"store_false\",\n \"append\",\n \"append_const\",\n \"count\")\n \n \n \n TYPED_ACTIONS=(\"store\",\n \"append\",\n \"callback\")\n \n \n \n ALWAYS_TYPED_ACTIONS=(\"store\",\n \"append\")\n \n \n CONST_ACTIONS=(\"store_const\",\n \"append_const\")\n \n \n \n TYPES=(\"string\",\"int\",\"long\",\"float\",\"complex\",\"choice\")\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n TYPE_CHECKER={\"int\":check_builtin,\n \"long\":check_builtin,\n \"float\":check_builtin,\n \"complex\":check_builtin,\n \"choice\":check_choice,\n }\n \n \n \n \n \n \n \n \n \n \n CHECK_METHODS=None\n \n \n \n \n def __init__(self,*opts,**attrs):\n \n \n  self. _short_opts=[]\n  self. _long_opts=[]\n  opts=self. _check_opt_strings(opts)\n  self. _set_opt_strings(opts)\n  \n  \n  self. _set_attrs(attrs)\n  \n  \n  \n  \n  \n  \n  for checker in self. CHECK_METHODS:\n   checker(self)\n   \n def _check_opt_strings(self,opts):\n \n \n \n  opts=[opt for opt in opts if opt]\n  if not opts:\n   raise TypeError(\"at least one option string must be supplied\")\n  return opts\n  \n def _set_opt_strings(self,opts):\n  for opt in opts:\n   if len(opt)<2:\n    raise OptionError(\n    \"invalid option string %r: \"\n    \"must be at least two characters long\"%opt,self)\n   elif len(opt)==2:\n    if not (opt[0]==\"-\"and opt[1]!=\"-\"):\n     raise OptionError(\n     \"invalid short option string %r: \"\n     \"must be of the form -x, (x any non-dash char)\"%opt,\n     self)\n    self. _short_opts. append(opt)\n   else :\n    if not (opt[0:2]==\"--\"and opt[2]!=\"-\"):\n     raise OptionError(\n     \"invalid long option string %r: \"\n     \"must start with --, followed by non-dash\"%opt,\n     self)\n    self. _long_opts. append(opt)\n    \n def _set_attrs(self,attrs):\n  for attr in self. ATTRS:\n   if attr in attrs:\n    setattr(self,attr,attrs[attr])\n    del attrs[attr]\n   else :\n    if attr =='default':\n     setattr(self,attr,NO_DEFAULT)\n    else :\n     setattr(self,attr,None )\n  if attrs:\n   attrs=sorted(attrs. keys())\n   raise OptionError(\n   \"invalid keyword arguments: %s\"%\", \". join(attrs),\n   self)\n   \n   \n   \n   \n def _check_action(self):\n  if self. action is None :\n   self. action=\"store\"\n  elif self. action not in self. ACTIONS:\n   raise OptionError(\"invalid action: %r\"%self. action,self)\n   \n def _check_type(self):\n  if self. type is None :\n   if self. action in self. ALWAYS_TYPED_ACTIONS:\n    if self. choices is not None :\n    \n     self. type=\"choice\"\n    else :\n    \n     self. type=\"string\"\n  else :\n  \n  \n  \n  \n  \n   import builtins\n   if (isinstance(self. type,type)or\n   (hasattr(self. type,\"__name__\")and\n   getattr(builtins,self. type. __name__,None )is self. type)):\n    self. type=self. type. __name__\n    \n   if self. type ==\"str\":\n    self. type=\"string\"\n    \n   if self. type not in self. TYPES:\n    raise OptionError(\"invalid option type: %r\"%self. type,self)\n   if self. action not in self. TYPED_ACTIONS:\n    raise OptionError(\n    \"must not supply a type for action %r\"%self. action,self)\n    \n def _check_choice(self):\n  if self. type ==\"choice\":\n   if self. choices is None :\n    raise OptionError(\n    \"must supply a list of choices for type 'choice'\",self)\n   elif not isinstance(self. choices,(tuple,list)):\n    raise OptionError(\n    \"choices must be a list of strings ('%s' supplied)\"\n    %str(type(self. choices)). split(\"'\")[1],self)\n  elif self. choices is not None :\n   raise OptionError(\n   \"must not supply choices for type %r\"%self. type,self)\n   \n def _check_dest(self):\n \n \n  takes_value=(self. action in self. STORE_ACTIONS or\n  self. type is not None )\n  if self. dest is None and takes_value:\n  \n  \n  \n   if self. _long_opts:\n   \n    self. dest=self. _long_opts[0][2:]. replace('-','_')\n   else :\n    self. dest=self. _short_opts[0][1]\n    \n def _check_const(self):\n  if self. action not in self. CONST_ACTIONS and self. const is not None :\n   raise OptionError(\n   \"'const' must not be supplied for action %r\"%self. action,\n   self)\n   \n def _check_nargs(self):\n  if self. action in self. TYPED_ACTIONS:\n   if self. nargs is None :\n    self. nargs=1\n  elif self. nargs is not None :\n   raise OptionError(\n   \"'nargs' must not be supplied for action %r\"%self. action,\n   self)\n   \n def _check_callback(self):\n  if self. action ==\"callback\":\n   if not callable(self. callback):\n    raise OptionError(\n    \"callback not callable: %r\"%self. callback,self)\n   if (self. callback_args is not None and\n   not isinstance(self. callback_args,tuple)):\n    raise OptionError(\n    \"callback_args, if supplied, must be a tuple: not %r\"\n    %self. callback_args,self)\n   if (self. callback_kwargs is not None and\n   not isinstance(self. callback_kwargs,dict)):\n    raise OptionError(\n    \"callback_kwargs, if supplied, must be a dict: not %r\"\n    %self. callback_kwargs,self)\n  else :\n   if self. callback is not None :\n    raise OptionError(\n    \"callback supplied (%r) for non-callback option\"\n    %self. callback,self)\n   if self. callback_args is not None :\n    raise OptionError(\n    \"callback_args supplied for non-callback option\",self)\n   if self. callback_kwargs is not None :\n    raise OptionError(\n    \"callback_kwargs supplied for non-callback option\",self)\n    \n    \n CHECK_METHODS=[_check_action,\n _check_type,\n _check_choice,\n _check_dest,\n _check_const,\n _check_nargs,\n _check_callback]\n \n \n \n \n def __str__(self):\n  return\"/\". join(self. _short_opts+self. _long_opts)\n  \n __repr__=_repr\n \n def takes_value(self):\n  return self. type is not None\n  \n def get_opt_string(self):\n  if self. _long_opts:\n   return self. _long_opts[0]\n  else :\n   return self. _short_opts[0]\n   \n   \n   \n   \n def check_value(self,opt,value):\n  checker=self. TYPE_CHECKER. get(self. type)\n  if checker is None :\n   return value\n  else :\n   return checker(self,opt,value)\n   \n def convert_value(self,opt,value):\n  if value is not None :\n   if self. nargs ==1:\n    return self. check_value(opt,value)\n   else :\n    return tuple([self. check_value(opt,v)for v in value])\n    \n def process(self,opt,value,values,parser):\n \n \n \n  value=self. convert_value(opt,value)\n  \n  \n  \n  \n  return self. take_action(\n  self. action,self. dest,opt,value,values,parser)\n  \n def take_action(self,action,dest,opt,value,values,parser):\n  if action ==\"store\":\n   setattr(values,dest,value)\n  elif action ==\"store_const\":\n   setattr(values,dest,self. const)\n  elif action ==\"store_true\":\n   setattr(values,dest,True )\n  elif action ==\"store_false\":\n   setattr(values,dest,False )\n  elif action ==\"append\":\n   values. ensure_value(dest,[]). append(value)\n  elif action ==\"append_const\":\n   values. ensure_value(dest,[]). append(self. const)\n  elif action ==\"count\":\n   setattr(values,dest,values. ensure_value(dest,0)+1)\n  elif action ==\"callback\":\n   args=self. callback_args or ()\n   kwargs=self. callback_kwargs or {}\n   self. callback(self,opt,value,parser,*args,**kwargs)\n  elif action ==\"help\":\n   parser. print_help()\n   parser. exit()\n  elif action ==\"version\":\n   parser. print_version()\n   parser. exit()\n  else :\n   raise ValueError(\"unknown action %r\"%self. action)\n   \n  return 1\n  \n  \n  \n  \nSUPPRESS_HELP=\"SUPPRESS\"+\"HELP\"\nSUPPRESS_USAGE=\"SUPPRESS\"+\"USAGE\"\n\nclass Values:\n\n def __init__(self,defaults=None ):\n  if defaults:\n   for (attr,val)in defaults. items():\n    setattr(self,attr,val)\n    \n def __str__(self):\n  return str(self. __dict__)\n  \n __repr__=_repr\n \n def __eq__(self,other):\n  if isinstance(other,Values):\n   return self. __dict__ ==other. __dict__\n  elif isinstance(other,dict):\n   return self. __dict__ ==other\n  else :\n   return NotImplemented\n   \n def _update_careful(self,dict):\n  ''\n\n\n\n\n  \n  for attr in dir(self):\n   if attr in dict:\n    dval=dict[attr]\n    if dval is not None :\n     setattr(self,attr,dval)\n     \n def _update_loose(self,dict):\n  ''\n\n\n\n  \n  self. __dict__. update(dict)\n  \n def _update(self,dict,mode):\n  if mode ==\"careful\":\n   self. _update_careful(dict)\n  elif mode ==\"loose\":\n   self. _update_loose(dict)\n  else :\n   raise ValueError(\"invalid update mode: %r\"%mode)\n   \n def read_module(self,modname,mode=\"careful\"):\n  __import__(modname)\n  mod=sys. modules[modname]\n  self. _update(vars(mod),mode)\n  \n def read_file(self,filename,mode=\"careful\"):\n  vars={}\n  exec(open(filename). read(),vars)\n  self. _update(vars,mode)\n  \n def ensure_value(self,attr,value):\n  if not hasattr(self,attr)or getattr(self,attr)is None :\n   setattr(self,attr,value)\n  return getattr(self,attr)\n  \n  \nclass OptionContainer:\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,option_class,conflict_handler,description):\n \n \n \n \n  self. _create_option_list()\n  \n  self. option_class=option_class\n  self. set_conflict_handler(conflict_handler)\n  self. set_description(description)\n  \n def _create_option_mappings(self):\n \n \n \n  self. _short_opt={}\n  self. _long_opt={}\n  self. defaults={}\n  \n  \n def _share_option_mappings(self,parser):\n \n \n  self. _short_opt=parser. _short_opt\n  self. _long_opt=parser. _long_opt\n  self. defaults=parser. defaults\n  \n def set_conflict_handler(self,handler):\n  if handler not in (\"error\",\"resolve\"):\n   raise ValueError(\"invalid conflict_resolution value %r\"%handler)\n  self. conflict_handler=handler\n  \n def set_description(self,description):\n  self. description=description\n  \n def get_description(self):\n  return self. description\n  \n  \n def destroy(self):\n  ''\n  del self. _short_opt\n  del self. _long_opt\n  del self. defaults\n  \n  \n  \n  \n def _check_conflict(self,option):\n  conflict_opts=[]\n  for opt in option. _short_opts:\n   if opt in self. _short_opt:\n    conflict_opts. append((opt,self. _short_opt[opt]))\n  for opt in option. _long_opts:\n   if opt in self. _long_opt:\n    conflict_opts. append((opt,self. _long_opt[opt]))\n    \n  if conflict_opts:\n   handler=self. conflict_handler\n   if handler ==\"error\":\n    raise OptionConflictError(\n    \"conflicting option string(s): %s\"\n    %\", \". join([co[0]for co in conflict_opts]),\n    option)\n   elif handler ==\"resolve\":\n    for (opt,c_option)in conflict_opts:\n     if opt. startswith(\"--\"):\n      c_option. _long_opts. remove(opt)\n      del self. _long_opt[opt]\n     else :\n      c_option. _short_opts. remove(opt)\n      del self. _short_opt[opt]\n     if not (c_option. _short_opts or c_option. _long_opts):\n      c_option. container. option_list. remove(c_option)\n      \n def add_option(self,*args,**kwargs):\n  ''\n\n  \n  if isinstance(args[0],str):\n   option=self. option_class(*args,**kwargs)\n  elif len(args)==1 and not kwargs:\n   option=args[0]\n   if not isinstance(option,Option):\n    raise TypeError(\"not an Option instance: %r\"%option)\n  else :\n   raise TypeError(\"invalid arguments\")\n   \n  self. _check_conflict(option)\n  \n  self. option_list. append(option)\n  option. container=self\n  for opt in option. _short_opts:\n   self. _short_opt[opt]=option\n  for opt in option. _long_opts:\n   self. _long_opt[opt]=option\n   \n  if option. dest is not None :\n   if option. default is not NO_DEFAULT:\n    self. defaults[option. dest]=option. default\n   elif option. dest not in self. defaults:\n    self. defaults[option. dest]=None\n    \n  return option\n  \n def add_options(self,option_list):\n  for option in option_list:\n   self. add_option(option)\n   \n   \n   \n def get_option(self,opt_str):\n  return (self. _short_opt. get(opt_str)or\n  self. _long_opt. get(opt_str))\n  \n def has_option(self,opt_str):\n  return (opt_str in self. _short_opt or\n  opt_str in self. _long_opt)\n  \n def remove_option(self,opt_str):\n  option=self. _short_opt. get(opt_str)\n  if option is None :\n   option=self. _long_opt. get(opt_str)\n  if option is None :\n   raise ValueError(\"no such option %r\"%opt_str)\n   \n  for opt in option. _short_opts:\n   del self. _short_opt[opt]\n  for opt in option. _long_opts:\n   del self. _long_opt[opt]\n  option. container. option_list. remove(option)\n  \n  \n  \n  \n def format_option_help(self,formatter):\n  if not self. option_list:\n   return\"\"\n  result=[]\n  for option in self. option_list:\n   if not option. help is SUPPRESS_HELP:\n    result. append(formatter. format_option(option))\n  return\"\". join(result)\n  \n def format_description(self,formatter):\n  return formatter. format_description(self. get_description())\n  \n def format_help(self,formatter):\n  result=[]\n  if self. description:\n   result. append(self. format_description(formatter))\n  if self. option_list:\n   result. append(self. format_option_help(formatter))\n  return\"\\n\". join(result)\n  \n  \nclass OptionGroup(OptionContainer):\n\n def __init__(self,parser,title,description=None ):\n  self. parser=parser\n  OptionContainer. __init__(\n  self,parser. option_class,parser. conflict_handler,description)\n  self. title=title\n  \n def _create_option_list(self):\n  self. option_list=[]\n  self. _share_option_mappings(self. parser)\n  \n def set_title(self,title):\n  self. title=title\n  \n def destroy(self):\n  ''\n  OptionContainer. destroy(self)\n  del self. option_list\n  \n  \n  \n def format_help(self,formatter):\n  result=formatter. format_heading(self. title)\n  formatter. indent()\n  result +=OptionContainer. format_help(self,formatter)\n  formatter. dedent()\n  return result\n  \n  \nclass OptionParser(OptionContainer):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n standard_option_list=[]\n \n def __init__(self,\n usage=None ,\n option_list=None ,\n option_class=Option,\n version=None ,\n conflict_handler=\"error\",\n description=None ,\n formatter=None ,\n add_help_option=True ,\n prog=None ,\n epilog=None ):\n  OptionContainer. __init__(\n  self,option_class,conflict_handler,description)\n  self. set_usage(usage)\n  self. prog=prog\n  self. version=version\n  self. allow_interspersed_args=True\n  self. process_default_values=True\n  if formatter is None :\n   formatter=IndentedHelpFormatter()\n  self. formatter=formatter\n  self. formatter. set_parser(self)\n  self. epilog=epilog\n  \n  \n  \n  \n  \n  self. _populate_option_list(option_list,\n  add_help=add_help_option)\n  \n  self. _init_parsing_state()\n  \n  \n def destroy(self):\n  ''\n\n\n\n\n  \n  OptionContainer. destroy(self)\n  for group in self. option_groups:\n   group. destroy()\n  del self. option_list\n  del self. option_groups\n  del self. formatter\n  \n  \n  \n  \n  \n def _create_option_list(self):\n  self. option_list=[]\n  self. option_groups=[]\n  self. _create_option_mappings()\n  \n def _add_help_option(self):\n  self. add_option(\"-h\",\"--help\",\n  action=\"help\",\n  help=_(\"show this help message and exit\"))\n  \n def _add_version_option(self):\n  self. add_option(\"--version\",\n  action=\"version\",\n  help=_(\"show program's version number and exit\"))\n  \n def _populate_option_list(self,option_list,add_help=True ):\n  if self. standard_option_list:\n   self. add_options(self. standard_option_list)\n  if option_list:\n   self. add_options(option_list)\n  if self. version:\n   self. _add_version_option()\n  if add_help:\n   self. _add_help_option()\n   \n def _init_parsing_state(self):\n \n  self. rargs=None\n  self. largs=None\n  self. values=None\n  \n  \n  \n  \n def set_usage(self,usage):\n  if usage is None :\n   self. usage=_(\"%prog [options]\")\n  elif usage is SUPPRESS_USAGE:\n   self. usage=None\n   \n  elif usage. lower(). startswith(\"usage: \"):\n   self. usage=usage[7:]\n  else :\n   self. usage=usage\n   \n def enable_interspersed_args(self):\n  ''\n\n\n\n  \n  self. allow_interspersed_args=True\n  \n def disable_interspersed_args(self):\n  ''\n\n\n\n  \n  self. allow_interspersed_args=False\n  \n def set_process_default_values(self,process):\n  self. process_default_values=process\n  \n def set_default(self,dest,value):\n  self. defaults[dest]=value\n  \n def set_defaults(self,**kwargs):\n  self. defaults. update(kwargs)\n  \n def _get_all_options(self):\n  options=self. option_list[:]\n  for group in self. option_groups:\n   options. extend(group. option_list)\n  return options\n  \n def get_default_values(self):\n  if not self. process_default_values:\n  \n   return Values(self. defaults)\n   \n  defaults=self. defaults. copy()\n  for option in self. _get_all_options():\n   default=defaults. get(option. dest)\n   if isinstance(default,str):\n    opt_str=option. get_opt_string()\n    defaults[option. dest]=option. check_value(opt_str,default)\n    \n  return Values(defaults)\n  \n  \n  \n  \n def add_option_group(self,*args,**kwargs):\n \n  if isinstance(args[0],str):\n   group=OptionGroup(self,*args,**kwargs)\n  elif len(args)==1 and not kwargs:\n   group=args[0]\n   if not isinstance(group,OptionGroup):\n    raise TypeError(\"not an OptionGroup instance: %r\"%group)\n   if group. parser is not self:\n    raise ValueError(\"invalid OptionGroup (wrong parser)\")\n  else :\n   raise TypeError(\"invalid arguments\")\n   \n  self. option_groups. append(group)\n  return group\n  \n def get_option_group(self,opt_str):\n  option=(self. _short_opt. get(opt_str)or\n  self. _long_opt. get(opt_str))\n  if option and option. container is not self:\n   return option. container\n  return None\n  \n  \n  \n  \n def _get_args(self,args):\n  if args is None :\n   return sys. argv[1:]\n  else :\n   return args[:]\n   \n def parse_args(self,args=None ,values=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n  \n  rargs=self. _get_args(args)\n  if values is None :\n   values=self. get_default_values()\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n  self. rargs=rargs\n  self. largs=largs=[]\n  self. values=values\n  \n  try :\n   stop=self. _process_args(largs,rargs,values)\n  except (BadOptionError,OptionValueError)as err:\n   self. error(str(err))\n   \n  args=largs+rargs\n  return self. check_values(values,args)\n  \n def check_values(self,values,args):\n  ''\n\n\n\n\n\n\n\n\n  \n  return (values,args)\n  \n def _process_args(self,largs,rargs,values):\n  ''\n\n\n\n\n\n\n\n  \n  while rargs:\n   arg=rargs[0]\n   \n   \n   \n   if arg ==\"--\":\n    del rargs[0]\n    return\n   elif arg[0:2]==\"--\":\n   \n    self. _process_long_opt(rargs,values)\n   elif arg[:1]==\"-\"and len(arg)>1:\n   \n   \n    self. _process_short_opts(rargs,values)\n   elif self. allow_interspersed_args:\n    largs. append(arg)\n    del rargs[0]\n   else :\n    return\n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n    \n def _match_long_opt(self,opt):\n  ''\n\n\n\n\n  \n  return _match_abbrev(opt,self. _long_opt)\n  \n def _process_long_opt(self,rargs,values):\n  arg=rargs. pop(0)\n  \n  \n  \n  if\"=\"in arg:\n   (opt,next_arg)=arg. split(\"=\",1)\n   rargs. insert(0,next_arg)\n   had_explicit_value=True\n  else :\n   opt=arg\n   had_explicit_value=False\n   \n  opt=self. _match_long_opt(opt)\n  option=self. _long_opt[opt]\n  if option. takes_value():\n   nargs=option. nargs\n   if len(rargs)<nargs:\n    self. error(ngettext(\n    \"%(option)s option requires %(number)d argument\",\n    \"%(option)s option requires %(number)d arguments\",\n    nargs)%{\"option\":opt,\"number\":nargs})\n   elif nargs ==1:\n    value=rargs. pop(0)\n   else :\n    value=tuple(rargs[0:nargs])\n    del rargs[0:nargs]\n    \n  elif had_explicit_value:\n   self. error(_(\"%s option does not take a value\")%opt)\n   \n  else :\n   value=None\n   \n  option. process(opt,value,values,self)\n  \n def _process_short_opts(self,rargs,values):\n  arg=rargs. pop(0)\n  stop=False\n  i=1\n  for ch in arg[1:]:\n   opt=\"-\"+ch\n   option=self. _short_opt. get(opt)\n   i +=1\n   \n   if not option:\n    raise BadOptionError(opt)\n   if option. takes_value():\n   \n   \n    if i <len(arg):\n     rargs. insert(0,arg[i:])\n     stop=True\n     \n    nargs=option. nargs\n    if len(rargs)<nargs:\n     self. error(ngettext(\n     \"%(option)s option requires %(number)d argument\",\n     \"%(option)s option requires %(number)d arguments\",\n     nargs)%{\"option\":opt,\"number\":nargs})\n    elif nargs ==1:\n     value=rargs. pop(0)\n    else :\n     value=tuple(rargs[0:nargs])\n     del rargs[0:nargs]\n     \n   else :\n    value=None\n    \n   option. process(opt,value,values,self)\n   \n   if stop:\n    break\n    \n    \n    \n    \n def get_prog_name(self):\n  if self. prog is None :\n   return os. path. basename(sys. argv[0])\n  else :\n   return self. prog\n   \n def expand_prog_name(self,s):\n  return s. replace(\"%prog\",self. get_prog_name())\n  \n def get_description(self):\n  return self. expand_prog_name(self. description)\n  \n def exit(self,status=0,msg=None ):\n  if msg:\n   sys. stderr. write(msg)\n  sys. exit(status)\n  \n def error(self,msg):\n  ''\n\n\n\n\n  \n  self. print_usage(sys. stderr)\n  self. exit(2,\"%s: error: %s\\n\"%(self. get_prog_name(),msg))\n  \n def get_usage(self):\n  if self. usage:\n   return self. formatter. format_usage(\n   self. expand_prog_name(self. usage))\n  else :\n   return\"\"\n   \n def print_usage(self,file=None ):\n  ''\n\n\n\n\n\n\n  \n  if self. usage:\n   print(self. get_usage(),file=file)\n   \n def get_version(self):\n  if self. version:\n   return self. expand_prog_name(self. version)\n  else :\n   return\"\"\n   \n def print_version(self,file=None ):\n  ''\n\n\n\n\n\n  \n  if self. version:\n   print(self. get_version(),file=file)\n   \n def format_option_help(self,formatter=None ):\n  if formatter is None :\n   formatter=self. formatter\n  formatter. store_option_strings(self)\n  result=[]\n  result. append(formatter. format_heading(_(\"Options\")))\n  formatter. indent()\n  if self. option_list:\n   result. append(OptionContainer. format_option_help(self,formatter))\n   result. append(\"\\n\")\n  for group in self. option_groups:\n   result. append(group. format_help(formatter))\n   result. append(\"\\n\")\n  formatter. dedent()\n  \n  return\"\". join(result[:-1])\n  \n def format_epilog(self,formatter):\n  return formatter. format_epilog(self. epilog)\n  \n def format_help(self,formatter=None ):\n  if formatter is None :\n   formatter=self. formatter\n  result=[]\n  if self. usage:\n   result. append(self. get_usage()+\"\\n\")\n  if self. description:\n   result. append(self. format_description(formatter)+\"\\n\")\n  result. append(self. format_option_help(formatter))\n  result. append(self. format_epilog(formatter))\n  return\"\". join(result)\n  \n def print_help(self,file=None ):\n  ''\n\n\n\n  \n  if file is None :\n   file=sys. stdout\n  file. write(self. format_help())\n  \n  \n  \n  \ndef _match_abbrev(s,wordmap):\n ''\n\n\n\n\n \n \n if s in wordmap:\n  return s\n else :\n \n  possibilities=[word for word in wordmap. keys()\n  if word. startswith(s)]\n  \n  if len(possibilities)==1:\n   return possibilities[0]\n  elif not possibilities:\n   raise BadOptionError(s)\n  else :\n  \n   possibilities. sort()\n   raise AmbiguousOptionError(s,possibilities)\n   \n   \n   \n   \n   \n   \nmake_option=Option\n", ["builtins", "gettext", "os", "sys", "textwrap"]], "sre_compile": [".py", "\n\n\n\n\n\n\n\n\n\n\"\"\"Internal support module for sre\"\"\"\n\n\nimport sys\nimport _sre\nimport sre_parse\nfrom sre_constants import *\nfrom _sre import MAXREPEAT\n\n\nassert _sre. MAGIC ==MAGIC,\"SRE module mismatch\"\n\nif _sre. CODESIZE ==2:\n MAXCODE=65535\nelse :\n MAXCODE=0xFFFFFFFF\n \ndef _identityfunction(x):\n return x\n \n \n_LITERAL_CODES=set([LITERAL,NOT_LITERAL])\n_REPEATING_CODES=set([REPEAT,MIN_REPEAT,MAX_REPEAT])\n_SUCCESS_CODES=set([SUCCESS,FAILURE])\n_ASSERT_CODES=set([ASSERT,ASSERT_NOT])\n\ndef _compile(code,pattern,flags):\n\n emit=code. append\n _len=len\n LITERAL_CODES=_LITERAL_CODES\n REPEATING_CODES=_REPEATING_CODES\n SUCCESS_CODES=_SUCCESS_CODES\n ASSERT_CODES=_ASSERT_CODES\n for op,av in pattern:\n \n \n  if op in LITERAL_CODES:\n   if flags&SRE_FLAG_IGNORECASE:\n    emit(OPCODES[OP_IGNORE[op]])\n    emit(_sre. getlower(av,flags))\n   else :\n    emit(OPCODES[op])\n    emit(av)\n  elif op is IN:\n   if flags&SRE_FLAG_IGNORECASE:\n    emit(OPCODES[OP_IGNORE[op]])\n    def fixup(literal,flags=flags):\n     return _sre. getlower(literal,flags)\n   else :\n    emit(OPCODES[op])\n    fixup=_identityfunction\n   skip=_len(code);emit(0)\n   _compile_charset(av,flags,code,fixup)\n   code[skip]=_len(code)-skip\n  elif op is ANY:\n   if flags&SRE_FLAG_DOTALL:\n    emit(OPCODES[ANY_ALL])\n   else :\n    emit(OPCODES[ANY])\n  elif op in REPEATING_CODES:\n   if flags&SRE_FLAG_TEMPLATE:\n    raise error(\"internal: unsupported template operator\")\n    emit(OPCODES[REPEAT])\n    skip=_len(code);emit(0)\n    emit(av[0])\n    emit(av[1])\n    _compile(code,av[2],flags)\n    emit(OPCODES[SUCCESS])\n    code[skip]=_len(code)-skip\n   elif _simple(av)and op is not REPEAT:\n    if op is MAX_REPEAT:\n     emit(OPCODES[REPEAT_ONE])\n    else :\n     emit(OPCODES[MIN_REPEAT_ONE])\n    skip=_len(code);emit(0)\n    emit(av[0])\n    emit(av[1])\n    _compile(code,av[2],flags)\n    emit(OPCODES[SUCCESS])\n    code[skip]=_len(code)-skip\n   else :\n    emit(OPCODES[REPEAT])\n    skip=_len(code);emit(0)\n    emit(av[0])\n    emit(av[1])\n    _compile(code,av[2],flags)\n    code[skip]=_len(code)-skip\n    if op is MAX_REPEAT:\n     emit(OPCODES[MAX_UNTIL])\n    else :\n     emit(OPCODES[MIN_UNTIL])\n  elif op is SUBPATTERN:\n   if av[0]:\n    emit(OPCODES[MARK])\n    emit((av[0]-1)*2)\n    \n   _compile(code,av[1],flags)\n   if av[0]:\n    emit(OPCODES[MARK])\n    emit((av[0]-1)*2+1)\n  elif op in SUCCESS_CODES:\n   emit(OPCODES[op])\n  elif op in ASSERT_CODES:\n   emit(OPCODES[op])\n   skip=_len(code);emit(0)\n   if av[0]>=0:\n    emit(0)\n   else :\n    lo,hi=av[1]. getwidth()\n    if lo !=hi:\n     raise error(\"look-behind requires fixed-width pattern\")\n    emit(lo)\n   _compile(code,av[1],flags)\n   emit(OPCODES[SUCCESS])\n   code[skip]=_len(code)-skip\n  elif op is CALL:\n   emit(OPCODES[op])\n   skip=_len(code);emit(0)\n   _compile(code,av,flags)\n   emit(OPCODES[SUCCESS])\n   code[skip]=_len(code)-skip\n  elif op is AT:\n   emit(OPCODES[op])\n   if flags&SRE_FLAG_MULTILINE:\n    av=AT_MULTILINE. get(av,av)\n   if flags&SRE_FLAG_LOCALE:\n    av=AT_LOCALE. get(av,av)\n   elif flags&SRE_FLAG_UNICODE:\n    av=AT_UNICODE. get(av,av)\n   emit(ATCODES[av])\n  elif op is BRANCH:\n   emit(OPCODES[op])\n   tail=[]\n   tailappend=tail. append\n   for av in av[1]:\n    skip=_len(code);emit(0)\n    \n    _compile(code,av,flags)\n    emit(OPCODES[JUMP])\n    tailappend(_len(code));emit(0)\n    code[skip]=_len(code)-skip\n   emit(0)\n   for tail in tail:\n    code[tail]=_len(code)-tail\n  elif op is CATEGORY:\n   emit(OPCODES[op])\n   if flags&SRE_FLAG_LOCALE:\n    av=CH_LOCALE[av]\n   elif flags&SRE_FLAG_UNICODE:\n    av=CH_UNICODE[av]\n   emit(CHCODES[av])\n  elif op is GROUPREF:\n   if flags&SRE_FLAG_IGNORECASE:\n    emit(OPCODES[OP_IGNORE[op]])\n   else :\n    emit(OPCODES[op])\n   emit(av -1)\n  elif op is GROUPREF_EXISTS:\n   emit(OPCODES[op])\n   emit(av[0]-1)\n   skipyes=_len(code);emit(0)\n   _compile(code,av[1],flags)\n   if av[2]:\n    emit(OPCODES[JUMP])\n    skipno=_len(code);emit(0)\n    code[skipyes]=_len(code)-skipyes+1\n    _compile(code,av[2],flags)\n    code[skipno]=_len(code)-skipno\n   else :\n    code[skipyes]=_len(code)-skipyes+1\n  else :\n   raise ValueError(\"unsupported operand type\",op)\n   \ndef _compile_charset(charset,flags,code,fixup=None ):\n\n emit=code. append\n if fixup is None :\n  fixup=_identityfunction\n for op,av in _optimize_charset(charset,fixup):\n  emit(OPCODES[op])\n  if op is NEGATE:\n   pass\n  elif op is LITERAL:\n   emit(fixup(av))\n  elif op is RANGE:\n   emit(fixup(av[0]))\n   emit(fixup(av[1]))\n  elif op is CHARSET:\n   code. extend(av)\n  elif op is BIGCHARSET:\n   code. extend(av)\n  elif op is CATEGORY:\n   if flags&SRE_FLAG_LOCALE:\n    emit(CHCODES[CH_LOCALE[av]])\n   elif flags&SRE_FLAG_UNICODE:\n    emit(CHCODES[CH_UNICODE[av]])\n   else :\n    emit(CHCODES[av])\n  else :\n   raise error(\"internal: unsupported set operator\")\n emit(OPCODES[FAILURE])\n \n \ndef _optimize_charset(charset,fixup):\n\n out=[]\n outappend=out. append\n charmap=[0]*256\n try :\n  for op,av in charset:\n   if op is NEGATE:\n    outappend((op,av))\n   elif op is LITERAL:\n    charmap[fixup(av)]=1\n   elif op is RANGE:\n    for i in range(fixup(av[0]),fixup(av[1])+1):\n     charmap[i]=1\n   elif op is CATEGORY:\n   \n    return charset\n except IndexError:\n \n  return _optimize_unicode(charset,fixup)\n  \n i=p=n=0\n runs=[]\n runsappend=runs. append\n for c in charmap:\n  if c:\n   if n ==0:\n    p=i\n   n=n+1\n  elif n:\n   runsappend((p,n))\n   n=0\n  i=i+1\n if n:\n  runsappend((p,n))\n if len(runs)<=2:\n \n  for p,n in runs:\n   if n ==1:\n    outappend((LITERAL,p))\n   else :\n    outappend((RANGE,(p,p+n -1)))\n  if len(out)<len(charset):\n   return out\n else :\n \n  data=_mk_bitmap(charmap)\n  outappend((CHARSET,data))\n  return out\n return charset\n \ndef _mk_bitmap(bits):\n data=[]\n dataappend=data. append\n if _sre. CODESIZE ==2:\n  start=(1,0)\n else :\n  start=(1,0)\n m,v=start\n for c in bits:\n  if c:\n   v=v+m\n  m=m+m\n  if m >MAXCODE:\n   dataappend(v)\n   m,v=start\n return data\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \ndef _optimize_unicode(charset,fixup):\n try :\n  import array\n except ImportError:\n  return charset\n charmap=[0]*65536\n negate=0\n try :\n  for op,av in charset:\n   if op is NEGATE:\n    negate=1\n   elif op is LITERAL:\n    charmap[fixup(av)]=1\n   elif op is RANGE:\n    for i in range(fixup(av[0]),fixup(av[1])+1):\n     charmap[i]=1\n   elif op is CATEGORY:\n   \n    return charset\n except IndexError:\n \n  return charset\n if negate:\n  if sys. maxunicode !=65535:\n  \n  \n  \n   return charset\n  for i in range(65536):\n   charmap[i]=not charmap[i]\n comps={}\n mapping=[0]*256\n block=0\n data=[]\n for i in range(256):\n  chunk=tuple(charmap[i *256:(i+1)*256])\n  new=comps. setdefault(chunk,block)\n  mapping[i]=new\n  if new ==block:\n   block=block+1\n   data=data+_mk_bitmap(chunk)\n header=[block]\n if _sre. CODESIZE ==2:\n  code='H'\n else :\n  code='I'\n  \n mapping=array. array('b',mapping). tobytes()\n \n mapping=array. array(code,mapping)\n assert mapping. itemsize ==_sre. CODESIZE\n assert len(mapping)*mapping. itemsize ==256\n header=header+mapping. tolist()\n data[0:0]=header\n return [(BIGCHARSET,data)]\n \ndef _simple(av):\n\n lo,hi=av[2]. getwidth()\n if lo ==0 and hi ==MAXREPEAT:\n  raise error(\"nothing to repeat\")\n return lo ==hi ==1 and av[2][0][0]!=SUBPATTERN\n \ndef _compile_info(code,pattern,flags):\n\n\n\n lo,hi=pattern. getwidth()\n \n if lo ==0:\n  return\n  \n prefix=[]\n prefixappend=prefix. append\n prefix_skip=0\n charset=[]\n charsetappend=charset. append\n if not (flags&SRE_FLAG_IGNORECASE):\n \n  for op,av in pattern. data:\n  \n   if op is LITERAL:\n    if len(prefix)==prefix_skip:\n     prefix_skip=prefix_skip+1\n    prefixappend(av)\n   elif op is SUBPATTERN and len(av[1])==1:\n    op,av=av[1][0]\n    if op is LITERAL:\n     prefixappend(av)\n    else :\n     break\n   else :\n    break\n    \n  if not prefix and pattern. data:\n   op,av=pattern. data[0]\n   if op is SUBPATTERN and av[1]:\n    op,av=av[1][0]\n    if op is LITERAL:\n     charsetappend((op,av))\n    elif op is BRANCH:\n     c=[]\n     cappend=c. append\n     for p in av[1]:\n      if not p:\n       break\n      op,av=p[0]\n      if op is LITERAL:\n       cappend((op,av))\n      else :\n       break\n     else :\n      charset=c\n   elif op is BRANCH:\n    c=[]\n    cappend=c. append\n    for p in av[1]:\n     if not p:\n      break\n     op,av=p[0]\n     if op is LITERAL:\n      cappend((op,av))\n     else :\n      break\n    else :\n     charset=c\n   elif op is IN:\n    charset=av\n    \n    \n    \n    \n    \n    \n    \n emit=code. append\n emit(OPCODES[INFO])\n skip=len(code);emit(0)\n \n mask=0\n if prefix:\n  mask=SRE_INFO_PREFIX\n  if len(prefix)==prefix_skip ==len(pattern. data):\n   mask=mask+SRE_INFO_LITERAL\n elif charset:\n  mask=mask+SRE_INFO_CHARSET\n emit(mask)\n \n if lo <MAXCODE:\n  emit(lo)\n else :\n  emit(MAXCODE)\n  prefix=prefix[:MAXCODE]\n if hi <MAXCODE:\n  emit(hi)\n else :\n  emit(0)\n  \n  \n if prefix:\n  emit(len(prefix))\n  emit(prefix_skip)\n  code. extend(prefix)\n  \n  table=[-1]+([0]*len(prefix))\n  for i in range(len(prefix)):\n   table[i+1]=table[i]+1\n   while table[i+1]>0 and prefix[i]!=prefix[table[i+1]-1]:\n    table[i+1]=table[table[i+1]-1]+1\n  code. extend(table[1:])\n elif charset:\n  _compile_charset(charset,flags,code)\n code[skip]=len(code)-skip\n \ndef isstring(obj):\n return isinstance(obj,(str,bytes))\n \ndef _code(p,flags):\n\n flags=p. pattern. flags |flags\n code=[]\n \n \n _compile_info(code,p,flags)\n \n \n _compile(code,p. data,flags)\n \n code. append(OPCODES[SUCCESS])\n \n return code\n \ndef compile(p,flags=0):\n\n\n\n if isstring(p):\n  pattern=p\n  p=sre_parse. parse(p,flags)\n else :\n  pattern=None\n  \n  \n code=_code(p,flags)\n \n \n \n \n \n if p. pattern. groups >100:\n  raise AssertionError(\n  \"sorry, but this version only supports 100 named groups\"\n  )\n  \n  \n groupindex=p. pattern. groupdict\n indexgroup=[None ]*p. pattern. groups\n for k,i in groupindex. items():\n  indexgroup[i]=k\n  \n return _sre. compile(\n pattern,flags |p. pattern. flags,code,\n p. pattern. groups -1,\n groupindex,indexgroup\n )\n", ["_sre", "array", "sre_constants", "sre_parse", "sys"]], "difflib": [".py", "#! /usr/bin/env python3\n\n\"\"\"\nModule difflib -- helpers for computing deltas between objects.\n\nFunction get_close_matches(word, possibilities, n=3, cutoff=0.6):\n    Use SequenceMatcher to return list of the best \"good enough\" matches.\n\nFunction context_diff(a, b):\n    For two lists of strings, return a delta in context diff format.\n\nFunction ndiff(a, b):\n    Return a delta: the difference between `a` and `b` (lists of strings).\n\nFunction restore(delta, which):\n    Return one of the two sequences that generated an ndiff delta.\n\nFunction unified_diff(a, b):\n    For two lists of strings, return a delta in unified diff format.\n\nClass SequenceMatcher:\n    A flexible class for comparing pairs of sequences of any type.\n\nClass Differ:\n    For producing human-readable deltas from sequences of lines of text.\n\nClass HtmlDiff:\n    For producing HTML side by side comparison with change highlights.\n\"\"\"\n\n__all__=['get_close_matches','ndiff','restore','SequenceMatcher',\n'Differ','IS_CHARACTER_JUNK','IS_LINE_JUNK','context_diff',\n'unified_diff','HtmlDiff','Match']\n\nimport warnings\nimport heapq\nfrom collections import namedtuple as _namedtuple\n\nMatch=_namedtuple('Match','a b size')\n\ndef _calculate_ratio(matches,length):\n if length:\n  return 2.0 *matches /length\n return 1.0\n \nclass SequenceMatcher:\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,isjunk=None ,a='',b='',autojunk=True ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  self. isjunk=isjunk\n  self. a=self. b=None\n  self. autojunk=autojunk\n  self. set_seqs(a,b)\n  \n def set_seqs(self,a,b):\n  ''\n\n\n\n\n\n  \n  \n  self. set_seq1(a)\n  self. set_seq2(b)\n  \n def set_seq1(self,a):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if a is self. a:\n   return\n  self. a=a\n  self. matching_blocks=self. opcodes=None\n  \n def set_seq2(self,b):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if b is self. b:\n   return\n  self. b=b\n  self. matching_blocks=self. opcodes=None\n  self. fullbcount=None\n  self. __chain_b()\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n def __chain_b(self):\n \n \n \n \n \n \n \n \n \n \n  b=self. b\n  self. b2j=b2j={}\n  \n  for i,elt in enumerate(b):\n   indices=b2j. setdefault(elt,[])\n   indices. append(i)\n   \n   \n  self. bjunk=junk=set()\n  isjunk=self. isjunk\n  if isjunk:\n   for elt in b2j. keys():\n    if isjunk(elt):\n     junk. add(elt)\n   for elt in junk:\n    del b2j[elt]\n    \n    \n  self. bpopular=popular=set()\n  n=len(b)\n  if self. autojunk and n >=200:\n   ntest=n //100+1\n   for elt,idxs in b2j. items():\n    if len(idxs)>ntest:\n     popular. add(elt)\n   for elt in popular:\n    del b2j[elt]\n    \n def isbjunk(self,item):\n  ''\n  warnings. warn(\"'SequenceMatcher().isbjunk(item)' is deprecated;\\n\"\n  \"use 'item in SMinstance.bjunk' instead.\",\n  DeprecationWarning,2)\n  return item in self. bjunk\n  \n def isbpopular(self,item):\n  ''\n  warnings. warn(\"'SequenceMatcher().isbpopular(item)' is deprecated;\\n\"\n  \"use 'item in SMinstance.bpopular' instead.\",\n  DeprecationWarning,2)\n  return item in self. bpopular\n  \n def find_longest_match(self,alo,ahi,blo,bhi):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  a,b,b2j,isbjunk=self. a,self. b,self. b2j,self. bjunk. __contains__\n  besti,bestj,bestsize=alo,blo,0\n  \n  \n  \n  j2len={}\n  nothing=[]\n  for i in range(alo,ahi):\n  \n  \n   j2lenget=j2len. get\n   newj2len={}\n   for j in b2j. get(a[i],nothing):\n   \n    if j <blo:\n     continue\n    if j >=bhi:\n     break\n    k=newj2len[j]=j2lenget(j -1,0)+1\n    if k >bestsize:\n     besti,bestj,bestsize=i -k+1,j -k+1,k\n   j2len=newj2len\n   \n   \n   \n   \n   \n  while besti >alo and bestj >blo and  not isbjunk(b[bestj -1])and  a[besti -1]==b[bestj -1]:\n   besti,bestj,bestsize=besti -1,bestj -1,bestsize+1\n  while besti+bestsize <ahi and bestj+bestsize <bhi and  not isbjunk(b[bestj+bestsize])and  a[besti+bestsize]==b[bestj+bestsize]:\n   bestsize +=1\n   \n   \n   \n   \n   \n   \n   \n   \n  while besti >alo and bestj >blo and  isbjunk(b[bestj -1])and  a[besti -1]==b[bestj -1]:\n   besti,bestj,bestsize=besti -1,bestj -1,bestsize+1\n  while besti+bestsize <ahi and bestj+bestsize <bhi and  isbjunk(b[bestj+bestsize])and  a[besti+bestsize]==b[bestj+bestsize]:\n   bestsize=bestsize+1\n   \n  return Match(besti,bestj,bestsize)\n  \n def get_matching_blocks(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if self. matching_blocks is not None :\n   return self. matching_blocks\n  la,lb=len(self. a),len(self. b)\n  \n  \n  \n  \n  \n  \n  \n  queue=[(0,la,0,lb)]\n  matching_blocks=[]\n  while queue:\n   alo,ahi,blo,bhi=queue. pop()\n   i,j,k=x=self. find_longest_match(alo,ahi,blo,bhi)\n   \n   \n   \n   if k:\n    matching_blocks. append(x)\n    if alo <i and blo <j:\n     queue. append((alo,i,blo,j))\n    if i+k <ahi and j+k <bhi:\n     queue. append((i+k,ahi,j+k,bhi))\n  matching_blocks. sort()\n  \n  \n  \n  \n  i1=j1=k1=0\n  non_adjacent=[]\n  for i2,j2,k2 in matching_blocks:\n  \n   if i1+k1 ==i2 and j1+k1 ==j2:\n   \n   \n   \n    k1 +=k2\n   else :\n   \n   \n   \n    if k1:\n     non_adjacent. append((i1,j1,k1))\n    i1,j1,k1=i2,j2,k2\n  if k1:\n   non_adjacent. append((i1,j1,k1))\n   \n  non_adjacent. append((la,lb,0))\n  self. matching_blocks=non_adjacent\n  return map(Match. _make,self. matching_blocks)\n  \n def get_opcodes(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if self. opcodes is not None :\n   return self. opcodes\n  i=j=0\n  self. opcodes=answer=[]\n  for ai,bj,size in self. get_matching_blocks():\n  \n  \n  \n  \n  \n   tag=''\n   if i <ai and j <bj:\n    tag='replace'\n   elif i <ai:\n    tag='delete'\n   elif j <bj:\n    tag='insert'\n   if tag:\n    answer. append((tag,i,ai,j,bj))\n   i,j=ai+size,bj+size\n   \n   \n   if size:\n    answer. append(('equal',ai,i,bj,j))\n  return answer\n  \n def get_grouped_opcodes(self,n=3):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  codes=self. get_opcodes()\n  if not codes:\n   codes=[(\"equal\",0,1,0,1)]\n   \n  if codes[0][0]=='equal':\n   tag,i1,i2,j1,j2=codes[0]\n   codes[0]=tag,max(i1,i2 -n),i2,max(j1,j2 -n),j2\n  if codes[-1][0]=='equal':\n   tag,i1,i2,j1,j2=codes[-1]\n   codes[-1]=tag,i1,min(i2,i1+n),j1,min(j2,j1+n)\n   \n  nn=n+n\n  group=[]\n  for tag,i1,i2,j1,j2 in codes:\n  \n  \n   if tag =='equal'and i2 -i1 >nn:\n    group. append((tag,i1,min(i2,i1+n),j1,min(j2,j1+n)))\n    yield group\n    group=[]\n    i1,j1=max(i1,i2 -n),max(j1,j2 -n)\n   group. append((tag,i1,i2,j1,j2))\n  if group and not (len(group)==1 and group[0][0]=='equal'):\n   yield group\n   \n def ratio(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  matches=sum(triple[-1]for triple in self. get_matching_blocks())\n  return _calculate_ratio(matches,len(self. a)+len(self. b))\n  \n def quick_ratio(self):\n  ''\n\n\n\n  \n  \n  \n  \n  \n  if self. fullbcount is None :\n   self. fullbcount=fullbcount={}\n   for elt in self. b:\n    fullbcount[elt]=fullbcount. get(elt,0)+1\n  fullbcount=self. fullbcount\n  \n  \n  avail={}\n  availhas,matches=avail. __contains__,0\n  for elt in self. a:\n   if availhas(elt):\n    numb=avail[elt]\n   else :\n    numb=fullbcount. get(elt,0)\n   avail[elt]=numb -1\n   if numb >0:\n    matches=matches+1\n  return _calculate_ratio(matches,len(self. a)+len(self. b))\n  \n def real_quick_ratio(self):\n  ''\n\n\n\n  \n  \n  la,lb=len(self. a),len(self. b)\n  \n  \n  return _calculate_ratio(min(la,lb),la+lb)\n  \ndef get_close_matches(word,possibilities,n=3,cutoff=0.6):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n if not n >0:\n  raise ValueError(\"n must be > 0: %r\"%(n,))\n if not 0.0 <=cutoff <=1.0:\n  raise ValueError(\"cutoff must be in [0.0, 1.0]: %r\"%(cutoff,))\n result=[]\n s=SequenceMatcher()\n s. set_seq2(word)\n for x in possibilities:\n  s. set_seq1(x)\n  if s. real_quick_ratio()>=cutoff and  s. quick_ratio()>=cutoff and  s. ratio()>=cutoff:\n   result. append((s. ratio(),x))\n   \n   \n result=heapq. nlargest(n,result)\n \n return [x for score,x in result]\n \ndef _count_leading(line,ch):\n ''\n\n\n\n\n\n\n \n \n i,n=0,len(line)\n while i <n and line[i]==ch:\n  i +=1\n return i\n \nclass Differ:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,linejunk=None ,charjunk=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  self. linejunk=linejunk\n  self. charjunk=charjunk\n  \n def compare(self,a,b):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  cruncher=SequenceMatcher(self. linejunk,a,b)\n  for tag,alo,ahi,blo,bhi in cruncher. get_opcodes():\n   if tag =='replace':\n    g=self. _fancy_replace(a,alo,ahi,b,blo,bhi)\n   elif tag =='delete':\n    g=self. _dump('-',a,alo,ahi)\n   elif tag =='insert':\n    g=self. _dump('+',b,blo,bhi)\n   elif tag =='equal':\n    g=self. _dump(' ',a,alo,ahi)\n   else :\n    raise ValueError('unknown tag %r'%(tag,))\n    \n   for line in g:\n    yield line\n    \n def _dump(self,tag,x,lo,hi):\n  ''\n  for i in range(lo,hi):\n   yield'%s %s'%(tag,x[i])\n   \n def _plain_replace(self,a,alo,ahi,b,blo,bhi):\n  assert alo <ahi and blo <bhi\n  \n  \n  if bhi -blo <ahi -alo:\n   first=self. _dump('+',b,blo,bhi)\n   second=self. _dump('-',a,alo,ahi)\n  else :\n   first=self. _dump('-',a,alo,ahi)\n   second=self. _dump('+',b,blo,bhi)\n   \n  for g in first,second:\n   for line in g:\n    yield line\n    \n def _fancy_replace(self,a,alo,ahi,b,blo,bhi):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  \n  \n  best_ratio,cutoff=0.74,0.75\n  cruncher=SequenceMatcher(self. charjunk)\n  eqi,eqj=None ,None\n  \n  \n  \n  \n  for j in range(blo,bhi):\n   bj=b[j]\n   cruncher. set_seq2(bj)\n   for i in range(alo,ahi):\n    ai=a[i]\n    if ai ==bj:\n     if eqi is None :\n      eqi,eqj=i,j\n     continue\n    cruncher. set_seq1(ai)\n    \n    \n    \n    \n    \n    \n    if cruncher. real_quick_ratio()>best_ratio and    cruncher. quick_ratio()>best_ratio and    cruncher. ratio()>best_ratio:\n     best_ratio,best_i,best_j=cruncher. ratio(),i,j\n  if best_ratio <cutoff:\n  \n   if eqi is None :\n   \n    for line in self. _plain_replace(a,alo,ahi,b,blo,bhi):\n     yield line\n    return\n    \n   best_i,best_j,best_ratio=eqi,eqj,1.0\n  else :\n  \n   eqi=None\n   \n   \n   \n   \n   \n  for line in self. _fancy_helper(a,alo,best_i,b,blo,best_j):\n   yield line\n   \n   \n  aelt,belt=a[best_i],b[best_j]\n  if eqi is None :\n  \n   atags=btags=\"\"\n   cruncher. set_seqs(aelt,belt)\n   for tag,ai1,ai2,bj1,bj2 in cruncher. get_opcodes():\n    la,lb=ai2 -ai1,bj2 -bj1\n    if tag =='replace':\n     atags +='^'*la\n     btags +='^'*lb\n    elif tag =='delete':\n     atags +='-'*la\n    elif tag =='insert':\n     btags +='+'*lb\n    elif tag =='equal':\n     atags +=' '*la\n     btags +=' '*lb\n    else :\n     raise ValueError('unknown tag %r'%(tag,))\n   for line in self. _qformat(aelt,belt,atags,btags):\n    yield line\n  else :\n  \n   yield'  '+aelt\n   \n   \n  for line in self. _fancy_helper(a,best_i+1,ahi,b,best_j+1,bhi):\n   yield line\n   \n def _fancy_helper(self,a,alo,ahi,b,blo,bhi):\n  g=[]\n  if alo <ahi:\n   if blo <bhi:\n    g=self. _fancy_replace(a,alo,ahi,b,blo,bhi)\n   else :\n    g=self. _dump('-',a,alo,ahi)\n  elif blo <bhi:\n   g=self. _dump('+',b,blo,bhi)\n   \n  for line in g:\n   yield line\n   \n def _qformat(self,aline,bline,atags,btags):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  \n  common=min(_count_leading(aline,\"\\t\"),\n  _count_leading(bline,\"\\t\"))\n  common=min(common,_count_leading(atags[:common],\" \"))\n  common=min(common,_count_leading(btags[:common],\" \"))\n  atags=atags[common:]. rstrip()\n  btags=btags[common:]. rstrip()\n  \n  yield\"- \"+aline\n  if atags:\n   yield\"? %s%s\\n\"%(\"\\t\"*common,atags)\n   \n  yield\"+ \"+bline\n  if btags:\n   yield\"? %s%s\\n\"%(\"\\t\"*common,btags)\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \nimport re\n\ndef IS_LINE_JUNK(line,pat=re. compile(r\"\\s*#?\\s*$\"). match):\n ''\n\n\n\n\n\n\n\n\n\n\n \n \n return pat(line)is not None\n \ndef IS_CHARACTER_JUNK(ch,ws=\" \\t\"):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n return ch in ws\n \n \n \n \n \n \ndef _format_range_unified(start,stop):\n ''\n \n beginning=start+1\n length=stop -start\n if length ==1:\n  return'{}'. format(beginning)\n if not length:\n  beginning -=1\n return'{},{}'. format(beginning,length)\n \ndef unified_diff(a,b,fromfile='',tofile='',fromfiledate='',\ntofiledate='',n=3,lineterm='\\n'):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n started=False\n for group in SequenceMatcher(None ,a,b). get_grouped_opcodes(n):\n  if not started:\n   started=True\n   fromdate='\\t{}'. format(fromfiledate)if fromfiledate else''\n   todate='\\t{}'. format(tofiledate)if tofiledate else''\n   yield'--- {}{}{}'. format(fromfile,fromdate,lineterm)\n   yield'+++ {}{}{}'. format(tofile,todate,lineterm)\n   \n  first,last=group[0],group[-1]\n  file1_range=_format_range_unified(first[1],last[2])\n  file2_range=_format_range_unified(first[3],last[4])\n  yield'@@ -{} +{} @@{}'. format(file1_range,file2_range,lineterm)\n  \n  for tag,i1,i2,j1,j2 in group:\n   if tag =='equal':\n    for line in a[i1:i2]:\n     yield' '+line\n    continue\n   if tag in {'replace','delete'}:\n    for line in a[i1:i2]:\n     yield'-'+line\n   if tag in {'replace','insert'}:\n    for line in b[j1:j2]:\n     yield'+'+line\n     \n     \n     \n     \n     \n     \ndef _format_range_context(start,stop):\n ''\n \n beginning=start+1\n length=stop -start\n if not length:\n  beginning -=1\n if length <=1:\n  return'{}'. format(beginning)\n return'{},{}'. format(beginning,beginning+length -1)\n \n \ndef context_diff(a,b,fromfile='',tofile='',\nfromfiledate='',tofiledate='',n=3,lineterm='\\n'):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n prefix=dict(insert='+ ',delete='- ',replace='! ',equal='  ')\n started=False\n for group in SequenceMatcher(None ,a,b). get_grouped_opcodes(n):\n  if not started:\n   started=True\n   fromdate='\\t{}'. format(fromfiledate)if fromfiledate else''\n   todate='\\t{}'. format(tofiledate)if tofiledate else''\n   yield'*** {}{}{}'. format(fromfile,fromdate,lineterm)\n   yield'--- {}{}{}'. format(tofile,todate,lineterm)\n   \n  first,last=group[0],group[-1]\n  yield'***************'+lineterm\n  \n  file1_range=_format_range_context(first[1],last[2])\n  yield'*** {} ****{}'. format(file1_range,lineterm)\n  \n  if any(tag in {'replace','delete'}for tag,_,_,_,_ in group):\n   for tag,i1,i2,_,_ in group:\n    if tag !='insert':\n     for line in a[i1:i2]:\n      yield prefix[tag]+line\n      \n  file2_range=_format_range_context(first[3],last[4])\n  yield'--- {} ----{}'. format(file2_range,lineterm)\n  \n  if any(tag in {'replace','insert'}for tag,_,_,_,_ in group):\n   for tag,_,_,j1,j2 in group:\n    if tag !='delete':\n     for line in b[j1:j2]:\n      yield prefix[tag]+line\n      \ndef ndiff(a,b,linejunk=None ,charjunk=IS_CHARACTER_JUNK):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n return Differ(linejunk,charjunk). compare(a,b)\n \ndef _mdiff(fromlines,tolines,context=None ,linejunk=None ,\ncharjunk=IS_CHARACTER_JUNK):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n import re\n \n \n change_re=re. compile('(\\++|\\-+|\\^+)')\n \n \n diff_lines_iterator=ndiff(fromlines,tolines,linejunk,charjunk)\n \n def _make_line(lines,format_key,side,num_lines=[0,0]):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  num_lines[side]+=1\n  \n  \n  if format_key is None :\n   return (num_lines[side],lines. pop(0)[2:])\n   \n  if format_key =='?':\n   text,markers=lines. pop(0),lines. pop(0)\n   \n   sub_info=[]\n   def record_sub_info(match_object,sub_info=sub_info):\n    sub_info. append([match_object. group(1)[0],match_object. span()])\n    return match_object. group(1)\n   change_re. sub(record_sub_info,markers)\n   \n   \n   for key,(begin,end)in sub_info[::-1]:\n    text=text[0:begin]+'\\0'+key+text[begin:end]+'\\1'+text[end:]\n   text=text[2:]\n   \n  else :\n   text=lines. pop(0)[2:]\n   \n   \n   if not text:\n    text=' '\n    \n   text='\\0'+format_key+text+'\\1'\n   \n   \n   \n  return (num_lines[side],text)\n  \n def _line_iterator():\n  ''\n\n\n\n\n\n\n\n\n\n\n\n  \n  lines=[]\n  num_blanks_pending,num_blanks_to_yield=0,0\n  while True :\n  \n  \n  \n   while len(lines)<4:\n    try :\n     lines. append(next(diff_lines_iterator))\n    except StopIteration:\n     lines. append('X')\n   s=''. join([line[0]for line in lines])\n   if s. startswith('X'):\n   \n   \n   \n    num_blanks_to_yield=num_blanks_pending\n   elif s. startswith('-?+?'):\n   \n    yield _make_line(lines,'?',0),_make_line(lines,'?',1),True\n    continue\n   elif s. startswith('--++'):\n   \n   \n    num_blanks_pending -=1\n    yield _make_line(lines,'-',0),None ,True\n    continue\n   elif s. startswith(('--?+','--+','- ')):\n   \n   \n    from_line,to_line=_make_line(lines,'-',0),None\n    num_blanks_to_yield,num_blanks_pending=num_blanks_pending -1,0\n   elif s. startswith('-+?'):\n   \n    yield _make_line(lines,None ,0),_make_line(lines,'?',1),True\n    continue\n   elif s. startswith('-?+'):\n   \n    yield _make_line(lines,'?',0),_make_line(lines,None ,1),True\n    continue\n   elif s. startswith('-'):\n   \n    num_blanks_pending -=1\n    yield _make_line(lines,'-',0),None ,True\n    continue\n   elif s. startswith('+--'):\n   \n   \n    num_blanks_pending +=1\n    yield None ,_make_line(lines,'+',1),True\n    continue\n   elif s. startswith(('+ ','+-')):\n   \n    from_line,to_line=None ,_make_line(lines,'+',1)\n    num_blanks_to_yield,num_blanks_pending=num_blanks_pending+1,0\n   elif s. startswith('+'):\n   \n    num_blanks_pending +=1\n    yield None ,_make_line(lines,'+',1),True\n    continue\n   elif s. startswith(' '):\n   \n    yield _make_line(lines[:],None ,0),_make_line(lines,None ,1),False\n    continue\n    \n    \n   while (num_blanks_to_yield <0):\n    num_blanks_to_yield +=1\n    yield None ,('','\\n'),True\n   while (num_blanks_to_yield >0):\n    num_blanks_to_yield -=1\n    yield ('','\\n'),None ,True\n   if s. startswith('X'):\n    raise StopIteration\n   else :\n    yield from_line,to_line,True\n    \n def _line_pair_iterator():\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  line_iterator=_line_iterator()\n  fromlines,tolines=[],[]\n  while True :\n  \n   while (len(fromlines)==0 or len(tolines)==0):\n    from_line,to_line,found_diff=next(line_iterator)\n    if from_line is not None :\n     fromlines. append((from_line,found_diff))\n    if to_line is not None :\n     tolines. append((to_line,found_diff))\n     \n   from_line,fromDiff=fromlines. pop(0)\n   to_line,to_diff=tolines. pop(0)\n   yield (from_line,to_line,fromDiff or to_diff)\n   \n   \n   \n line_pair_iterator=_line_pair_iterator()\n if context is None :\n  while True :\n   yield next(line_pair_iterator)\n   \n   \n else :\n  context +=1\n  lines_to_write=0\n  while True :\n  \n  \n  \n   index,contextLines=0,[None ]*(context)\n   found_diff=False\n   while (found_diff is False ):\n    from_line,to_line,found_diff=next(line_pair_iterator)\n    i=index %context\n    contextLines[i]=(from_line,to_line,found_diff)\n    index +=1\n    \n    \n   if index >context:\n    yield None ,None ,None\n    lines_to_write=context\n   else :\n    lines_to_write=index\n    index=0\n   while (lines_to_write):\n    i=index %context\n    index +=1\n    yield contextLines[i]\n    lines_to_write -=1\n    \n   lines_to_write=context -1\n   while (lines_to_write):\n    from_line,to_line,found_diff=next(line_pair_iterator)\n    \n    if found_diff:\n     lines_to_write=context -1\n    else :\n     lines_to_write -=1\n    yield from_line,to_line,found_diff\n    \n    \n_file_template=\"\"\"\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"\n          \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n\n<html>\n\n<head>\n    <meta http-equiv=\"Content-Type\"\n          content=\"text/html; charset=ISO-8859-1\" />\n    <title></title>\n    <style type=\"text/css\">%(styles)s\n    </style>\n</head>\n\n<body>\n    %(table)s%(legend)s\n</body>\n\n</html>\"\"\"\n\n_styles=\"\"\"\n        table.diff {font-family:Courier; border:medium;}\n        .diff_header {background-color:#e0e0e0}\n        td.diff_header {text-align:right}\n        .diff_next {background-color:#c0c0c0}\n        .diff_add {background-color:#aaffaa}\n        .diff_chg {background-color:#ffff77}\n        .diff_sub {background-color:#ffaaaa}\"\"\"\n\n_table_template=\"\"\"\n    <table class=\"diff\" id=\"difflib_chg_%(prefix)s_top\"\n           cellspacing=\"0\" cellpadding=\"0\" rules=\"groups\" >\n        <colgroup></colgroup> <colgroup></colgroup> <colgroup></colgroup>\n        <colgroup></colgroup> <colgroup></colgroup> <colgroup></colgroup>\n        %(header_row)s\n        <tbody>\n%(data_rows)s        </tbody>\n    </table>\"\"\"\n\n_legend=\"\"\"\n    <table class=\"diff\" summary=\"Legends\">\n        <tr> <th colspan=\"2\"> Legends </th> </tr>\n        <tr> <td> <table border=\"\" summary=\"Colors\">\n                      <tr><th> Colors </th> </tr>\n                      <tr><td class=\"diff_add\">&nbsp;Added&nbsp;</td></tr>\n                      <tr><td class=\"diff_chg\">Changed</td> </tr>\n                      <tr><td class=\"diff_sub\">Deleted</td> </tr>\n                  </table></td>\n             <td> <table border=\"\" summary=\"Links\">\n                      <tr><th colspan=\"2\"> Links </th> </tr>\n                      <tr><td>(f)irst change</td> </tr>\n                      <tr><td>(n)ext change</td> </tr>\n                      <tr><td>(t)op</td> </tr>\n                  </table></td> </tr>\n    </table>\"\"\"\n\nclass HtmlDiff(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n _file_template=_file_template\n _styles=_styles\n _table_template=_table_template\n _legend=_legend\n _default_prefix=0\n \n def __init__(self,tabsize=8,wrapcolumn=None ,linejunk=None ,\n charjunk=IS_CHARACTER_JUNK):\n  ''\n\n\n\n\n\n\n\n\n  \n  self. _tabsize=tabsize\n  self. _wrapcolumn=wrapcolumn\n  self. _linejunk=linejunk\n  self. _charjunk=charjunk\n  \n def make_file(self,fromlines,tolines,fromdesc='',todesc='',context=False ,\n numlines=5):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  return self. _file_template %dict(\n  styles=self. _styles,\n  legend=self. _legend,\n  table=self. make_table(fromlines,tolines,fromdesc,todesc,\n  context=context,numlines=numlines))\n  \n def _tab_newline_replace(self,fromlines,tolines):\n  ''\n\n\n\n\n\n\n\n  \n  def expand_tabs(line):\n  \n   line=line. replace(' ','\\0')\n   \n   line=line. expandtabs(self. _tabsize)\n   \n   \n   line=line. replace(' ','\\t')\n   return line. replace('\\0',' '). rstrip('\\n')\n  fromlines=[expand_tabs(line)for line in fromlines]\n  tolines=[expand_tabs(line)for line in tolines]\n  return fromlines,tolines\n  \n def _split_line(self,data_list,line_num,text):\n  ''\n\n\n\n\n\n\n  \n  \n  if not line_num:\n   data_list. append((line_num,text))\n   return\n   \n   \n  size=len(text)\n  max=self. _wrapcolumn\n  if (size <=max)or ((size -(text. count('\\0')*3))<=max):\n   data_list. append((line_num,text))\n   return\n   \n   \n   \n  i=0\n  n=0\n  mark=''\n  while n <max and i <size:\n   if text[i]=='\\0':\n    i +=1\n    mark=text[i]\n    i +=1\n   elif text[i]=='\\1':\n    i +=1\n    mark=''\n   else :\n    i +=1\n    n +=1\n    \n    \n  line1=text[:i]\n  line2=text[i:]\n  \n  \n  \n  \n  if mark:\n   line1=line1+'\\1'\n   line2='\\0'+mark+line2\n   \n   \n  data_list. append((line_num,line1))\n  \n  \n  self. _split_line(data_list,'>',line2)\n  \n def _line_wrapper(self,diffs):\n  ''\n  \n  \n  for fromdata,todata,flag in diffs:\n  \n   if flag is None :\n    yield fromdata,todata,flag\n    continue\n   (fromline,fromtext),(toline,totext)=fromdata,todata\n   \n   \n   fromlist,tolist=[],[]\n   self. _split_line(fromlist,fromline,fromtext)\n   self. _split_line(tolist,toline,totext)\n   \n   \n   while fromlist or tolist:\n    if fromlist:\n     fromdata=fromlist. pop(0)\n    else :\n     fromdata=('',' ')\n    if tolist:\n     todata=tolist. pop(0)\n    else :\n     todata=('',' ')\n    yield fromdata,todata,flag\n    \n def _collect_lines(self,diffs):\n  ''\n\n\n\n  \n  \n  fromlist,tolist,flaglist=[],[],[]\n  \n  for fromdata,todata,flag in diffs:\n   try :\n   \n    fromlist. append(self. _format_line(0,flag,*fromdata))\n    tolist. append(self. _format_line(1,flag,*todata))\n   except TypeError:\n   \n    fromlist. append(None )\n    tolist. append(None )\n   flaglist. append(flag)\n  return fromlist,tolist,flaglist\n  \n def _format_line(self,side,flag,linenum,text):\n  ''\n\n\n\n\n\n  \n  try :\n   linenum='%d'%linenum\n   id=' id=\"%s%s\"'%(self. _prefix[side],linenum)\n  except TypeError:\n  \n   id=''\n   \n  text=text. replace(\"&\",\"&amp;\"). replace(\">\",\"&gt;\"). replace(\"<\",\"&lt;\")\n  \n  \n  text=text. replace(' ','&nbsp;'). rstrip()\n  \n  return'<td class=\"diff_header\"%s>%s</td><td nowrap=\"nowrap\">%s</td>'  %(id,linenum,text)\n  \n def _make_prefix(self):\n  ''\n  \n  \n  \n  fromprefix=\"from%d_\"%HtmlDiff. _default_prefix\n  toprefix=\"to%d_\"%HtmlDiff. _default_prefix\n  HtmlDiff. _default_prefix +=1\n  \n  self. _prefix=[fromprefix,toprefix]\n  \n def _convert_flags(self,fromlist,tolist,flaglist,context,numlines):\n  ''\n  \n  \n  toprefix=self. _prefix[1]\n  \n  \n  next_id=['']*len(flaglist)\n  next_href=['']*len(flaglist)\n  num_chg,in_change=0,False\n  last=0\n  for i,flag in enumerate(flaglist):\n   if flag:\n    if not in_change:\n     in_change=True\n     last=i\n     \n     \n     \n     i=max([0,i -numlines])\n     next_id[i]=' id=\"difflib_chg_%s_%d\"'%(toprefix,num_chg)\n     \n     \n     num_chg +=1\n     next_href[last]='<a href=\"#difflib_chg_%s_%d\">n</a>'%(\n     toprefix,num_chg)\n   else :\n    in_change=False\n    \n  if not flaglist:\n   flaglist=[False ]\n   next_id=['']\n   next_href=['']\n   last=0\n   if context:\n    fromlist=['<td></td><td>&nbsp;No Differences Found&nbsp;</td>']\n    tolist=fromlist\n   else :\n    fromlist=tolist=['<td></td><td>&nbsp;Empty File&nbsp;</td>']\n    \n  if not flaglist[0]:\n   next_href[0]='<a href=\"#difflib_chg_%s_0\">f</a>'%toprefix\n   \n  next_href[last]='<a href=\"#difflib_chg_%s_top\">t</a>'%(toprefix)\n  \n  return fromlist,tolist,flaglist,next_href,next_id\n  \n def make_table(self,fromlines,tolines,fromdesc='',todesc='',context=False ,\n numlines=5):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  \n  \n  self. _make_prefix()\n  \n  \n  \n  fromlines,tolines=self. _tab_newline_replace(fromlines,tolines)\n  \n  \n  if context:\n   context_lines=numlines\n  else :\n   context_lines=None\n  diffs=_mdiff(fromlines,tolines,context_lines,linejunk=self. _linejunk,\n  charjunk=self. _charjunk)\n  \n  \n  if self. _wrapcolumn:\n   diffs=self. _line_wrapper(diffs)\n   \n   \n  fromlist,tolist,flaglist=self. _collect_lines(diffs)\n  \n  \n  fromlist,tolist,flaglist,next_href,next_id=self. _convert_flags(\n  fromlist,tolist,flaglist,context,numlines)\n  \n  s=[]\n  fmt='            <tr><td class=\"diff_next\"%s>%s</td>%s'+  '<td class=\"diff_next\">%s</td>%s</tr>\\n'\n  for i in range(len(flaglist)):\n   if flaglist[i]is None :\n   \n   \n    if i >0:\n     s. append('        </tbody>        \\n        <tbody>\\n')\n   else :\n    s. append(fmt %(next_id[i],next_href[i],fromlist[i],\n    next_href[i],tolist[i]))\n  if fromdesc or todesc:\n   header_row='<thead><tr>%s%s%s%s</tr></thead>'%(\n   '<th class=\"diff_next\"><br /></th>',\n   '<th colspan=\"2\" class=\"diff_header\">%s</th>'%fromdesc,\n   '<th class=\"diff_next\"><br /></th>',\n   '<th colspan=\"2\" class=\"diff_header\">%s</th>'%todesc)\n  else :\n   header_row=''\n   \n  table=self. _table_template %dict(\n  data_rows=''. join(s),\n  header_row=header_row,\n  prefix=self. _prefix[1])\n  \n  return table. replace('\\0+','<span class=\"diff_add\">').  replace('\\0-','<span class=\"diff_sub\">').  replace('\\0^','<span class=\"diff_chg\">').  replace('\\1','</span>').  replace('\\t','&nbsp;')\n  \ndel re\n\ndef restore(delta,which):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n try :\n  tag={1:\"- \",2:\"+ \"}[int(which)]\n except KeyError:\n  raise ValueError('unknown delta choice (must be 1 or 2): %r'\n  %which)\n prefixes=(\"  \",tag)\n for line in delta:\n  if line[:2]in prefixes:\n   yield line[2:]\n   \ndef _test():\n import doctest,difflib\n return doctest. testmod(difflib)\n \nif __name__ ==\"__main__\":\n _test()\n", ["collections", "difflib", "doctest", "heapq", "re", "warnings"]], "unittest.suite": [".py", "''\n\nimport sys\n\nfrom . import case\nfrom . import util\n\n__unittest=True\n\n\ndef _call_if_exists(parent,attr):\n func=getattr(parent,attr,lambda :None )\n func()\n \n \nclass BaseTestSuite(object):\n ''\n \n def __init__(self,tests=()):\n  self. _tests=[]\n  self. addTests(tests)\n  \n def __repr__(self):\n  return\"<%s tests=%s>\"%(util. strclass(self. __class__),list(self))\n  \n def __eq__(self,other):\n  if not isinstance(other,self. __class__):\n   return NotImplemented\n  return list(self)==list(other)\n  \n def __ne__(self,other):\n  return not self ==other\n  \n def __iter__(self):\n  return iter(self. _tests)\n  \n def countTestCases(self):\n  cases=0\n  for test in self:\n   cases +=test. countTestCases()\n  return cases\n  \n def addTest(self,test):\n \n  if not callable(test):\n   raise TypeError(\"{} is not callable\". format(repr(test)))\n  if isinstance(test,type)and issubclass(test,\n  (case. TestCase,TestSuite)):\n   raise TypeError(\"TestCases and TestSuites must be instantiated \"\n   \"before passing them to addTest()\")\n  self. _tests. append(test)\n  \n def addTests(self,tests):\n  if isinstance(tests,str):\n   raise TypeError(\"tests must be an iterable of tests, not a string\")\n  for test in tests:\n   self. addTest(test)\n   \n def run(self,result):\n  for test in self:\n   if result. shouldStop:\n    break\n   test(result)\n  return result\n  \n def __call__(self,*args,**kwds):\n  return self. run(*args,**kwds)\n  \n def debug(self):\n  ''\n  for test in self:\n   test. debug()\n   \n   \nclass TestSuite(BaseTestSuite):\n ''\n\n\n\n\n\n\n \n \n def run(self,result,debug=False ):\n  topLevel=False\n  if getattr(result,'_testRunEntered',False )is False :\n   result. _testRunEntered=topLevel=True\n   \n  for test in self:\n   if result. shouldStop:\n    break\n    \n   if _isnotsuite(test):\n    self. _tearDownPreviousClass(test,result)\n    self. _handleModuleFixture(test,result)\n    self. _handleClassSetUp(test,result)\n    result. _previousTestClass=test. __class__\n    \n    if (getattr(test. __class__,'_classSetupFailed',False )or\n    getattr(result,'_moduleSetUpFailed',False )):\n     continue\n     \n   if not debug:\n    test(result)\n   else :\n    test. debug()\n    \n  if topLevel:\n   self. _tearDownPreviousClass(None ,result)\n   self. _handleModuleTearDown(result)\n   result. _testRunEntered=False\n  return result\n  \n def debug(self):\n  ''\n  debug=_DebugResult()\n  self. run(debug,True )\n  \n  \n  \n def _handleClassSetUp(self,test,result):\n  previousClass=getattr(result,'_previousTestClass',None )\n  currentClass=test. __class__\n  if currentClass ==previousClass:\n   return\n  if result. _moduleSetUpFailed:\n   return\n  if getattr(currentClass,\"__unittest_skip__\",False ):\n   return\n   \n  try :\n   currentClass. _classSetupFailed=False\n  except TypeError:\n  \n  \n   pass\n   \n  setUpClass=getattr(currentClass,'setUpClass',None )\n  if setUpClass is not None :\n   _call_if_exists(result,'_setupStdout')\n   try :\n    setUpClass()\n   except Exception as e:\n    if isinstance(result,_DebugResult):\n     raise\n    currentClass. _classSetupFailed=True\n    className=util. strclass(currentClass)\n    errorName='setUpClass (%s)'%className\n    self. _addClassOrModuleLevelException(result,e,errorName)\n   finally :\n    _call_if_exists(result,'_restoreStdout')\n    \n def _get_previous_module(self,result):\n  previousModule=None\n  previousClass=getattr(result,'_previousTestClass',None )\n  if previousClass is not None :\n   previousModule=previousClass. __module__\n  return previousModule\n  \n  \n def _handleModuleFixture(self,test,result):\n  previousModule=self. _get_previous_module(result)\n  currentModule=test. __class__. __module__\n  if currentModule ==previousModule:\n   return\n   \n  self. _handleModuleTearDown(result)\n  \n  \n  result. _moduleSetUpFailed=False\n  try :\n   module=sys. modules[currentModule]\n  except KeyError:\n   return\n  setUpModule=getattr(module,'setUpModule',None )\n  if setUpModule is not None :\n   _call_if_exists(result,'_setupStdout')\n   try :\n    setUpModule()\n   except Exception as e:\n    if isinstance(result,_DebugResult):\n     raise\n    result. _moduleSetUpFailed=True\n    errorName='setUpModule (%s)'%currentModule\n    self. _addClassOrModuleLevelException(result,e,errorName)\n   finally :\n    _call_if_exists(result,'_restoreStdout')\n    \n def _addClassOrModuleLevelException(self,result,exception,errorName):\n  error=_ErrorHolder(errorName)\n  addSkip=getattr(result,'addSkip',None )\n  if addSkip is not None and isinstance(exception,case. SkipTest):\n   addSkip(error,str(exception))\n  else :\n   result. addError(error,sys. exc_info())\n   \n def _handleModuleTearDown(self,result):\n  previousModule=self. _get_previous_module(result)\n  if previousModule is None :\n   return\n  if result. _moduleSetUpFailed:\n   return\n   \n  try :\n   module=sys. modules[previousModule]\n  except KeyError:\n   return\n   \n  tearDownModule=getattr(module,'tearDownModule',None )\n  if tearDownModule is not None :\n   _call_if_exists(result,'_setupStdout')\n   try :\n    tearDownModule()\n   except Exception as e:\n    if isinstance(result,_DebugResult):\n     raise\n    errorName='tearDownModule (%s)'%previousModule\n    self. _addClassOrModuleLevelException(result,e,errorName)\n   finally :\n    _call_if_exists(result,'_restoreStdout')\n    \n def _tearDownPreviousClass(self,test,result):\n  previousClass=getattr(result,'_previousTestClass',None )\n  currentClass=test. __class__\n  if currentClass ==previousClass:\n   return\n  if getattr(previousClass,'_classSetupFailed',False ):\n   return\n  if getattr(result,'_moduleSetUpFailed',False ):\n   return\n  if getattr(previousClass,\"__unittest_skip__\",False ):\n   return\n   \n  tearDownClass=getattr(previousClass,'tearDownClass',None )\n  if tearDownClass is not None :\n   _call_if_exists(result,'_setupStdout')\n   try :\n    tearDownClass()\n   except Exception as e:\n    if isinstance(result,_DebugResult):\n     raise\n    className=util. strclass(previousClass)\n    errorName='tearDownClass (%s)'%className\n    self. _addClassOrModuleLevelException(result,e,errorName)\n   finally :\n    _call_if_exists(result,'_restoreStdout')\n    \n    \nclass _ErrorHolder(object):\n ''\n\n\n\n \n \n \n \n \n failureException=None\n \n def __init__(self,description):\n  self. description=description\n  \n def id(self):\n  return self. description\n  \n def shortDescription(self):\n  return None\n  \n def __repr__(self):\n  return\"<ErrorHolder description=%r>\"%(self. description,)\n  \n def __str__(self):\n  return self. id()\n  \n def run(self,result):\n \n \n  pass\n  \n def __call__(self,result):\n  return self. run(result)\n  \n def countTestCases(self):\n  return 0\n  \ndef _isnotsuite(test):\n ''\n try :\n  iter(test)\n except TypeError:\n  return True\n return False\n \n \nclass _DebugResult(object):\n ''\n _previousTestClass=None\n _moduleSetUpFailed=False\n shouldStop=False\n", ["sys", "unittest", "unittest.case", "unittest.util"]], "browser.html": [".py", "from _html import *", ["_html"]], "keyword": [".py", "#! /usr/bin/env python3\n\n\"\"\"Keywords (from \"graminit.c\")\n\nThis file is automatically generated; please don't muck it up!\n\nTo update the symbols in this file, 'cd' to the top directory of\nthe python source tree after building the interpreter and run:\n\n    ./python Lib/keyword.py\n\"\"\"\n\n__all__=[\"iskeyword\",\"kwlist\"]\n\nkwlist=[\n\n'False',\n'None',\n'True',\n'and',\n'as',\n'assert',\n'break',\n'class',\n'continue',\n'def',\n'del',\n'elif',\n'else',\n'except',\n'finally',\n'for',\n'from',\n'global',\n'if',\n'import',\n'in',\n'is',\n'lambda',\n'nonlocal',\n'not',\n'or',\n'pass',\n'raise',\n'return',\n'try',\n'while',\n'with',\n'yield',\n\n]\n\niskeyword=frozenset(kwlist). __contains__\n\ndef main():\n import sys,re\n \n args=sys. argv[1:]\n iptfile=args and args[0]or\"Python/graminit.c\"\n if len(args)>1:optfile=args[1]\n else :optfile=\"Lib/keyword.py\"\n \n \n with open(iptfile)as fp:\n  strprog=re. compile('\"([^\"]+)\"')\n  lines=[]\n  for line in fp:\n   if'{1, \"'in line:\n    match=strprog. search(line)\n    if match:\n     lines. append(\"        '\"+match. group(1)+\"',\\n\")\n lines. sort()\n \n \n with open(optfile)as fp:\n  format=fp. readlines()\n  \n  \n try :\n  start=format. index(\"#--start keywords--\\n\")+1\n  end=format. index(\"#--end keywords--\\n\")\n  format[start:end]=lines\n except ValueError:\n  sys. stderr. write(\"target does not contain format markers\\n\")\n  sys. exit(1)\n  \n  \n fp=open(optfile,'w')\n fp. write(''. join(format))\n fp. close()\n \nif __name__ ==\"__main__\":\n main()\n", ["re", "sys"]], "posixpath": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\nimport os\nimport sys\nimport genericpath\nfrom genericpath import *\n\n__all__=[\"normcase\",\"isabs\",\"join\",\"splitdrive\",\"split\",\"splitext\",\n\"basename\",\"dirname\",\"commonprefix\",\"getsize\",\"getmtime\",\n\"getatime\",\"getctime\",\"islink\",\"exists\",\"lexists\",\"isdir\",\"isfile\",\n\"ismount\",\"expanduser\",\"expandvars\",\"normpath\",\"abspath\",\n\"samefile\",\"sameopenfile\",\"samestat\",\n\"curdir\",\"pardir\",\"sep\",\"pathsep\",\"defpath\",\"altsep\",\"extsep\",\n\"devnull\",\"realpath\",\"supports_unicode_filenames\",\"relpath\"]\n\n\n\ncurdir='.'\npardir='..'\nextsep='.'\nsep='/'\npathsep=':'\ndefpath=':/bin:/usr/bin'\naltsep=None\ndevnull='/dev/null'\n\ndef _get_sep(path):\n if isinstance(path,bytes):\n  return b'/'\n else :\n  return'/'\n  \n  \n  \n  \n  \n  \ndef normcase(s):\n ''\n \n if not isinstance(s,(bytes,str)):\n  raise TypeError(\"normcase() argument must be str or bytes, \"\n  \"not '{}'\". format(s. __class__. __name__))\n return s\n \n \n \n \n \ndef isabs(s):\n ''\n sep=_get_sep(s)\n return s. startswith(sep)\n \n \n \n \n \n \ndef join(a,*p):\n ''\n\n\n \n sep=_get_sep(a)\n path=a\n try :\n  for b in p:\n   if b. startswith(sep):\n    path=b\n   elif not path or path. endswith(sep):\n    path +=b\n   else :\n    path +=sep+b\n except TypeError:\n  valid_types=all(isinstance(s,(str,bytes,bytearray))\n  for s in (a,)+p)\n  if valid_types:\n  \n   raise TypeError(\"Can't mix strings and bytes in path \"\n   \"components.\")from None\n  raise\n return path\n \n \n \n \n \n \n \ndef split(p):\n ''\n \n sep=_get_sep(p)\n i=p. rfind(sep)+1\n head,tail=p[:i],p[i:]\n if head and head !=sep *len(head):\n  head=head. rstrip(sep)\n return head,tail\n \n \n \n \n \n \n \ndef splitext(p):\n if isinstance(p,bytes):\n  sep=b'/'\n  extsep=b'.'\n else :\n  sep='/'\n  extsep='.'\n return genericpath. _splitext(p,sep,None ,extsep)\nsplitext. __doc__=genericpath. _splitext. __doc__\n\n\n\n\ndef splitdrive(p):\n ''\n \n return p[:0],p\n \n \n \n \ndef basename(p):\n ''\n sep=_get_sep(p)\n i=p. rfind(sep)+1\n return p[i:]\n \n \n \n \ndef dirname(p):\n ''\n sep=_get_sep(p)\n i=p. rfind(sep)+1\n head=p[:i]\n if head and head !=sep *len(head):\n  head=head. rstrip(sep)\n return head\n \n \n \n \n \ndef islink(path):\n ''\n \n return False\n \n \n \ndef lexists(path):\n ''\n try :\n  os. lstat(path)\n except os. error:\n  return False\n return True\n \n \n \n \ndef samefile(f1,f2):\n ''\n s1=os. stat(f1)\n s2=os. stat(f2)\n return samestat(s1,s2)\n \n \n \n \n \ndef sameopenfile(fp1,fp2):\n ''\n s1=os. fstat(fp1)\n s2=os. fstat(fp2)\n return samestat(s1,s2)\n \n \n \n \n \ndef samestat(s1,s2):\n ''\n return s1. st_ino ==s2. st_ino and s1. st_dev ==s2. st_dev\n \n \n \n \n \ndef ismount(path):\n ''\n if islink(path):\n \n  return False\n try :\n  s1=os. lstat(path)\n  if isinstance(path,bytes):\n   parent=join(path,b'..')\n  else :\n   parent=join(path,'..')\n  s2=os. lstat(parent)\n except os. error:\n  return False\n dev1=s1. st_dev\n dev2=s2. st_dev\n if dev1 !=dev2:\n  return True\n ino1=s1. st_ino\n ino2=s2. st_ino\n if ino1 ==ino2:\n  return True\n return False\n \n \n \n \n \n \n \n \n \n \n \ndef expanduser(path):\n ''\n return path\n \n \n \n \n \n_varprog=None\n_varprogb=None\n\ndef expandvars(path):\n ''\n \n global _varprog,_varprogb\n if isinstance(path,bytes):\n  if b'$'not in path:\n   return path\n  if not _varprogb:\n   import re\n   _varprogb=re. compile(br'\\$(\\w+|\\{[^}]*\\})',re. ASCII)\n  search=_varprogb. search\n  start=b'{'\n  end=b'}'\n else :\n  if'$'not in path:\n   return path\n  if not _varprog:\n   import re\n   _varprog=re. compile(r'\\$(\\w+|\\{[^}]*\\})',re. ASCII)\n  search=_varprog. search\n  start='{'\n  end='}'\n i=0\n while True :\n  m=search(path,i)\n  if not m:\n   break\n  i,j=m. span(0)\n  name=m. group(1)\n  if name. startswith(start)and name. endswith(end):\n   name=name[1:-1]\n  if isinstance(name,bytes):\n   name=str(name,'ASCII')\n  if name in os. environ:\n   tail=path[j:]\n   value=os. environ[name]\n   if isinstance(path,bytes):\n    value=value. encode('ASCII')\n   path=path[:i]+value\n   i=len(path)\n   path +=tail\n  else :\n   i=j\n return path\n \n \n \n \n \n \ndef normpath(path):\n ''\n if isinstance(path,bytes):\n  sep=b'/'\n  empty=b''\n  dot=b'.'\n  dotdot=b'..'\n else :\n  sep='/'\n  empty=''\n  dot='.'\n  dotdot='..'\n if path ==empty:\n  return dot\n initial_slashes=path. startswith(sep)\n \n \n if (initial_slashes and\n path. startswith(sep *2)and not path. startswith(sep *3)):\n  initial_slashes=2\n comps=path. split(sep)\n new_comps=[]\n for comp in comps:\n  if comp in (empty,dot):\n   continue\n  if (comp !=dotdot or (not initial_slashes and not new_comps)or\n  (new_comps and new_comps[-1]==dotdot)):\n   new_comps. append(comp)\n  elif new_comps:\n   new_comps. pop()\n comps=new_comps\n path=sep. join(comps)\n if initial_slashes:\n  path=sep *initial_slashes+path\n return path or dot\n \n \ndef abspath(path):\n ''\n if not isabs(path):\n  if isinstance(path,bytes):\n   cwd=os. getcwdb()\n  else :\n   cwd=os. getcwd()\n  path=join(cwd,path)\n return normpath(path)\n \n \n \n \n \ndef realpath(filename):\n ''\n \n path,ok=_joinrealpath(filename[:0],filename,{})\n return abspath(path)\n \n \n \ndef _joinrealpath(path,rest,seen):\n if isinstance(path,bytes):\n  sep=b'/'\n  curdir=b'.'\n  pardir=b'..'\n else :\n  sep='/'\n  curdir='.'\n  pardir='..'\n  \n if isabs(rest):\n  rest=rest[1:]\n  path=sep\n  \n while rest:\n  name,_,rest=rest. partition(sep)\n  if not name or name ==curdir:\n  \n   continue\n  if name ==pardir:\n  \n   if path:\n    path,name=split(path)\n    if name ==pardir:\n     path=join(path,pardir,pardir)\n   else :\n    path=pardir\n   continue\n  newpath=join(path,name)\n  if not islink(newpath):\n   path=newpath\n   continue\n   \n  if newpath in seen:\n  \n   path=seen[newpath]\n   if path is not None :\n   \n    continue\n    \n    \n   return join(newpath,rest),False\n  seen[newpath]=None\n  path,ok=_joinrealpath(path,os. readlink(newpath),seen)\n  if not ok:\n   return join(path,rest),False\n  seen[newpath]=path\n  \n return path,True\n \n \nsupports_unicode_filenames=(sys. platform =='darwin')\n\ndef relpath(path,start=None ):\n ''\n \n if not path:\n  raise ValueError(\"no path specified\")\n  \n if isinstance(path,bytes):\n  curdir=b'.'\n  sep=b'/'\n  pardir=b'..'\n else :\n  curdir='.'\n  sep='/'\n  pardir='..'\n  \n if start is None :\n  start=curdir\n  \n start_list=[x for x in abspath(start). split(sep)if x]\n path_list=[x for x in abspath(path). split(sep)if x]\n \n \n i=len(commonprefix([start_list,path_list]))\n \n rel_list=[pardir]*(len(start_list)-i)+path_list[i:]\n if not rel_list:\n  return curdir\n return join(*rel_list)\n", ["genericpath", "os", "re", "sys"]], "webbrowser": [".py", "from browser import window\n\n__all__=[\"Error\",\"open\",\"open_new\",\"open_new_tab\"]\n\nclass Error(Exception):\n pass\n \n_target={0:'',1:'_blank',2:'_new'}\n\n\ndef open(url,new=0,autoraise=True ):\n ''\n\n\n \n \n \n if'://'in url:\n  if url[:6]=='ftp://':\n   print('entro')\n  else :\n   protocol=url. split('//:')[0]\n   url=url. replace(protocol+'//:','//')\n else :\n  url='//'+url\n print(url)\n if window. open(url,_target[new]):\n  return True\n return False\n \ndef open_new(url):\n return open(url,1)\n \ndef open_new_tab(url):\n return open(url,2)\n \n \n", ["browser"]], "browser.local_storage": [".py", "\nimport sys\nfrom browser import window,console\n\nhas_local_storage=hasattr(window,'localStorage')\n\nclass _UnProvided():\n pass\n \nclass LocalStorage():\n storage_type=\"local_storage\"\n \n def __init__(self):\n  if not has_local_storage:\n   raise EnvironmentError(\"LocalStorage not available\")\n  self. store=window. localStorage\n  \n def __delitem__(self,key):\n  if (not isinstance(key,str)):\n   raise TypeError(\"key must be string\")\n  if key not in self:\n   raise KeyError(key)\n  self. store. removeItem(key)\n  \n def __getitem__(self,key):\n  if (not isinstance(key,str)):\n   raise TypeError(\"key must be string\")\n  res=self. store. getItem(key)\n  if res is not None :\n   return res\n  raise KeyError(key)\n  \n def __setitem__(self,key,value):\n  if not isinstance(key,str):\n   raise TypeError(\"key must be string\")\n  if not isinstance(value,str):\n   raise TypeError(\"value must be string\")\n  self. store. setItem(key,value)\n  \n  \n def __contains__(self,key):\n  if (not isinstance(key,str)):\n   raise TypeError(\"key must be string\")\n  res=self. store. getItem(key)\n  if res is None :\n   return False\n  return True\n  \n def __iter__(self):\n  keys=self. keys()\n  return keys. __iter__()\n  \n def get(self,key,default=None ):\n  if (not isinstance(key,str)):\n   raise TypeError(\"key must be string\")\n  return self. store. getItem(key)or default\n  \n def pop(self,key,default=_UnProvided()):\n  if (not isinstance(key,str)):\n   raise TypeError(\"key must be string\")\n  if type(default)is _UnProvided:\n   ret=self. get(key)\n   del self[key]\n   return ret\n  else :\n   if key in self:\n    ret=self. get(key)\n    del self[key]\n    return ret\n   else :\n    return default\n    \n    \n    \n def keys(self):\n  return [self. store. key(i)for i in range(self. store. length)]\n  \n def values(self):\n  return [self. __getitem__(k)for k in self. keys()]\n  \n def items(self):\n  return list(zip(self. keys(),self. values()))\n  \n def clear(self):\n  self. store. clear()\n  \n def __len__(self):\n  return self. store. length\n  \nif has_local_storage:\n storage=LocalStorage()\n", ["browser", "sys"]], "unittest.util": [".py", "''\n\nfrom collections import namedtuple,OrderedDict\n\n__unittest=True\n\n_MAX_LENGTH=80\ndef safe_repr(obj,short=False ):\n try :\n  result=repr(obj)\n except Exception:\n  result=object. __repr__(obj)\n if not short or len(result)<_MAX_LENGTH:\n  return result\n return result[:_MAX_LENGTH]+' [truncated]...'\n \ndef strclass(cls):\n return\"%s.%s\"%(cls. __module__,cls. __name__)\n \ndef sorted_list_difference(expected,actual):\n ''\n\n\n\n\n\n \n i=j=0\n missing=[]\n unexpected=[]\n while True :\n  try :\n   e=expected[i]\n   a=actual[j]\n   if e <a:\n    missing. append(e)\n    i +=1\n    while expected[i]==e:\n     i +=1\n   elif e >a:\n    unexpected. append(a)\n    j +=1\n    while actual[j]==a:\n     j +=1\n   else :\n    i +=1\n    try :\n     while expected[i]==e:\n      i +=1\n    finally :\n     j +=1\n     while actual[j]==a:\n      j +=1\n  except IndexError:\n   missing. extend(expected[i:])\n   unexpected. extend(actual[j:])\n   break\n return missing,unexpected\n \n \ndef unorderable_list_difference(expected,actual):\n ''\n\n\n\n \n missing=[]\n while expected:\n  item=expected. pop()\n  try :\n   actual. remove(item)\n  except ValueError:\n   missing. append(item)\n   \n   \n return missing,actual\n \ndef three_way_cmp(x,y):\n ''\n return (x >y)-(x <y)\n \n_Mismatch=namedtuple('Mismatch','actual expected value')\n\ndef _count_diff_all_purpose(actual,expected):\n ''\n \n s,t=list(actual),list(expected)\n m,n=len(s),len(t)\n NULL=object()\n result=[]\n for i,elem in enumerate(s):\n  if elem is NULL:\n   continue\n  cnt_s=cnt_t=0\n  for j in range(i,m):\n   if s[j]==elem:\n    cnt_s +=1\n    s[j]=NULL\n  for j,other_elem in enumerate(t):\n   if other_elem ==elem:\n    cnt_t +=1\n    t[j]=NULL\n  if cnt_s !=cnt_t:\n   diff=_Mismatch(cnt_s,cnt_t,elem)\n   result. append(diff)\n   \n for i,elem in enumerate(t):\n  if elem is NULL:\n   continue\n  cnt_t=0\n  for j in range(i,n):\n   if t[j]==elem:\n    cnt_t +=1\n    t[j]=NULL\n  diff=_Mismatch(0,cnt_t,elem)\n  result. append(diff)\n return result\n \ndef _ordered_count(iterable):\n ''\n c=OrderedDict()\n for elem in iterable:\n  c[elem]=c. get(elem,0)+1\n return c\n \ndef _count_diff_hashable(actual,expected):\n ''\n \n s,t=_ordered_count(actual),_ordered_count(expected)\n result=[]\n for elem,cnt_s in s. items():\n  cnt_t=t. get(elem,0)\n  if cnt_s !=cnt_t:\n   diff=_Mismatch(cnt_s,cnt_t,elem)\n   result. append(diff)\n for elem,cnt_t in t. items():\n  if elem not in s:\n   diff=_Mismatch(0,cnt_t,elem)\n   result. append(diff)\n return result\n", ["collections"]], "imp": [".py", "''\n\n\n\n\n\n\n\nfrom _imp import (lock_held,acquire_lock,release_lock,\nget_frozen_object,is_frozen_package,\ninit_builtin,init_frozen,is_builtin,is_frozen,\n_fix_co_filename)\ntry :\n from _imp import load_dynamic\nexcept ImportError:\n\n load_dynamic=None\n \n \nfrom importlib. _bootstrap import new_module\nfrom importlib. _bootstrap import cache_from_source,source_from_cache\n\n\nfrom importlib import _bootstrap\n\n\nimport importlib. machinery as machinery\nimport os\nimport sys\nimport tokenize\nimport warnings\n\n\n\nSEARCH_ERROR=0\nPY_SOURCE=1\nPY_COMPILED=2\nC_EXTENSION=3\nPY_RESOURCE=4\nPKG_DIRECTORY=5\nC_BUILTIN=6\nPY_FROZEN=7\nPY_CODERESOURCE=8\nIMP_HOOK=9\n\n\ndef get_magic():\n ''\n return _bootstrap. _MAGIC_BYTES\n \n \ndef get_tag():\n ''\n return sys. implementation. cache_tag\n \n \ndef get_suffixes():\n warnings. warn('imp.get_suffixes() is deprecated; use the constants '\n 'defined on importlib.machinery instead',\n DeprecationWarning,2)\n extensions=[(s,'rb',C_EXTENSION)for s in machinery. EXTENSION_SUFFIXES]\n source=[(s,'U',PY_SOURCE)for s in machinery. SOURCE_SUFFIXES]\n bytecode=[(s,'rb',PY_COMPILED)for s in machinery. BYTECODE_SUFFIXES]\n \n return extensions+source+bytecode\n \n \nclass NullImporter:\n\n ''\n \n def __init__(self,path):\n  if path =='':\n   raise ImportError('empty pathname',path='')\n  elif os. path. isdir(path):\n   raise ImportError('existing directory',path=path)\n   \n def find_module(self,fullname):\n  ''\n  return None\n  \n  \nclass _HackedGetData:\n\n ''\n \n \n def __init__(self,fullname,path,file=None ):\n  super(). __init__(fullname,path)\n  self. file=file\n  \n def get_data(self,path):\n  ''\n  if self. file and path ==self. path:\n   if not self. file. closed:\n    file=self. file\n   else :\n    self. file=file=open(self. path,'r')\n    \n   with file:\n   \n   \n   \n   \n   \n    return file. read()\n  else :\n   return super(). get_data(path)\n   \n   \nclass _LoadSourceCompatibility(_HackedGetData,_bootstrap. SourceFileLoader):\n\n ''\n \n pass\n \ndef load_source(name,pathname,file=None ):\n msg=('imp.load_source() is deprecated; use '\n 'importlib.machinery.SourceFileLoader(name, pathname).load_module()'\n ' instead')\n warnings. warn(msg,DeprecationWarning,2)\n _LoadSourceCompatibility(name,pathname,file). load_module(name)\n module=sys. modules[name]\n \n \n module. __loader__=_bootstrap. SourceFileLoader(name,pathname)\n return module\n \n \nclass _LoadCompiledCompatibility(_HackedGetData,\n_bootstrap. SourcelessFileLoader):\n\n ''\n \n pass\n \ndef load_compiled(name,pathname,file=None ):\n msg=('imp.load_compiled() is deprecated; use '\n 'importlib.machinery.SourcelessFileLoader(name, pathname).'\n 'load_module() instead ')\n warnings. warn(msg,DeprecationWarning,2)\n _LoadCompiledCompatibility(name,pathname,file). load_module(name)\n module=sys. modules[name]\n \n \n module. __loader__=_bootstrap. SourcelessFileLoader(name,pathname)\n return module\n \n \ndef load_package(name,path):\n msg=('imp.load_package() is deprecated; use either '\n 'importlib.machinery.SourceFileLoader() or '\n 'importlib.machinery.SourcelessFileLoader() instead')\n warnings. warn(msg,DeprecationWarning,2)\n if os. path. isdir(path):\n  extensions=(machinery. SOURCE_SUFFIXES[:]+\n  machinery. BYTECODE_SUFFIXES[:])\n  for extension in extensions:\n   path=os. path. join(path,'__init__'+extension)\n   if os. path. exists(path):\n    break\n  else :\n   raise ValueError('{!r} is not a package'. format(path))\n return _bootstrap. SourceFileLoader(name,path). load_module(name)\n \n \ndef load_module(name,file,filename,details):\n ''\n\n\n\n\n\n \n suffix,mode,type_=details\n with warnings. catch_warnings():\n  warnings. simplefilter('ignore')\n  if mode and (not mode. startswith(('r','U'))or'+'in mode):\n   raise ValueError('invalid file open mode {!r}'. format(mode))\n  elif file is None and type_ in {PY_SOURCE,PY_COMPILED}:\n   msg='file object required for import (type code {})'. format(type_)\n   raise ValueError(msg)\n  elif type_ ==PY_SOURCE:\n   return load_source(name,filename,file)\n  elif type_ ==PY_COMPILED:\n   return load_compiled(name,filename,file)\n  elif type_ ==C_EXTENSION and load_dynamic is not None :\n   if file is None :\n    with open(filename,'rb')as opened_file:\n     return load_dynamic(name,filename,opened_file)\n   else :\n    return load_dynamic(name,filename,file)\n  elif type_ ==PKG_DIRECTORY:\n   return load_package(name,filename)\n  elif type_ ==C_BUILTIN:\n   return init_builtin(name)\n  elif type_ ==PY_FROZEN:\n   return init_frozen(name)\n  else :\n   msg=\"Don't know how to import {} (type code {})\". format(name,type_)\n   raise ImportError(msg,name=name)\n   \n   \ndef find_module(name,path=None ):\n ''\n\n\n\n\n\n\n\n\n \n if not isinstance(name,str):\n  raise TypeError(\"'name' must be a str, not {}\". format(type(name)))\n elif not isinstance(path,(type(None ),list)):\n \n  raise RuntimeError(\"'list' must be None or a list, \"\n  \"not {}\". format(type(name)))\n  \n if path is None :\n  if is_builtin(name):\n   return None ,None ,('','',C_BUILTIN)\n  elif is_frozen(name):\n   return None ,None ,('','',PY_FROZEN)\n  else :\n   path=sys. path\n   \n for entry in path:\n  package_directory=os. path. join(entry,name)\n  for suffix in ['.py',machinery. BYTECODE_SUFFIXES[0]]:\n   package_file_name='__init__'+suffix\n   file_path=os. path. join(package_directory,package_file_name)\n   if os. path. isfile(file_path):\n    return None ,package_directory,('','',PKG_DIRECTORY)\n  with warnings. catch_warnings():\n   warnings. simplefilter('ignore')\n   for suffix,mode,type_ in get_suffixes():\n    file_name=name+suffix\n    file_path=os. path. join(entry,file_name)\n    if os. path. isfile(file_path):\n     break\n   else :\n    continue\n   break\n else :\n  raise ImportError(_bootstrap. _ERR_MSG. format(name),name=name)\n  \n encoding=None\n if mode =='U':\n  with open(file_path,'rb')as file:\n   encoding=tokenize. detect_encoding(file. readline)[0]\n file=open(file_path,mode,encoding=encoding)\n return file,file_path,(suffix,mode,type_)\n \n \n_RELOADING={}\n\ndef reload(module):\n ''\n\n\n\n \n if not module or type(module)!=type(sys):\n  raise TypeError(\"reload() argument must be module\")\n name=module. __name__\n if name not in sys. modules:\n  msg=\"module {} not in sys.modules\"\n  raise ImportError(msg. format(name),name=name)\n if name in _RELOADING:\n  return _RELOADING[name]\n _RELOADING[name]=module\n try :\n  parent_name=name. rpartition('.')[0]\n  if parent_name and parent_name not in sys. modules:\n   msg=\"parent {!r} not in sys.modules\"\n   raise ImportError(msg. format(parent_name),name=parent_name)\n  module. __loader__. load_module(name)\n  \n  return sys. modules[module. __name__]\n finally :\n  try :\n   del _RELOADING[name]\n  except KeyError:\n   pass\n", ["_imp", "importlib", "importlib._bootstrap", "importlib.machinery", "os", "sys", "tokenize", "warnings"]], "browser.object_storage": [".py", "import json\n\nclass _UnProvided():\n pass\n \n \nclass ObjectStorage():\n\n def __init__(self,storage):\n  self. storage=storage\n  \n def __delitem__(self,key):\n  del self. storage[json. dumps(key)]\n  \n def __getitem__(self,key):\n  return json. loads(self. storage[json. dumps(key)])\n  \n def __setitem__(self,key,value):\n  self. storage[json. dumps(key)]=json. dumps(value)\n  \n def __contains__(self,key):\n  return json. dumps(key)in self. storage\n  \n def get(self,key,default=None ):\n  if json. dumps(key)in self. storage:\n   return self. storage[json. dumps(key)]\n  return default\n  \n def pop(self,key,default=_UnProvided()):\n  if type(default)is _UnProvided or json. dumps(key)in self. storage:\n   return json. loads(self. storage. pop(json. dumps(key)))\n  return default\n  \n def __iter__(self):\n  keys=self. keys()\n  return keys. __iter__()\n  \n def keys(self):\n  return [json. loads(key)for key in self. storage. keys()]\n  \n def values(self):\n  return [json. loads(val)for val in self. storage. values()]\n  \n def items(self):\n  return list(zip(self. keys(),self. values()))\n  \n def clear(self):\n  self. storage. clear()\n  \n def __len__(self):\n  return len(self. storage)\n", ["json"]], "glob": [".py", "''\n\nimport os\nimport re\nimport fnmatch\n\n__all__=[\"glob\",\"iglob\"]\n\ndef glob(pathname):\n ''\n\n\n\n\n\n\n \n return list(iglob(pathname))\n \ndef iglob(pathname):\n ''\n\n\n\n\n\n\n \n dirname,basename=os. path. split(pathname)\n if not has_magic(pathname):\n  if basename:\n   if os. path. lexists(pathname):\n    yield pathname\n  else :\n  \n   if os. path. isdir(dirname):\n    yield pathname\n  return\n if not dirname:\n  yield from glob1(None ,basename)\n  return\n  \n  \n  \n if dirname !=pathname and has_magic(dirname):\n  dirs=iglob(dirname)\n else :\n  dirs=[dirname]\n if has_magic(basename):\n  glob_in_dir=glob1\n else :\n  glob_in_dir=glob0\n for dirname in dirs:\n  for name in glob_in_dir(dirname,basename):\n   yield os. path. join(dirname,name)\n   \n   \n   \n   \n   \ndef glob1(dirname,pattern):\n if not dirname:\n  if isinstance(pattern,bytes):\n   dirname=bytes(os. curdir,'ASCII')\n  else :\n   dirname=os. curdir\n try :\n  names=os. listdir(dirname)\n except OSError:\n  return []\n if not _ishidden(pattern):\n  names=[x for x in names if not _ishidden(x)]\n return fnmatch. filter(names,pattern)\n \ndef glob0(dirname,basename):\n if not basename:\n \n \n  if os. path. isdir(dirname):\n   return [basename]\n else :\n  if os. path. lexists(os. path. join(dirname,basename)):\n   return [basename]\n return []\n \n \nmagic_check=re. compile('([*?[])')\nmagic_check_bytes=re. compile(b'([*?[])')\n\ndef has_magic(s):\n if isinstance(s,bytes):\n  match=magic_check_bytes. search(s)\n else :\n  match=magic_check. search(s)\n return match is not None\n \ndef _ishidden(path):\n return path[0]in ('.',b'.'[0])\n \ndef escape(pathname):\n ''\n \n \n \n drive,pathname=os. path. splitdrive(pathname)\n if isinstance(pathname,bytes):\n  pathname=magic_check_bytes. sub(br'[\\1]',pathname)\n else :\n  pathname=magic_check. sub(r'[\\1]',pathname)\n return drive+pathname\n", ["fnmatch", "os", "re"]], "genericpath": [".py", "''\n\n\n\n\nimport os\n\n__all__=['commonprefix','exists','getatime','getctime','getmtime',\n'getsize','isdir','isfile']\n\n\n\n\ndef exists(path):\n ''\n try :\n  os. stat(path)\n except os. error:\n  return False\n return True\n \n \n \n \ndef isfile(path):\n ''\n try :\n  st=os. stat(path)\n except os. error:\n  return False\n import stat\n return stat. S_ISREG(st. st_mode)\n \n \n \n \n \ndef isdir(s):\n ''\n try :\n  st=os. stat(s)\n except os. error:\n  return False\n import stat\n return stat. S_ISDIR(st. st_mode)\n \n \ndef getsize(filename):\n ''\n return os. stat(filename). st_size\n \n \ndef getmtime(filename):\n ''\n return os. stat(filename). st_mtime\n \n \ndef getatime(filename):\n ''\n return os. stat(filename). st_atime\n \n \ndef getctime(filename):\n ''\n return os. stat(filename). st_ctime\n \n \n \ndef commonprefix(m):\n ''\n if not m:return''\n s1=min(m)\n s2=max(m)\n for i,c in enumerate(s1):\n  if c !=s2[i]:\n   return s1[:i]\n return s1\n \n \n \n \n \n \n \n \ndef _splitext(p,sep,altsep,extsep):\n ''\n\n\n \n \n \n sepIndex=p. rfind(sep)\n if altsep:\n  altsepIndex=p. rfind(altsep)\n  sepIndex=max(sepIndex,altsepIndex)\n  \n dotIndex=p. rfind(extsep)\n if dotIndex >sepIndex:\n \n  filenameIndex=sepIndex+1\n  while filenameIndex <dotIndex:\n   if p[filenameIndex:filenameIndex+1]!=extsep:\n    return p[:dotIndex],p[dotIndex:]\n   filenameIndex +=1\n   \n return p,p[:0]\n", ["os", "stat"]], "stat": [".py", "''\n\n\n\n\n\n\nST_MODE=0\nST_INO=1\nST_DEV=2\nST_NLINK=3\nST_UID=4\nST_GID=5\nST_SIZE=6\nST_ATIME=7\nST_MTIME=8\nST_CTIME=9\n\n\n\ndef S_IMODE(mode):\n ''\n\n \n return mode&0o7777\n \ndef S_IFMT(mode):\n ''\n\n \n return mode&0o170000\n \n \n \n \nS_IFDIR=0o040000\nS_IFCHR=0o020000\nS_IFBLK=0o060000\nS_IFREG=0o100000\nS_IFIFO=0o010000\nS_IFLNK=0o120000\nS_IFSOCK=0o140000\n\n\n\ndef S_ISDIR(mode):\n ''\n return S_IFMT(mode)==S_IFDIR\n \ndef S_ISCHR(mode):\n ''\n return S_IFMT(mode)==S_IFCHR\n \ndef S_ISBLK(mode):\n ''\n return S_IFMT(mode)==S_IFBLK\n \ndef S_ISREG(mode):\n ''\n return S_IFMT(mode)==S_IFREG\n \ndef S_ISFIFO(mode):\n ''\n return S_IFMT(mode)==S_IFIFO\n \ndef S_ISLNK(mode):\n ''\n return S_IFMT(mode)==S_IFLNK\n \ndef S_ISSOCK(mode):\n ''\n return S_IFMT(mode)==S_IFSOCK\n \n \n \nS_ISUID=0o4000\nS_ISGID=0o2000\nS_ENFMT=S_ISGID\nS_ISVTX=0o1000\nS_IREAD=0o0400\nS_IWRITE=0o0200\nS_IEXEC=0o0100\nS_IRWXU=0o0700\nS_IRUSR=0o0400\nS_IWUSR=0o0200\nS_IXUSR=0o0100\nS_IRWXG=0o0070\nS_IRGRP=0o0040\nS_IWGRP=0o0020\nS_IXGRP=0o0010\nS_IRWXO=0o0007\nS_IROTH=0o0004\nS_IWOTH=0o0002\nS_IXOTH=0o0001\n\n\n\nUF_NODUMP=0x00000001\nUF_IMMUTABLE=0x00000002\nUF_APPEND=0x00000004\nUF_OPAQUE=0x00000008\nUF_NOUNLINK=0x00000010\nUF_COMPRESSED=0x00000020\nUF_HIDDEN=0x00008000\nSF_ARCHIVED=0x00010000\nSF_IMMUTABLE=0x00020000\nSF_APPEND=0x00040000\nSF_NOUNLINK=0x00100000\nSF_SNAPSHOT=0x00200000\n\n\n_filemode_table=(\n((S_IFLNK,\"l\"),\n(S_IFREG,\"-\"),\n(S_IFBLK,\"b\"),\n(S_IFDIR,\"d\"),\n(S_IFCHR,\"c\"),\n(S_IFIFO,\"p\")),\n\n((S_IRUSR,\"r\"),),\n((S_IWUSR,\"w\"),),\n((S_IXUSR |S_ISUID,\"s\"),\n(S_ISUID,\"S\"),\n(S_IXUSR,\"x\")),\n\n((S_IRGRP,\"r\"),),\n((S_IWGRP,\"w\"),),\n((S_IXGRP |S_ISGID,\"s\"),\n(S_ISGID,\"S\"),\n(S_IXGRP,\"x\")),\n\n((S_IROTH,\"r\"),),\n((S_IWOTH,\"w\"),),\n((S_IXOTH |S_ISVTX,\"t\"),\n(S_ISVTX,\"T\"),\n(S_IXOTH,\"x\"))\n)\n\ndef filemode(mode):\n ''\n perm=[]\n for table in _filemode_table:\n  for bit,char in table:\n   if mode&bit ==bit:\n    perm. append(char)\n    break\n  else :\n   perm. append(\"-\")\n return\"\". join(perm)\n", []], "sre_constants": [".py", "\n\n\n\n\n\n\n\n\n\n\n\"\"\"Internal support module for sre\"\"\"\n\n\n\nMAGIC=20031017\n\n\n\n\n\n\n\nclass error(Exception):\n pass\n \n \n \nFAILURE=\"failure\"\nSUCCESS=\"success\"\n\nANY=\"any\"\nANY_ALL=\"any_all\"\nASSERT=\"assert\"\nASSERT_NOT=\"assert_not\"\nAT=\"at\"\nBIGCHARSET=\"bigcharset\"\nBRANCH=\"branch\"\nCALL=\"call\"\nCATEGORY=\"category\"\nCHARSET=\"charset\"\nGROUPREF=\"groupref\"\nGROUPREF_IGNORE=\"groupref_ignore\"\nGROUPREF_EXISTS=\"groupref_exists\"\nIN=\"in\"\nIN_IGNORE=\"in_ignore\"\nINFO=\"info\"\nJUMP=\"jump\"\nLITERAL=\"literal\"\nLITERAL_IGNORE=\"literal_ignore\"\nMARK=\"mark\"\nMAX_REPEAT=\"max_repeat\"\nMAX_UNTIL=\"max_until\"\nMIN_REPEAT=\"min_repeat\"\nMIN_UNTIL=\"min_until\"\nNEGATE=\"negate\"\nNOT_LITERAL=\"not_literal\"\nNOT_LITERAL_IGNORE=\"not_literal_ignore\"\nRANGE=\"range\"\nREPEAT=\"repeat\"\nREPEAT_ONE=\"repeat_one\"\nSUBPATTERN=\"subpattern\"\nMIN_REPEAT_ONE=\"min_repeat_one\"\n\n\nAT_BEGINNING=\"at_beginning\"\nAT_BEGINNING_LINE=\"at_beginning_line\"\nAT_BEGINNING_STRING=\"at_beginning_string\"\nAT_BOUNDARY=\"at_boundary\"\nAT_NON_BOUNDARY=\"at_non_boundary\"\nAT_END=\"at_end\"\nAT_END_LINE=\"at_end_line\"\nAT_END_STRING=\"at_end_string\"\nAT_LOC_BOUNDARY=\"at_loc_boundary\"\nAT_LOC_NON_BOUNDARY=\"at_loc_non_boundary\"\nAT_UNI_BOUNDARY=\"at_uni_boundary\"\nAT_UNI_NON_BOUNDARY=\"at_uni_non_boundary\"\n\n\nCATEGORY_DIGIT=\"category_digit\"\nCATEGORY_NOT_DIGIT=\"category_not_digit\"\nCATEGORY_SPACE=\"category_space\"\nCATEGORY_NOT_SPACE=\"category_not_space\"\nCATEGORY_WORD=\"category_word\"\nCATEGORY_NOT_WORD=\"category_not_word\"\nCATEGORY_LINEBREAK=\"category_linebreak\"\nCATEGORY_NOT_LINEBREAK=\"category_not_linebreak\"\nCATEGORY_LOC_WORD=\"category_loc_word\"\nCATEGORY_LOC_NOT_WORD=\"category_loc_not_word\"\nCATEGORY_UNI_DIGIT=\"category_uni_digit\"\nCATEGORY_UNI_NOT_DIGIT=\"category_uni_not_digit\"\nCATEGORY_UNI_SPACE=\"category_uni_space\"\nCATEGORY_UNI_NOT_SPACE=\"category_uni_not_space\"\nCATEGORY_UNI_WORD=\"category_uni_word\"\nCATEGORY_UNI_NOT_WORD=\"category_uni_not_word\"\nCATEGORY_UNI_LINEBREAK=\"category_uni_linebreak\"\nCATEGORY_UNI_NOT_LINEBREAK=\"category_uni_not_linebreak\"\n\nOPCODES=[\n\n\nFAILURE,SUCCESS,\n\nANY,ANY_ALL,\nASSERT,ASSERT_NOT,\nAT,\nBRANCH,\nCALL,\nCATEGORY,\nCHARSET,BIGCHARSET,\nGROUPREF,GROUPREF_EXISTS,GROUPREF_IGNORE,\nIN,IN_IGNORE,\nINFO,\nJUMP,\nLITERAL,LITERAL_IGNORE,\nMARK,\nMAX_UNTIL,\nMIN_UNTIL,\nNOT_LITERAL,NOT_LITERAL_IGNORE,\nNEGATE,\nRANGE,\nREPEAT,\nREPEAT_ONE,\nSUBPATTERN,\nMIN_REPEAT_ONE\n\n]\n\nATCODES=[\nAT_BEGINNING,AT_BEGINNING_LINE,AT_BEGINNING_STRING,AT_BOUNDARY,\nAT_NON_BOUNDARY,AT_END,AT_END_LINE,AT_END_STRING,\nAT_LOC_BOUNDARY,AT_LOC_NON_BOUNDARY,AT_UNI_BOUNDARY,\nAT_UNI_NON_BOUNDARY\n]\n\nCHCODES=[\nCATEGORY_DIGIT,CATEGORY_NOT_DIGIT,CATEGORY_SPACE,\nCATEGORY_NOT_SPACE,CATEGORY_WORD,CATEGORY_NOT_WORD,\nCATEGORY_LINEBREAK,CATEGORY_NOT_LINEBREAK,CATEGORY_LOC_WORD,\nCATEGORY_LOC_NOT_WORD,CATEGORY_UNI_DIGIT,CATEGORY_UNI_NOT_DIGIT,\nCATEGORY_UNI_SPACE,CATEGORY_UNI_NOT_SPACE,CATEGORY_UNI_WORD,\nCATEGORY_UNI_NOT_WORD,CATEGORY_UNI_LINEBREAK,\nCATEGORY_UNI_NOT_LINEBREAK\n]\n\ndef makedict(list):\n d={}\n i=0\n for item in list:\n  d[item]=i\n  i=i+1\n return d\n \nOPCODES=makedict(OPCODES)\nATCODES=makedict(ATCODES)\nCHCODES=makedict(CHCODES)\n\n\nOP_IGNORE={\nGROUPREF:GROUPREF_IGNORE,\nIN:IN_IGNORE,\nLITERAL:LITERAL_IGNORE,\nNOT_LITERAL:NOT_LITERAL_IGNORE\n}\n\nAT_MULTILINE={\nAT_BEGINNING:AT_BEGINNING_LINE,\nAT_END:AT_END_LINE\n}\n\nAT_LOCALE={\nAT_BOUNDARY:AT_LOC_BOUNDARY,\nAT_NON_BOUNDARY:AT_LOC_NON_BOUNDARY\n}\n\nAT_UNICODE={\nAT_BOUNDARY:AT_UNI_BOUNDARY,\nAT_NON_BOUNDARY:AT_UNI_NON_BOUNDARY\n}\n\nCH_LOCALE={\nCATEGORY_DIGIT:CATEGORY_DIGIT,\nCATEGORY_NOT_DIGIT:CATEGORY_NOT_DIGIT,\nCATEGORY_SPACE:CATEGORY_SPACE,\nCATEGORY_NOT_SPACE:CATEGORY_NOT_SPACE,\nCATEGORY_WORD:CATEGORY_LOC_WORD,\nCATEGORY_NOT_WORD:CATEGORY_LOC_NOT_WORD,\nCATEGORY_LINEBREAK:CATEGORY_LINEBREAK,\nCATEGORY_NOT_LINEBREAK:CATEGORY_NOT_LINEBREAK\n}\n\nCH_UNICODE={\nCATEGORY_DIGIT:CATEGORY_UNI_DIGIT,\nCATEGORY_NOT_DIGIT:CATEGORY_UNI_NOT_DIGIT,\nCATEGORY_SPACE:CATEGORY_UNI_SPACE,\nCATEGORY_NOT_SPACE:CATEGORY_UNI_NOT_SPACE,\nCATEGORY_WORD:CATEGORY_UNI_WORD,\nCATEGORY_NOT_WORD:CATEGORY_UNI_NOT_WORD,\nCATEGORY_LINEBREAK:CATEGORY_UNI_LINEBREAK,\nCATEGORY_NOT_LINEBREAK:CATEGORY_UNI_NOT_LINEBREAK\n}\n\n\nSRE_FLAG_TEMPLATE=1\nSRE_FLAG_IGNORECASE=2\nSRE_FLAG_LOCALE=4\nSRE_FLAG_MULTILINE=8\nSRE_FLAG_DOTALL=16\nSRE_FLAG_UNICODE=32\nSRE_FLAG_VERBOSE=64\nSRE_FLAG_DEBUG=128\nSRE_FLAG_ASCII=256\n\n\nSRE_INFO_PREFIX=1\nSRE_INFO_LITERAL=2\nSRE_INFO_CHARSET=4\n\nif __name__ ==\"__main__\":\n def dump(f,d,prefix):\n  items=sorted(d. items(),key=lambda a:a[1])\n  for k,v in items:\n   f. write(\"#define %s_%s %s\\n\"%(prefix,k. upper(),v))\n f=open(\"sre_constants.h\",\"w\")\n f. write(\"\"\"\\\n/*\n * Secret Labs' Regular Expression Engine\n *\n * regular expression matching engine\n *\n * NOTE: This file is generated by sre_constants.py.  If you need\n * to change anything in here, edit sre_constants.py and run it.\n *\n * Copyright (c) 1997-2001 by Secret Labs AB.  All rights reserved.\n *\n * See the _sre.c file for information on usage and redistribution.\n */\n\n\"\"\")\n \n f. write(\"#define SRE_MAGIC %d\\n\"%MAGIC)\n \n dump(f,OPCODES,\"SRE_OP\")\n dump(f,ATCODES,\"SRE\")\n dump(f,CHCODES,\"SRE\")\n \n f. write(\"#define SRE_FLAG_TEMPLATE %d\\n\"%SRE_FLAG_TEMPLATE)\n f. write(\"#define SRE_FLAG_IGNORECASE %d\\n\"%SRE_FLAG_IGNORECASE)\n f. write(\"#define SRE_FLAG_LOCALE %d\\n\"%SRE_FLAG_LOCALE)\n f. write(\"#define SRE_FLAG_MULTILINE %d\\n\"%SRE_FLAG_MULTILINE)\n f. write(\"#define SRE_FLAG_DOTALL %d\\n\"%SRE_FLAG_DOTALL)\n f. write(\"#define SRE_FLAG_UNICODE %d\\n\"%SRE_FLAG_UNICODE)\n f. write(\"#define SRE_FLAG_VERBOSE %d\\n\"%SRE_FLAG_VERBOSE)\n \n f. write(\"#define SRE_INFO_PREFIX %d\\n\"%SRE_INFO_PREFIX)\n f. write(\"#define SRE_INFO_LITERAL %d\\n\"%SRE_INFO_LITERAL)\n f. write(\"#define SRE_INFO_CHARSET %d\\n\"%SRE_INFO_CHARSET)\n \n f. close()\n print(\"done\")\n", []], "unittest.signals": [".py", "import signal\nimport weakref\n\nfrom functools import wraps\n\n__unittest=True\n\n\nclass _InterruptHandler(object):\n def __init__(self,default_handler):\n  self. called=False\n  self. original_handler=default_handler\n  if isinstance(default_handler,int):\n   if default_handler ==signal. SIG_DFL:\n   \n    default_handler=signal. default_int_handler\n   elif default_handler ==signal. SIG_IGN:\n   \n   \n    def default_handler(unused_signum,unused_frame):\n     pass\n   else :\n    raise TypeError(\"expected SIGINT signal handler to be \"\n    \"signal.SIG_IGN, signal.SIG_DFL, or a \"\n    \"callable object\")\n  self. default_handler=default_handler\n  \n def __call__(self,signum,frame):\n  installed_handler=signal. getsignal(signal. SIGINT)\n  if installed_handler is not self:\n  \n  \n   self. default_handler(signum,frame)\n   \n  if self. called:\n   self. default_handler(signum,frame)\n  self. called=True\n  for result in _results. keys():\n   result. stop()\n   \n_results=weakref. WeakKeyDictionary()\ndef registerResult(result):\n _results[result]=1\n \ndef removeResult(result):\n return bool(_results. pop(result,None ))\n \n_interrupt_handler=None\ndef installHandler():\n global _interrupt_handler\n if _interrupt_handler is None :\n  default_handler=signal. getsignal(signal. SIGINT)\n  _interrupt_handler=_InterruptHandler(default_handler)\n  signal. signal(signal. SIGINT,_interrupt_handler)\n  \n  \ndef removeHandler(method=None ):\n if method is not None :\n  @wraps(method)\n  def inner(*args,**kwargs):\n   initial=signal. getsignal(signal. SIGINT)\n   removeHandler()\n   try :\n    return method(*args,**kwargs)\n   finally :\n    signal. signal(signal. SIGINT,initial)\n  return inner\n  \n global _interrupt_handler\n if _interrupt_handler is not None :\n  signal. signal(signal. SIGINT,_interrupt_handler. original_handler)\n", ["functools", "signal", "weakref"]], "errno": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\nE2BIG=7\n\nEACCES=13\n\nEADDRINUSE=10048\n\nEADDRNOTAVAIL=10049\n\nEAFNOSUPPORT=10047\n\nEAGAIN=11\n\nEALREADY=10037\n\nEBADF=9\n\nEBADMSG=104\n\nEBUSY=16\n\nECANCELED=105\n\nECHILD=10\n\nECONNABORTED=10053\n\nECONNREFUSED=10061\n\nECONNRESET=10054\n\nEDEADLK=36\n\nEDEADLOCK=36\n\nEDESTADDRREQ=10039\n\nEDOM=33\n\nEDQUOT=10069\n\nEEXIST=17\n\nEFAULT=14\n\nEFBIG=27\n\nEHOSTDOWN=10064\n\nEHOSTUNREACH=10065\n\nEIDRM=111\n\nEILSEQ=42\n\nEINPROGRESS=10036\n\nEINTR=4\n\nEINVAL=22\n\nEIO=5\n\nEISCONN=10056\n\nEISDIR=21\n\nELOOP=10062\n\nEMFILE=24\n\nEMLINK=31\n\nEMSGSIZE=10040\n\nENAMETOOLONG=38\n\nENETDOWN=10050\n\nENETRESET=10052\n\nENETUNREACH=10051\n\nENFILE=23\n\nENOBUFS=10055\n\nENODATA=120\n\nENODEV=19\n\nENOENT=2\n\nENOEXEC=8\n\nENOLCK=39\n\nENOLINK=121\n\nENOMEM=12\n\nENOMSG=122\n\nENOPROTOOPT=10042\n\nENOSPC=28\n\nENOSR=124\n\nENOSTR=125\n\nENOSYS=40\n\nENOTCONN=10057\n\nENOTDIR=20\n\nENOTEMPTY=41\n\nENOTRECOVERABLE=127\n\nENOTSOCK=10038\n\nENOTSUP=129\n\nENOTTY=25\n\nENXIO=6\n\nEOPNOTSUPP=10045\n\nEOVERFLOW=132\n\nEOWNERDEAD=133\n\nEPERM=1\n\nEPFNOSUPPORT=10046\n\nEPIPE=32\n\nEPROTO=134\n\nEPROTONOSUPPORT=10043\n\nEPROTOTYPE=10041\n\nERANGE=34\n\nEREMOTE=10071\n\nEROFS=30\n\nESHUTDOWN=10058\n\nESOCKTNOSUPPORT=10044\n\nESPIPE=29\n\nESRCH=3\n\nESTALE=10070\n\nETIME=137\n\nETIMEDOUT=10060\n\nETOOMANYREFS=10059\n\nETXTBSY=139\n\nEUSERS=10068\n\nEWOULDBLOCK=10035\n\nEXDEV=18\n\nWSABASEERR=10000\n\nWSAEACCES=10013\n\nWSAEADDRINUSE=10048\n\nWSAEADDRNOTAVAIL=10049\n\nWSAEAFNOSUPPORT=10047\n\nWSAEALREADY=10037\n\nWSAEBADF=10009\n\nWSAECONNABORTED=10053\n\nWSAECONNREFUSED=10061\n\nWSAECONNRESET=10054\n\nWSAEDESTADDRREQ=10039\n\nWSAEDISCON=10101\n\nWSAEDQUOT=10069\n\nWSAEFAULT=10014\n\nWSAEHOSTDOWN=10064\n\nWSAEHOSTUNREACH=10065\n\nWSAEINPROGRESS=10036\n\nWSAEINTR=10004\n\nWSAEINVAL=10022\n\nWSAEISCONN=10056\n\nWSAELOOP=10062\n\nWSAEMFILE=10024\n\nWSAEMSGSIZE=10040\n\nWSAENAMETOOLONG=10063\n\nWSAENETDOWN=10050\n\nWSAENETRESET=10052\n\nWSAENETUNREACH=10051\n\nWSAENOBUFS=10055\n\nWSAENOPROTOOPT=10042\n\nWSAENOTCONN=10057\n\nWSAENOTEMPTY=10066\n\nWSAENOTSOCK=10038\n\nWSAEOPNOTSUPP=10045\n\nWSAEPFNOSUPPORT=10046\n\nWSAEPROCLIM=10067\n\nWSAEPROTONOSUPPORT=10043\n\nWSAEPROTOTYPE=10041\n\nWSAEREMOTE=10071\n\nWSAESHUTDOWN=10058\n\nWSAESOCKTNOSUPPORT=10044\n\nWSAESTALE=10070\n\nWSAETIMEDOUT=10060\n\nWSAETOOMANYREFS=10059\n\nWSAEUSERS=10068\n\nWSAEWOULDBLOCK=10035\n\nWSANOTINITIALISED=10093\n\nWSASYSNOTREADY=10091\n\nWSAVERNOTSUPPORTED=10092\n\nclass __loader__(object):\n ''\n\n\n\n\n \n \n \n __delattr__=\"<slot wrapper '__delattr__' of 'object' objects>\"\n \n __dict__=\"{'__module__': '_frozen_importlib', '__doc__': 'Meta path import for built-in modules.\\n\\n    All methods are either class or static methods to avoid the need to\\n    instantiate the class.\\n\\n    ', 'module_repr': <staticmethod object at 0x00000153E1934208>, 'find_spec': <classmethod object at 0x00000153E1934240>, 'find_module': <classmethod object at 0x00000153E1934278>, 'create_module': <classmethod object at 0x00000153E19342B0>, 'exec_module': <classmethod object at 0x00000153E19342E8>, 'get_code': <classmethod object at 0x00000153E1934358>, 'get_source': <classmethod object at 0x00000153E19343C8>, 'is_package': <classmethod object at 0x00000153E1934438>, 'load_module': <classmethod object at 0x00000153E1934470>, '__dict__': <attribute '__dict__' of 'BuiltinImporter' objects>, '__weakref__': <attribute '__weakref__' of 'BuiltinImporter' objects>}\"\n \n __dir__=\"<method '__dir__' of 'object' objects>\"\n \n __eq__=\"<slot wrapper '__eq__' of 'object' objects>\"\n \n __format__=\"<method '__format__' of 'object' objects>\"\n \n __ge__=\"<slot wrapper '__ge__' of 'object' objects>\"\n \n __getattribute__=\"<slot wrapper '__getattribute__' of 'object' objects>\"\n \n __gt__=\"<slot wrapper '__gt__' of 'object' objects>\"\n \n __hash__=\"<slot wrapper '__hash__' of 'object' objects>\"\n \n __init__=\"<slot wrapper '__init__' of 'object' objects>\"\n \n def __init_subclass__(*args,**kw):\n  ''\n\n\n  \n  pass\n  \n __le__=\"<slot wrapper '__le__' of 'object' objects>\"\n \n __lt__=\"<slot wrapper '__lt__' of 'object' objects>\"\n \n __module__=\"\"\"_frozen_importlib\"\"\"\n \n __ne__=\"<slot wrapper '__ne__' of 'object' objects>\"\n \n def __new__(*args,**kw):\n  ''\n  pass\n  \n __reduce__=\"<method '__reduce__' of 'object' objects>\"\n \n __reduce_ex__=\"<method '__reduce_ex__' of 'object' objects>\"\n \n __repr__=\"<slot wrapper '__repr__' of 'object' objects>\"\n \n __setattr__=\"<slot wrapper '__setattr__' of 'object' objects>\"\n \n __sizeof__=\"<method '__sizeof__' of 'object' objects>\"\n \n __str__=\"<slot wrapper '__str__' of 'object' objects>\"\n \n def __subclasshook__(*args,**kw):\n  ''\n\n\n\n\n  \n  pass\n  \n __weakref__=\"<attribute '__weakref__' of 'BuiltinImporter' objects>\"\n \n create_module=\"<bound method BuiltinImporter.create_module of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n exec_module=\"<bound method BuiltinImporter.exec_module of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n find_module=\"<bound method BuiltinImporter.find_module of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n find_spec=\"<bound method BuiltinImporter.find_spec of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n get_code=\"<bound method BuiltinImporter.get_code of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n get_source=\"<bound method BuiltinImporter.get_source of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n is_package=\"<bound method BuiltinImporter.is_package of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n load_module=\"<bound method _load_module_shim of <class '_frozen_importlib.BuiltinImporter'>>\"\n \n def module_repr(*args,**kw):\n  ''\n\n\n  \n  pass\n__spec__=\"ModuleSpec(name='errno', loader=<class '_frozen_importlib.BuiltinImporter'>, origin='built-in')\"\n\nerrorcode={v:k for (k,v)in globals(). items()if k ==k. upper()}\n", []], "pydoc_data.topics": [".py", "\n\ntopics={'assert':'\\nThe ``assert`` statement\\n************************\\n\\nAssert statements are a convenient way to insert debugging assertions\\ninto a program:\\n\\n   assert_stmt ::= \"assert\" expression [\",\" expression]\\n\\nThe simple form, ``assert expression``, is equivalent to\\n\\n   if __debug__:\\n      if not expression: raise AssertionError\\n\\nThe extended form, ``assert expression1, expression2``, is equivalent\\nto\\n\\n   if __debug__:\\n      if not expression1: raise AssertionError(expression2)\\n\\nThese equivalences assume that ``__debug__`` and ``AssertionError``\\nrefer to the built-in variables with those names.  In the current\\nimplementation, the built-in variable ``__debug__`` is ``True`` under\\nnormal circumstances, ``False`` when optimization is requested\\n(command line option -O).  The current code generator emits no code\\nfor an assert statement when optimization is requested at compile\\ntime.  Note that it is unnecessary to include the source code for the\\nexpression that failed in the error message; it will be displayed as\\npart of the stack trace.\\n\\nAssignments to ``__debug__`` are illegal.  The value for the built-in\\nvariable is determined when the interpreter starts.\\n',\n'assignment':'\\nAssignment statements\\n*********************\\n\\nAssignment statements are used to (re)bind names to values and to\\nmodify attributes or items of mutable objects:\\n\\n   assignment_stmt ::= (target_list \"=\")+ (expression_list | yield_expression)\\n   target_list     ::= target (\",\" target)* [\",\"]\\n   target          ::= identifier\\n              | \"(\" target_list \")\"\\n              | \"[\" target_list \"]\"\\n              | attributeref\\n              | subscription\\n              | slicing\\n              | \"*\" target\\n\\n(See section *Primaries* for the syntax definitions for the last three\\nsymbols.)\\n\\nAn assignment statement evaluates the expression list (remember that\\nthis can be a single expression or a comma-separated list, the latter\\nyielding a tuple) and assigns the single resulting object to each of\\nthe target lists, from left to right.\\n\\nAssignment is defined recursively depending on the form of the target\\n(list). When a target is part of a mutable object (an attribute\\nreference, subscription or slicing), the mutable object must\\nultimately perform the assignment and decide about its validity, and\\nmay raise an exception if the assignment is unacceptable.  The rules\\nobserved by various types and the exceptions raised are given with the\\ndefinition of the object types (see section *The standard type\\nhierarchy*).\\n\\nAssignment of an object to a target list, optionally enclosed in\\nparentheses or square brackets, is recursively defined as follows.\\n\\n* If the target list is a single target: The object is assigned to\\n  that target.\\n\\n* If the target list is a comma-separated list of targets: The object\\n  must be an iterable with the same number of items as there are\\n  targets in the target list, and the items are assigned, from left to\\n  right, to the corresponding targets.\\n\\n  * If the target list contains one target prefixed with an asterisk,\\n    called a \"starred\" target: The object must be a sequence with at\\n    least as many items as there are targets in the target list, minus\\n    one.  The first items of the sequence are assigned, from left to\\n    right, to the targets before the starred target.  The final items\\n    of the sequence are assigned to the targets after the starred\\n    target.  A list of the remaining items in the sequence is then\\n    assigned to the starred target (the list can be empty).\\n\\n  * Else: The object must be a sequence with the same number of items\\n    as there are targets in the target list, and the items are\\n    assigned, from left to right, to the corresponding targets.\\n\\nAssignment of an object to a single target is recursively defined as\\nfollows.\\n\\n* If the target is an identifier (name):\\n\\n  * If the name does not occur in a ``global`` or ``nonlocal``\\n    statement in the current code block: the name is bound to the\\n    object in the current local namespace.\\n\\n  * Otherwise: the name is bound to the object in the global namespace\\n    or the outer namespace determined by ``nonlocal``, respectively.\\n\\n  The name is rebound if it was already bound.  This may cause the\\n  reference count for the object previously bound to the name to reach\\n  zero, causing the object to be deallocated and its destructor (if it\\n  has one) to be called.\\n\\n* If the target is a target list enclosed in parentheses or in square\\n  brackets: The object must be an iterable with the same number of\\n  items as there are targets in the target list, and its items are\\n  assigned, from left to right, to the corresponding targets.\\n\\n* If the target is an attribute reference: The primary expression in\\n  the reference is evaluated.  It should yield an object with\\n  assignable attributes; if this is not the case, ``TypeError`` is\\n  raised.  That object is then asked to assign the assigned object to\\n  the given attribute; if it cannot perform the assignment, it raises\\n  an exception (usually but not necessarily ``AttributeError``).\\n\\n  Note: If the object is a class instance and the attribute reference\\n  occurs on both sides of the assignment operator, the RHS expression,\\n  ``a.x`` can access either an instance attribute or (if no instance\\n  attribute exists) a class attribute.  The LHS target ``a.x`` is\\n  always set as an instance attribute, creating it if necessary.\\n  Thus, the two occurrences of ``a.x`` do not necessarily refer to the\\n  same attribute: if the RHS expression refers to a class attribute,\\n  the LHS creates a new instance attribute as the target of the\\n  assignment:\\n\\n     class Cls:\\n         x = 3             # class variable\\n     inst = Cls()\\n     inst.x = inst.x + 1   # writes inst.x as 4 leaving Cls.x as 3\\n\\n  This description does not necessarily apply to descriptor\\n  attributes, such as properties created with ``property()``.\\n\\n* If the target is a subscription: The primary expression in the\\n  reference is evaluated.  It should yield either a mutable sequence\\n  object (such as a list) or a mapping object (such as a dictionary).\\n  Next, the subscript expression is evaluated.\\n\\n  If the primary is a mutable sequence object (such as a list), the\\n  subscript must yield an integer.  If it is negative, the sequence\\'s\\n  length is added to it.  The resulting value must be a nonnegative\\n  integer less than the sequence\\'s length, and the sequence is asked\\n  to assign the assigned object to its item with that index.  If the\\n  index is out of range, ``IndexError`` is raised (assignment to a\\n  subscripted sequence cannot add new items to a list).\\n\\n  If the primary is a mapping object (such as a dictionary), the\\n  subscript must have a type compatible with the mapping\\'s key type,\\n  and the mapping is then asked to create a key/datum pair which maps\\n  the subscript to the assigned object.  This can either replace an\\n  existing key/value pair with the same key value, or insert a new\\n  key/value pair (if no key with the same value existed).\\n\\n  For user-defined objects, the ``__setitem__()`` method is called\\n  with appropriate arguments.\\n\\n* If the target is a slicing: The primary expression in the reference\\n  is evaluated.  It should yield a mutable sequence object (such as a\\n  list).  The assigned object should be a sequence object of the same\\n  type.  Next, the lower and upper bound expressions are evaluated,\\n  insofar they are present; defaults are zero and the sequence\\'s\\n  length.  The bounds should evaluate to integers. If either bound is\\n  negative, the sequence\\'s length is added to it.  The resulting\\n  bounds are clipped to lie between zero and the sequence\\'s length,\\n  inclusive.  Finally, the sequence object is asked to replace the\\n  slice with the items of the assigned sequence.  The length of the\\n  slice may be different from the length of the assigned sequence,\\n  thus changing the length of the target sequence, if the object\\n  allows it.\\n\\n**CPython implementation detail:** In the current implementation, the\\nsyntax for targets is taken to be the same as for expressions, and\\ninvalid syntax is rejected during the code generation phase, causing\\nless detailed error messages.\\n\\nWARNING: Although the definition of assignment implies that overlaps\\nbetween the left-hand side and the right-hand side are \\'safe\\' (for\\nexample ``a, b = b, a`` swaps two variables), overlaps *within* the\\ncollection of assigned-to variables are not safe!  For instance, the\\nfollowing program prints ``[0, 2]``:\\n\\n   x = [0, 1]\\n   i = 0\\n   i, x[i] = 1, 2\\n   print(x)\\n\\nSee also:\\n\\n   **PEP 3132** - Extended Iterable Unpacking\\n      The specification for the ``*target`` feature.\\n\\n\\nAugmented assignment statements\\n===============================\\n\\nAugmented assignment is the combination, in a single statement, of a\\nbinary operation and an assignment statement:\\n\\n   augmented_assignment_stmt ::= augtarget augop (expression_list | yield_expression)\\n   augtarget                 ::= identifier | attributeref | subscription | slicing\\n   augop                     ::= \"+=\" | \"-=\" | \"*=\" | \"/=\" | \"//=\" | \"%=\" | \"**=\"\\n             | \">>=\" | \"<<=\" | \"&=\" | \"^=\" | \"|=\"\\n\\n(See section *Primaries* for the syntax definitions for the last three\\nsymbols.)\\n\\nAn augmented assignment evaluates the target (which, unlike normal\\nassignment statements, cannot be an unpacking) and the expression\\nlist, performs the binary operation specific to the type of assignment\\non the two operands, and assigns the result to the original target.\\nThe target is only evaluated once.\\n\\nAn augmented assignment expression like ``x += 1`` can be rewritten as\\n``x = x + 1`` to achieve a similar, but not exactly equal effect. In\\nthe augmented version, ``x`` is only evaluated once. Also, when\\npossible, the actual operation is performed *in-place*, meaning that\\nrather than creating a new object and assigning that to the target,\\nthe old object is modified instead.\\n\\nWith the exception of assigning to tuples and multiple targets in a\\nsingle statement, the assignment done by augmented assignment\\nstatements is handled the same way as normal assignments. Similarly,\\nwith the exception of the possible *in-place* behavior, the binary\\noperation performed by augmented assignment is the same as the normal\\nbinary operations.\\n\\nFor targets which are attribute references, the same *caveat about\\nclass and instance attributes* applies as for regular assignments.\\n',\n'atom-identifiers':'\\nIdentifiers (Names)\\n*******************\\n\\nAn identifier occurring as an atom is a name.  See section\\n*Identifiers and keywords* for lexical definition and section *Naming\\nand binding* for documentation of naming and binding.\\n\\nWhen the name is bound to an object, evaluation of the atom yields\\nthat object. When a name is not bound, an attempt to evaluate it\\nraises a ``NameError`` exception.\\n\\n**Private name mangling:** When an identifier that textually occurs in\\na class definition begins with two or more underscore characters and\\ndoes not end in two or more underscores, it is considered a *private\\nname* of that class. Private names are transformed to a longer form\\nbefore code is generated for them.  The transformation inserts the\\nclass name in front of the name, with leading underscores removed, and\\na single underscore inserted in front of the class name.  For example,\\nthe identifier ``__spam`` occurring in a class named ``Ham`` will be\\ntransformed to ``_Ham__spam``.  This transformation is independent of\\nthe syntactical context in which the identifier is used.  If the\\ntransformed name is extremely long (longer than 255 characters),\\nimplementation defined truncation may happen.  If the class name\\nconsists only of underscores, no transformation is done.\\n',\n'atom-literals':\"\\nLiterals\\n********\\n\\nPython supports string and bytes literals and various numeric\\nliterals:\\n\\n   literal ::= stringliteral | bytesliteral\\n               | integer | floatnumber | imagnumber\\n\\nEvaluation of a literal yields an object of the given type (string,\\nbytes, integer, floating point number, complex number) with the given\\nvalue.  The value may be approximated in the case of floating point\\nand imaginary (complex) literals.  See section *Literals* for details.\\n\\nAll literals correspond to immutable data types, and hence the\\nobject's identity is less important than its value.  Multiple\\nevaluations of literals with the same value (either the same\\noccurrence in the program text or a different occurrence) may obtain\\nthe same object or a different object with the same value.\\n\",\n'attribute-access':'\\nCustomizing attribute access\\n****************************\\n\\nThe following methods can be defined to customize the meaning of\\nattribute access (use of, assignment to, or deletion of ``x.name``)\\nfor class instances.\\n\\nobject.__getattr__(self, name)\\n\\n   Called when an attribute lookup has not found the attribute in the\\n   usual places (i.e. it is not an instance attribute nor is it found\\n   in the class tree for ``self``).  ``name`` is the attribute name.\\n   This method should return the (computed) attribute value or raise\\n   an ``AttributeError`` exception.\\n\\n   Note that if the attribute is found through the normal mechanism,\\n   ``__getattr__()`` is not called.  (This is an intentional asymmetry\\n   between ``__getattr__()`` and ``__setattr__()``.) This is done both\\n   for efficiency reasons and because otherwise ``__getattr__()``\\n   would have no way to access other attributes of the instance.  Note\\n   that at least for instance variables, you can fake total control by\\n   not inserting any values in the instance attribute dictionary (but\\n   instead inserting them in another object).  See the\\n   ``__getattribute__()`` method below for a way to actually get total\\n   control over attribute access.\\n\\nobject.__getattribute__(self, name)\\n\\n   Called unconditionally to implement attribute accesses for\\n   instances of the class. If the class also defines\\n   ``__getattr__()``, the latter will not be called unless\\n   ``__getattribute__()`` either calls it explicitly or raises an\\n   ``AttributeError``. This method should return the (computed)\\n   attribute value or raise an ``AttributeError`` exception. In order\\n   to avoid infinite recursion in this method, its implementation\\n   should always call the base class method with the same name to\\n   access any attributes it needs, for example,\\n   ``object.__getattribute__(self, name)``.\\n\\n   Note: This method may still be bypassed when looking up special methods\\n     as the result of implicit invocation via language syntax or\\n     built-in functions. See *Special method lookup*.\\n\\nobject.__setattr__(self, name, value)\\n\\n   Called when an attribute assignment is attempted.  This is called\\n   instead of the normal mechanism (i.e. store the value in the\\n   instance dictionary). *name* is the attribute name, *value* is the\\n   value to be assigned to it.\\n\\n   If ``__setattr__()`` wants to assign to an instance attribute, it\\n   should call the base class method with the same name, for example,\\n   ``object.__setattr__(self, name, value)``.\\n\\nobject.__delattr__(self, name)\\n\\n   Like ``__setattr__()`` but for attribute deletion instead of\\n   assignment.  This should only be implemented if ``del obj.name`` is\\n   meaningful for the object.\\n\\nobject.__dir__(self)\\n\\n   Called when ``dir()`` is called on the object. A sequence must be\\n   returned. ``dir()`` converts the returned sequence to a list and\\n   sorts it.\\n\\n\\nImplementing Descriptors\\n========================\\n\\nThe following methods only apply when an instance of the class\\ncontaining the method (a so-called *descriptor* class) appears in an\\n*owner* class (the descriptor must be in either the owner\\'s class\\ndictionary or in the class dictionary for one of its parents).  In the\\nexamples below, \"the attribute\" refers to the attribute whose name is\\nthe key of the property in the owner class\\' ``__dict__``.\\n\\nobject.__get__(self, instance, owner)\\n\\n   Called to get the attribute of the owner class (class attribute\\n   access) or of an instance of that class (instance attribute\\n   access). *owner* is always the owner class, while *instance* is the\\n   instance that the attribute was accessed through, or ``None`` when\\n   the attribute is accessed through the *owner*.  This method should\\n   return the (computed) attribute value or raise an\\n   ``AttributeError`` exception.\\n\\nobject.__set__(self, instance, value)\\n\\n   Called to set the attribute on an instance *instance* of the owner\\n   class to a new value, *value*.\\n\\nobject.__delete__(self, instance)\\n\\n   Called to delete the attribute on an instance *instance* of the\\n   owner class.\\n\\n\\nInvoking Descriptors\\n====================\\n\\nIn general, a descriptor is an object attribute with \"binding\\nbehavior\", one whose attribute access has been overridden by methods\\nin the descriptor protocol:  ``__get__()``, ``__set__()``, and\\n``__delete__()``. If any of those methods are defined for an object,\\nit is said to be a descriptor.\\n\\nThe default behavior for attribute access is to get, set, or delete\\nthe attribute from an object\\'s dictionary. For instance, ``a.x`` has a\\nlookup chain starting with ``a.__dict__[\\'x\\']``, then\\n``type(a).__dict__[\\'x\\']``, and continuing through the base classes of\\n``type(a)`` excluding metaclasses.\\n\\nHowever, if the looked-up value is an object defining one of the\\ndescriptor methods, then Python may override the default behavior and\\ninvoke the descriptor method instead.  Where this occurs in the\\nprecedence chain depends on which descriptor methods were defined and\\nhow they were called.\\n\\nThe starting point for descriptor invocation is a binding, ``a.x``.\\nHow the arguments are assembled depends on ``a``:\\n\\nDirect Call\\n   The simplest and least common call is when user code directly\\n   invokes a descriptor method:    ``x.__get__(a)``.\\n\\nInstance Binding\\n   If binding to an object instance, ``a.x`` is transformed into the\\n   call: ``type(a).__dict__[\\'x\\'].__get__(a, type(a))``.\\n\\nClass Binding\\n   If binding to a class, ``A.x`` is transformed into the call:\\n   ``A.__dict__[\\'x\\'].__get__(None, A)``.\\n\\nSuper Binding\\n   If ``a`` is an instance of ``super``, then the binding ``super(B,\\n   obj).m()`` searches ``obj.__class__.__mro__`` for the base class\\n   ``A`` immediately preceding ``B`` and then invokes the descriptor\\n   with the call: ``A.__dict__[\\'m\\'].__get__(obj, obj.__class__)``.\\n\\nFor instance bindings, the precedence of descriptor invocation depends\\non the which descriptor methods are defined.  A descriptor can define\\nany combination of ``__get__()``, ``__set__()`` and ``__delete__()``.\\nIf it does not define ``__get__()``, then accessing the attribute will\\nreturn the descriptor object itself unless there is a value in the\\nobject\\'s instance dictionary.  If the descriptor defines ``__set__()``\\nand/or ``__delete__()``, it is a data descriptor; if it defines\\nneither, it is a non-data descriptor.  Normally, data descriptors\\ndefine both ``__get__()`` and ``__set__()``, while non-data\\ndescriptors have just the ``__get__()`` method.  Data descriptors with\\n``__set__()`` and ``__get__()`` defined always override a redefinition\\nin an instance dictionary.  In contrast, non-data descriptors can be\\noverridden by instances.\\n\\nPython methods (including ``staticmethod()`` and ``classmethod()``)\\nare implemented as non-data descriptors.  Accordingly, instances can\\nredefine and override methods.  This allows individual instances to\\nacquire behaviors that differ from other instances of the same class.\\n\\nThe ``property()`` function is implemented as a data descriptor.\\nAccordingly, instances cannot override the behavior of a property.\\n\\n\\n__slots__\\n=========\\n\\nBy default, instances of classes have a dictionary for attribute\\nstorage.  This wastes space for objects having very few instance\\nvariables.  The space consumption can become acute when creating large\\nnumbers of instances.\\n\\nThe default can be overridden by defining *__slots__* in a class\\ndefinition. The *__slots__* declaration takes a sequence of instance\\nvariables and reserves just enough space in each instance to hold a\\nvalue for each variable.  Space is saved because *__dict__* is not\\ncreated for each instance.\\n\\nobject.__slots__\\n\\n   This class variable can be assigned a string, iterable, or sequence\\n   of strings with variable names used by instances.  If defined in a\\n   class, *__slots__* reserves space for the declared variables and\\n   prevents the automatic creation of *__dict__* and *__weakref__* for\\n   each instance.\\n\\n\\nNotes on using *__slots__*\\n--------------------------\\n\\n* When inheriting from a class without *__slots__*, the *__dict__*\\n  attribute of that class will always be accessible, so a *__slots__*\\n  definition in the subclass is meaningless.\\n\\n* Without a *__dict__* variable, instances cannot be assigned new\\n  variables not listed in the *__slots__* definition.  Attempts to\\n  assign to an unlisted variable name raises ``AttributeError``. If\\n  dynamic assignment of new variables is desired, then add\\n  ``\\'__dict__\\'`` to the sequence of strings in the *__slots__*\\n  declaration.\\n\\n* Without a *__weakref__* variable for each instance, classes defining\\n  *__slots__* do not support weak references to its instances. If weak\\n  reference support is needed, then add ``\\'__weakref__\\'`` to the\\n  sequence of strings in the *__slots__* declaration.\\n\\n* *__slots__* are implemented at the class level by creating\\n  descriptors (*Implementing Descriptors*) for each variable name.  As\\n  a result, class attributes cannot be used to set default values for\\n  instance variables defined by *__slots__*; otherwise, the class\\n  attribute would overwrite the descriptor assignment.\\n\\n* The action of a *__slots__* declaration is limited to the class\\n  where it is defined.  As a result, subclasses will have a *__dict__*\\n  unless they also define *__slots__* (which must only contain names\\n  of any *additional* slots).\\n\\n* If a class defines a slot also defined in a base class, the instance\\n  variable defined by the base class slot is inaccessible (except by\\n  retrieving its descriptor directly from the base class). This\\n  renders the meaning of the program undefined.  In the future, a\\n  check may be added to prevent this.\\n\\n* Nonempty *__slots__* does not work for classes derived from\\n  \"variable-length\" built-in types such as ``int``, ``str`` and\\n  ``tuple``.\\n\\n* Any non-string iterable may be assigned to *__slots__*. Mappings may\\n  also be used; however, in the future, special meaning may be\\n  assigned to the values corresponding to each key.\\n\\n* *__class__* assignment works only if both classes have the same\\n  *__slots__*.\\n',\n'attribute-references':'\\nAttribute references\\n********************\\n\\nAn attribute reference is a primary followed by a period and a name:\\n\\n   attributeref ::= primary \".\" identifier\\n\\nThe primary must evaluate to an object of a type that supports\\nattribute references, which most objects do.  This object is then\\nasked to produce the attribute whose name is the identifier (which can\\nbe customized by overriding the ``__getattr__()`` method).  If this\\nattribute is not available, the exception ``AttributeError`` is\\nraised.  Otherwise, the type and value of the object produced is\\ndetermined by the object.  Multiple evaluations of the same attribute\\nreference may yield different objects.\\n',\n'augassign':'\\nAugmented assignment statements\\n*******************************\\n\\nAugmented assignment is the combination, in a single statement, of a\\nbinary operation and an assignment statement:\\n\\n   augmented_assignment_stmt ::= augtarget augop (expression_list | yield_expression)\\n   augtarget                 ::= identifier | attributeref | subscription | slicing\\n   augop                     ::= \"+=\" | \"-=\" | \"*=\" | \"/=\" | \"//=\" | \"%=\" | \"**=\"\\n             | \">>=\" | \"<<=\" | \"&=\" | \"^=\" | \"|=\"\\n\\n(See section *Primaries* for the syntax definitions for the last three\\nsymbols.)\\n\\nAn augmented assignment evaluates the target (which, unlike normal\\nassignment statements, cannot be an unpacking) and the expression\\nlist, performs the binary operation specific to the type of assignment\\non the two operands, and assigns the result to the original target.\\nThe target is only evaluated once.\\n\\nAn augmented assignment expression like ``x += 1`` can be rewritten as\\n``x = x + 1`` to achieve a similar, but not exactly equal effect. In\\nthe augmented version, ``x`` is only evaluated once. Also, when\\npossible, the actual operation is performed *in-place*, meaning that\\nrather than creating a new object and assigning that to the target,\\nthe old object is modified instead.\\n\\nWith the exception of assigning to tuples and multiple targets in a\\nsingle statement, the assignment done by augmented assignment\\nstatements is handled the same way as normal assignments. Similarly,\\nwith the exception of the possible *in-place* behavior, the binary\\noperation performed by augmented assignment is the same as the normal\\nbinary operations.\\n\\nFor targets which are attribute references, the same *caveat about\\nclass and instance attributes* applies as for regular assignments.\\n',\n'binary':'\\nBinary arithmetic operations\\n****************************\\n\\nThe binary arithmetic operations have the conventional priority\\nlevels.  Note that some of these operations also apply to certain non-\\nnumeric types.  Apart from the power operator, there are only two\\nlevels, one for multiplicative operators and one for additive\\noperators:\\n\\n   m_expr ::= u_expr | m_expr \"*\" u_expr | m_expr \"//\" u_expr | m_expr \"/\" u_expr\\n              | m_expr \"%\" u_expr\\n   a_expr ::= m_expr | a_expr \"+\" m_expr | a_expr \"-\" m_expr\\n\\nThe ``*`` (multiplication) operator yields the product of its\\narguments.  The arguments must either both be numbers, or one argument\\nmust be an integer and the other must be a sequence. In the former\\ncase, the numbers are converted to a common type and then multiplied\\ntogether.  In the latter case, sequence repetition is performed; a\\nnegative repetition factor yields an empty sequence.\\n\\nThe ``/`` (division) and ``//`` (floor division) operators yield the\\nquotient of their arguments.  The numeric arguments are first\\nconverted to a common type. Integer division yields a float, while\\nfloor division of integers results in an integer; the result is that\\nof mathematical division with the \\'floor\\' function applied to the\\nresult.  Division by zero raises the ``ZeroDivisionError`` exception.\\n\\nThe ``%`` (modulo) operator yields the remainder from the division of\\nthe first argument by the second.  The numeric arguments are first\\nconverted to a common type.  A zero right argument raises the\\n``ZeroDivisionError`` exception.  The arguments may be floating point\\nnumbers, e.g., ``3.14%0.7`` equals ``0.34`` (since ``3.14`` equals\\n``4*0.7 + 0.34``.)  The modulo operator always yields a result with\\nthe same sign as its second operand (or zero); the absolute value of\\nthe result is strictly smaller than the absolute value of the second\\noperand [1].\\n\\nThe floor division and modulo operators are connected by the following\\nidentity: ``x == (x//y)*y + (x%y)``.  Floor division and modulo are\\nalso connected with the built-in function ``divmod()``: ``divmod(x, y)\\n== (x//y, x%y)``. [2].\\n\\nIn addition to performing the modulo operation on numbers, the ``%``\\noperator is also overloaded by string objects to perform old-style\\nstring formatting (also known as interpolation).  The syntax for\\nstring formatting is described in the Python Library Reference,\\nsection *printf-style String Formatting*.\\n\\nThe floor division operator, the modulo operator, and the ``divmod()``\\nfunction are not defined for complex numbers.  Instead, convert to a\\nfloating point number using the ``abs()`` function if appropriate.\\n\\nThe ``+`` (addition) operator yields the sum of its arguments.  The\\narguments must either both be numbers or both sequences of the same\\ntype.  In the former case, the numbers are converted to a common type\\nand then added together.  In the latter case, the sequences are\\nconcatenated.\\n\\nThe ``-`` (subtraction) operator yields the difference of its\\narguments.  The numeric arguments are first converted to a common\\ntype.\\n',\n'bitwise':'\\nBinary bitwise operations\\n*************************\\n\\nEach of the three bitwise operations has a different priority level:\\n\\n   and_expr ::= shift_expr | and_expr \"&\" shift_expr\\n   xor_expr ::= and_expr | xor_expr \"^\" and_expr\\n   or_expr  ::= xor_expr | or_expr \"|\" xor_expr\\n\\nThe ``&`` operator yields the bitwise AND of its arguments, which must\\nbe integers.\\n\\nThe ``^`` operator yields the bitwise XOR (exclusive OR) of its\\narguments, which must be integers.\\n\\nThe ``|`` operator yields the bitwise (inclusive) OR of its arguments,\\nwhich must be integers.\\n',\n'bltin-code-objects':'\\nCode Objects\\n************\\n\\nCode objects are used by the implementation to represent \"pseudo-\\ncompiled\" executable Python code such as a function body. They differ\\nfrom function objects because they don\\'t contain a reference to their\\nglobal execution environment.  Code objects are returned by the built-\\nin ``compile()`` function and can be extracted from function objects\\nthrough their ``__code__`` attribute. See also the ``code`` module.\\n\\nA code object can be executed or evaluated by passing it (instead of a\\nsource string) to the ``exec()`` or ``eval()``  built-in functions.\\n\\nSee *The standard type hierarchy* for more information.\\n',\n'bltin-ellipsis-object':'\\nThe Ellipsis Object\\n*******************\\n\\nThis object is commonly used by slicing (see *Slicings*).  It supports\\nno special operations.  There is exactly one ellipsis object, named\\n``Ellipsis`` (a built-in name).  ``type(Ellipsis)()`` produces the\\n``Ellipsis`` singleton.\\n\\nIt is written as ``Ellipsis`` or ``...``.\\n',\n'bltin-null-object':\"\\nThe Null Object\\n***************\\n\\nThis object is returned by functions that don't explicitly return a\\nvalue.  It supports no special operations.  There is exactly one null\\nobject, named ``None`` (a built-in name).  ``type(None)()`` produces\\nthe same singleton.\\n\\nIt is written as ``None``.\\n\",\n'bltin-type-objects':\"\\nType Objects\\n************\\n\\nType objects represent the various object types.  An object's type is\\naccessed by the built-in function ``type()``.  There are no special\\noperations on types.  The standard module ``types`` defines names for\\nall standard built-in types.\\n\\nTypes are written like this: ``<class 'int'>``.\\n\",\n'booleans':'\\nBoolean operations\\n******************\\n\\n   or_test  ::= and_test | or_test \"or\" and_test\\n   and_test ::= not_test | and_test \"and\" not_test\\n   not_test ::= comparison | \"not\" not_test\\n\\nIn the context of Boolean operations, and also when expressions are\\nused by control flow statements, the following values are interpreted\\nas false: ``False``, ``None``, numeric zero of all types, and empty\\nstrings and containers (including strings, tuples, lists,\\ndictionaries, sets and frozensets).  All other values are interpreted\\nas true.  User-defined objects can customize their truth value by\\nproviding a ``__bool__()`` method.\\n\\nThe operator ``not`` yields ``True`` if its argument is false,\\n``False`` otherwise.\\n\\nThe expression ``x and y`` first evaluates *x*; if *x* is false, its\\nvalue is returned; otherwise, *y* is evaluated and the resulting value\\nis returned.\\n\\nThe expression ``x or y`` first evaluates *x*; if *x* is true, its\\nvalue is returned; otherwise, *y* is evaluated and the resulting value\\nis returned.\\n\\n(Note that neither ``and`` nor ``or`` restrict the value and type they\\nreturn to ``False`` and ``True``, but rather return the last evaluated\\nargument.  This is sometimes useful, e.g., if ``s`` is a string that\\nshould be replaced by a default value if it is empty, the expression\\n``s or \\'foo\\'`` yields the desired value.  Because ``not`` has to\\ninvent a value anyway, it does not bother to return a value of the\\nsame type as its argument, so e.g., ``not \\'foo\\'`` yields ``False``,\\nnot ``\\'\\'``.)\\n',\n'break':'\\nThe ``break`` statement\\n***********************\\n\\n   break_stmt ::= \"break\"\\n\\n``break`` may only occur syntactically nested in a ``for`` or\\n``while`` loop, but not nested in a function or class definition\\nwithin that loop.\\n\\nIt terminates the nearest enclosing loop, skipping the optional\\n``else`` clause if the loop has one.\\n\\nIf a ``for`` loop is terminated by ``break``, the loop control target\\nkeeps its current value.\\n\\nWhen ``break`` passes control out of a ``try`` statement with a\\n``finally`` clause, that ``finally`` clause is executed before really\\nleaving the loop.\\n',\n'callable-types':'\\nEmulating callable objects\\n**************************\\n\\nobject.__call__(self[, args...])\\n\\n   Called when the instance is \"called\" as a function; if this method\\n   is defined, ``x(arg1, arg2, ...)`` is a shorthand for\\n   ``x.__call__(arg1, arg2, ...)``.\\n',\n'calls':'\\nCalls\\n*****\\n\\nA call calls a callable object (e.g., a *function*) with a possibly\\nempty series of *arguments*:\\n\\n   call                 ::= primary \"(\" [argument_list [\",\"] | comprehension] \")\"\\n   argument_list        ::= positional_arguments [\",\" keyword_arguments]\\n                       [\",\" \"*\" expression] [\",\" keyword_arguments]\\n                       [\",\" \"**\" expression]\\n                     | keyword_arguments [\",\" \"*\" expression]\\n                       [\",\" keyword_arguments] [\",\" \"**\" expression]\\n                     | \"*\" expression [\",\" keyword_arguments] [\",\" \"**\" expression]\\n                     | \"**\" expression\\n   positional_arguments ::= expression (\",\" expression)*\\n   keyword_arguments    ::= keyword_item (\",\" keyword_item)*\\n   keyword_item         ::= identifier \"=\" expression\\n\\nA trailing comma may be present after the positional and keyword\\narguments but does not affect the semantics.\\n\\nThe primary must evaluate to a callable object (user-defined\\nfunctions, built-in functions, methods of built-in objects, class\\nobjects, methods of class instances, and all objects having a\\n``__call__()`` method are callable).  All argument expressions are\\nevaluated before the call is attempted.  Please refer to section\\n*Function definitions* for the syntax of formal *parameter* lists.\\n\\nIf keyword arguments are present, they are first converted to\\npositional arguments, as follows.  First, a list of unfilled slots is\\ncreated for the formal parameters.  If there are N positional\\narguments, they are placed in the first N slots.  Next, for each\\nkeyword argument, the identifier is used to determine the\\ncorresponding slot (if the identifier is the same as the first formal\\nparameter name, the first slot is used, and so on).  If the slot is\\nalready filled, a ``TypeError`` exception is raised. Otherwise, the\\nvalue of the argument is placed in the slot, filling it (even if the\\nexpression is ``None``, it fills the slot).  When all arguments have\\nbeen processed, the slots that are still unfilled are filled with the\\ncorresponding default value from the function definition.  (Default\\nvalues are calculated, once, when the function is defined; thus, a\\nmutable object such as a list or dictionary used as default value will\\nbe shared by all calls that don\\'t specify an argument value for the\\ncorresponding slot; this should usually be avoided.)  If there are any\\nunfilled slots for which no default value is specified, a\\n``TypeError`` exception is raised.  Otherwise, the list of filled\\nslots is used as the argument list for the call.\\n\\n**CPython implementation detail:** An implementation may provide\\nbuilt-in functions whose positional parameters do not have names, even\\nif they are \\'named\\' for the purpose of documentation, and which\\ntherefore cannot be supplied by keyword.  In CPython, this is the case\\nfor functions implemented in C that use ``PyArg_ParseTuple()`` to\\nparse their arguments.\\n\\nIf there are more positional arguments than there are formal parameter\\nslots, a ``TypeError`` exception is raised, unless a formal parameter\\nusing the syntax ``*identifier`` is present; in this case, that formal\\nparameter receives a tuple containing the excess positional arguments\\n(or an empty tuple if there were no excess positional arguments).\\n\\nIf any keyword argument does not correspond to a formal parameter\\nname, a ``TypeError`` exception is raised, unless a formal parameter\\nusing the syntax ``**identifier`` is present; in this case, that\\nformal parameter receives a dictionary containing the excess keyword\\narguments (using the keywords as keys and the argument values as\\ncorresponding values), or a (new) empty dictionary if there were no\\nexcess keyword arguments.\\n\\nIf the syntax ``*expression`` appears in the function call,\\n``expression`` must evaluate to an iterable.  Elements from this\\niterable are treated as if they were additional positional arguments;\\nif there are positional arguments *x1*, ..., *xN*, and ``expression``\\nevaluates to a sequence *y1*, ..., *yM*, this is equivalent to a call\\nwith M+N positional arguments *x1*, ..., *xN*, *y1*, ..., *yM*.\\n\\nA consequence of this is that although the ``*expression`` syntax may\\nappear *after* some keyword arguments, it is processed *before* the\\nkeyword arguments (and the ``**expression`` argument, if any -- see\\nbelow).  So:\\n\\n   >>> def f(a, b):\\n   ...  print(a, b)\\n   ...\\n   >>> f(b=1, *(2,))\\n   2 1\\n   >>> f(a=1, *(2,))\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 1, in ?\\n   TypeError: f() got multiple values for keyword argument \\'a\\'\\n   >>> f(1, *(2,))\\n   1 2\\n\\nIt is unusual for both keyword arguments and the ``*expression``\\nsyntax to be used in the same call, so in practice this confusion does\\nnot arise.\\n\\nIf the syntax ``**expression`` appears in the function call,\\n``expression`` must evaluate to a mapping, the contents of which are\\ntreated as additional keyword arguments.  In the case of a keyword\\nappearing in both ``expression`` and as an explicit keyword argument,\\na ``TypeError`` exception is raised.\\n\\nFormal parameters using the syntax ``*identifier`` or ``**identifier``\\ncannot be used as positional argument slots or as keyword argument\\nnames.\\n\\nA call always returns some value, possibly ``None``, unless it raises\\nan exception.  How this value is computed depends on the type of the\\ncallable object.\\n\\nIf it is---\\n\\na user-defined function:\\n   The code block for the function is executed, passing it the\\n   argument list.  The first thing the code block will do is bind the\\n   formal parameters to the arguments; this is described in section\\n   *Function definitions*.  When the code block executes a ``return``\\n   statement, this specifies the return value of the function call.\\n\\na built-in function or method:\\n   The result is up to the interpreter; see *Built-in Functions* for\\n   the descriptions of built-in functions and methods.\\n\\na class object:\\n   A new instance of that class is returned.\\n\\na class instance method:\\n   The corresponding user-defined function is called, with an argument\\n   list that is one longer than the argument list of the call: the\\n   instance becomes the first argument.\\n\\na class instance:\\n   The class must define a ``__call__()`` method; the effect is then\\n   the same as if that method was called.\\n',\n'class':'\\nClass definitions\\n*****************\\n\\nA class definition defines a class object (see section *The standard\\ntype hierarchy*):\\n\\n   classdef    ::= [decorators] \"class\" classname [inheritance] \":\" suite\\n   inheritance ::= \"(\" [parameter_list] \")\"\\n   classname   ::= identifier\\n\\nA class definition is an executable statement.  The inheritance list\\nusually gives a list of base classes (see *Customizing class creation*\\nfor more advanced uses), so each item in the list should evaluate to a\\nclass object which allows subclassing.  Classes without an inheritance\\nlist inherit, by default, from the base class ``object``; hence,\\n\\n   class Foo:\\n       pass\\n\\nis equivalent to\\n\\n   class Foo(object):\\n       pass\\n\\nThe class\\'s suite is then executed in a new execution frame (see\\n*Naming and binding*), using a newly created local namespace and the\\noriginal global namespace. (Usually, the suite contains mostly\\nfunction definitions.)  When the class\\'s suite finishes execution, its\\nexecution frame is discarded but its local namespace is saved. [4] A\\nclass object is then created using the inheritance list for the base\\nclasses and the saved local namespace for the attribute dictionary.\\nThe class name is bound to this class object in the original local\\nnamespace.\\n\\nClass creation can be customized heavily using *metaclasses*.\\n\\nClasses can also be decorated: just like when decorating functions,\\n\\n   @f1(arg)\\n   @f2\\n   class Foo: pass\\n\\nis equivalent to\\n\\n   class Foo: pass\\n   Foo = f1(arg)(f2(Foo))\\n\\nThe evaluation rules for the decorator expressions are the same as for\\nfunction decorators.  The result must be a class object, which is then\\nbound to the class name.\\n\\n**Programmer\\'s note:** Variables defined in the class definition are\\nclass attributes; they are shared by instances.  Instance attributes\\ncan be set in a method with ``self.name = value``.  Both class and\\ninstance attributes are accessible through the notation\\n\"``self.name``\", and an instance attribute hides a class attribute\\nwith the same name when accessed in this way.  Class attributes can be\\nused as defaults for instance attributes, but using mutable values\\nthere can lead to unexpected results.  *Descriptors* can be used to\\ncreate instance variables with different implementation details.\\n\\nSee also:\\n\\n   **PEP 3115** - Metaclasses in Python 3 **PEP 3129** - Class\\n   Decorators\\n\\n-[ Footnotes ]-\\n\\n[1] The exception is propagated to the invocation stack unless there\\n    is a ``finally`` clause which happens to raise another exception.\\n    That new exception causes the old one to be lost.\\n\\n[2] Currently, control \"flows off the end\" except in the case of an\\n    exception or the execution of a ``return``, ``continue``, or\\n    ``break`` statement.\\n\\n[3] A string literal appearing as the first statement in the function\\n    body is transformed into the function\\'s ``__doc__`` attribute and\\n    therefore the function\\'s *docstring*.\\n\\n[4] A string literal appearing as the first statement in the class\\n    body is transformed into the namespace\\'s ``__doc__`` item and\\n    therefore the class\\'s *docstring*.\\n',\n'comparisons':'\\nComparisons\\n***********\\n\\nUnlike C, all comparison operations in Python have the same priority,\\nwhich is lower than that of any arithmetic, shifting or bitwise\\noperation.  Also unlike C, expressions like ``a < b < c`` have the\\ninterpretation that is conventional in mathematics:\\n\\n   comparison    ::= or_expr ( comp_operator or_expr )*\\n   comp_operator ::= \"<\" | \">\" | \"==\" | \">=\" | \"<=\" | \"!=\"\\n                     | \"is\" [\"not\"] | [\"not\"] \"in\"\\n\\nComparisons yield boolean values: ``True`` or ``False``.\\n\\nComparisons can be chained arbitrarily, e.g., ``x < y <= z`` is\\nequivalent to ``x < y and y <= z``, except that ``y`` is evaluated\\nonly once (but in both cases ``z`` is not evaluated at all when ``x <\\ny`` is found to be false).\\n\\nFormally, if *a*, *b*, *c*, ..., *y*, *z* are expressions and *op1*,\\n*op2*, ..., *opN* are comparison operators, then ``a op1 b op2 c ... y\\nopN z`` is equivalent to ``a op1 b and b op2 c and ... y opN z``,\\nexcept that each expression is evaluated at most once.\\n\\nNote that ``a op1 b op2 c`` doesn\\'t imply any kind of comparison\\nbetween *a* and *c*, so that, e.g., ``x < y > z`` is perfectly legal\\n(though perhaps not pretty).\\n\\nThe operators ``<``, ``>``, ``==``, ``>=``, ``<=``, and ``!=`` compare\\nthe values of two objects.  The objects need not have the same type.\\nIf both are numbers, they are converted to a common type.  Otherwise,\\nthe ``==`` and ``!=`` operators *always* consider objects of different\\ntypes to be unequal, while the ``<``, ``>``, ``>=`` and ``<=``\\noperators raise a ``TypeError`` when comparing objects of different\\ntypes that do not implement these operators for the given pair of\\ntypes.  You can control comparison behavior of objects of non-built-in\\ntypes by defining rich comparison methods like ``__gt__()``, described\\nin section *Basic customization*.\\n\\nComparison of objects of the same type depends on the type:\\n\\n* Numbers are compared arithmetically.\\n\\n* The values ``float(\\'NaN\\')`` and ``Decimal(\\'NaN\\')`` are special. The\\n  are identical to themselves, ``x is x`` but are not equal to\\n  themselves, ``x != x``.  Additionally, comparing any value to a\\n  not-a-number value will return ``False``.  For example, both ``3 <\\n  float(\\'NaN\\')`` and ``float(\\'NaN\\') < 3`` will return ``False``.\\n\\n* Bytes objects are compared lexicographically using the numeric\\n  values of their elements.\\n\\n* Strings are compared lexicographically using the numeric equivalents\\n  (the result of the built-in function ``ord()``) of their characters.\\n  [3] String and bytes object can\\'t be compared!\\n\\n* Tuples and lists are compared lexicographically using comparison of\\n  corresponding elements.  This means that to compare equal, each\\n  element must compare equal and the two sequences must be of the same\\n  type and have the same length.\\n\\n  If not equal, the sequences are ordered the same as their first\\n  differing elements.  For example, ``[1,2,x] <= [1,2,y]`` has the\\n  same value as ``x <= y``.  If the corresponding element does not\\n  exist, the shorter sequence is ordered first (for example, ``[1,2] <\\n  [1,2,3]``).\\n\\n* Mappings (dictionaries) compare equal if and only if they have the\\n  same ``(key, value)`` pairs. Order comparisons ``(\\'<\\', \\'<=\\', \\'>=\\',\\n  \\'>\\')`` raise ``TypeError``.\\n\\n* Sets and frozensets define comparison operators to mean subset and\\n  superset tests.  Those relations do not define total orderings (the\\n  two sets ``{1,2}`` and {2,3} are not equal, nor subsets of one\\n  another, nor supersets of one another).  Accordingly, sets are not\\n  appropriate arguments for functions which depend on total ordering.\\n  For example, ``min()``, ``max()``, and ``sorted()`` produce\\n  undefined results given a list of sets as inputs.\\n\\n* Most other objects of built-in types compare unequal unless they are\\n  the same object; the choice whether one object is considered smaller\\n  or larger than another one is made arbitrarily but consistently\\n  within one execution of a program.\\n\\nComparison of objects of the differing types depends on whether either\\nof the types provide explicit support for the comparison.  Most\\nnumeric types can be compared with one another.  When cross-type\\ncomparison is not supported, the comparison method returns\\n``NotImplemented``.\\n\\nThe operators ``in`` and ``not in`` test for membership.  ``x in s``\\nevaluates to true if *x* is a member of *s*, and false otherwise.  ``x\\nnot in s`` returns the negation of ``x in s``.  All built-in sequences\\nand set types support this as well as dictionary, for which ``in``\\ntests whether a the dictionary has a given key. For container types\\nsuch as list, tuple, set, frozenset, dict, or collections.deque, the\\nexpression ``x in y`` is equivalent to ``any(x is e or x == e for e in\\ny)``.\\n\\nFor the string and bytes types, ``x in y`` is true if and only if *x*\\nis a substring of *y*.  An equivalent test is ``y.find(x) != -1``.\\nEmpty strings are always considered to be a substring of any other\\nstring, so ``\"\" in \"abc\"`` will return ``True``.\\n\\nFor user-defined classes which define the ``__contains__()`` method,\\n``x in y`` is true if and only if ``y.__contains__(x)`` is true.\\n\\nFor user-defined classes which do not define ``__contains__()`` but do\\ndefine ``__iter__()``, ``x in y`` is true if some value ``z`` with ``x\\n== z`` is produced while iterating over ``y``.  If an exception is\\nraised during the iteration, it is as if ``in`` raised that exception.\\n\\nLastly, the old-style iteration protocol is tried: if a class defines\\n``__getitem__()``, ``x in y`` is true if and only if there is a non-\\nnegative integer index *i* such that ``x == y[i]``, and all lower\\ninteger indices do not raise ``IndexError`` exception.  (If any other\\nexception is raised, it is as if ``in`` raised that exception).\\n\\nThe operator ``not in`` is defined to have the inverse true value of\\n``in``.\\n\\nThe operators ``is`` and ``is not`` test for object identity: ``x is\\ny`` is true if and only if *x* and *y* are the same object.  ``x is\\nnot y`` yields the inverse truth value. [4]\\n',\n'compound':'\\nCompound statements\\n*******************\\n\\nCompound statements contain (groups of) other statements; they affect\\nor control the execution of those other statements in some way.  In\\ngeneral, compound statements span multiple lines, although in simple\\nincarnations a whole compound statement may be contained in one line.\\n\\nThe ``if``, ``while`` and ``for`` statements implement traditional\\ncontrol flow constructs.  ``try`` specifies exception handlers and/or\\ncleanup code for a group of statements, while the ``with`` statement\\nallows the execution of initialization and finalization code around a\\nblock of code.  Function and class definitions are also syntactically\\ncompound statements.\\n\\nCompound statements consist of one or more \\'clauses.\\'  A clause\\nconsists of a header and a \\'suite.\\'  The clause headers of a\\nparticular compound statement are all at the same indentation level.\\nEach clause header begins with a uniquely identifying keyword and ends\\nwith a colon.  A suite is a group of statements controlled by a\\nclause.  A suite can be one or more semicolon-separated simple\\nstatements on the same line as the header, following the header\\'s\\ncolon, or it can be one or more indented statements on subsequent\\nlines.  Only the latter form of suite can contain nested compound\\nstatements; the following is illegal, mostly because it wouldn\\'t be\\nclear to which ``if`` clause a following ``else`` clause would belong:\\n\\n   if test1: if test2: print(x)\\n\\nAlso note that the semicolon binds tighter than the colon in this\\ncontext, so that in the following example, either all or none of the\\n``print()`` calls are executed:\\n\\n   if x < y < z: print(x); print(y); print(z)\\n\\nSummarizing:\\n\\n   compound_stmt ::= if_stmt\\n                     | while_stmt\\n                     | for_stmt\\n                     | try_stmt\\n                     | with_stmt\\n                     | funcdef\\n                     | classdef\\n   suite         ::= stmt_list NEWLINE | NEWLINE INDENT statement+ DEDENT\\n   statement     ::= stmt_list NEWLINE | compound_stmt\\n   stmt_list     ::= simple_stmt (\";\" simple_stmt)* [\";\"]\\n\\nNote that statements always end in a ``NEWLINE`` possibly followed by\\na ``DEDENT``.  Also note that optional continuation clauses always\\nbegin with a keyword that cannot start a statement, thus there are no\\nambiguities (the \\'dangling ``else``\\' problem is solved in Python by\\nrequiring nested ``if`` statements to be indented).\\n\\nThe formatting of the grammar rules in the following sections places\\neach clause on a separate line for clarity.\\n\\n\\nThe ``if`` statement\\n====================\\n\\nThe ``if`` statement is used for conditional execution:\\n\\n   if_stmt ::= \"if\" expression \":\" suite\\n               ( \"elif\" expression \":\" suite )*\\n               [\"else\" \":\" suite]\\n\\nIt selects exactly one of the suites by evaluating the expressions one\\nby one until one is found to be true (see section *Boolean operations*\\nfor the definition of true and false); then that suite is executed\\n(and no other part of the ``if`` statement is executed or evaluated).\\nIf all expressions are false, the suite of the ``else`` clause, if\\npresent, is executed.\\n\\n\\nThe ``while`` statement\\n=======================\\n\\nThe ``while`` statement is used for repeated execution as long as an\\nexpression is true:\\n\\n   while_stmt ::= \"while\" expression \":\" suite\\n                  [\"else\" \":\" suite]\\n\\nThis repeatedly tests the expression and, if it is true, executes the\\nfirst suite; if the expression is false (which may be the first time\\nit is tested) the suite of the ``else`` clause, if present, is\\nexecuted and the loop terminates.\\n\\nA ``break`` statement executed in the first suite terminates the loop\\nwithout executing the ``else`` clause\\'s suite.  A ``continue``\\nstatement executed in the first suite skips the rest of the suite and\\ngoes back to testing the expression.\\n\\n\\nThe ``for`` statement\\n=====================\\n\\nThe ``for`` statement is used to iterate over the elements of a\\nsequence (such as a string, tuple or list) or other iterable object:\\n\\n   for_stmt ::= \"for\" target_list \"in\" expression_list \":\" suite\\n                [\"else\" \":\" suite]\\n\\nThe expression list is evaluated once; it should yield an iterable\\nobject.  An iterator is created for the result of the\\n``expression_list``.  The suite is then executed once for each item\\nprovided by the iterator, in the order of ascending indices.  Each\\nitem in turn is assigned to the target list using the standard rules\\nfor assignments (see *Assignment statements*), and then the suite is\\nexecuted.  When the items are exhausted (which is immediately when the\\nsequence is empty or an iterator raises a ``StopIteration``\\nexception), the suite in the ``else`` clause, if present, is executed,\\nand the loop terminates.\\n\\nA ``break`` statement executed in the first suite terminates the loop\\nwithout executing the ``else`` clause\\'s suite.  A ``continue``\\nstatement executed in the first suite skips the rest of the suite and\\ncontinues with the next item, or with the ``else`` clause if there was\\nno next item.\\n\\nThe suite may assign to the variable(s) in the target list; this does\\nnot affect the next item assigned to it.\\n\\nNames in the target list are not deleted when the loop is finished,\\nbut if the sequence is empty, it will not have been assigned to at all\\nby the loop.  Hint: the built-in function ``range()`` returns an\\niterator of integers suitable to emulate the effect of Pascal\\'s ``for\\ni := a to b do``; e.g., ``list(range(3))`` returns the list ``[0, 1,\\n2]``.\\n\\nNote: There is a subtlety when the sequence is being modified by the loop\\n  (this can only occur for mutable sequences, i.e. lists).  An\\n  internal counter is used to keep track of which item is used next,\\n  and this is incremented on each iteration.  When this counter has\\n  reached the length of the sequence the loop terminates.  This means\\n  that if the suite deletes the current (or a previous) item from the\\n  sequence, the next item will be skipped (since it gets the index of\\n  the current item which has already been treated).  Likewise, if the\\n  suite inserts an item in the sequence before the current item, the\\n  current item will be treated again the next time through the loop.\\n  This can lead to nasty bugs that can be avoided by making a\\n  temporary copy using a slice of the whole sequence, e.g.,\\n\\n     for x in a[:]:\\n         if x < 0: a.remove(x)\\n\\n\\nThe ``try`` statement\\n=====================\\n\\nThe ``try`` statement specifies exception handlers and/or cleanup code\\nfor a group of statements:\\n\\n   try_stmt  ::= try1_stmt | try2_stmt\\n   try1_stmt ::= \"try\" \":\" suite\\n                 (\"except\" [expression [\"as\" target]] \":\" suite)+\\n                 [\"else\" \":\" suite]\\n                 [\"finally\" \":\" suite]\\n   try2_stmt ::= \"try\" \":\" suite\\n                 \"finally\" \":\" suite\\n\\nThe ``except`` clause(s) specify one or more exception handlers. When\\nno exception occurs in the ``try`` clause, no exception handler is\\nexecuted. When an exception occurs in the ``try`` suite, a search for\\nan exception handler is started.  This search inspects the except\\nclauses in turn until one is found that matches the exception.  An\\nexpression-less except clause, if present, must be last; it matches\\nany exception.  For an except clause with an expression, that\\nexpression is evaluated, and the clause matches the exception if the\\nresulting object is \"compatible\" with the exception.  An object is\\ncompatible with an exception if it is the class or a base class of the\\nexception object or a tuple containing an item compatible with the\\nexception.\\n\\nIf no except clause matches the exception, the search for an exception\\nhandler continues in the surrounding code and on the invocation stack.\\n[1]\\n\\nIf the evaluation of an expression in the header of an except clause\\nraises an exception, the original search for a handler is canceled and\\na search starts for the new exception in the surrounding code and on\\nthe call stack (it is treated as if the entire ``try`` statement\\nraised the exception).\\n\\nWhen a matching except clause is found, the exception is assigned to\\nthe target specified after the ``as`` keyword in that except clause,\\nif present, and the except clause\\'s suite is executed.  All except\\nclauses must have an executable block.  When the end of this block is\\nreached, execution continues normally after the entire try statement.\\n(This means that if two nested handlers exist for the same exception,\\nand the exception occurs in the try clause of the inner handler, the\\nouter handler will not handle the exception.)\\n\\nWhen an exception has been assigned using ``as target``, it is cleared\\nat the end of the except clause.  This is as if\\n\\n   except E as N:\\n       foo\\n\\nwas translated to\\n\\n   except E as N:\\n       try:\\n           foo\\n       finally:\\n           del N\\n\\nThis means the exception must be assigned to a different name to be\\nable to refer to it after the except clause.  Exceptions are cleared\\nbecause with the traceback attached to them, they form a reference\\ncycle with the stack frame, keeping all locals in that frame alive\\nuntil the next garbage collection occurs.\\n\\nBefore an except clause\\'s suite is executed, details about the\\nexception are stored in the ``sys`` module and can be access via\\n``sys.exc_info()``. ``sys.exc_info()`` returns a 3-tuple consisting of\\nthe exception class, the exception instance and a traceback object\\n(see section *The standard type hierarchy*) identifying the point in\\nthe program where the exception occurred.  ``sys.exc_info()`` values\\nare restored to their previous values (before the call) when returning\\nfrom a function that handled an exception.\\n\\nThe optional ``else`` clause is executed if and when control flows off\\nthe end of the ``try`` clause. [2] Exceptions in the ``else`` clause\\nare not handled by the preceding ``except`` clauses.\\n\\nIf ``finally`` is present, it specifies a \\'cleanup\\' handler.  The\\n``try`` clause is executed, including any ``except`` and ``else``\\nclauses.  If an exception occurs in any of the clauses and is not\\nhandled, the exception is temporarily saved. The ``finally`` clause is\\nexecuted.  If there is a saved exception it is re-raised at the end of\\nthe ``finally`` clause.  If the ``finally`` clause raises another\\nexception, the saved exception is set as the context of the new\\nexception. If the ``finally`` clause executes a ``return`` or\\n``break`` statement, the saved exception is discarded:\\n\\n   def f():\\n       try:\\n           1/0\\n       finally:\\n           return 42\\n\\n   >>> f()\\n   42\\n\\nThe exception information is not available to the program during\\nexecution of the ``finally`` clause.\\n\\nWhen a ``return``, ``break`` or ``continue`` statement is executed in\\nthe ``try`` suite of a ``try``...``finally`` statement, the\\n``finally`` clause is also executed \\'on the way out.\\' A ``continue``\\nstatement is illegal in the ``finally`` clause. (The reason is a\\nproblem with the current implementation --- this restriction may be\\nlifted in the future).\\n\\nAdditional information on exceptions can be found in section\\n*Exceptions*, and information on using the ``raise`` statement to\\ngenerate exceptions may be found in section *The raise statement*.\\n\\n\\nThe ``with`` statement\\n======================\\n\\nThe ``with`` statement is used to wrap the execution of a block with\\nmethods defined by a context manager (see section *With Statement\\nContext Managers*). This allows common\\n``try``...``except``...``finally`` usage patterns to be encapsulated\\nfor convenient reuse.\\n\\n   with_stmt ::= \"with\" with_item (\",\" with_item)* \":\" suite\\n   with_item ::= expression [\"as\" target]\\n\\nThe execution of the ``with`` statement with one \"item\" proceeds as\\nfollows:\\n\\n1. The context expression (the expression given in the ``with_item``)\\n   is evaluated to obtain a context manager.\\n\\n2. The context manager\\'s ``__exit__()`` is loaded for later use.\\n\\n3. The context manager\\'s ``__enter__()`` method is invoked.\\n\\n4. If a target was included in the ``with`` statement, the return\\n   value from ``__enter__()`` is assigned to it.\\n\\n   Note: The ``with`` statement guarantees that if the ``__enter__()``\\n     method returns without an error, then ``__exit__()`` will always\\n     be called. Thus, if an error occurs during the assignment to the\\n     target list, it will be treated the same as an error occurring\\n     within the suite would be. See step 6 below.\\n\\n5. The suite is executed.\\n\\n6. The context manager\\'s ``__exit__()`` method is invoked.  If an\\n   exception caused the suite to be exited, its type, value, and\\n   traceback are passed as arguments to ``__exit__()``. Otherwise,\\n   three ``None`` arguments are supplied.\\n\\n   If the suite was exited due to an exception, and the return value\\n   from the ``__exit__()`` method was false, the exception is\\n   reraised.  If the return value was true, the exception is\\n   suppressed, and execution continues with the statement following\\n   the ``with`` statement.\\n\\n   If the suite was exited for any reason other than an exception, the\\n   return value from ``__exit__()`` is ignored, and execution proceeds\\n   at the normal location for the kind of exit that was taken.\\n\\nWith more than one item, the context managers are processed as if\\nmultiple ``with`` statements were nested:\\n\\n   with A() as a, B() as b:\\n       suite\\n\\nis equivalent to\\n\\n   with A() as a:\\n       with B() as b:\\n           suite\\n\\nChanged in version 3.1: Support for multiple context expressions.\\n\\nSee also:\\n\\n   **PEP 0343** - The \"with\" statement\\n      The specification, background, and examples for the Python\\n      ``with`` statement.\\n\\n\\nFunction definitions\\n====================\\n\\nA function definition defines a user-defined function object (see\\nsection *The standard type hierarchy*):\\n\\n   funcdef        ::= [decorators] \"def\" funcname \"(\" [parameter_list] \")\" [\"->\" expression] \":\" suite\\n   decorators     ::= decorator+\\n   decorator      ::= \"@\" dotted_name [\"(\" [parameter_list [\",\"]] \")\"] NEWLINE\\n   dotted_name    ::= identifier (\".\" identifier)*\\n   parameter_list ::= (defparameter \",\")*\\n                      ( \"*\" [parameter] (\",\" defparameter)* [\",\" \"**\" parameter]\\n                      | \"**\" parameter\\n                      | defparameter [\",\"] )\\n   parameter      ::= identifier [\":\" expression]\\n   defparameter   ::= parameter [\"=\" expression]\\n   funcname       ::= identifier\\n\\nA function definition is an executable statement.  Its execution binds\\nthe function name in the current local namespace to a function object\\n(a wrapper around the executable code for the function).  This\\nfunction object contains a reference to the current global namespace\\nas the global namespace to be used when the function is called.\\n\\nThe function definition does not execute the function body; this gets\\nexecuted only when the function is called. [3]\\n\\nA function definition may be wrapped by one or more *decorator*\\nexpressions. Decorator expressions are evaluated when the function is\\ndefined, in the scope that contains the function definition.  The\\nresult must be a callable, which is invoked with the function object\\nas the only argument. The returned value is bound to the function name\\ninstead of the function object.  Multiple decorators are applied in\\nnested fashion. For example, the following code\\n\\n   @f1(arg)\\n   @f2\\n   def func(): pass\\n\\nis equivalent to\\n\\n   def func(): pass\\n   func = f1(arg)(f2(func))\\n\\nWhen one or more *parameters* have the form *parameter* ``=``\\n*expression*, the function is said to have \"default parameter values.\"\\nFor a parameter with a default value, the corresponding *argument* may\\nbe omitted from a call, in which case the parameter\\'s default value is\\nsubstituted.  If a parameter has a default value, all following\\nparameters up until the \"``*``\" must also have a default value ---\\nthis is a syntactic restriction that is not expressed by the grammar.\\n\\n**Default parameter values are evaluated when the function definition\\nis executed.** This means that the expression is evaluated once, when\\nthe function is defined, and that the same \"pre-computed\" value is\\nused for each call.  This is especially important to understand when a\\ndefault parameter is a mutable object, such as a list or a dictionary:\\nif the function modifies the object (e.g. by appending an item to a\\nlist), the default value is in effect modified. This is generally not\\nwhat was intended.  A way around this is to use ``None`` as the\\ndefault, and explicitly test for it in the body of the function, e.g.:\\n\\n   def whats_on_the_telly(penguin=None):\\n       if penguin is None:\\n           penguin = []\\n       penguin.append(\"property of the zoo\")\\n       return penguin\\n\\nFunction call semantics are described in more detail in section\\n*Calls*. A function call always assigns values to all parameters\\nmentioned in the parameter list, either from position arguments, from\\nkeyword arguments, or from default values.  If the form\\n\"``*identifier``\" is present, it is initialized to a tuple receiving\\nany excess positional parameters, defaulting to the empty tuple.  If\\nthe form \"``**identifier``\" is present, it is initialized to a new\\ndictionary receiving any excess keyword arguments, defaulting to a new\\nempty dictionary. Parameters after \"``*``\" or \"``*identifier``\" are\\nkeyword-only parameters and may only be passed used keyword arguments.\\n\\nParameters may have annotations of the form \"``: expression``\"\\nfollowing the parameter name.  Any parameter may have an annotation\\neven those of the form ``*identifier`` or ``**identifier``.  Functions\\nmay have \"return\" annotation of the form \"``-> expression``\" after the\\nparameter list.  These annotations can be any valid Python expression\\nand are evaluated when the function definition is executed.\\nAnnotations may be evaluated in a different order than they appear in\\nthe source code.  The presence of annotations does not change the\\nsemantics of a function.  The annotation values are available as\\nvalues of a dictionary keyed by the parameters\\' names in the\\n``__annotations__`` attribute of the function object.\\n\\nIt is also possible to create anonymous functions (functions not bound\\nto a name), for immediate use in expressions.  This uses lambda forms,\\ndescribed in section *Lambdas*.  Note that the lambda form is merely a\\nshorthand for a simplified function definition; a function defined in\\na \"``def``\" statement can be passed around or assigned to another name\\njust like a function defined by a lambda form.  The \"``def``\" form is\\nactually more powerful since it allows the execution of multiple\\nstatements and annotations.\\n\\n**Programmer\\'s note:** Functions are first-class objects.  A \"``def``\"\\nform executed inside a function definition defines a local function\\nthat can be returned or passed around.  Free variables used in the\\nnested function can access the local variables of the function\\ncontaining the def.  See section *Naming and binding* for details.\\n\\nSee also:\\n\\n   **PEP 3107** - Function Annotations\\n      The original specification for function annotations.\\n\\n\\nClass definitions\\n=================\\n\\nA class definition defines a class object (see section *The standard\\ntype hierarchy*):\\n\\n   classdef    ::= [decorators] \"class\" classname [inheritance] \":\" suite\\n   inheritance ::= \"(\" [parameter_list] \")\"\\n   classname   ::= identifier\\n\\nA class definition is an executable statement.  The inheritance list\\nusually gives a list of base classes (see *Customizing class creation*\\nfor more advanced uses), so each item in the list should evaluate to a\\nclass object which allows subclassing.  Classes without an inheritance\\nlist inherit, by default, from the base class ``object``; hence,\\n\\n   class Foo:\\n       pass\\n\\nis equivalent to\\n\\n   class Foo(object):\\n       pass\\n\\nThe class\\'s suite is then executed in a new execution frame (see\\n*Naming and binding*), using a newly created local namespace and the\\noriginal global namespace. (Usually, the suite contains mostly\\nfunction definitions.)  When the class\\'s suite finishes execution, its\\nexecution frame is discarded but its local namespace is saved. [4] A\\nclass object is then created using the inheritance list for the base\\nclasses and the saved local namespace for the attribute dictionary.\\nThe class name is bound to this class object in the original local\\nnamespace.\\n\\nClass creation can be customized heavily using *metaclasses*.\\n\\nClasses can also be decorated: just like when decorating functions,\\n\\n   @f1(arg)\\n   @f2\\n   class Foo: pass\\n\\nis equivalent to\\n\\n   class Foo: pass\\n   Foo = f1(arg)(f2(Foo))\\n\\nThe evaluation rules for the decorator expressions are the same as for\\nfunction decorators.  The result must be a class object, which is then\\nbound to the class name.\\n\\n**Programmer\\'s note:** Variables defined in the class definition are\\nclass attributes; they are shared by instances.  Instance attributes\\ncan be set in a method with ``self.name = value``.  Both class and\\ninstance attributes are accessible through the notation\\n\"``self.name``\", and an instance attribute hides a class attribute\\nwith the same name when accessed in this way.  Class attributes can be\\nused as defaults for instance attributes, but using mutable values\\nthere can lead to unexpected results.  *Descriptors* can be used to\\ncreate instance variables with different implementation details.\\n\\nSee also:\\n\\n   **PEP 3115** - Metaclasses in Python 3 **PEP 3129** - Class\\n   Decorators\\n\\n-[ Footnotes ]-\\n\\n[1] The exception is propagated to the invocation stack unless there\\n    is a ``finally`` clause which happens to raise another exception.\\n    That new exception causes the old one to be lost.\\n\\n[2] Currently, control \"flows off the end\" except in the case of an\\n    exception or the execution of a ``return``, ``continue``, or\\n    ``break`` statement.\\n\\n[3] A string literal appearing as the first statement in the function\\n    body is transformed into the function\\'s ``__doc__`` attribute and\\n    therefore the function\\'s *docstring*.\\n\\n[4] A string literal appearing as the first statement in the class\\n    body is transformed into the namespace\\'s ``__doc__`` item and\\n    therefore the class\\'s *docstring*.\\n',\n'context-managers':'\\nWith Statement Context Managers\\n*******************************\\n\\nA *context manager* is an object that defines the runtime context to\\nbe established when executing a ``with`` statement. The context\\nmanager handles the entry into, and the exit from, the desired runtime\\ncontext for the execution of the block of code.  Context managers are\\nnormally invoked using the ``with`` statement (described in section\\n*The with statement*), but can also be used by directly invoking their\\nmethods.\\n\\nTypical uses of context managers include saving and restoring various\\nkinds of global state, locking and unlocking resources, closing opened\\nfiles, etc.\\n\\nFor more information on context managers, see *Context Manager Types*.\\n\\nobject.__enter__(self)\\n\\n   Enter the runtime context related to this object. The ``with``\\n   statement will bind this method\\'s return value to the target(s)\\n   specified in the ``as`` clause of the statement, if any.\\n\\nobject.__exit__(self, exc_type, exc_value, traceback)\\n\\n   Exit the runtime context related to this object. The parameters\\n   describe the exception that caused the context to be exited. If the\\n   context was exited without an exception, all three arguments will\\n   be ``None``.\\n\\n   If an exception is supplied, and the method wishes to suppress the\\n   exception (i.e., prevent it from being propagated), it should\\n   return a true value. Otherwise, the exception will be processed\\n   normally upon exit from this method.\\n\\n   Note that ``__exit__()`` methods should not reraise the passed-in\\n   exception; this is the caller\\'s responsibility.\\n\\nSee also:\\n\\n   **PEP 0343** - The \"with\" statement\\n      The specification, background, and examples for the Python\\n      ``with`` statement.\\n',\n'continue':'\\nThe ``continue`` statement\\n**************************\\n\\n   continue_stmt ::= \"continue\"\\n\\n``continue`` may only occur syntactically nested in a ``for`` or\\n``while`` loop, but not nested in a function or class definition or\\n``finally`` clause within that loop.  It continues with the next cycle\\nof the nearest enclosing loop.\\n\\nWhen ``continue`` passes control out of a ``try`` statement with a\\n``finally`` clause, that ``finally`` clause is executed before really\\nstarting the next loop cycle.\\n',\n'conversions':'\\nArithmetic conversions\\n**********************\\n\\nWhen a description of an arithmetic operator below uses the phrase\\n\"the numeric arguments are converted to a common type,\" this means\\nthat the operator implementation for built-in types works that way:\\n\\n* If either argument is a complex number, the other is converted to\\n  complex;\\n\\n* otherwise, if either argument is a floating point number, the other\\n  is converted to floating point;\\n\\n* otherwise, both must be integers and no conversion is necessary.\\n\\nSome additional rules apply for certain operators (e.g., a string left\\nargument to the \\'%\\' operator).  Extensions must define their own\\nconversion behavior.\\n',\n'customization':'\\nBasic customization\\n*******************\\n\\nobject.__new__(cls[, ...])\\n\\n   Called to create a new instance of class *cls*.  ``__new__()`` is a\\n   static method (special-cased so you need not declare it as such)\\n   that takes the class of which an instance was requested as its\\n   first argument.  The remaining arguments are those passed to the\\n   object constructor expression (the call to the class).  The return\\n   value of ``__new__()`` should be the new object instance (usually\\n   an instance of *cls*).\\n\\n   Typical implementations create a new instance of the class by\\n   invoking the superclass\\'s ``__new__()`` method using\\n   ``super(currentclass, cls).__new__(cls[, ...])`` with appropriate\\n   arguments and then modifying the newly-created instance as\\n   necessary before returning it.\\n\\n   If ``__new__()`` returns an instance of *cls*, then the new\\n   instance\\'s ``__init__()`` method will be invoked like\\n   ``__init__(self[, ...])``, where *self* is the new instance and the\\n   remaining arguments are the same as were passed to ``__new__()``.\\n\\n   If ``__new__()`` does not return an instance of *cls*, then the new\\n   instance\\'s ``__init__()`` method will not be invoked.\\n\\n   ``__new__()`` is intended mainly to allow subclasses of immutable\\n   types (like int, str, or tuple) to customize instance creation.  It\\n   is also commonly overridden in custom metaclasses in order to\\n   customize class creation.\\n\\nobject.__init__(self[, ...])\\n\\n   Called when the instance is created.  The arguments are those\\n   passed to the class constructor expression.  If a base class has an\\n   ``__init__()`` method, the derived class\\'s ``__init__()`` method,\\n   if any, must explicitly call it to ensure proper initialization of\\n   the base class part of the instance; for example:\\n   ``BaseClass.__init__(self, [args...])``.  As a special constraint\\n   on constructors, no value may be returned; doing so will cause a\\n   ``TypeError`` to be raised at runtime.\\n\\nobject.__del__(self)\\n\\n   Called when the instance is about to be destroyed.  This is also\\n   called a destructor.  If a base class has a ``__del__()`` method,\\n   the derived class\\'s ``__del__()`` method, if any, must explicitly\\n   call it to ensure proper deletion of the base class part of the\\n   instance.  Note that it is possible (though not recommended!) for\\n   the ``__del__()`` method to postpone destruction of the instance by\\n   creating a new reference to it.  It may then be called at a later\\n   time when this new reference is deleted.  It is not guaranteed that\\n   ``__del__()`` methods are called for objects that still exist when\\n   the interpreter exits.\\n\\n   Note: ``del x`` doesn\\'t directly call ``x.__del__()`` --- the former\\n     decrements the reference count for ``x`` by one, and the latter\\n     is only called when ``x``\\'s reference count reaches zero.  Some\\n     common situations that may prevent the reference count of an\\n     object from going to zero include: circular references between\\n     objects (e.g., a doubly-linked list or a tree data structure with\\n     parent and child pointers); a reference to the object on the\\n     stack frame of a function that caught an exception (the traceback\\n     stored in ``sys.exc_info()[2]`` keeps the stack frame alive); or\\n     a reference to the object on the stack frame that raised an\\n     unhandled exception in interactive mode (the traceback stored in\\n     ``sys.last_traceback`` keeps the stack frame alive).  The first\\n     situation can only be remedied by explicitly breaking the cycles;\\n     the latter two situations can be resolved by storing ``None`` in\\n     ``sys.last_traceback``. Circular references which are garbage are\\n     detected when the option cycle detector is enabled (it\\'s on by\\n     default), but can only be cleaned up if there are no Python-\\n     level ``__del__()`` methods involved. Refer to the documentation\\n     for the ``gc`` module for more information about how\\n     ``__del__()`` methods are handled by the cycle detector,\\n     particularly the description of the ``garbage`` value.\\n\\n   Warning: Due to the precarious circumstances under which ``__del__()``\\n     methods are invoked, exceptions that occur during their execution\\n     are ignored, and a warning is printed to ``sys.stderr`` instead.\\n     Also, when ``__del__()`` is invoked in response to a module being\\n     deleted (e.g., when execution of the program is done), other\\n     globals referenced by the ``__del__()`` method may already have\\n     been deleted or in the process of being torn down (e.g. the\\n     import machinery shutting down).  For this reason, ``__del__()``\\n     methods should do the absolute minimum needed to maintain\\n     external invariants.  Starting with version 1.5, Python\\n     guarantees that globals whose name begins with a single\\n     underscore are deleted from their module before other globals are\\n     deleted; if no other references to such globals exist, this may\\n     help in assuring that imported modules are still available at the\\n     time when the ``__del__()`` method is called.\\n\\nobject.__repr__(self)\\n\\n   Called by the ``repr()`` built-in function to compute the\\n   \"official\" string representation of an object.  If at all possible,\\n   this should look like a valid Python expression that could be used\\n   to recreate an object with the same value (given an appropriate\\n   environment).  If this is not possible, a string of the form\\n   ``<...some useful description...>`` should be returned. The return\\n   value must be a string object. If a class defines ``__repr__()``\\n   but not ``__str__()``, then ``__repr__()`` is also used when an\\n   \"informal\" string representation of instances of that class is\\n   required.\\n\\n   This is typically used for debugging, so it is important that the\\n   representation is information-rich and unambiguous.\\n\\nobject.__str__(self)\\n\\n   Called by ``str(object)`` and the built-in functions ``format()``\\n   and ``print()`` to compute the \"informal\" or nicely printable\\n   string representation of an object.  The return value must be a\\n   *string* object.\\n\\n   This method differs from ``object.__repr__()`` in that there is no\\n   expectation that ``__str__()`` return a valid Python expression: a\\n   more convenient or concise representation can be used.\\n\\n   The default implementation defined by the built-in type ``object``\\n   calls ``object.__repr__()``.\\n\\nobject.__bytes__(self)\\n\\n   Called by ``bytes()`` to compute a byte-string representation of an\\n   object. This should return a ``bytes`` object.\\n\\nobject.__format__(self, format_spec)\\n\\n   Called by the ``format()`` built-in function (and by extension, the\\n   ``str.format()`` method of class ``str``) to produce a \"formatted\"\\n   string representation of an object. The ``format_spec`` argument is\\n   a string that contains a description of the formatting options\\n   desired. The interpretation of the ``format_spec`` argument is up\\n   to the type implementing ``__format__()``, however most classes\\n   will either delegate formatting to one of the built-in types, or\\n   use a similar formatting option syntax.\\n\\n   See *Format Specification Mini-Language* for a description of the\\n   standard formatting syntax.\\n\\n   The return value must be a string object.\\n\\nobject.__lt__(self, other)\\nobject.__le__(self, other)\\nobject.__eq__(self, other)\\nobject.__ne__(self, other)\\nobject.__gt__(self, other)\\nobject.__ge__(self, other)\\n\\n   These are the so-called \"rich comparison\" methods. The\\n   correspondence between operator symbols and method names is as\\n   follows: ``x<y`` calls ``x.__lt__(y)``, ``x<=y`` calls\\n   ``x.__le__(y)``, ``x==y`` calls ``x.__eq__(y)``, ``x!=y`` calls\\n   ``x.__ne__(y)``, ``x>y`` calls ``x.__gt__(y)``, and ``x>=y`` calls\\n   ``x.__ge__(y)``.\\n\\n   A rich comparison method may return the singleton\\n   ``NotImplemented`` if it does not implement the operation for a\\n   given pair of arguments. By convention, ``False`` and ``True`` are\\n   returned for a successful comparison. However, these methods can\\n   return any value, so if the comparison operator is used in a\\n   Boolean context (e.g., in the condition of an ``if`` statement),\\n   Python will call ``bool()`` on the value to determine if the result\\n   is true or false.\\n\\n   There are no implied relationships among the comparison operators.\\n   The truth of ``x==y`` does not imply that ``x!=y`` is false.\\n   Accordingly, when defining ``__eq__()``, one should also define\\n   ``__ne__()`` so that the operators will behave as expected.  See\\n   the paragraph on ``__hash__()`` for some important notes on\\n   creating *hashable* objects which support custom comparison\\n   operations and are usable as dictionary keys.\\n\\n   There are no swapped-argument versions of these methods (to be used\\n   when the left argument does not support the operation but the right\\n   argument does); rather, ``__lt__()`` and ``__gt__()`` are each\\n   other\\'s reflection, ``__le__()`` and ``__ge__()`` are each other\\'s\\n   reflection, and ``__eq__()`` and ``__ne__()`` are their own\\n   reflection.\\n\\n   Arguments to rich comparison methods are never coerced.\\n\\n   To automatically generate ordering operations from a single root\\n   operation, see ``functools.total_ordering()``.\\n\\nobject.__hash__(self)\\n\\n   Called by built-in function ``hash()`` and for operations on\\n   members of hashed collections including ``set``, ``frozenset``, and\\n   ``dict``.  ``__hash__()`` should return an integer.  The only\\n   required property is that objects which compare equal have the same\\n   hash value; it is advised to somehow mix together (e.g. using\\n   exclusive or) the hash values for the components of the object that\\n   also play a part in comparison of objects.\\n\\n   If a class does not define an ``__eq__()`` method it should not\\n   define a ``__hash__()`` operation either; if it defines\\n   ``__eq__()`` but not ``__hash__()``, its instances will not be\\n   usable as items in hashable collections.  If a class defines\\n   mutable objects and implements an ``__eq__()`` method, it should\\n   not implement ``__hash__()``, since the implementation of hashable\\n   collections requires that a key\\'s hash value is immutable (if the\\n   object\\'s hash value changes, it will be in the wrong hash bucket).\\n\\n   User-defined classes have ``__eq__()`` and ``__hash__()`` methods\\n   by default; with them, all objects compare unequal (except with\\n   themselves) and ``x.__hash__()`` returns an appropriate value such\\n   that ``x == y`` implies both that ``x is y`` and ``hash(x) ==\\n   hash(y)``.\\n\\n   A class that overrides ``__eq__()`` and does not define\\n   ``__hash__()`` will have its ``__hash__()`` implicitly set to\\n   ``None``.  When the ``__hash__()`` method of a class is ``None``,\\n   instances of the class will raise an appropriate ``TypeError`` when\\n   a program attempts to retrieve their hash value, and will also be\\n   correctly identified as unhashable when checking ``isinstance(obj,\\n   collections.Hashable``).\\n\\n   If a class that overrides ``__eq__()`` needs to retain the\\n   implementation of ``__hash__()`` from a parent class, the\\n   interpreter must be told this explicitly by setting ``__hash__ =\\n   <ParentClass>.__hash__``.\\n\\n   If a class that does not override ``__eq__()`` wishes to suppress\\n   hash support, it should include ``__hash__ = None`` in the class\\n   definition. A class which defines its own ``__hash__()`` that\\n   explicitly raises a ``TypeError`` would be incorrectly identified\\n   as hashable by an ``isinstance(obj, collections.Hashable)`` call.\\n\\n   Note: By default, the ``__hash__()`` values of str, bytes and datetime\\n     objects are \"salted\" with an unpredictable random value.\\n     Although they remain constant within an individual Python\\n     process, they are not predictable between repeated invocations of\\n     Python.This is intended to provide protection against a denial-\\n     of-service caused by carefully-chosen inputs that exploit the\\n     worst case performance of a dict insertion, O(n^2) complexity.\\n     See http://www.ocert.org/advisories/ocert-2011-003.html for\\n     details.Changing hash values affects the iteration order of\\n     dicts, sets and other mappings.  Python has never made guarantees\\n     about this ordering (and it typically varies between 32-bit and\\n     64-bit builds).See also ``PYTHONHASHSEED``.\\n\\n   Changed in version 3.3: Hash randomization is enabled by default.\\n\\nobject.__bool__(self)\\n\\n   Called to implement truth value testing and the built-in operation\\n   ``bool()``; should return ``False`` or ``True``.  When this method\\n   is not defined, ``__len__()`` is called, if it is defined, and the\\n   object is considered true if its result is nonzero.  If a class\\n   defines neither ``__len__()`` nor ``__bool__()``, all its instances\\n   are considered true.\\n',\n'debugger':'\\n``pdb`` --- The Python Debugger\\n*******************************\\n\\nThe module ``pdb`` defines an interactive source code debugger for\\nPython programs.  It supports setting (conditional) breakpoints and\\nsingle stepping at the source line level, inspection of stack frames,\\nsource code listing, and evaluation of arbitrary Python code in the\\ncontext of any stack frame.  It also supports post-mortem debugging\\nand can be called under program control.\\n\\nThe debugger is extensible -- it is actually defined as the class\\n``Pdb``. This is currently undocumented but easily understood by\\nreading the source.  The extension interface uses the modules ``bdb``\\nand ``cmd``.\\n\\nThe debugger\\'s prompt is ``(Pdb)``. Typical usage to run a program\\nunder control of the debugger is:\\n\\n   >>> import pdb\\n   >>> import mymodule\\n   >>> pdb.run(\\'mymodule.test()\\')\\n   > <string>(0)?()\\n   (Pdb) continue\\n   > <string>(1)?()\\n   (Pdb) continue\\n   NameError: \\'spam\\'\\n   > <string>(1)?()\\n   (Pdb)\\n\\nChanged in version 3.3: Tab-completion via the ``readline`` module is\\navailable for commands and command arguments, e.g. the current global\\nand local names are offered as arguments of the ``print`` command.\\n\\n``pdb.py`` can also be invoked as a script to debug other scripts.\\nFor example:\\n\\n   python3 -m pdb myscript.py\\n\\nWhen invoked as a script, pdb will automatically enter post-mortem\\ndebugging if the program being debugged exits abnormally.  After post-\\nmortem debugging (or after normal exit of the program), pdb will\\nrestart the program.  Automatic restarting preserves pdb\\'s state (such\\nas breakpoints) and in most cases is more useful than quitting the\\ndebugger upon program\\'s exit.\\n\\nNew in version 3.2: ``pdb.py`` now accepts a ``-c`` option that\\nexecutes commands as if given in a ``.pdbrc`` file, see *Debugger\\nCommands*.\\n\\nThe typical usage to break into the debugger from a running program is\\nto insert\\n\\n   import pdb; pdb.set_trace()\\n\\nat the location you want to break into the debugger.  You can then\\nstep through the code following this statement, and continue running\\nwithout the debugger using the ``continue`` command.\\n\\nThe typical usage to inspect a crashed program is:\\n\\n   >>> import pdb\\n   >>> import mymodule\\n   >>> mymodule.test()\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 1, in ?\\n     File \"./mymodule.py\", line 4, in test\\n       test2()\\n     File \"./mymodule.py\", line 3, in test2\\n       print(spam)\\n   NameError: spam\\n   >>> pdb.pm()\\n   > ./mymodule.py(3)test2()\\n   -> print(spam)\\n   (Pdb)\\n\\nThe module defines the following functions; each enters the debugger\\nin a slightly different way:\\n\\npdb.run(statement, globals=None, locals=None)\\n\\n   Execute the *statement* (given as a string or a code object) under\\n   debugger control.  The debugger prompt appears before any code is\\n   executed; you can set breakpoints and type ``continue``, or you can\\n   step through the statement using ``step`` or ``next`` (all these\\n   commands are explained below).  The optional *globals* and *locals*\\n   arguments specify the environment in which the code is executed; by\\n   default the dictionary of the module ``__main__`` is used.  (See\\n   the explanation of the built-in ``exec()`` or ``eval()``\\n   functions.)\\n\\npdb.runeval(expression, globals=None, locals=None)\\n\\n   Evaluate the *expression* (given as a string or a code object)\\n   under debugger control.  When ``runeval()`` returns, it returns the\\n   value of the expression.  Otherwise this function is similar to\\n   ``run()``.\\n\\npdb.runcall(function, *args, **kwds)\\n\\n   Call the *function* (a function or method object, not a string)\\n   with the given arguments.  When ``runcall()`` returns, it returns\\n   whatever the function call returned.  The debugger prompt appears\\n   as soon as the function is entered.\\n\\npdb.set_trace()\\n\\n   Enter the debugger at the calling stack frame.  This is useful to\\n   hard-code a breakpoint at a given point in a program, even if the\\n   code is not otherwise being debugged (e.g. when an assertion\\n   fails).\\n\\npdb.post_mortem(traceback=None)\\n\\n   Enter post-mortem debugging of the given *traceback* object.  If no\\n   *traceback* is given, it uses the one of the exception that is\\n   currently being handled (an exception must be being handled if the\\n   default is to be used).\\n\\npdb.pm()\\n\\n   Enter post-mortem debugging of the traceback found in\\n   ``sys.last_traceback``.\\n\\nThe ``run*`` functions and ``set_trace()`` are aliases for\\ninstantiating the ``Pdb`` class and calling the method of the same\\nname.  If you want to access further features, you have to do this\\nyourself:\\n\\nclass class pdb.Pdb(completekey=\\'tab\\', stdin=None, stdout=None, skip=None, nosigint=False)\\n\\n   ``Pdb`` is the debugger class.\\n\\n   The *completekey*, *stdin* and *stdout* arguments are passed to the\\n   underlying ``cmd.Cmd`` class; see the description there.\\n\\n   The *skip* argument, if given, must be an iterable of glob-style\\n   module name patterns.  The debugger will not step into frames that\\n   originate in a module that matches one of these patterns. [1]\\n\\n   By default, Pdb sets a handler for the SIGINT signal (which is sent\\n   when the user presses Ctrl-C on the console) when you give a\\n   ``continue`` command. This allows you to break into the debugger\\n   again by pressing Ctrl-C.  If you want Pdb not to touch the SIGINT\\n   handler, set *nosigint* tot true.\\n\\n   Example call to enable tracing with *skip*:\\n\\n      import pdb; pdb.Pdb(skip=[\\'django.*\\']).set_trace()\\n\\n   New in version 3.1: The *skip* argument.\\n\\n   New in version 3.2: The *nosigint* argument.  Previously, a SIGINT\\n   handler was never set by Pdb.\\n\\n   run(statement, globals=None, locals=None)\\n   runeval(expression, globals=None, locals=None)\\n   runcall(function, *args, **kwds)\\n   set_trace()\\n\\n      See the documentation for the functions explained above.\\n\\n\\nDebugger Commands\\n=================\\n\\nThe commands recognized by the debugger are listed below.  Most\\ncommands can be abbreviated to one or two letters as indicated; e.g.\\n``h(elp)`` means that either ``h`` or ``help`` can be used to enter\\nthe help command (but not ``he`` or ``hel``, nor ``H`` or ``Help`` or\\n``HELP``).  Arguments to commands must be separated by whitespace\\n(spaces or tabs).  Optional arguments are enclosed in square brackets\\n(``[]``) in the command syntax; the square brackets must not be typed.\\nAlternatives in the command syntax are separated by a vertical bar\\n(``|``).\\n\\nEntering a blank line repeats the last command entered.  Exception: if\\nthe last command was a ``list`` command, the next 11 lines are listed.\\n\\nCommands that the debugger doesn\\'t recognize are assumed to be Python\\nstatements and are executed in the context of the program being\\ndebugged.  Python statements can also be prefixed with an exclamation\\npoint (``!``).  This is a powerful way to inspect the program being\\ndebugged; it is even possible to change a variable or call a function.\\nWhen an exception occurs in such a statement, the exception name is\\nprinted but the debugger\\'s state is not changed.\\n\\nThe debugger supports *aliases*.  Aliases can have parameters which\\nallows one a certain level of adaptability to the context under\\nexamination.\\n\\nMultiple commands may be entered on a single line, separated by\\n``;;``.  (A single ``;`` is not used as it is the separator for\\nmultiple commands in a line that is passed to the Python parser.)  No\\nintelligence is applied to separating the commands; the input is split\\nat the first ``;;`` pair, even if it is in the middle of a quoted\\nstring.\\n\\nIf a file ``.pdbrc`` exists in the user\\'s home directory or in the\\ncurrent directory, it is read in and executed as if it had been typed\\nat the debugger prompt.  This is particularly useful for aliases.  If\\nboth files exist, the one in the home directory is read first and\\naliases defined there can be overridden by the local file.\\n\\nChanged in version 3.2: ``.pdbrc`` can now contain commands that\\ncontinue debugging, such as ``continue`` or ``next``.  Previously,\\nthese commands had no effect.\\n\\nh(elp) [command]\\n\\n   Without argument, print the list of available commands.  With a\\n   *command* as argument, print help about that command.  ``help pdb``\\n   displays the full documentation (the docstring of the ``pdb``\\n   module).  Since the *command* argument must be an identifier,\\n   ``help exec`` must be entered to get help on the ``!`` command.\\n\\nw(here)\\n\\n   Print a stack trace, with the most recent frame at the bottom.  An\\n   arrow indicates the current frame, which determines the context of\\n   most commands.\\n\\nd(own) [count]\\n\\n   Move the current frame *count* (default one) levels down in the\\n   stack trace (to a newer frame).\\n\\nu(p) [count]\\n\\n   Move the current frame *count* (default one) levels up in the stack\\n   trace (to an older frame).\\n\\nb(reak) [([filename:]lineno | function) [, condition]]\\n\\n   With a *lineno* argument, set a break there in the current file.\\n   With a *function* argument, set a break at the first executable\\n   statement within that function.  The line number may be prefixed\\n   with a filename and a colon, to specify a breakpoint in another\\n   file (probably one that hasn\\'t been loaded yet).  The file is\\n   searched on ``sys.path``.  Note that each breakpoint is assigned a\\n   number to which all the other breakpoint commands refer.\\n\\n   If a second argument is present, it is an expression which must\\n   evaluate to true before the breakpoint is honored.\\n\\n   Without argument, list all breaks, including for each breakpoint,\\n   the number of times that breakpoint has been hit, the current\\n   ignore count, and the associated condition if any.\\n\\ntbreak [([filename:]lineno | function) [, condition]]\\n\\n   Temporary breakpoint, which is removed automatically when it is\\n   first hit. The arguments are the same as for ``break``.\\n\\ncl(ear) [filename:lineno | bpnumber [bpnumber ...]]\\n\\n   With a *filename:lineno* argument, clear all the breakpoints at\\n   this line. With a space separated list of breakpoint numbers, clear\\n   those breakpoints. Without argument, clear all breaks (but first\\n   ask confirmation).\\n\\ndisable [bpnumber [bpnumber ...]]\\n\\n   Disable the breakpoints given as a space separated list of\\n   breakpoint numbers.  Disabling a breakpoint means it cannot cause\\n   the program to stop execution, but unlike clearing a breakpoint, it\\n   remains in the list of breakpoints and can be (re-)enabled.\\n\\nenable [bpnumber [bpnumber ...]]\\n\\n   Enable the breakpoints specified.\\n\\nignore bpnumber [count]\\n\\n   Set the ignore count for the given breakpoint number.  If count is\\n   omitted, the ignore count is set to 0.  A breakpoint becomes active\\n   when the ignore count is zero.  When non-zero, the count is\\n   decremented each time the breakpoint is reached and the breakpoint\\n   is not disabled and any associated condition evaluates to true.\\n\\ncondition bpnumber [condition]\\n\\n   Set a new *condition* for the breakpoint, an expression which must\\n   evaluate to true before the breakpoint is honored.  If *condition*\\n   is absent, any existing condition is removed; i.e., the breakpoint\\n   is made unconditional.\\n\\ncommands [bpnumber]\\n\\n   Specify a list of commands for breakpoint number *bpnumber*.  The\\n   commands themselves appear on the following lines.  Type a line\\n   containing just ``end`` to terminate the commands. An example:\\n\\n      (Pdb) commands 1\\n      (com) print some_variable\\n      (com) end\\n      (Pdb)\\n\\n   To remove all commands from a breakpoint, type commands and follow\\n   it immediately with ``end``; that is, give no commands.\\n\\n   With no *bpnumber* argument, commands refers to the last breakpoint\\n   set.\\n\\n   You can use breakpoint commands to start your program up again.\\n   Simply use the continue command, or step, or any other command that\\n   resumes execution.\\n\\n   Specifying any command resuming execution (currently continue,\\n   step, next, return, jump, quit and their abbreviations) terminates\\n   the command list (as if that command was immediately followed by\\n   end). This is because any time you resume execution (even with a\\n   simple next or step), you may encounter another breakpoint--which\\n   could have its own command list, leading to ambiguities about which\\n   list to execute.\\n\\n   If you use the \\'silent\\' command in the command list, the usual\\n   message about stopping at a breakpoint is not printed.  This may be\\n   desirable for breakpoints that are to print a specific message and\\n   then continue.  If none of the other commands print anything, you\\n   see no sign that the breakpoint was reached.\\n\\ns(tep)\\n\\n   Execute the current line, stop at the first possible occasion\\n   (either in a function that is called or on the next line in the\\n   current function).\\n\\nn(ext)\\n\\n   Continue execution until the next line in the current function is\\n   reached or it returns.  (The difference between ``next`` and\\n   ``step`` is that ``step`` stops inside a called function, while\\n   ``next`` executes called functions at (nearly) full speed, only\\n   stopping at the next line in the current function.)\\n\\nunt(il) [lineno]\\n\\n   Without argument, continue execution until the line with a number\\n   greater than the current one is reached.\\n\\n   With a line number, continue execution until a line with a number\\n   greater or equal to that is reached.  In both cases, also stop when\\n   the current frame returns.\\n\\n   Changed in version 3.2: Allow giving an explicit line number.\\n\\nr(eturn)\\n\\n   Continue execution until the current function returns.\\n\\nc(ont(inue))\\n\\n   Continue execution, only stop when a breakpoint is encountered.\\n\\nj(ump) lineno\\n\\n   Set the next line that will be executed.  Only available in the\\n   bottom-most frame.  This lets you jump back and execute code again,\\n   or jump forward to skip code that you don\\'t want to run.\\n\\n   It should be noted that not all jumps are allowed -- for instance\\n   it is not possible to jump into the middle of a ``for`` loop or out\\n   of a ``finally`` clause.\\n\\nl(ist) [first[, last]]\\n\\n   List source code for the current file.  Without arguments, list 11\\n   lines around the current line or continue the previous listing.\\n   With ``.`` as argument, list 11 lines around the current line.\\n   With one argument, list 11 lines around at that line.  With two\\n   arguments, list the given range; if the second argument is less\\n   than the first, it is interpreted as a count.\\n\\n   The current line in the current frame is indicated by ``->``.  If\\n   an exception is being debugged, the line where the exception was\\n   originally raised or propagated is indicated by ``>>``, if it\\n   differs from the current line.\\n\\n   New in version 3.2: The ``>>`` marker.\\n\\nll | longlist\\n\\n   List all source code for the current function or frame.\\n   Interesting lines are marked as for ``list``.\\n\\n   New in version 3.2.\\n\\na(rgs)\\n\\n   Print the argument list of the current function.\\n\\np(rint) expression\\n\\n   Evaluate the *expression* in the current context and print its\\n   value.\\n\\npp expression\\n\\n   Like the ``print`` command, except the value of the expression is\\n   pretty-printed using the ``pprint`` module.\\n\\nwhatis expression\\n\\n   Print the type of the *expression*.\\n\\nsource expression\\n\\n   Try to get source code for the given object and display it.\\n\\n   New in version 3.2.\\n\\ndisplay [expression]\\n\\n   Display the value of the expression if it changed, each time\\n   execution stops in the current frame.\\n\\n   Without expression, list all display expressions for the current\\n   frame.\\n\\n   New in version 3.2.\\n\\nundisplay [expression]\\n\\n   Do not display the expression any more in the current frame.\\n   Without expression, clear all display expressions for the current\\n   frame.\\n\\n   New in version 3.2.\\n\\ninteract\\n\\n   Start an interative interpreter (using the ``code`` module) whose\\n   global namespace contains all the (global and local) names found in\\n   the current scope.\\n\\n   New in version 3.2.\\n\\nalias [name [command]]\\n\\n   Create an alias called *name* that executes *command*.  The command\\n   must *not* be enclosed in quotes.  Replaceable parameters can be\\n   indicated by ``%1``, ``%2``, and so on, while ``%*`` is replaced by\\n   all the parameters. If no command is given, the current alias for\\n   *name* is shown. If no arguments are given, all aliases are listed.\\n\\n   Aliases may be nested and can contain anything that can be legally\\n   typed at the pdb prompt.  Note that internal pdb commands *can* be\\n   overridden by aliases.  Such a command is then hidden until the\\n   alias is removed.  Aliasing is recursively applied to the first\\n   word of the command line; all other words in the line are left\\n   alone.\\n\\n   As an example, here are two useful aliases (especially when placed\\n   in the ``.pdbrc`` file):\\n\\n      # Print instance variables (usage \"pi classInst\")\\n      alias pi for k in %1.__dict__.keys(): print(\"%1.\",k,\"=\",%1.__dict__[k])\\n      # Print instance variables in self\\n      alias ps pi self\\n\\nunalias name\\n\\n   Delete the specified alias.\\n\\n! statement\\n\\n   Execute the (one-line) *statement* in the context of the current\\n   stack frame. The exclamation point can be omitted unless the first\\n   word of the statement resembles a debugger command.  To set a\\n   global variable, you can prefix the assignment command with a\\n   ``global`` statement on the same line, e.g.:\\n\\n      (Pdb) global list_options; list_options = [\\'-l\\']\\n      (Pdb)\\n\\nrun [args ...]\\nrestart [args ...]\\n\\n   Restart the debugged Python program.  If an argument is supplied,\\n   it is split with ``shlex`` and the result is used as the new\\n   ``sys.argv``. History, breakpoints, actions and debugger options\\n   are preserved. ``restart`` is an alias for ``run``.\\n\\nq(uit)\\n\\n   Quit from the debugger.  The program being executed is aborted.\\n\\n-[ Footnotes ]-\\n\\n[1] Whether a frame is considered to originate in a certain module is\\n    determined by the ``__name__`` in the frame globals.\\n',\n'del':'\\nThe ``del`` statement\\n*********************\\n\\n   del_stmt ::= \"del\" target_list\\n\\nDeletion is recursively defined very similar to the way assignment is\\ndefined. Rather than spelling it out in full details, here are some\\nhints.\\n\\nDeletion of a target list recursively deletes each target, from left\\nto right.\\n\\nDeletion of a name removes the binding of that name from the local or\\nglobal namespace, depending on whether the name occurs in a ``global``\\nstatement in the same code block.  If the name is unbound, a\\n``NameError`` exception will be raised.\\n\\nDeletion of attribute references, subscriptions and slicings is passed\\nto the primary object involved; deletion of a slicing is in general\\nequivalent to assignment of an empty slice of the right type (but even\\nthis is determined by the sliced object).\\n\\nChanged in version 3.2: Previously it was illegal to delete a name\\nfrom the local namespace if it occurs as a free variable in a nested\\nblock.\\n',\n'dict':'\\nDictionary displays\\n*******************\\n\\nA dictionary display is a possibly empty series of key/datum pairs\\nenclosed in curly braces:\\n\\n   dict_display       ::= \"{\" [key_datum_list | dict_comprehension] \"}\"\\n   key_datum_list     ::= key_datum (\",\" key_datum)* [\",\"]\\n   key_datum          ::= expression \":\" expression\\n   dict_comprehension ::= expression \":\" expression comp_for\\n\\nA dictionary display yields a new dictionary object.\\n\\nIf a comma-separated sequence of key/datum pairs is given, they are\\nevaluated from left to right to define the entries of the dictionary:\\neach key object is used as a key into the dictionary to store the\\ncorresponding datum.  This means that you can specify the same key\\nmultiple times in the key/datum list, and the final dictionary\\'s value\\nfor that key will be the last one given.\\n\\nA dict comprehension, in contrast to list and set comprehensions,\\nneeds two expressions separated with a colon followed by the usual\\n\"for\" and \"if\" clauses. When the comprehension is run, the resulting\\nkey and value elements are inserted in the new dictionary in the order\\nthey are produced.\\n\\nRestrictions on the types of the key values are listed earlier in\\nsection *The standard type hierarchy*.  (To summarize, the key type\\nshould be *hashable*, which excludes all mutable objects.)  Clashes\\nbetween duplicate keys are not detected; the last datum (textually\\nrightmost in the display) stored for a given key value prevails.\\n',\n'dynamic-features':'\\nInteraction with dynamic features\\n*********************************\\n\\nThere are several cases where Python statements are illegal when used\\nin conjunction with nested scopes that contain free variables.\\n\\nIf a variable is referenced in an enclosing scope, it is illegal to\\ndelete the name.  An error will be reported at compile time.\\n\\nIf the wild card form of import --- ``import *`` --- is used in a\\nfunction and the function contains or is a nested block with free\\nvariables, the compiler will raise a ``SyntaxError``.\\n\\nThe ``eval()`` and ``exec()`` functions do not have access to the full\\nenvironment for resolving names.  Names may be resolved in the local\\nand global namespaces of the caller.  Free variables are not resolved\\nin the nearest enclosing namespace, but in the global namespace.  [1]\\nThe ``exec()`` and ``eval()`` functions have optional arguments to\\noverride the global and local namespace.  If only one namespace is\\nspecified, it is used for both.\\n',\n'else':'\\nThe ``if`` statement\\n********************\\n\\nThe ``if`` statement is used for conditional execution:\\n\\n   if_stmt ::= \"if\" expression \":\" suite\\n               ( \"elif\" expression \":\" suite )*\\n               [\"else\" \":\" suite]\\n\\nIt selects exactly one of the suites by evaluating the expressions one\\nby one until one is found to be true (see section *Boolean operations*\\nfor the definition of true and false); then that suite is executed\\n(and no other part of the ``if`` statement is executed or evaluated).\\nIf all expressions are false, the suite of the ``else`` clause, if\\npresent, is executed.\\n',\n'exceptions':'\\nExceptions\\n**********\\n\\nExceptions are a means of breaking out of the normal flow of control\\nof a code block in order to handle errors or other exceptional\\nconditions.  An exception is *raised* at the point where the error is\\ndetected; it may be *handled* by the surrounding code block or by any\\ncode block that directly or indirectly invoked the code block where\\nthe error occurred.\\n\\nThe Python interpreter raises an exception when it detects a run-time\\nerror (such as division by zero).  A Python program can also\\nexplicitly raise an exception with the ``raise`` statement. Exception\\nhandlers are specified with the ``try`` ... ``except`` statement.  The\\n``finally`` clause of such a statement can be used to specify cleanup\\ncode which does not handle the exception, but is executed whether an\\nexception occurred or not in the preceding code.\\n\\nPython uses the \"termination\" model of error handling: an exception\\nhandler can find out what happened and continue execution at an outer\\nlevel, but it cannot repair the cause of the error and retry the\\nfailing operation (except by re-entering the offending piece of code\\nfrom the top).\\n\\nWhen an exception is not handled at all, the interpreter terminates\\nexecution of the program, or returns to its interactive main loop.  In\\neither case, it prints a stack backtrace, except when the exception is\\n``SystemExit``.\\n\\nExceptions are identified by class instances.  The ``except`` clause\\nis selected depending on the class of the instance: it must reference\\nthe class of the instance or a base class thereof.  The instance can\\nbe received by the handler and can carry additional information about\\nthe exceptional condition.\\n\\nNote: Exception messages are not part of the Python API.  Their contents\\n  may change from one version of Python to the next without warning\\n  and should not be relied on by code which will run under multiple\\n  versions of the interpreter.\\n\\nSee also the description of the ``try`` statement in section *The try\\nstatement* and ``raise`` statement in section *The raise statement*.\\n\\n-[ Footnotes ]-\\n\\n[1] This limitation occurs because the code that is executed by these\\n    operations is not available at the time the module is compiled.\\n',\n'execmodel':'\\nExecution model\\n***************\\n\\n\\nNaming and binding\\n==================\\n\\n*Names* refer to objects.  Names are introduced by name binding\\noperations. Each occurrence of a name in the program text refers to\\nthe *binding* of that name established in the innermost function block\\ncontaining the use.\\n\\nA *block* is a piece of Python program text that is executed as a\\nunit. The following are blocks: a module, a function body, and a class\\ndefinition. Each command typed interactively is a block.  A script\\nfile (a file given as standard input to the interpreter or specified\\non the interpreter command line the first argument) is a code block.\\nA script command (a command specified on the interpreter command line\\nwith the \\'**-c**\\' option) is a code block.  The string argument passed\\nto the built-in functions ``eval()`` and ``exec()`` is a code block.\\n\\nA code block is executed in an *execution frame*.  A frame contains\\nsome administrative information (used for debugging) and determines\\nwhere and how execution continues after the code block\\'s execution has\\ncompleted.\\n\\nA *scope* defines the visibility of a name within a block.  If a local\\nvariable is defined in a block, its scope includes that block.  If the\\ndefinition occurs in a function block, the scope extends to any blocks\\ncontained within the defining one, unless a contained block introduces\\na different binding for the name.  The scope of names defined in a\\nclass block is limited to the class block; it does not extend to the\\ncode blocks of methods -- this includes comprehensions and generator\\nexpressions since they are implemented using a function scope.  This\\nmeans that the following will fail:\\n\\n   class A:\\n       a = 42\\n       b = list(a + i for i in range(10))\\n\\nWhen a name is used in a code block, it is resolved using the nearest\\nenclosing scope.  The set of all such scopes visible to a code block\\nis called the block\\'s *environment*.\\n\\nIf a name is bound in a block, it is a local variable of that block,\\nunless declared as ``nonlocal``.  If a name is bound at the module\\nlevel, it is a global variable.  (The variables of the module code\\nblock are local and global.)  If a variable is used in a code block\\nbut not defined there, it is a *free variable*.\\n\\nWhen a name is not found at all, a ``NameError`` exception is raised.\\nIf the name refers to a local variable that has not been bound, a\\n``UnboundLocalError`` exception is raised.  ``UnboundLocalError`` is a\\nsubclass of ``NameError``.\\n\\nThe following constructs bind names: formal parameters to functions,\\n``import`` statements, class and function definitions (these bind the\\nclass or function name in the defining block), and targets that are\\nidentifiers if occurring in an assignment, ``for`` loop header, or\\nafter ``as`` in a ``with`` statement or ``except`` clause. The\\n``import`` statement of the form ``from ... import *`` binds all names\\ndefined in the imported module, except those beginning with an\\nunderscore.  This form may only be used at the module level.\\n\\nA target occurring in a ``del`` statement is also considered bound for\\nthis purpose (though the actual semantics are to unbind the name).\\n\\nEach assignment or import statement occurs within a block defined by a\\nclass or function definition or at the module level (the top-level\\ncode block).\\n\\nIf a name binding operation occurs anywhere within a code block, all\\nuses of the name within the block are treated as references to the\\ncurrent block.  This can lead to errors when a name is used within a\\nblock before it is bound.  This rule is subtle.  Python lacks\\ndeclarations and allows name binding operations to occur anywhere\\nwithin a code block.  The local variables of a code block can be\\ndetermined by scanning the entire text of the block for name binding\\noperations.\\n\\nIf the ``global`` statement occurs within a block, all uses of the\\nname specified in the statement refer to the binding of that name in\\nthe top-level namespace.  Names are resolved in the top-level\\nnamespace by searching the global namespace, i.e. the namespace of the\\nmodule containing the code block, and the builtins namespace, the\\nnamespace of the module ``builtins``.  The global namespace is\\nsearched first.  If the name is not found there, the builtins\\nnamespace is searched.  The global statement must precede all uses of\\nthe name.\\n\\nThe builtins namespace associated with the execution of a code block\\nis actually found by looking up the name ``__builtins__`` in its\\nglobal namespace; this should be a dictionary or a module (in the\\nlatter case the module\\'s dictionary is used).  By default, when in the\\n``__main__`` module, ``__builtins__`` is the built-in module\\n``builtins``; when in any other module, ``__builtins__`` is an alias\\nfor the dictionary of the ``builtins`` module itself.\\n``__builtins__`` can be set to a user-created dictionary to create a\\nweak form of restricted execution.\\n\\n**CPython implementation detail:** Users should not touch\\n``__builtins__``; it is strictly an implementation detail.  Users\\nwanting to override values in the builtins namespace should ``import``\\nthe ``builtins`` module and modify its attributes appropriately.\\n\\nThe namespace for a module is automatically created the first time a\\nmodule is imported.  The main module for a script is always called\\n``__main__``.\\n\\nThe ``global`` statement has the same scope as a name binding\\noperation in the same block.  If the nearest enclosing scope for a\\nfree variable contains a global statement, the free variable is\\ntreated as a global.\\n\\nA class definition is an executable statement that may use and define\\nnames. These references follow the normal rules for name resolution.\\nThe namespace of the class definition becomes the attribute dictionary\\nof the class.  Names defined at the class scope are not visible in\\nmethods.\\n\\n\\nInteraction with dynamic features\\n---------------------------------\\n\\nThere are several cases where Python statements are illegal when used\\nin conjunction with nested scopes that contain free variables.\\n\\nIf a variable is referenced in an enclosing scope, it is illegal to\\ndelete the name.  An error will be reported at compile time.\\n\\nIf the wild card form of import --- ``import *`` --- is used in a\\nfunction and the function contains or is a nested block with free\\nvariables, the compiler will raise a ``SyntaxError``.\\n\\nThe ``eval()`` and ``exec()`` functions do not have access to the full\\nenvironment for resolving names.  Names may be resolved in the local\\nand global namespaces of the caller.  Free variables are not resolved\\nin the nearest enclosing namespace, but in the global namespace.  [1]\\nThe ``exec()`` and ``eval()`` functions have optional arguments to\\noverride the global and local namespace.  If only one namespace is\\nspecified, it is used for both.\\n\\n\\nExceptions\\n==========\\n\\nExceptions are a means of breaking out of the normal flow of control\\nof a code block in order to handle errors or other exceptional\\nconditions.  An exception is *raised* at the point where the error is\\ndetected; it may be *handled* by the surrounding code block or by any\\ncode block that directly or indirectly invoked the code block where\\nthe error occurred.\\n\\nThe Python interpreter raises an exception when it detects a run-time\\nerror (such as division by zero).  A Python program can also\\nexplicitly raise an exception with the ``raise`` statement. Exception\\nhandlers are specified with the ``try`` ... ``except`` statement.  The\\n``finally`` clause of such a statement can be used to specify cleanup\\ncode which does not handle the exception, but is executed whether an\\nexception occurred or not in the preceding code.\\n\\nPython uses the \"termination\" model of error handling: an exception\\nhandler can find out what happened and continue execution at an outer\\nlevel, but it cannot repair the cause of the error and retry the\\nfailing operation (except by re-entering the offending piece of code\\nfrom the top).\\n\\nWhen an exception is not handled at all, the interpreter terminates\\nexecution of the program, or returns to its interactive main loop.  In\\neither case, it prints a stack backtrace, except when the exception is\\n``SystemExit``.\\n\\nExceptions are identified by class instances.  The ``except`` clause\\nis selected depending on the class of the instance: it must reference\\nthe class of the instance or a base class thereof.  The instance can\\nbe received by the handler and can carry additional information about\\nthe exceptional condition.\\n\\nNote: Exception messages are not part of the Python API.  Their contents\\n  may change from one version of Python to the next without warning\\n  and should not be relied on by code which will run under multiple\\n  versions of the interpreter.\\n\\nSee also the description of the ``try`` statement in section *The try\\nstatement* and ``raise`` statement in section *The raise statement*.\\n\\n-[ Footnotes ]-\\n\\n[1] This limitation occurs because the code that is executed by these\\n    operations is not available at the time the module is compiled.\\n',\n'exprlists':'\\nExpression lists\\n****************\\n\\n   expression_list ::= expression ( \",\" expression )* [\",\"]\\n\\nAn expression list containing at least one comma yields a tuple.  The\\nlength of the tuple is the number of expressions in the list.  The\\nexpressions are evaluated from left to right.\\n\\nThe trailing comma is required only to create a single tuple (a.k.a. a\\n*singleton*); it is optional in all other cases.  A single expression\\nwithout a trailing comma doesn\\'t create a tuple, but rather yields the\\nvalue of that expression. (To create an empty tuple, use an empty pair\\nof parentheses: ``()``.)\\n',\n'floating':'\\nFloating point literals\\n***********************\\n\\nFloating point literals are described by the following lexical\\ndefinitions:\\n\\n   floatnumber   ::= pointfloat | exponentfloat\\n   pointfloat    ::= [intpart] fraction | intpart \".\"\\n   exponentfloat ::= (intpart | pointfloat) exponent\\n   intpart       ::= digit+\\n   fraction      ::= \".\" digit+\\n   exponent      ::= (\"e\" | \"E\") [\"+\" | \"-\"] digit+\\n\\nNote that the integer and exponent parts are always interpreted using\\nradix 10. For example, ``077e010`` is legal, and denotes the same\\nnumber as ``77e10``. The allowed range of floating point literals is\\nimplementation-dependent. Some examples of floating point literals:\\n\\n   3.14    10.    .001    1e100    3.14e-10    0e0\\n\\nNote that numeric literals do not include a sign; a phrase like ``-1``\\nis actually an expression composed of the unary operator ``-`` and the\\nliteral ``1``.\\n',\n'for':'\\nThe ``for`` statement\\n*********************\\n\\nThe ``for`` statement is used to iterate over the elements of a\\nsequence (such as a string, tuple or list) or other iterable object:\\n\\n   for_stmt ::= \"for\" target_list \"in\" expression_list \":\" suite\\n                [\"else\" \":\" suite]\\n\\nThe expression list is evaluated once; it should yield an iterable\\nobject.  An iterator is created for the result of the\\n``expression_list``.  The suite is then executed once for each item\\nprovided by the iterator, in the order of ascending indices.  Each\\nitem in turn is assigned to the target list using the standard rules\\nfor assignments (see *Assignment statements*), and then the suite is\\nexecuted.  When the items are exhausted (which is immediately when the\\nsequence is empty or an iterator raises a ``StopIteration``\\nexception), the suite in the ``else`` clause, if present, is executed,\\nand the loop terminates.\\n\\nA ``break`` statement executed in the first suite terminates the loop\\nwithout executing the ``else`` clause\\'s suite.  A ``continue``\\nstatement executed in the first suite skips the rest of the suite and\\ncontinues with the next item, or with the ``else`` clause if there was\\nno next item.\\n\\nThe suite may assign to the variable(s) in the target list; this does\\nnot affect the next item assigned to it.\\n\\nNames in the target list are not deleted when the loop is finished,\\nbut if the sequence is empty, it will not have been assigned to at all\\nby the loop.  Hint: the built-in function ``range()`` returns an\\niterator of integers suitable to emulate the effect of Pascal\\'s ``for\\ni := a to b do``; e.g., ``list(range(3))`` returns the list ``[0, 1,\\n2]``.\\n\\nNote: There is a subtlety when the sequence is being modified by the loop\\n  (this can only occur for mutable sequences, i.e. lists).  An\\n  internal counter is used to keep track of which item is used next,\\n  and this is incremented on each iteration.  When this counter has\\n  reached the length of the sequence the loop terminates.  This means\\n  that if the suite deletes the current (or a previous) item from the\\n  sequence, the next item will be skipped (since it gets the index of\\n  the current item which has already been treated).  Likewise, if the\\n  suite inserts an item in the sequence before the current item, the\\n  current item will be treated again the next time through the loop.\\n  This can lead to nasty bugs that can be avoided by making a\\n  temporary copy using a slice of the whole sequence, e.g.,\\n\\n     for x in a[:]:\\n         if x < 0: a.remove(x)\\n',\n'formatstrings':'\\nFormat String Syntax\\n********************\\n\\nThe ``str.format()`` method and the ``Formatter`` class share the same\\nsyntax for format strings (although in the case of ``Formatter``,\\nsubclasses can define their own format string syntax).\\n\\nFormat strings contain \"replacement fields\" surrounded by curly braces\\n``{}``. Anything that is not contained in braces is considered literal\\ntext, which is copied unchanged to the output.  If you need to include\\na brace character in the literal text, it can be escaped by doubling:\\n``{{`` and ``}}``.\\n\\nThe grammar for a replacement field is as follows:\\n\\n      replacement_field ::= \"{\" [field_name] [\"!\" conversion] [\":\" format_spec] \"}\"\\n      field_name        ::= arg_name (\".\" attribute_name | \"[\" element_index \"]\")*\\n      arg_name          ::= [identifier | integer]\\n      attribute_name    ::= identifier\\n      element_index     ::= integer | index_string\\n      index_string      ::= <any source character except \"]\"> +\\n      conversion        ::= \"r\" | \"s\" | \"a\"\\n      format_spec       ::= <described in the next section>\\n\\nIn less formal terms, the replacement field can start with a\\n*field_name* that specifies the object whose value is to be formatted\\nand inserted into the output instead of the replacement field. The\\n*field_name* is optionally followed by a  *conversion* field, which is\\npreceded by an exclamation point ``\\'!\\'``, and a *format_spec*, which\\nis preceded by a colon ``\\':\\'``.  These specify a non-default format\\nfor the replacement value.\\n\\nSee also the *Format Specification Mini-Language* section.\\n\\nThe *field_name* itself begins with an *arg_name* that is either a\\nnumber or a keyword.  If it\\'s a number, it refers to a positional\\nargument, and if it\\'s a keyword, it refers to a named keyword\\nargument.  If the numerical arg_names in a format string are 0, 1, 2,\\n... in sequence, they can all be omitted (not just some) and the\\nnumbers 0, 1, 2, ... will be automatically inserted in that order.\\nBecause *arg_name* is not quote-delimited, it is not possible to\\nspecify arbitrary dictionary keys (e.g., the strings ``\\'10\\'`` or\\n``\\':-]\\'``) within a format string. The *arg_name* can be followed by\\nany number of index or attribute expressions. An expression of the\\nform ``\\'.name\\'`` selects the named attribute using ``getattr()``,\\nwhile an expression of the form ``\\'[index]\\'`` does an index lookup\\nusing ``__getitem__()``.\\n\\nChanged in version 3.1: The positional argument specifiers can be\\nomitted, so ``\\'{} {}\\'`` is equivalent to ``\\'{0} {1}\\'``.\\n\\nSome simple format string examples:\\n\\n   \"First, thou shalt count to {0}\" # References first positional argument\\n   \"Bring me a {}\"                  # Implicitly references the first positional argument\\n   \"From {} to {}\"                  # Same as \"From {0} to {1}\"\\n   \"My quest is {name}\"             # References keyword argument \\'name\\'\\n   \"Weight in tons {0.weight}\"      # \\'weight\\' attribute of first positional arg\\n   \"Units destroyed: {players[0]}\"  # First element of keyword argument \\'players\\'.\\n\\nThe *conversion* field causes a type coercion before formatting.\\nNormally, the job of formatting a value is done by the\\n``__format__()`` method of the value itself.  However, in some cases\\nit is desirable to force a type to be formatted as a string,\\noverriding its own definition of formatting.  By converting the value\\nto a string before calling ``__format__()``, the normal formatting\\nlogic is bypassed.\\n\\nThree conversion flags are currently supported: ``\\'!s\\'`` which calls\\n``str()`` on the value, ``\\'!r\\'`` which calls ``repr()`` and ``\\'!a\\'``\\nwhich calls ``ascii()``.\\n\\nSome examples:\\n\\n   \"Harold\\'s a clever {0!s}\"        # Calls str() on the argument first\\n   \"Bring out the holy {name!r}\"    # Calls repr() on the argument first\\n   \"More {!a}\"                      # Calls ascii() on the argument first\\n\\nThe *format_spec* field contains a specification of how the value\\nshould be presented, including such details as field width, alignment,\\npadding, decimal precision and so on.  Each value type can define its\\nown \"formatting mini-language\" or interpretation of the *format_spec*.\\n\\nMost built-in types support a common formatting mini-language, which\\nis described in the next section.\\n\\nA *format_spec* field can also include nested replacement fields\\nwithin it. These nested replacement fields can contain only a field\\nname; conversion flags and format specifications are not allowed.  The\\nreplacement fields within the format_spec are substituted before the\\n*format_spec* string is interpreted. This allows the formatting of a\\nvalue to be dynamically specified.\\n\\nSee the *Format examples* section for some examples.\\n\\n\\nFormat Specification Mini-Language\\n==================================\\n\\n\"Format specifications\" are used within replacement fields contained\\nwithin a format string to define how individual values are presented\\n(see *Format String Syntax*).  They can also be passed directly to the\\nbuilt-in ``format()`` function.  Each formattable type may define how\\nthe format specification is to be interpreted.\\n\\nMost built-in types implement the following options for format\\nspecifications, although some of the formatting options are only\\nsupported by the numeric types.\\n\\nA general convention is that an empty format string (``\"\"``) produces\\nthe same result as if you had called ``str()`` on the value. A non-\\nempty format string typically modifies the result.\\n\\nThe general form of a *standard format specifier* is:\\n\\n   format_spec ::= [[fill]align][sign][#][0][width][,][.precision][type]\\n   fill        ::= <a character other than \\'{\\' or \\'}\\'>\\n   align       ::= \"<\" | \">\" | \"=\" | \"^\"\\n   sign        ::= \"+\" | \"-\" | \" \"\\n   width       ::= integer\\n   precision   ::= integer\\n   type        ::= \"b\" | \"c\" | \"d\" | \"e\" | \"E\" | \"f\" | \"F\" | \"g\" | \"G\" | \"n\" | \"o\" | \"s\" | \"x\" | \"X\" | \"%\"\\n\\nThe *fill* character can be any character other than \\'{\\' or \\'}\\'.  The\\npresence of a fill character is signaled by the character following\\nit, which must be one of the alignment options.  If the second\\ncharacter of *format_spec* is not a valid alignment option, then it is\\nassumed that both the fill character and the alignment option are\\nabsent.\\n\\nThe meaning of the various alignment options is as follows:\\n\\n   +-----------+------------------------------------------------------------+\\n   | Option    | Meaning                                                    |\\n   +===========+============================================================+\\n   | ``\\'<\\'``   | Forces the field to be left-aligned within the available   |\\n   |           | space (this is the default for most objects).              |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'>\\'``   | Forces the field to be right-aligned within the available  |\\n   |           | space (this is the default for numbers).                   |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'=\\'``   | Forces the padding to be placed after the sign (if any)    |\\n   |           | but before the digits.  This is used for printing fields   |\\n   |           | in the form \\'+000000120\\'. This alignment option is only    |\\n   |           | valid for numeric types.                                   |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'^\\'``   | Forces the field to be centered within the available       |\\n   |           | space.                                                     |\\n   +-----------+------------------------------------------------------------+\\n\\nNote that unless a minimum field width is defined, the field width\\nwill always be the same size as the data to fill it, so that the\\nalignment option has no meaning in this case.\\n\\nThe *sign* option is only valid for number types, and can be one of\\nthe following:\\n\\n   +-----------+------------------------------------------------------------+\\n   | Option    | Meaning                                                    |\\n   +===========+============================================================+\\n   | ``\\'+\\'``   | indicates that a sign should be used for both positive as  |\\n   |           | well as negative numbers.                                  |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'-\\'``   | indicates that a sign should be used only for negative     |\\n   |           | numbers (this is the default behavior).                    |\\n   +-----------+------------------------------------------------------------+\\n   | space     | indicates that a leading space should be used on positive  |\\n   |           | numbers, and a minus sign on negative numbers.             |\\n   +-----------+------------------------------------------------------------+\\n\\nThe ``\\'#\\'`` option causes the \"alternate form\" to be used for the\\nconversion.  The alternate form is defined differently for different\\ntypes.  This option is only valid for integer, float, complex and\\nDecimal types. For integers, when binary, octal, or hexadecimal output\\nis used, this option adds the prefix respective ``\\'0b\\'``, ``\\'0o\\'``, or\\n``\\'0x\\'`` to the output value. For floats, complex and Decimal the\\nalternate form causes the result of the conversion to always contain a\\ndecimal-point character, even if no digits follow it. Normally, a\\ndecimal-point character appears in the result of these conversions\\nonly if a digit follows it. In addition, for ``\\'g\\'`` and ``\\'G\\'``\\nconversions, trailing zeros are not removed from the result.\\n\\nThe ``\\',\\'`` option signals the use of a comma for a thousands\\nseparator. For a locale aware separator, use the ``\\'n\\'`` integer\\npresentation type instead.\\n\\nChanged in version 3.1: Added the ``\\',\\'`` option (see also **PEP\\n378**).\\n\\n*width* is a decimal integer defining the minimum field width.  If not\\nspecified, then the field width will be determined by the content.\\n\\nPreceding the *width* field by a zero (``\\'0\\'``) character enables\\nsign-aware zero-padding for numeric types.  This is equivalent to a\\n*fill* character of ``\\'0\\'`` with an *alignment* type of ``\\'=\\'``.\\n\\nThe *precision* is a decimal number indicating how many digits should\\nbe displayed after the decimal point for a floating point value\\nformatted with ``\\'f\\'`` and ``\\'F\\'``, or before and after the decimal\\npoint for a floating point value formatted with ``\\'g\\'`` or ``\\'G\\'``.\\nFor non-number types the field indicates the maximum field size - in\\nother words, how many characters will be used from the field content.\\nThe *precision* is not allowed for integer values.\\n\\nFinally, the *type* determines how the data should be presented.\\n\\nThe available string presentation types are:\\n\\n   +-----------+------------------------------------------------------------+\\n   | Type      | Meaning                                                    |\\n   +===========+============================================================+\\n   | ``\\'s\\'``   | String format. This is the default type for strings and    |\\n   |           | may be omitted.                                            |\\n   +-----------+------------------------------------------------------------+\\n   | None      | The same as ``\\'s\\'``.                                       |\\n   +-----------+------------------------------------------------------------+\\n\\nThe available integer presentation types are:\\n\\n   +-----------+------------------------------------------------------------+\\n   | Type      | Meaning                                                    |\\n   +===========+============================================================+\\n   | ``\\'b\\'``   | Binary format. Outputs the number in base 2.               |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'c\\'``   | Character. Converts the integer to the corresponding       |\\n   |           | unicode character before printing.                         |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'d\\'``   | Decimal Integer. Outputs the number in base 10.            |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'o\\'``   | Octal format. Outputs the number in base 8.                |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'x\\'``   | Hex format. Outputs the number in base 16, using lower-    |\\n   |           | case letters for the digits above 9.                       |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'X\\'``   | Hex format. Outputs the number in base 16, using upper-    |\\n   |           | case letters for the digits above 9.                       |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'n\\'``   | Number. This is the same as ``\\'d\\'``, except that it uses   |\\n   |           | the current locale setting to insert the appropriate       |\\n   |           | number separator characters.                               |\\n   +-----------+------------------------------------------------------------+\\n   | None      | The same as ``\\'d\\'``.                                       |\\n   +-----------+------------------------------------------------------------+\\n\\nIn addition to the above presentation types, integers can be formatted\\nwith the floating point presentation types listed below (except\\n``\\'n\\'`` and None). When doing so, ``float()`` is used to convert the\\ninteger to a floating point number before formatting.\\n\\nThe available presentation types for floating point and decimal values\\nare:\\n\\n   +-----------+------------------------------------------------------------+\\n   | Type      | Meaning                                                    |\\n   +===========+============================================================+\\n   | ``\\'e\\'``   | Exponent notation. Prints the number in scientific         |\\n   |           | notation using the letter \\'e\\' to indicate the exponent.    |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'E\\'``   | Exponent notation. Same as ``\\'e\\'`` except it uses an upper |\\n   |           | case \\'E\\' as the separator character.                       |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'f\\'``   | Fixed point. Displays the number as a fixed-point number.  |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'F\\'``   | Fixed point. Same as ``\\'f\\'``, but converts ``nan`` to      |\\n   |           | ``NAN`` and ``inf`` to ``INF``.                            |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'g\\'``   | General format.  For a given precision ``p >= 1``, this    |\\n   |           | rounds the number to ``p`` significant digits and then     |\\n   |           | formats the result in either fixed-point format or in      |\\n   |           | scientific notation, depending on its magnitude.  The      |\\n   |           | precise rules are as follows: suppose that the result      |\\n   |           | formatted with presentation type ``\\'e\\'`` and precision     |\\n   |           | ``p-1`` would have exponent ``exp``.  Then if ``-4 <= exp  |\\n   |           | < p``, the number is formatted with presentation type      |\\n   |           | ``\\'f\\'`` and precision ``p-1-exp``. Otherwise, the number   |\\n   |           | is formatted with presentation type ``\\'e\\'`` and precision  |\\n   |           | ``p-1``. In both cases insignificant trailing zeros are    |\\n   |           | removed from the significand, and the decimal point is     |\\n   |           | also removed if there are no remaining digits following    |\\n   |           | it.  Positive and negative infinity, positive and negative |\\n   |           | zero, and nans, are formatted as ``inf``, ``-inf``, ``0``, |\\n   |           | ``-0`` and ``nan`` respectively, regardless of the         |\\n   |           | precision.  A precision of ``0`` is treated as equivalent  |\\n   |           | to a precision of ``1``.                                   |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'G\\'``   | General format. Same as ``\\'g\\'`` except switches to ``\\'E\\'`` |\\n   |           | if the number gets too large. The representations of       |\\n   |           | infinity and NaN are uppercased, too.                      |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'n\\'``   | Number. This is the same as ``\\'g\\'``, except that it uses   |\\n   |           | the current locale setting to insert the appropriate       |\\n   |           | number separator characters.                               |\\n   +-----------+------------------------------------------------------------+\\n   | ``\\'%\\'``   | Percentage. Multiplies the number by 100 and displays in   |\\n   |           | fixed (``\\'f\\'``) format, followed by a percent sign.        |\\n   +-----------+------------------------------------------------------------+\\n   | None      | Similar to ``\\'g\\'``, except with at least one digit past    |\\n   |           | the decimal point and a default precision of 12. This is   |\\n   |           | intended to match ``str()``, except you can add the other  |\\n   |           | format modifiers.                                          |\\n   +-----------+------------------------------------------------------------+\\n\\n\\nFormat examples\\n===============\\n\\nThis section contains examples of the new format syntax and comparison\\nwith the old ``%``-formatting.\\n\\nIn most of the cases the syntax is similar to the old\\n``%``-formatting, with the addition of the ``{}`` and with ``:`` used\\ninstead of ``%``. For example, ``\\'%03.2f\\'`` can be translated to\\n``\\'{:03.2f}\\'``.\\n\\nThe new format syntax also supports new and different options, shown\\nin the follow examples.\\n\\nAccessing arguments by position:\\n\\n   >>> \\'{0}, {1}, {2}\\'.format(\\'a\\', \\'b\\', \\'c\\')\\n   \\'a, b, c\\'\\n   >>> \\'{}, {}, {}\\'.format(\\'a\\', \\'b\\', \\'c\\')  # 3.1+ only\\n   \\'a, b, c\\'\\n   >>> \\'{2}, {1}, {0}\\'.format(\\'a\\', \\'b\\', \\'c\\')\\n   \\'c, b, a\\'\\n   >>> \\'{2}, {1}, {0}\\'.format(*\\'abc\\')      # unpacking argument sequence\\n   \\'c, b, a\\'\\n   >>> \\'{0}{1}{0}\\'.format(\\'abra\\', \\'cad\\')   # arguments\\' indices can be repeated\\n   \\'abracadabra\\'\\n\\nAccessing arguments by name:\\n\\n   >>> \\'Coordinates: {latitude}, {longitude}\\'.format(latitude=\\'37.24N\\', longitude=\\'-115.81W\\')\\n   \\'Coordinates: 37.24N, -115.81W\\'\\n   >>> coord = {\\'latitude\\': \\'37.24N\\', \\'longitude\\': \\'-115.81W\\'}\\n   >>> \\'Coordinates: {latitude}, {longitude}\\'.format(**coord)\\n   \\'Coordinates: 37.24N, -115.81W\\'\\n\\nAccessing arguments\\' attributes:\\n\\n   >>> c = 3-5j\\n   >>> (\\'The complex number {0} is formed from the real part {0.real} \\'\\n   ...  \\'and the imaginary part {0.imag}.\\').format(c)\\n   \\'The complex number (3-5j) is formed from the real part 3.0 and the imaginary part -5.0.\\'\\n   >>> class Point:\\n   ...     def __init__(self, x, y):\\n   ...         self.x, self.y = x, y\\n   ...     def __str__(self):\\n   ...         return \\'Point({self.x}, {self.y})\\'.format(self=self)\\n   ...\\n   >>> str(Point(4, 2))\\n   \\'Point(4, 2)\\'\\n\\nAccessing arguments\\' items:\\n\\n   >>> coord = (3, 5)\\n   >>> \\'X: {0[0]};  Y: {0[1]}\\'.format(coord)\\n   \\'X: 3;  Y: 5\\'\\n\\nReplacing ``%s`` and ``%r``:\\n\\n   >>> \"repr() shows quotes: {!r}; str() doesn\\'t: {!s}\".format(\\'test1\\', \\'test2\\')\\n   \"repr() shows quotes: \\'test1\\'; str() doesn\\'t: test2\"\\n\\nAligning the text and specifying a width:\\n\\n   >>> \\'{:<30}\\'.format(\\'left aligned\\')\\n   \\'left aligned                  \\'\\n   >>> \\'{:>30}\\'.format(\\'right aligned\\')\\n   \\'                 right aligned\\'\\n   >>> \\'{:^30}\\'.format(\\'centered\\')\\n   \\'           centered           \\'\\n   >>> \\'{:*^30}\\'.format(\\'centered\\')  # use \\'*\\' as a fill char\\n   \\'***********centered***********\\'\\n\\nReplacing ``%+f``, ``%-f``, and ``% f`` and specifying a sign:\\n\\n   >>> \\'{:+f}; {:+f}\\'.format(3.14, -3.14)  # show it always\\n   \\'+3.140000; -3.140000\\'\\n   >>> \\'{: f}; {: f}\\'.format(3.14, -3.14)  # show a space for positive numbers\\n   \\' 3.140000; -3.140000\\'\\n   >>> \\'{:-f}; {:-f}\\'.format(3.14, -3.14)  # show only the minus -- same as \\'{:f}; {:f}\\'\\n   \\'3.140000; -3.140000\\'\\n\\nReplacing ``%x`` and ``%o`` and converting the value to different\\nbases:\\n\\n   >>> # format also supports binary numbers\\n   >>> \"int: {0:d};  hex: {0:x};  oct: {0:o};  bin: {0:b}\".format(42)\\n   \\'int: 42;  hex: 2a;  oct: 52;  bin: 101010\\'\\n   >>> # with 0x, 0o, or 0b as prefix:\\n   >>> \"int: {0:d};  hex: {0:#x};  oct: {0:#o};  bin: {0:#b}\".format(42)\\n   \\'int: 42;  hex: 0x2a;  oct: 0o52;  bin: 0b101010\\'\\n\\nUsing the comma as a thousands separator:\\n\\n   >>> \\'{:,}\\'.format(1234567890)\\n   \\'1,234,567,890\\'\\n\\nExpressing a percentage:\\n\\n   >>> points = 19\\n   >>> total = 22\\n   >>> \\'Correct answers: {:.2%}\\'.format(points/total)\\n   \\'Correct answers: 86.36%\\'\\n\\nUsing type-specific formatting:\\n\\n   >>> import datetime\\n   >>> d = datetime.datetime(2010, 7, 4, 12, 15, 58)\\n   >>> \\'{:%Y-%m-%d %H:%M:%S}\\'.format(d)\\n   \\'2010-07-04 12:15:58\\'\\n\\nNesting arguments and more complex examples:\\n\\n   >>> for align, text in zip(\\'<^>\\', [\\'left\\', \\'center\\', \\'right\\']):\\n   ...     \\'{0:{fill}{align}16}\\'.format(text, fill=align, align=align)\\n   ...\\n   \\'left<<<<<<<<<<<<\\'\\n   \\'^^^^^center^^^^^\\'\\n   \\'>>>>>>>>>>>right\\'\\n   >>>\\n   >>> octets = [192, 168, 0, 1]\\n   >>> \\'{:02X}{:02X}{:02X}{:02X}\\'.format(*octets)\\n   \\'C0A80001\\'\\n   >>> int(_, 16)\\n   3232235521\\n   >>>\\n   >>> width = 5\\n   >>> for num in range(5,12): #doctest: +NORMALIZE_WHITESPACE\\n   ...     for base in \\'dXob\\':\\n   ...         print(\\'{0:{width}{base}}\\'.format(num, base=base, width=width), end=\\' \\')\\n   ...     print()\\n   ...\\n       5     5     5   101\\n       6     6     6   110\\n       7     7     7   111\\n       8     8    10  1000\\n       9     9    11  1001\\n      10     A    12  1010\\n      11     B    13  1011\\n',\n'function':'\\nFunction definitions\\n********************\\n\\nA function definition defines a user-defined function object (see\\nsection *The standard type hierarchy*):\\n\\n   funcdef        ::= [decorators] \"def\" funcname \"(\" [parameter_list] \")\" [\"->\" expression] \":\" suite\\n   decorators     ::= decorator+\\n   decorator      ::= \"@\" dotted_name [\"(\" [parameter_list [\",\"]] \")\"] NEWLINE\\n   dotted_name    ::= identifier (\".\" identifier)*\\n   parameter_list ::= (defparameter \",\")*\\n                      ( \"*\" [parameter] (\",\" defparameter)* [\",\" \"**\" parameter]\\n                      | \"**\" parameter\\n                      | defparameter [\",\"] )\\n   parameter      ::= identifier [\":\" expression]\\n   defparameter   ::= parameter [\"=\" expression]\\n   funcname       ::= identifier\\n\\nA function definition is an executable statement.  Its execution binds\\nthe function name in the current local namespace to a function object\\n(a wrapper around the executable code for the function).  This\\nfunction object contains a reference to the current global namespace\\nas the global namespace to be used when the function is called.\\n\\nThe function definition does not execute the function body; this gets\\nexecuted only when the function is called. [3]\\n\\nA function definition may be wrapped by one or more *decorator*\\nexpressions. Decorator expressions are evaluated when the function is\\ndefined, in the scope that contains the function definition.  The\\nresult must be a callable, which is invoked with the function object\\nas the only argument. The returned value is bound to the function name\\ninstead of the function object.  Multiple decorators are applied in\\nnested fashion. For example, the following code\\n\\n   @f1(arg)\\n   @f2\\n   def func(): pass\\n\\nis equivalent to\\n\\n   def func(): pass\\n   func = f1(arg)(f2(func))\\n\\nWhen one or more *parameters* have the form *parameter* ``=``\\n*expression*, the function is said to have \"default parameter values.\"\\nFor a parameter with a default value, the corresponding *argument* may\\nbe omitted from a call, in which case the parameter\\'s default value is\\nsubstituted.  If a parameter has a default value, all following\\nparameters up until the \"``*``\" must also have a default value ---\\nthis is a syntactic restriction that is not expressed by the grammar.\\n\\n**Default parameter values are evaluated when the function definition\\nis executed.** This means that the expression is evaluated once, when\\nthe function is defined, and that the same \"pre-computed\" value is\\nused for each call.  This is especially important to understand when a\\ndefault parameter is a mutable object, such as a list or a dictionary:\\nif the function modifies the object (e.g. by appending an item to a\\nlist), the default value is in effect modified. This is generally not\\nwhat was intended.  A way around this is to use ``None`` as the\\ndefault, and explicitly test for it in the body of the function, e.g.:\\n\\n   def whats_on_the_telly(penguin=None):\\n       if penguin is None:\\n           penguin = []\\n       penguin.append(\"property of the zoo\")\\n       return penguin\\n\\nFunction call semantics are described in more detail in section\\n*Calls*. A function call always assigns values to all parameters\\nmentioned in the parameter list, either from position arguments, from\\nkeyword arguments, or from default values.  If the form\\n\"``*identifier``\" is present, it is initialized to a tuple receiving\\nany excess positional parameters, defaulting to the empty tuple.  If\\nthe form \"``**identifier``\" is present, it is initialized to a new\\ndictionary receiving any excess keyword arguments, defaulting to a new\\nempty dictionary. Parameters after \"``*``\" or \"``*identifier``\" are\\nkeyword-only parameters and may only be passed used keyword arguments.\\n\\nParameters may have annotations of the form \"``: expression``\"\\nfollowing the parameter name.  Any parameter may have an annotation\\neven those of the form ``*identifier`` or ``**identifier``.  Functions\\nmay have \"return\" annotation of the form \"``-> expression``\" after the\\nparameter list.  These annotations can be any valid Python expression\\nand are evaluated when the function definition is executed.\\nAnnotations may be evaluated in a different order than they appear in\\nthe source code.  The presence of annotations does not change the\\nsemantics of a function.  The annotation values are available as\\nvalues of a dictionary keyed by the parameters\\' names in the\\n``__annotations__`` attribute of the function object.\\n\\nIt is also possible to create anonymous functions (functions not bound\\nto a name), for immediate use in expressions.  This uses lambda forms,\\ndescribed in section *Lambdas*.  Note that the lambda form is merely a\\nshorthand for a simplified function definition; a function defined in\\na \"``def``\" statement can be passed around or assigned to another name\\njust like a function defined by a lambda form.  The \"``def``\" form is\\nactually more powerful since it allows the execution of multiple\\nstatements and annotations.\\n\\n**Programmer\\'s note:** Functions are first-class objects.  A \"``def``\"\\nform executed inside a function definition defines a local function\\nthat can be returned or passed around.  Free variables used in the\\nnested function can access the local variables of the function\\ncontaining the def.  See section *Naming and binding* for details.\\n\\nSee also:\\n\\n   **PEP 3107** - Function Annotations\\n      The original specification for function annotations.\\n',\n'global':'\\nThe ``global`` statement\\n************************\\n\\n   global_stmt ::= \"global\" identifier (\",\" identifier)*\\n\\nThe ``global`` statement is a declaration which holds for the entire\\ncurrent code block.  It means that the listed identifiers are to be\\ninterpreted as globals.  It would be impossible to assign to a global\\nvariable without ``global``, although free variables may refer to\\nglobals without being declared global.\\n\\nNames listed in a ``global`` statement must not be used in the same\\ncode block textually preceding that ``global`` statement.\\n\\nNames listed in a ``global`` statement must not be defined as formal\\nparameters or in a ``for`` loop control target, ``class`` definition,\\nfunction definition, or ``import`` statement.\\n\\n**CPython implementation detail:** The current implementation does not\\nenforce the latter two restrictions, but programs should not abuse\\nthis freedom, as future implementations may enforce them or silently\\nchange the meaning of the program.\\n\\n**Programmer\\'s note:** the ``global`` is a directive to the parser.\\nIt applies only to code parsed at the same time as the ``global``\\nstatement. In particular, a ``global`` statement contained in a string\\nor code object supplied to the built-in ``exec()`` function does not\\naffect the code block *containing* the function call, and code\\ncontained in such a string is unaffected by ``global`` statements in\\nthe code containing the function call.  The same applies to the\\n``eval()`` and ``compile()`` functions.\\n',\n'id-classes':'\\nReserved classes of identifiers\\n*******************************\\n\\nCertain classes of identifiers (besides keywords) have special\\nmeanings.  These classes are identified by the patterns of leading and\\ntrailing underscore characters:\\n\\n``_*``\\n   Not imported by ``from module import *``.  The special identifier\\n   ``_`` is used in the interactive interpreter to store the result of\\n   the last evaluation; it is stored in the ``builtins`` module.  When\\n   not in interactive mode, ``_`` has no special meaning and is not\\n   defined. See section *The import statement*.\\n\\n   Note: The name ``_`` is often used in conjunction with\\n     internationalization; refer to the documentation for the\\n     ``gettext`` module for more information on this convention.\\n\\n``__*__``\\n   System-defined names. These names are defined by the interpreter\\n   and its implementation (including the standard library).  Current\\n   system names are discussed in the *Special method names* section\\n   and elsewhere.  More will likely be defined in future versions of\\n   Python.  *Any* use of ``__*__`` names, in any context, that does\\n   not follow explicitly documented use, is subject to breakage\\n   without warning.\\n\\n``__*``\\n   Class-private names.  Names in this category, when used within the\\n   context of a class definition, are re-written to use a mangled form\\n   to help avoid name clashes between \"private\" attributes of base and\\n   derived classes. See section *Identifiers (Names)*.\\n',\n'identifiers':'\\nIdentifiers and keywords\\n************************\\n\\nIdentifiers (also referred to as *names*) are described by the\\nfollowing lexical definitions.\\n\\nThe syntax of identifiers in Python is based on the Unicode standard\\nannex UAX-31, with elaboration and changes as defined below; see also\\n**PEP 3131** for further details.\\n\\nWithin the ASCII range (U+0001..U+007F), the valid characters for\\nidentifiers are the same as in Python 2.x: the uppercase and lowercase\\nletters ``A`` through ``Z``, the underscore ``_`` and, except for the\\nfirst character, the digits ``0`` through ``9``.\\n\\nPython 3.0 introduces additional characters from outside the ASCII\\nrange (see **PEP 3131**).  For these characters, the classification\\nuses the version of the Unicode Character Database as included in the\\n``unicodedata`` module.\\n\\nIdentifiers are unlimited in length.  Case is significant.\\n\\n   identifier   ::= xid_start xid_continue*\\n   id_start     ::= <all characters in general categories Lu, Ll, Lt, Lm, Lo, Nl, the underscore, and characters with the Other_ID_Start property>\\n   id_continue  ::= <all characters in id_start, plus characters in the categories Mn, Mc, Nd, Pc and others with the Other_ID_Continue property>\\n   xid_start    ::= <all characters in id_start whose NFKC normalization is in \"id_start xid_continue*\">\\n   xid_continue ::= <all characters in id_continue whose NFKC normalization is in \"id_continue*\">\\n\\nThe Unicode category codes mentioned above stand for:\\n\\n* *Lu* - uppercase letters\\n\\n* *Ll* - lowercase letters\\n\\n* *Lt* - titlecase letters\\n\\n* *Lm* - modifier letters\\n\\n* *Lo* - other letters\\n\\n* *Nl* - letter numbers\\n\\n* *Mn* - nonspacing marks\\n\\n* *Mc* - spacing combining marks\\n\\n* *Nd* - decimal numbers\\n\\n* *Pc* - connector punctuations\\n\\n* *Other_ID_Start* - explicit list of characters in PropList.txt to\\n  support backwards compatibility\\n\\n* *Other_ID_Continue* - likewise\\n\\nAll identifiers are converted into the normal form NFKC while parsing;\\ncomparison of identifiers is based on NFKC.\\n\\nA non-normative HTML file listing all valid identifier characters for\\nUnicode 4.1 can be found at http://www.dcl.hpi.uni-\\npotsdam.de/home/loewis/table-3131.html.\\n\\n\\nKeywords\\n========\\n\\nThe following identifiers are used as reserved words, or *keywords* of\\nthe language, and cannot be used as ordinary identifiers.  They must\\nbe spelled exactly as written here:\\n\\n   False      class      finally    is         return\\n   None       continue   for        lambda     try\\n   True       def        from       nonlocal   while\\n   and        del        global     not        with\\n   as         elif       if         or         yield\\n   assert     else       import     pass\\n   break      except     in         raise\\n\\n\\nReserved classes of identifiers\\n===============================\\n\\nCertain classes of identifiers (besides keywords) have special\\nmeanings.  These classes are identified by the patterns of leading and\\ntrailing underscore characters:\\n\\n``_*``\\n   Not imported by ``from module import *``.  The special identifier\\n   ``_`` is used in the interactive interpreter to store the result of\\n   the last evaluation; it is stored in the ``builtins`` module.  When\\n   not in interactive mode, ``_`` has no special meaning and is not\\n   defined. See section *The import statement*.\\n\\n   Note: The name ``_`` is often used in conjunction with\\n     internationalization; refer to the documentation for the\\n     ``gettext`` module for more information on this convention.\\n\\n``__*__``\\n   System-defined names. These names are defined by the interpreter\\n   and its implementation (including the standard library).  Current\\n   system names are discussed in the *Special method names* section\\n   and elsewhere.  More will likely be defined in future versions of\\n   Python.  *Any* use of ``__*__`` names, in any context, that does\\n   not follow explicitly documented use, is subject to breakage\\n   without warning.\\n\\n``__*``\\n   Class-private names.  Names in this category, when used within the\\n   context of a class definition, are re-written to use a mangled form\\n   to help avoid name clashes between \"private\" attributes of base and\\n   derived classes. See section *Identifiers (Names)*.\\n',\n'if':'\\nThe ``if`` statement\\n********************\\n\\nThe ``if`` statement is used for conditional execution:\\n\\n   if_stmt ::= \"if\" expression \":\" suite\\n               ( \"elif\" expression \":\" suite )*\\n               [\"else\" \":\" suite]\\n\\nIt selects exactly one of the suites by evaluating the expressions one\\nby one until one is found to be true (see section *Boolean operations*\\nfor the definition of true and false); then that suite is executed\\n(and no other part of the ``if`` statement is executed or evaluated).\\nIf all expressions are false, the suite of the ``else`` clause, if\\npresent, is executed.\\n',\n'imaginary':'\\nImaginary literals\\n******************\\n\\nImaginary literals are described by the following lexical definitions:\\n\\n   imagnumber ::= (floatnumber | intpart) (\"j\" | \"J\")\\n\\nAn imaginary literal yields a complex number with a real part of 0.0.\\nComplex numbers are represented as a pair of floating point numbers\\nand have the same restrictions on their range.  To create a complex\\nnumber with a nonzero real part, add a floating point number to it,\\ne.g., ``(3+4j)``.  Some examples of imaginary literals:\\n\\n   3.14j   10.j    10j     .001j   1e100j  3.14e-10j\\n',\n'import':'\\nThe ``import`` statement\\n************************\\n\\n   import_stmt     ::= \"import\" module [\"as\" name] ( \",\" module [\"as\" name] )*\\n                   | \"from\" relative_module \"import\" identifier [\"as\" name]\\n                   ( \",\" identifier [\"as\" name] )*\\n                   | \"from\" relative_module \"import\" \"(\" identifier [\"as\" name]\\n                   ( \",\" identifier [\"as\" name] )* [\",\"] \")\"\\n                   | \"from\" module \"import\" \"*\"\\n   module          ::= (identifier \".\")* identifier\\n   relative_module ::= \".\"* module | \".\"+\\n   name            ::= identifier\\n\\nThe basic import statement (no ``from`` clause) is executed in two\\nsteps:\\n\\n1. find a module, loading and initializing it if necessary\\n\\n2. define a name or names in the local namespace for the scope where\\n   the ``import`` statement occurs.\\n\\nWhen the statement contains multiple clauses (separated by commas) the\\ntwo steps are carried out separately for each clause, just as though\\nthe clauses had been separated out into individiual import statements.\\n\\nThe details of the first step, finding and loading modules is\\ndescribed in greater detail in the section on the *import system*,\\nwhich also describes the various types of packages and modules that\\ncan be imported, as well as all the hooks that can be used to\\ncustomize the import system. Note that failures in this step may\\nindicate either that the module could not be located, *or* that an\\nerror occurred while initializing the module, which includes execution\\nof the module\\'s code.\\n\\nIf the requested module is retrieved successfully, it will be made\\navailable in the local namespace in one of three ways:\\n\\n* If the module name is followed by ``as``, then the name following\\n  ``as`` is bound directly to the imported module.\\n\\n* If no other name is specified, and the module being imported is a\\n  top level module, the module\\'s name is bound in the local namespace\\n  as a reference to the imported module\\n\\n* If the module being imported is *not* a top level module, then the\\n  name of the top level package that contains the module is bound in\\n  the local namespace as a reference to the top level package. The\\n  imported module must be accessed using its full qualified name\\n  rather than directly\\n\\nThe ``from`` form uses a slightly more complex process:\\n\\n1. find the module specified in the ``from`` clause loading and\\n   initializing it if necessary;\\n\\n2. for each of the identifiers specified in the ``import`` clauses:\\n\\n   1. check if the imported module has an attribute by that name\\n\\n   2. if not, attempt to import a submodule with that name and then\\n      check the imported module again for that attribute\\n\\n   3. if the attribute is not found, ``ImportError`` is raised.\\n\\n   4. otherwise, a reference to that value is bound in the local\\n      namespace, using the name in the ``as`` clause if it is present,\\n      otherwise using the attribute name\\n\\nExamples:\\n\\n   import foo                 # foo imported and bound locally\\n   import foo.bar.baz         # foo.bar.baz imported, foo bound locally\\n   import foo.bar.baz as fbb  # foo.bar.baz imported and bound as fbb\\n   from foo.bar import baz    # foo.bar.baz imported and bound as baz\\n   from foo import attr       # foo imported and foo.attr bound as attr\\n\\nIf the list of identifiers is replaced by a star (``\\'*\\'``), all public\\nnames defined in the module are bound in the local namespace for the\\nscope where the ``import`` statement occurs.\\n\\nThe *public names* defined by a module are determined by checking the\\nmodule\\'s namespace for a variable named ``__all__``; if defined, it\\nmust be a sequence of strings which are names defined or imported by\\nthat module.  The names given in ``__all__`` are all considered public\\nand are required to exist.  If ``__all__`` is not defined, the set of\\npublic names includes all names found in the module\\'s namespace which\\ndo not begin with an underscore character (``\\'_\\'``).  ``__all__``\\nshould contain the entire public API. It is intended to avoid\\naccidentally exporting items that are not part of the API (such as\\nlibrary modules which were imported and used within the module).\\n\\nThe ``from`` form with ``*`` may only occur in a module scope.\\nAttempting to use it in class or function definitions will raise a\\n``SyntaxError``.\\n\\nThe *public names* defined by a module are determined by checking the\\nmodule\\'s namespace for a variable named ``__all__``; if defined, it\\nmust be a sequence of strings which are names defined or imported by\\nthat module.  The names given in ``__all__`` are all considered public\\nand are required to exist.  If ``__all__`` is not defined, the set of\\npublic names includes all names found in the module\\'s namespace which\\ndo not begin with an underscore character (``\\'_\\'``).  ``__all__``\\nshould contain the entire public API. It is intended to avoid\\naccidentally exporting items that are not part of the API (such as\\nlibrary modules which were imported and used within the module).\\n\\nThe ``from`` form with ``*`` may only occur in a module scope.  The\\nwild card form of import --- ``import *`` --- is only allowed at the\\nmodule level. Attempting to use it in class or function definitions\\nwill raise a ``SyntaxError``.\\n\\nWhen specifying what module to import you do not have to specify the\\nabsolute name of the module. When a module or package is contained\\nwithin another package it is possible to make a relative import within\\nthe same top package without having to mention the package name. By\\nusing leading dots in the specified module or package after ``from``\\nyou can specify how high to traverse up the current package hierarchy\\nwithout specifying exact names. One leading dot means the current\\npackage where the module making the import exists. Two dots means up\\none package level. Three dots is up two levels, etc. So if you execute\\n``from . import mod`` from a module in the ``pkg`` package then you\\nwill end up importing ``pkg.mod``. If you execute ``from ..subpkg2\\nimport mod`` from within ``pkg.subpkg1`` you will import\\n``pkg.subpkg2.mod``. The specification for relative imports is\\ncontained within **PEP 328**.\\n\\n``importlib.import_module()`` is provided to support applications that\\ndetermine which modules need to be loaded dynamically.\\n\\n\\nFuture statements\\n=================\\n\\nA *future statement* is a directive to the compiler that a particular\\nmodule should be compiled using syntax or semantics that will be\\navailable in a specified future release of Python.  The future\\nstatement is intended to ease migration to future versions of Python\\nthat introduce incompatible changes to the language.  It allows use of\\nthe new features on a per-module basis before the release in which the\\nfeature becomes standard.\\n\\n   future_statement ::= \"from\" \"__future__\" \"import\" feature [\"as\" name]\\n                        (\",\" feature [\"as\" name])*\\n                        | \"from\" \"__future__\" \"import\" \"(\" feature [\"as\" name]\\n                        (\",\" feature [\"as\" name])* [\",\"] \")\"\\n   feature          ::= identifier\\n   name             ::= identifier\\n\\nA future statement must appear near the top of the module.  The only\\nlines that can appear before a future statement are:\\n\\n* the module docstring (if any),\\n\\n* comments,\\n\\n* blank lines, and\\n\\n* other future statements.\\n\\nThe features recognized by Python 3.0 are ``absolute_import``,\\n``division``, ``generators``, ``unicode_literals``,\\n``print_function``, ``nested_scopes`` and ``with_statement``.  They\\nare all redundant because they are always enabled, and only kept for\\nbackwards compatibility.\\n\\nA future statement is recognized and treated specially at compile\\ntime: Changes to the semantics of core constructs are often\\nimplemented by generating different code.  It may even be the case\\nthat a new feature introduces new incompatible syntax (such as a new\\nreserved word), in which case the compiler may need to parse the\\nmodule differently.  Such decisions cannot be pushed off until\\nruntime.\\n\\nFor any given release, the compiler knows which feature names have\\nbeen defined, and raises a compile-time error if a future statement\\ncontains a feature not known to it.\\n\\nThe direct runtime semantics are the same as for any import statement:\\nthere is a standard module ``__future__``, described later, and it\\nwill be imported in the usual way at the time the future statement is\\nexecuted.\\n\\nThe interesting runtime semantics depend on the specific feature\\nenabled by the future statement.\\n\\nNote that there is nothing special about the statement:\\n\\n   import __future__ [as name]\\n\\nThat is not a future statement; it\\'s an ordinary import statement with\\nno special semantics or syntax restrictions.\\n\\nCode compiled by calls to the built-in functions ``exec()`` and\\n``compile()`` that occur in a module ``M`` containing a future\\nstatement will, by default, use the new syntax or semantics associated\\nwith the future statement.  This can be controlled by optional\\narguments to ``compile()`` --- see the documentation of that function\\nfor details.\\n\\nA future statement typed at an interactive interpreter prompt will\\ntake effect for the rest of the interpreter session.  If an\\ninterpreter is started with the *-i* option, is passed a script name\\nto execute, and the script includes a future statement, it will be in\\neffect in the interactive session started after the script is\\nexecuted.\\n\\nSee also:\\n\\n   **PEP 236** - Back to the __future__\\n      The original proposal for the __future__ mechanism.\\n',\n'in':'\\nComparisons\\n***********\\n\\nUnlike C, all comparison operations in Python have the same priority,\\nwhich is lower than that of any arithmetic, shifting or bitwise\\noperation.  Also unlike C, expressions like ``a < b < c`` have the\\ninterpretation that is conventional in mathematics:\\n\\n   comparison    ::= or_expr ( comp_operator or_expr )*\\n   comp_operator ::= \"<\" | \">\" | \"==\" | \">=\" | \"<=\" | \"!=\"\\n                     | \"is\" [\"not\"] | [\"not\"] \"in\"\\n\\nComparisons yield boolean values: ``True`` or ``False``.\\n\\nComparisons can be chained arbitrarily, e.g., ``x < y <= z`` is\\nequivalent to ``x < y and y <= z``, except that ``y`` is evaluated\\nonly once (but in both cases ``z`` is not evaluated at all when ``x <\\ny`` is found to be false).\\n\\nFormally, if *a*, *b*, *c*, ..., *y*, *z* are expressions and *op1*,\\n*op2*, ..., *opN* are comparison operators, then ``a op1 b op2 c ... y\\nopN z`` is equivalent to ``a op1 b and b op2 c and ... y opN z``,\\nexcept that each expression is evaluated at most once.\\n\\nNote that ``a op1 b op2 c`` doesn\\'t imply any kind of comparison\\nbetween *a* and *c*, so that, e.g., ``x < y > z`` is perfectly legal\\n(though perhaps not pretty).\\n\\nThe operators ``<``, ``>``, ``==``, ``>=``, ``<=``, and ``!=`` compare\\nthe values of two objects.  The objects need not have the same type.\\nIf both are numbers, they are converted to a common type.  Otherwise,\\nthe ``==`` and ``!=`` operators *always* consider objects of different\\ntypes to be unequal, while the ``<``, ``>``, ``>=`` and ``<=``\\noperators raise a ``TypeError`` when comparing objects of different\\ntypes that do not implement these operators for the given pair of\\ntypes.  You can control comparison behavior of objects of non-built-in\\ntypes by defining rich comparison methods like ``__gt__()``, described\\nin section *Basic customization*.\\n\\nComparison of objects of the same type depends on the type:\\n\\n* Numbers are compared arithmetically.\\n\\n* The values ``float(\\'NaN\\')`` and ``Decimal(\\'NaN\\')`` are special. The\\n  are identical to themselves, ``x is x`` but are not equal to\\n  themselves, ``x != x``.  Additionally, comparing any value to a\\n  not-a-number value will return ``False``.  For example, both ``3 <\\n  float(\\'NaN\\')`` and ``float(\\'NaN\\') < 3`` will return ``False``.\\n\\n* Bytes objects are compared lexicographically using the numeric\\n  values of their elements.\\n\\n* Strings are compared lexicographically using the numeric equivalents\\n  (the result of the built-in function ``ord()``) of their characters.\\n  [3] String and bytes object can\\'t be compared!\\n\\n* Tuples and lists are compared lexicographically using comparison of\\n  corresponding elements.  This means that to compare equal, each\\n  element must compare equal and the two sequences must be of the same\\n  type and have the same length.\\n\\n  If not equal, the sequences are ordered the same as their first\\n  differing elements.  For example, ``[1,2,x] <= [1,2,y]`` has the\\n  same value as ``x <= y``.  If the corresponding element does not\\n  exist, the shorter sequence is ordered first (for example, ``[1,2] <\\n  [1,2,3]``).\\n\\n* Mappings (dictionaries) compare equal if and only if they have the\\n  same ``(key, value)`` pairs. Order comparisons ``(\\'<\\', \\'<=\\', \\'>=\\',\\n  \\'>\\')`` raise ``TypeError``.\\n\\n* Sets and frozensets define comparison operators to mean subset and\\n  superset tests.  Those relations do not define total orderings (the\\n  two sets ``{1,2}`` and {2,3} are not equal, nor subsets of one\\n  another, nor supersets of one another).  Accordingly, sets are not\\n  appropriate arguments for functions which depend on total ordering.\\n  For example, ``min()``, ``max()``, and ``sorted()`` produce\\n  undefined results given a list of sets as inputs.\\n\\n* Most other objects of built-in types compare unequal unless they are\\n  the same object; the choice whether one object is considered smaller\\n  or larger than another one is made arbitrarily but consistently\\n  within one execution of a program.\\n\\nComparison of objects of the differing types depends on whether either\\nof the types provide explicit support for the comparison.  Most\\nnumeric types can be compared with one another.  When cross-type\\ncomparison is not supported, the comparison method returns\\n``NotImplemented``.\\n\\nThe operators ``in`` and ``not in`` test for membership.  ``x in s``\\nevaluates to true if *x* is a member of *s*, and false otherwise.  ``x\\nnot in s`` returns the negation of ``x in s``.  All built-in sequences\\nand set types support this as well as dictionary, for which ``in``\\ntests whether a the dictionary has a given key. For container types\\nsuch as list, tuple, set, frozenset, dict, or collections.deque, the\\nexpression ``x in y`` is equivalent to ``any(x is e or x == e for e in\\ny)``.\\n\\nFor the string and bytes types, ``x in y`` is true if and only if *x*\\nis a substring of *y*.  An equivalent test is ``y.find(x) != -1``.\\nEmpty strings are always considered to be a substring of any other\\nstring, so ``\"\" in \"abc\"`` will return ``True``.\\n\\nFor user-defined classes which define the ``__contains__()`` method,\\n``x in y`` is true if and only if ``y.__contains__(x)`` is true.\\n\\nFor user-defined classes which do not define ``__contains__()`` but do\\ndefine ``__iter__()``, ``x in y`` is true if some value ``z`` with ``x\\n== z`` is produced while iterating over ``y``.  If an exception is\\nraised during the iteration, it is as if ``in`` raised that exception.\\n\\nLastly, the old-style iteration protocol is tried: if a class defines\\n``__getitem__()``, ``x in y`` is true if and only if there is a non-\\nnegative integer index *i* such that ``x == y[i]``, and all lower\\ninteger indices do not raise ``IndexError`` exception.  (If any other\\nexception is raised, it is as if ``in`` raised that exception).\\n\\nThe operator ``not in`` is defined to have the inverse true value of\\n``in``.\\n\\nThe operators ``is`` and ``is not`` test for object identity: ``x is\\ny`` is true if and only if *x* and *y* are the same object.  ``x is\\nnot y`` yields the inverse truth value. [4]\\n',\n'integers':'\\nInteger literals\\n****************\\n\\nInteger literals are described by the following lexical definitions:\\n\\n   integer        ::= decimalinteger | octinteger | hexinteger | bininteger\\n   decimalinteger ::= nonzerodigit digit* | \"0\"+\\n   nonzerodigit   ::= \"1\"...\"9\"\\n   digit          ::= \"0\"...\"9\"\\n   octinteger     ::= \"0\" (\"o\" | \"O\") octdigit+\\n   hexinteger     ::= \"0\" (\"x\" | \"X\") hexdigit+\\n   bininteger     ::= \"0\" (\"b\" | \"B\") bindigit+\\n   octdigit       ::= \"0\"...\"7\"\\n   hexdigit       ::= digit | \"a\"...\"f\" | \"A\"...\"F\"\\n   bindigit       ::= \"0\" | \"1\"\\n\\nThere is no limit for the length of integer literals apart from what\\ncan be stored in available memory.\\n\\nNote that leading zeros in a non-zero decimal number are not allowed.\\nThis is for disambiguation with C-style octal literals, which Python\\nused before version 3.0.\\n\\nSome examples of integer literals:\\n\\n   7     2147483647                        0o177    0b100110111\\n   3     79228162514264337593543950336     0o377    0x100000000\\n         79228162514264337593543950336              0xdeadbeef\\n',\n'lambda':'\\nLambdas\\n*******\\n\\n   lambda_form        ::= \"lambda\" [parameter_list]: expression\\n   lambda_form_nocond ::= \"lambda\" [parameter_list]: expression_nocond\\n\\nLambda forms (lambda expressions) have the same syntactic position as\\nexpressions.  They are a shorthand to create anonymous functions; the\\nexpression ``lambda arguments: expression`` yields a function object.\\nThe unnamed object behaves like a function object defined with\\n\\n   def <lambda>(arguments):\\n       return expression\\n\\nSee section *Function definitions* for the syntax of parameter lists.\\nNote that functions created with lambda forms cannot contain\\nstatements or annotations.\\n',\n'lists':'\\nList displays\\n*************\\n\\nA list display is a possibly empty series of expressions enclosed in\\nsquare brackets:\\n\\n   list_display ::= \"[\" [expression_list | comprehension] \"]\"\\n\\nA list display yields a new list object, the contents being specified\\nby either a list of expressions or a comprehension.  When a comma-\\nseparated list of expressions is supplied, its elements are evaluated\\nfrom left to right and placed into the list object in that order.\\nWhen a comprehension is supplied, the list is constructed from the\\nelements resulting from the comprehension.\\n',\n'naming':\"\\nNaming and binding\\n******************\\n\\n*Names* refer to objects.  Names are introduced by name binding\\noperations. Each occurrence of a name in the program text refers to\\nthe *binding* of that name established in the innermost function block\\ncontaining the use.\\n\\nA *block* is a piece of Python program text that is executed as a\\nunit. The following are blocks: a module, a function body, and a class\\ndefinition. Each command typed interactively is a block.  A script\\nfile (a file given as standard input to the interpreter or specified\\non the interpreter command line the first argument) is a code block.\\nA script command (a command specified on the interpreter command line\\nwith the '**-c**' option) is a code block.  The string argument passed\\nto the built-in functions ``eval()`` and ``exec()`` is a code block.\\n\\nA code block is executed in an *execution frame*.  A frame contains\\nsome administrative information (used for debugging) and determines\\nwhere and how execution continues after the code block's execution has\\ncompleted.\\n\\nA *scope* defines the visibility of a name within a block.  If a local\\nvariable is defined in a block, its scope includes that block.  If the\\ndefinition occurs in a function block, the scope extends to any blocks\\ncontained within the defining one, unless a contained block introduces\\na different binding for the name.  The scope of names defined in a\\nclass block is limited to the class block; it does not extend to the\\ncode blocks of methods -- this includes comprehensions and generator\\nexpressions since they are implemented using a function scope.  This\\nmeans that the following will fail:\\n\\n   class A:\\n       a = 42\\n       b = list(a + i for i in range(10))\\n\\nWhen a name is used in a code block, it is resolved using the nearest\\nenclosing scope.  The set of all such scopes visible to a code block\\nis called the block's *environment*.\\n\\nIf a name is bound in a block, it is a local variable of that block,\\nunless declared as ``nonlocal``.  If a name is bound at the module\\nlevel, it is a global variable.  (The variables of the module code\\nblock are local and global.)  If a variable is used in a code block\\nbut not defined there, it is a *free variable*.\\n\\nWhen a name is not found at all, a ``NameError`` exception is raised.\\nIf the name refers to a local variable that has not been bound, a\\n``UnboundLocalError`` exception is raised.  ``UnboundLocalError`` is a\\nsubclass of ``NameError``.\\n\\nThe following constructs bind names: formal parameters to functions,\\n``import`` statements, class and function definitions (these bind the\\nclass or function name in the defining block), and targets that are\\nidentifiers if occurring in an assignment, ``for`` loop header, or\\nafter ``as`` in a ``with`` statement or ``except`` clause. The\\n``import`` statement of the form ``from ... import *`` binds all names\\ndefined in the imported module, except those beginning with an\\nunderscore.  This form may only be used at the module level.\\n\\nA target occurring in a ``del`` statement is also considered bound for\\nthis purpose (though the actual semantics are to unbind the name).\\n\\nEach assignment or import statement occurs within a block defined by a\\nclass or function definition or at the module level (the top-level\\ncode block).\\n\\nIf a name binding operation occurs anywhere within a code block, all\\nuses of the name within the block are treated as references to the\\ncurrent block.  This can lead to errors when a name is used within a\\nblock before it is bound.  This rule is subtle.  Python lacks\\ndeclarations and allows name binding operations to occur anywhere\\nwithin a code block.  The local variables of a code block can be\\ndetermined by scanning the entire text of the block for name binding\\noperations.\\n\\nIf the ``global`` statement occurs within a block, all uses of the\\nname specified in the statement refer to the binding of that name in\\nthe top-level namespace.  Names are resolved in the top-level\\nnamespace by searching the global namespace, i.e. the namespace of the\\nmodule containing the code block, and the builtins namespace, the\\nnamespace of the module ``builtins``.  The global namespace is\\nsearched first.  If the name is not found there, the builtins\\nnamespace is searched.  The global statement must precede all uses of\\nthe name.\\n\\nThe builtins namespace associated with the execution of a code block\\nis actually found by looking up the name ``__builtins__`` in its\\nglobal namespace; this should be a dictionary or a module (in the\\nlatter case the module's dictionary is used).  By default, when in the\\n``__main__`` module, ``__builtins__`` is the built-in module\\n``builtins``; when in any other module, ``__builtins__`` is an alias\\nfor the dictionary of the ``builtins`` module itself.\\n``__builtins__`` can be set to a user-created dictionary to create a\\nweak form of restricted execution.\\n\\n**CPython implementation detail:** Users should not touch\\n``__builtins__``; it is strictly an implementation detail.  Users\\nwanting to override values in the builtins namespace should ``import``\\nthe ``builtins`` module and modify its attributes appropriately.\\n\\nThe namespace for a module is automatically created the first time a\\nmodule is imported.  The main module for a script is always called\\n``__main__``.\\n\\nThe ``global`` statement has the same scope as a name binding\\noperation in the same block.  If the nearest enclosing scope for a\\nfree variable contains a global statement, the free variable is\\ntreated as a global.\\n\\nA class definition is an executable statement that may use and define\\nnames. These references follow the normal rules for name resolution.\\nThe namespace of the class definition becomes the attribute dictionary\\nof the class.  Names defined at the class scope are not visible in\\nmethods.\\n\\n\\nInteraction with dynamic features\\n=================================\\n\\nThere are several cases where Python statements are illegal when used\\nin conjunction with nested scopes that contain free variables.\\n\\nIf a variable is referenced in an enclosing scope, it is illegal to\\ndelete the name.  An error will be reported at compile time.\\n\\nIf the wild card form of import --- ``import *`` --- is used in a\\nfunction and the function contains or is a nested block with free\\nvariables, the compiler will raise a ``SyntaxError``.\\n\\nThe ``eval()`` and ``exec()`` functions do not have access to the full\\nenvironment for resolving names.  Names may be resolved in the local\\nand global namespaces of the caller.  Free variables are not resolved\\nin the nearest enclosing namespace, but in the global namespace.  [1]\\nThe ``exec()`` and ``eval()`` functions have optional arguments to\\noverride the global and local namespace.  If only one namespace is\\nspecified, it is used for both.\\n\",\n'nonlocal':'\\nThe ``nonlocal`` statement\\n**************************\\n\\n   nonlocal_stmt ::= \"nonlocal\" identifier (\",\" identifier)*\\n\\nThe ``nonlocal`` statement causes the listed identifiers to refer to\\npreviously bound variables in the nearest enclosing scope.  This is\\nimportant because the default behavior for binding is to search the\\nlocal namespace first.  The statement allows encapsulated code to\\nrebind variables outside of the local scope besides the global\\n(module) scope.\\n\\nNames listed in a ``nonlocal`` statement, unlike to those listed in a\\n``global`` statement, must refer to pre-existing bindings in an\\nenclosing scope (the scope in which a new binding should be created\\ncannot be determined unambiguously).\\n\\nNames listed in a ``nonlocal`` statement must not collide with pre-\\nexisting bindings in the local scope.\\n\\nSee also:\\n\\n   **PEP 3104** - Access to Names in Outer Scopes\\n      The specification for the ``nonlocal`` statement.\\n',\n'numbers':\"\\nNumeric literals\\n****************\\n\\nThere are three types of numeric literals: integers, floating point\\nnumbers, and imaginary numbers.  There are no complex literals\\n(complex numbers can be formed by adding a real number and an\\nimaginary number).\\n\\nNote that numeric literals do not include a sign; a phrase like ``-1``\\nis actually an expression composed of the unary operator '``-``' and\\nthe literal ``1``.\\n\",\n'numeric-types':\"\\nEmulating numeric types\\n***********************\\n\\nThe following methods can be defined to emulate numeric objects.\\nMethods corresponding to operations that are not supported by the\\nparticular kind of number implemented (e.g., bitwise operations for\\nnon-integral numbers) should be left undefined.\\n\\nobject.__add__(self, other)\\nobject.__sub__(self, other)\\nobject.__mul__(self, other)\\nobject.__truediv__(self, other)\\nobject.__floordiv__(self, other)\\nobject.__mod__(self, other)\\nobject.__divmod__(self, other)\\nobject.__pow__(self, other[, modulo])\\nobject.__lshift__(self, other)\\nobject.__rshift__(self, other)\\nobject.__and__(self, other)\\nobject.__xor__(self, other)\\nobject.__or__(self, other)\\n\\n   These methods are called to implement the binary arithmetic\\n   operations (``+``, ``-``, ``*``, ``/``, ``//``, ``%``,\\n   ``divmod()``, ``pow()``, ``**``, ``<<``, ``>>``, ``&``, ``^``,\\n   ``|``).  For instance, to evaluate the expression ``x + y``, where\\n   *x* is an instance of a class that has an ``__add__()`` method,\\n   ``x.__add__(y)`` is called.  The ``__divmod__()`` method should be\\n   the equivalent to using ``__floordiv__()`` and ``__mod__()``; it\\n   should not be related to ``__truediv__()``.  Note that\\n   ``__pow__()`` should be defined to accept an optional third\\n   argument if the ternary version of the built-in ``pow()`` function\\n   is to be supported.\\n\\n   If one of those methods does not support the operation with the\\n   supplied arguments, it should return ``NotImplemented``.\\n\\nobject.__radd__(self, other)\\nobject.__rsub__(self, other)\\nobject.__rmul__(self, other)\\nobject.__rtruediv__(self, other)\\nobject.__rfloordiv__(self, other)\\nobject.__rmod__(self, other)\\nobject.__rdivmod__(self, other)\\nobject.__rpow__(self, other)\\nobject.__rlshift__(self, other)\\nobject.__rrshift__(self, other)\\nobject.__rand__(self, other)\\nobject.__rxor__(self, other)\\nobject.__ror__(self, other)\\n\\n   These methods are called to implement the binary arithmetic\\n   operations (``+``, ``-``, ``*``, ``/``, ``//``, ``%``,\\n   ``divmod()``, ``pow()``, ``**``, ``<<``, ``>>``, ``&``, ``^``,\\n   ``|``) with reflected (swapped) operands. These functions are only\\n   called if the left operand does not support the corresponding\\n   operation and the operands are of different types. [2]  For\\n   instance, to evaluate the expression ``x - y``, where *y* is an\\n   instance of a class that has an ``__rsub__()`` method,\\n   ``y.__rsub__(x)`` is called if ``x.__sub__(y)`` returns\\n   *NotImplemented*.\\n\\n   Note that ternary ``pow()`` will not try calling ``__rpow__()``\\n   (the coercion rules would become too complicated).\\n\\n   Note: If the right operand's type is a subclass of the left operand's\\n     type and that subclass provides the reflected method for the\\n     operation, this method will be called before the left operand's\\n     non-reflected method.  This behavior allows subclasses to\\n     override their ancestors' operations.\\n\\nobject.__iadd__(self, other)\\nobject.__isub__(self, other)\\nobject.__imul__(self, other)\\nobject.__itruediv__(self, other)\\nobject.__ifloordiv__(self, other)\\nobject.__imod__(self, other)\\nobject.__ipow__(self, other[, modulo])\\nobject.__ilshift__(self, other)\\nobject.__irshift__(self, other)\\nobject.__iand__(self, other)\\nobject.__ixor__(self, other)\\nobject.__ior__(self, other)\\n\\n   These methods are called to implement the augmented arithmetic\\n   assignments (``+=``, ``-=``, ``*=``, ``/=``, ``//=``, ``%=``,\\n   ``**=``, ``<<=``, ``>>=``, ``&=``, ``^=``, ``|=``).  These methods\\n   should attempt to do the operation in-place (modifying *self*) and\\n   return the result (which could be, but does not have to be,\\n   *self*).  If a specific method is not defined, the augmented\\n   assignment falls back to the normal methods.  For instance, to\\n   execute the statement ``x += y``, where *x* is an instance of a\\n   class that has an ``__iadd__()`` method, ``x.__iadd__(y)`` is\\n   called.  If *x* is an instance of a class that does not define a\\n   ``__iadd__()`` method, ``x.__add__(y)`` and ``y.__radd__(x)`` are\\n   considered, as with the evaluation of ``x + y``.\\n\\nobject.__neg__(self)\\nobject.__pos__(self)\\nobject.__abs__(self)\\nobject.__invert__(self)\\n\\n   Called to implement the unary arithmetic operations (``-``, ``+``,\\n   ``abs()`` and ``~``).\\n\\nobject.__complex__(self)\\nobject.__int__(self)\\nobject.__float__(self)\\nobject.__round__(self[, n])\\n\\n   Called to implement the built-in functions ``complex()``,\\n   ``int()``, ``float()`` and ``round()``.  Should return a value of\\n   the appropriate type.\\n\\nobject.__index__(self)\\n\\n   Called to implement ``operator.index()``.  Also called whenever\\n   Python needs an integer object (such as in slicing, or in the\\n   built-in ``bin()``, ``hex()`` and ``oct()`` functions). Must return\\n   an integer.\\n\",\n'objects':'\\nObjects, values and types\\n*************************\\n\\n*Objects* are Python\\'s abstraction for data.  All data in a Python\\nprogram is represented by objects or by relations between objects. (In\\na sense, and in conformance to Von Neumann\\'s model of a \"stored\\nprogram computer,\" code is also represented by objects.)\\n\\nEvery object has an identity, a type and a value.  An object\\'s\\n*identity* never changes once it has been created; you may think of it\\nas the object\\'s address in memory.  The \\'``is``\\' operator compares the\\nidentity of two objects; the ``id()`` function returns an integer\\nrepresenting its identity.\\n\\n**CPython implementation detail:** For CPython, ``id(x)`` is the\\nmemory address where ``x`` is stored.\\n\\nAn object\\'s type determines the operations that the object supports\\n(e.g., \"does it have a length?\") and also defines the possible values\\nfor objects of that type.  The ``type()`` function returns an object\\'s\\ntype (which is an object itself).  Like its identity, an object\\'s\\n*type* is also unchangeable. [1]\\n\\nThe *value* of some objects can change.  Objects whose value can\\nchange are said to be *mutable*; objects whose value is unchangeable\\nonce they are created are called *immutable*. (The value of an\\nimmutable container object that contains a reference to a mutable\\nobject can change when the latter\\'s value is changed; however the\\ncontainer is still considered immutable, because the collection of\\nobjects it contains cannot be changed.  So, immutability is not\\nstrictly the same as having an unchangeable value, it is more subtle.)\\nAn object\\'s mutability is determined by its type; for instance,\\nnumbers, strings and tuples are immutable, while dictionaries and\\nlists are mutable.\\n\\nObjects are never explicitly destroyed; however, when they become\\nunreachable they may be garbage-collected.  An implementation is\\nallowed to postpone garbage collection or omit it altogether --- it is\\na matter of implementation quality how garbage collection is\\nimplemented, as long as no objects are collected that are still\\nreachable.\\n\\n**CPython implementation detail:** CPython currently uses a reference-\\ncounting scheme with (optional) delayed detection of cyclically linked\\ngarbage, which collects most objects as soon as they become\\nunreachable, but is not guaranteed to collect garbage containing\\ncircular references.  See the documentation of the ``gc`` module for\\ninformation on controlling the collection of cyclic garbage. Other\\nimplementations act differently and CPython may change. Do not depend\\non immediate finalization of objects when they become unreachable (ex:\\nalways close files).\\n\\nNote that the use of the implementation\\'s tracing or debugging\\nfacilities may keep objects alive that would normally be collectable.\\nAlso note that catching an exception with a \\'``try``...``except``\\'\\nstatement may keep objects alive.\\n\\nSome objects contain references to \"external\" resources such as open\\nfiles or windows.  It is understood that these resources are freed\\nwhen the object is garbage-collected, but since garbage collection is\\nnot guaranteed to happen, such objects also provide an explicit way to\\nrelease the external resource, usually a ``close()`` method. Programs\\nare strongly recommended to explicitly close such objects.  The\\n\\'``try``...``finally``\\' statement and the \\'``with``\\' statement provide\\nconvenient ways to do this.\\n\\nSome objects contain references to other objects; these are called\\n*containers*. Examples of containers are tuples, lists and\\ndictionaries.  The references are part of a container\\'s value.  In\\nmost cases, when we talk about the value of a container, we imply the\\nvalues, not the identities of the contained objects; however, when we\\ntalk about the mutability of a container, only the identities of the\\nimmediately contained objects are implied.  So, if an immutable\\ncontainer (like a tuple) contains a reference to a mutable object, its\\nvalue changes if that mutable object is changed.\\n\\nTypes affect almost all aspects of object behavior.  Even the\\nimportance of object identity is affected in some sense: for immutable\\ntypes, operations that compute new values may actually return a\\nreference to any existing object with the same type and value, while\\nfor mutable objects this is not allowed.  E.g., after ``a = 1; b =\\n1``, ``a`` and ``b`` may or may not refer to the same object with the\\nvalue one, depending on the implementation, but after ``c = []; d =\\n[]``, ``c`` and ``d`` are guaranteed to refer to two different,\\nunique, newly created empty lists. (Note that ``c = d = []`` assigns\\nthe same object to both ``c`` and ``d``.)\\n',\n'operator-summary':'\\nOperator precedence\\n*******************\\n\\nThe following table summarizes the operator precedences in Python,\\nfrom lowest precedence (least binding) to highest precedence (most\\nbinding).  Operators in the same box have the same precedence.  Unless\\nthe syntax is explicitly given, operators are binary.  Operators in\\nthe same box group left to right (except for comparisons, including\\ntests, which all have the same precedence and chain from left to right\\n--- see section *Comparisons* --- and exponentiation, which groups\\nfrom right to left).\\n\\n+-------------------------------------------------+---------------------------------------+\\n| Operator                                        | Description                           |\\n+=================================================+=======================================+\\n| ``lambda``                                      | Lambda expression                     |\\n+-------------------------------------------------+---------------------------------------+\\n| ``if`` -- ``else``                              | Conditional expression                |\\n+-------------------------------------------------+---------------------------------------+\\n| ``or``                                          | Boolean OR                            |\\n+-------------------------------------------------+---------------------------------------+\\n| ``and``                                         | Boolean AND                           |\\n+-------------------------------------------------+---------------------------------------+\\n| ``not`` ``x``                                   | Boolean NOT                           |\\n+-------------------------------------------------+---------------------------------------+\\n| ``in``, ``not in``, ``is``, ``is not``, ``<``,  | Comparisons, including membership     |\\n| ``<=``, ``>``, ``>=``, ``!=``, ``==``           | tests and identity tests,             |\\n+-------------------------------------------------+---------------------------------------+\\n| ``|``                                           | Bitwise OR                            |\\n+-------------------------------------------------+---------------------------------------+\\n| ``^``                                           | Bitwise XOR                           |\\n+-------------------------------------------------+---------------------------------------+\\n| ``&``                                           | Bitwise AND                           |\\n+-------------------------------------------------+---------------------------------------+\\n| ``<<``, ``>>``                                  | Shifts                                |\\n+-------------------------------------------------+---------------------------------------+\\n| ``+``, ``-``                                    | Addition and subtraction              |\\n+-------------------------------------------------+---------------------------------------+\\n| ``*``, ``/``, ``//``, ``%``                     | Multiplication, division, remainder   |\\n|                                                 | [5]                                   |\\n+-------------------------------------------------+---------------------------------------+\\n| ``+x``, ``-x``, ``~x``                          | Positive, negative, bitwise NOT       |\\n+-------------------------------------------------+---------------------------------------+\\n| ``**``                                          | Exponentiation [6]                    |\\n+-------------------------------------------------+---------------------------------------+\\n| ``x[index]``, ``x[index:index]``,               | Subscription, slicing, call,          |\\n| ``x(arguments...)``, ``x.attribute``            | attribute reference                   |\\n+-------------------------------------------------+---------------------------------------+\\n| ``(expressions...)``, ``[expressions...]``,     | Binding or tuple display, list        |\\n| ``{key: value...}``, ``{expressions...}``       | display, dictionary display, set      |\\n|                                                 | display                               |\\n+-------------------------------------------------+---------------------------------------+\\n\\n-[ Footnotes ]-\\n\\n[1] While ``abs(x%y) < abs(y)`` is true mathematically, for floats it\\n    may not be true numerically due to roundoff.  For example, and\\n    assuming a platform on which a Python float is an IEEE 754 double-\\n    precision number, in order that ``-1e-100 % 1e100`` have the same\\n    sign as ``1e100``, the computed result is ``-1e-100 + 1e100``,\\n    which is numerically exactly equal to ``1e100``.  The function\\n    ``math.fmod()`` returns a result whose sign matches the sign of\\n    the first argument instead, and so returns ``-1e-100`` in this\\n    case. Which approach is more appropriate depends on the\\n    application.\\n\\n[2] If x is very close to an exact integer multiple of y, it\\'s\\n    possible for ``x//y`` to be one larger than ``(x-x%y)//y`` due to\\n    rounding.  In such cases, Python returns the latter result, in\\n    order to preserve that ``divmod(x,y)[0] * y + x % y`` be very\\n    close to ``x``.\\n\\n[3] While comparisons between strings make sense at the byte level,\\n    they may be counter-intuitive to users.  For example, the strings\\n    ``\"\\\\u00C7\"`` and ``\"\\\\u0327\\\\u0043\"`` compare differently, even\\n    though they both represent the same unicode character (LATIN\\n    CAPITAL LETTER C WITH CEDILLA).  To compare strings in a human\\n    recognizable way, compare using ``unicodedata.normalize()``.\\n\\n[4] Due to automatic garbage-collection, free lists, and the dynamic\\n    nature of descriptors, you may notice seemingly unusual behaviour\\n    in certain uses of the ``is`` operator, like those involving\\n    comparisons between instance methods, or constants.  Check their\\n    documentation for more info.\\n\\n[5] The ``%`` operator is also used for string formatting; the same\\n    precedence applies.\\n\\n[6] The power operator ``**`` binds less tightly than an arithmetic or\\n    bitwise unary operator on its right, that is, ``2**-1`` is\\n    ``0.5``.\\n',\n'pass':'\\nThe ``pass`` statement\\n**********************\\n\\n   pass_stmt ::= \"pass\"\\n\\n``pass`` is a null operation --- when it is executed, nothing happens.\\nIt is useful as a placeholder when a statement is required\\nsyntactically, but no code needs to be executed, for example:\\n\\n   def f(arg): pass    # a function that does nothing (yet)\\n\\n   class C: pass       # a class with no methods (yet)\\n',\n'power':'\\nThe power operator\\n******************\\n\\nThe power operator binds more tightly than unary operators on its\\nleft; it binds less tightly than unary operators on its right.  The\\nsyntax is:\\n\\n   power ::= primary [\"**\" u_expr]\\n\\nThus, in an unparenthesized sequence of power and unary operators, the\\noperators are evaluated from right to left (this does not constrain\\nthe evaluation order for the operands): ``-1**2`` results in ``-1``.\\n\\nThe power operator has the same semantics as the built-in ``pow()``\\nfunction, when called with two arguments: it yields its left argument\\nraised to the power of its right argument.  The numeric arguments are\\nfirst converted to a common type, and the result is of that type.\\n\\nFor int operands, the result has the same type as the operands unless\\nthe second argument is negative; in that case, all arguments are\\nconverted to float and a float result is delivered. For example,\\n``10**2`` returns ``100``, but ``10**-2`` returns ``0.01``.\\n\\nRaising ``0.0`` to a negative power results in a\\n``ZeroDivisionError``. Raising a negative number to a fractional power\\nresults in a ``complex`` number. (In earlier versions it raised a\\n``ValueError``.)\\n',\n'raise':'\\nThe ``raise`` statement\\n***********************\\n\\n   raise_stmt ::= \"raise\" [expression [\"from\" expression]]\\n\\nIf no expressions are present, ``raise`` re-raises the last exception\\nthat was active in the current scope.  If no exception is active in\\nthe current scope, a ``RuntimeError`` exception is raised indicating\\nthat this is an error.\\n\\nOtherwise, ``raise`` evaluates the first expression as the exception\\nobject.  It must be either a subclass or an instance of\\n``BaseException``. If it is a class, the exception instance will be\\nobtained when needed by instantiating the class with no arguments.\\n\\nThe *type* of the exception is the exception instance\\'s class, the\\n*value* is the instance itself.\\n\\nA traceback object is normally created automatically when an exception\\nis raised and attached to it as the ``__traceback__`` attribute, which\\nis writable. You can create an exception and set your own traceback in\\none step using the ``with_traceback()`` exception method (which\\nreturns the same exception instance, with its traceback set to its\\nargument), like so:\\n\\n   raise Exception(\"foo occurred\").with_traceback(tracebackobj)\\n\\nThe ``from`` clause is used for exception chaining: if given, the\\nsecond *expression* must be another exception class or instance, which\\nwill then be attached to the raised exception as the ``__cause__``\\nattribute (which is writable).  If the raised exception is not\\nhandled, both exceptions will be printed:\\n\\n   >>> try:\\n   ...     print(1 / 0)\\n   ... except Exception as exc:\\n   ...     raise RuntimeError(\"Something bad happened\") from exc\\n   ...\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 2, in <module>\\n   ZeroDivisionError: int division or modulo by zero\\n\\n   The above exception was the direct cause of the following exception:\\n\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 4, in <module>\\n   RuntimeError: Something bad happened\\n\\nA similar mechanism works implicitly if an exception is raised inside\\nan exception handler: the previous exception is then attached as the\\nnew exception\\'s ``__context__`` attribute:\\n\\n   >>> try:\\n   ...     print(1 / 0)\\n   ... except:\\n   ...     raise RuntimeError(\"Something bad happened\")\\n   ...\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 2, in <module>\\n   ZeroDivisionError: int division or modulo by zero\\n\\n   During handling of the above exception, another exception occurred:\\n\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 4, in <module>\\n   RuntimeError: Something bad happened\\n\\nAdditional information on exceptions can be found in section\\n*Exceptions*, and information about handling exceptions is in section\\n*The try statement*.\\n',\n'return':'\\nThe ``return`` statement\\n************************\\n\\n   return_stmt ::= \"return\" [expression_list]\\n\\n``return`` may only occur syntactically nested in a function\\ndefinition, not within a nested class definition.\\n\\nIf an expression list is present, it is evaluated, else ``None`` is\\nsubstituted.\\n\\n``return`` leaves the current function call with the expression list\\n(or ``None``) as return value.\\n\\nWhen ``return`` passes control out of a ``try`` statement with a\\n``finally`` clause, that ``finally`` clause is executed before really\\nleaving the function.\\n\\nIn a generator function, the ``return`` statement indicates that the\\ngenerator is done and will cause ``StopIteration`` to be raised. The\\nreturned value (if any) is used as an argument to construct\\n``StopIteration`` and becomes the ``StopIteration.value`` attribute.\\n',\n'sequence-types':\"\\nEmulating container types\\n*************************\\n\\nThe following methods can be defined to implement container objects.\\nContainers usually are sequences (such as lists or tuples) or mappings\\n(like dictionaries), but can represent other containers as well.  The\\nfirst set of methods is used either to emulate a sequence or to\\nemulate a mapping; the difference is that for a sequence, the\\nallowable keys should be the integers *k* for which ``0 <= k < N``\\nwhere *N* is the length of the sequence, or slice objects, which\\ndefine a range of items.  It is also recommended that mappings provide\\nthe methods ``keys()``, ``values()``, ``items()``, ``get()``,\\n``clear()``, ``setdefault()``, ``pop()``, ``popitem()``, ``copy()``,\\nand ``update()`` behaving similar to those for Python's standard\\ndictionary objects.  The ``collections`` module provides a\\n``MutableMapping`` abstract base class to help create those methods\\nfrom a base set of ``__getitem__()``, ``__setitem__()``,\\n``__delitem__()``, and ``keys()``. Mutable sequences should provide\\nmethods ``append()``, ``count()``, ``index()``, ``extend()``,\\n``insert()``, ``pop()``, ``remove()``, ``reverse()`` and ``sort()``,\\nlike Python standard list objects.  Finally, sequence types should\\nimplement addition (meaning concatenation) and multiplication (meaning\\nrepetition) by defining the methods ``__add__()``, ``__radd__()``,\\n``__iadd__()``, ``__mul__()``, ``__rmul__()`` and ``__imul__()``\\ndescribed below; they should not define other numerical operators.  It\\nis recommended that both mappings and sequences implement the\\n``__contains__()`` method to allow efficient use of the ``in``\\noperator; for mappings, ``in`` should search the mapping's keys; for\\nsequences, it should search through the values.  It is further\\nrecommended that both mappings and sequences implement the\\n``__iter__()`` method to allow efficient iteration through the\\ncontainer; for mappings, ``__iter__()`` should be the same as\\n``keys()``; for sequences, it should iterate through the values.\\n\\nobject.__len__(self)\\n\\n   Called to implement the built-in function ``len()``.  Should return\\n   the length of the object, an integer ``>=`` 0.  Also, an object\\n   that doesn't define a ``__bool__()`` method and whose ``__len__()``\\n   method returns zero is considered to be false in a Boolean context.\\n\\nNote: Slicing is done exclusively with the following three methods.  A\\n  call like\\n\\n     a[1:2] = b\\n\\n  is translated to\\n\\n     a[slice(1, 2, None)] = b\\n\\n  and so forth.  Missing slice items are always filled in with\\n  ``None``.\\n\\nobject.__getitem__(self, key)\\n\\n   Called to implement evaluation of ``self[key]``. For sequence\\n   types, the accepted keys should be integers and slice objects.\\n   Note that the special interpretation of negative indexes (if the\\n   class wishes to emulate a sequence type) is up to the\\n   ``__getitem__()`` method. If *key* is of an inappropriate type,\\n   ``TypeError`` may be raised; if of a value outside the set of\\n   indexes for the sequence (after any special interpretation of\\n   negative values), ``IndexError`` should be raised. For mapping\\n   types, if *key* is missing (not in the container), ``KeyError``\\n   should be raised.\\n\\n   Note: ``for`` loops expect that an ``IndexError`` will be raised for\\n     illegal indexes to allow proper detection of the end of the\\n     sequence.\\n\\nobject.__setitem__(self, key, value)\\n\\n   Called to implement assignment to ``self[key]``.  Same note as for\\n   ``__getitem__()``.  This should only be implemented for mappings if\\n   the objects support changes to the values for keys, or if new keys\\n   can be added, or for sequences if elements can be replaced.  The\\n   same exceptions should be raised for improper *key* values as for\\n   the ``__getitem__()`` method.\\n\\nobject.__delitem__(self, key)\\n\\n   Called to implement deletion of ``self[key]``.  Same note as for\\n   ``__getitem__()``.  This should only be implemented for mappings if\\n   the objects support removal of keys, or for sequences if elements\\n   can be removed from the sequence.  The same exceptions should be\\n   raised for improper *key* values as for the ``__getitem__()``\\n   method.\\n\\nobject.__iter__(self)\\n\\n   This method is called when an iterator is required for a container.\\n   This method should return a new iterator object that can iterate\\n   over all the objects in the container.  For mappings, it should\\n   iterate over the keys of the container, and should also be made\\n   available as the method ``keys()``.\\n\\n   Iterator objects also need to implement this method; they are\\n   required to return themselves.  For more information on iterator\\n   objects, see *Iterator Types*.\\n\\nobject.__reversed__(self)\\n\\n   Called (if present) by the ``reversed()`` built-in to implement\\n   reverse iteration.  It should return a new iterator object that\\n   iterates over all the objects in the container in reverse order.\\n\\n   If the ``__reversed__()`` method is not provided, the\\n   ``reversed()`` built-in will fall back to using the sequence\\n   protocol (``__len__()`` and ``__getitem__()``).  Objects that\\n   support the sequence protocol should only provide\\n   ``__reversed__()`` if they can provide an implementation that is\\n   more efficient than the one provided by ``reversed()``.\\n\\nThe membership test operators (``in`` and ``not in``) are normally\\nimplemented as an iteration through a sequence.  However, container\\nobjects can supply the following special method with a more efficient\\nimplementation, which also does not require the object be a sequence.\\n\\nobject.__contains__(self, item)\\n\\n   Called to implement membership test operators.  Should return true\\n   if *item* is in *self*, false otherwise.  For mapping objects, this\\n   should consider the keys of the mapping rather than the values or\\n   the key-item pairs.\\n\\n   For objects that don't define ``__contains__()``, the membership\\n   test first tries iteration via ``__iter__()``, then the old\\n   sequence iteration protocol via ``__getitem__()``, see *this\\n   section in the language reference*.\\n\",\n'shifting':'\\nShifting operations\\n*******************\\n\\nThe shifting operations have lower priority than the arithmetic\\noperations:\\n\\n   shift_expr ::= a_expr | shift_expr ( \"<<\" | \">>\" ) a_expr\\n\\nThese operators accept integers as arguments.  They shift the first\\nargument to the left or right by the number of bits given by the\\nsecond argument.\\n\\nA right shift by *n* bits is defined as division by ``pow(2,n)``.  A\\nleft shift by *n* bits is defined as multiplication with ``pow(2,n)``.\\n\\nNote: In the current implementation, the right-hand operand is required to\\n  be at most ``sys.maxsize``.  If the right-hand operand is larger\\n  than ``sys.maxsize`` an ``OverflowError`` exception is raised.\\n',\n'slicings':'\\nSlicings\\n********\\n\\nA slicing selects a range of items in a sequence object (e.g., a\\nstring, tuple or list).  Slicings may be used as expressions or as\\ntargets in assignment or ``del`` statements.  The syntax for a\\nslicing:\\n\\n   slicing      ::= primary \"[\" slice_list \"]\"\\n   slice_list   ::= slice_item (\",\" slice_item)* [\",\"]\\n   slice_item   ::= expression | proper_slice\\n   proper_slice ::= [lower_bound] \":\" [upper_bound] [ \":\" [stride] ]\\n   lower_bound  ::= expression\\n   upper_bound  ::= expression\\n   stride       ::= expression\\n\\nThere is ambiguity in the formal syntax here: anything that looks like\\nan expression list also looks like a slice list, so any subscription\\ncan be interpreted as a slicing.  Rather than further complicating the\\nsyntax, this is disambiguated by defining that in this case the\\ninterpretation as a subscription takes priority over the\\ninterpretation as a slicing (this is the case if the slice list\\ncontains no proper slice).\\n\\nThe semantics for a slicing are as follows.  The primary must evaluate\\nto a mapping object, and it is indexed (using the same\\n``__getitem__()`` method as normal subscription) with a key that is\\nconstructed from the slice list, as follows.  If the slice list\\ncontains at least one comma, the key is a tuple containing the\\nconversion of the slice items; otherwise, the conversion of the lone\\nslice item is the key.  The conversion of a slice item that is an\\nexpression is that expression.  The conversion of a proper slice is a\\nslice object (see section *The standard type hierarchy*) whose\\n``start``, ``stop`` and ``step`` attributes are the values of the\\nexpressions given as lower bound, upper bound and stride,\\nrespectively, substituting ``None`` for missing expressions.\\n',\n'specialattrs':'\\nSpecial Attributes\\n******************\\n\\nThe implementation adds a few special read-only attributes to several\\nobject types, where they are relevant.  Some of these are not reported\\nby the ``dir()`` built-in function.\\n\\nobject.__dict__\\n\\n   A dictionary or other mapping object used to store an object\\'s\\n   (writable) attributes.\\n\\ninstance.__class__\\n\\n   The class to which a class instance belongs.\\n\\nclass.__bases__\\n\\n   The tuple of base classes of a class object.\\n\\nclass.__name__\\n\\n   The name of the class or type.\\n\\nclass.__qualname__\\n\\n   The *qualified name* of the class or type.\\n\\n   New in version 3.3.\\n\\nclass.__mro__\\n\\n   This attribute is a tuple of classes that are considered when\\n   looking for base classes during method resolution.\\n\\nclass.mro()\\n\\n   This method can be overridden by a metaclass to customize the\\n   method resolution order for its instances.  It is called at class\\n   instantiation, and its result is stored in ``__mro__``.\\n\\nclass.__subclasses__()\\n\\n   Each class keeps a list of weak references to its immediate\\n   subclasses.  This method returns a list of all those references\\n   still alive. Example:\\n\\n      >>> int.__subclasses__()\\n      [<class \\'bool\\'>]\\n\\n-[ Footnotes ]-\\n\\n[1] Additional information on these special methods may be found in\\n    the Python Reference Manual (*Basic customization*).\\n\\n[2] As a consequence, the list ``[1, 2]`` is considered equal to\\n    ``[1.0, 2.0]``, and similarly for tuples.\\n\\n[3] They must have since the parser can\\'t tell the type of the\\n    operands.\\n\\n[4] Cased characters are those with general category property being\\n    one of \"Lu\" (Letter, uppercase), \"Ll\" (Letter, lowercase), or \"Lt\"\\n    (Letter, titlecase).\\n\\n[5] To format only a tuple you should therefore provide a singleton\\n    tuple whose only element is the tuple to be formatted.\\n',\n'specialnames':'\\nSpecial method names\\n********************\\n\\nA class can implement certain operations that are invoked by special\\nsyntax (such as arithmetic operations or subscripting and slicing) by\\ndefining methods with special names. This is Python\\'s approach to\\n*operator overloading*, allowing classes to define their own behavior\\nwith respect to language operators.  For instance, if a class defines\\na method named ``__getitem__()``, and ``x`` is an instance of this\\nclass, then ``x[i]`` is roughly equivalent to ``type(x).__getitem__(x,\\ni)``.  Except where mentioned, attempts to execute an operation raise\\nan exception when no appropriate method is defined (typically\\n``AttributeError`` or ``TypeError``).\\n\\nWhen implementing a class that emulates any built-in type, it is\\nimportant that the emulation only be implemented to the degree that it\\nmakes sense for the object being modelled.  For example, some\\nsequences may work well with retrieval of individual elements, but\\nextracting a slice may not make sense.  (One example of this is the\\n``NodeList`` interface in the W3C\\'s Document Object Model.)\\n\\n\\nBasic customization\\n===================\\n\\nobject.__new__(cls[, ...])\\n\\n   Called to create a new instance of class *cls*.  ``__new__()`` is a\\n   static method (special-cased so you need not declare it as such)\\n   that takes the class of which an instance was requested as its\\n   first argument.  The remaining arguments are those passed to the\\n   object constructor expression (the call to the class).  The return\\n   value of ``__new__()`` should be the new object instance (usually\\n   an instance of *cls*).\\n\\n   Typical implementations create a new instance of the class by\\n   invoking the superclass\\'s ``__new__()`` method using\\n   ``super(currentclass, cls).__new__(cls[, ...])`` with appropriate\\n   arguments and then modifying the newly-created instance as\\n   necessary before returning it.\\n\\n   If ``__new__()`` returns an instance of *cls*, then the new\\n   instance\\'s ``__init__()`` method will be invoked like\\n   ``__init__(self[, ...])``, where *self* is the new instance and the\\n   remaining arguments are the same as were passed to ``__new__()``.\\n\\n   If ``__new__()`` does not return an instance of *cls*, then the new\\n   instance\\'s ``__init__()`` method will not be invoked.\\n\\n   ``__new__()`` is intended mainly to allow subclasses of immutable\\n   types (like int, str, or tuple) to customize instance creation.  It\\n   is also commonly overridden in custom metaclasses in order to\\n   customize class creation.\\n\\nobject.__init__(self[, ...])\\n\\n   Called when the instance is created.  The arguments are those\\n   passed to the class constructor expression.  If a base class has an\\n   ``__init__()`` method, the derived class\\'s ``__init__()`` method,\\n   if any, must explicitly call it to ensure proper initialization of\\n   the base class part of the instance; for example:\\n   ``BaseClass.__init__(self, [args...])``.  As a special constraint\\n   on constructors, no value may be returned; doing so will cause a\\n   ``TypeError`` to be raised at runtime.\\n\\nobject.__del__(self)\\n\\n   Called when the instance is about to be destroyed.  This is also\\n   called a destructor.  If a base class has a ``__del__()`` method,\\n   the derived class\\'s ``__del__()`` method, if any, must explicitly\\n   call it to ensure proper deletion of the base class part of the\\n   instance.  Note that it is possible (though not recommended!) for\\n   the ``__del__()`` method to postpone destruction of the instance by\\n   creating a new reference to it.  It may then be called at a later\\n   time when this new reference is deleted.  It is not guaranteed that\\n   ``__del__()`` methods are called for objects that still exist when\\n   the interpreter exits.\\n\\n   Note: ``del x`` doesn\\'t directly call ``x.__del__()`` --- the former\\n     decrements the reference count for ``x`` by one, and the latter\\n     is only called when ``x``\\'s reference count reaches zero.  Some\\n     common situations that may prevent the reference count of an\\n     object from going to zero include: circular references between\\n     objects (e.g., a doubly-linked list or a tree data structure with\\n     parent and child pointers); a reference to the object on the\\n     stack frame of a function that caught an exception (the traceback\\n     stored in ``sys.exc_info()[2]`` keeps the stack frame alive); or\\n     a reference to the object on the stack frame that raised an\\n     unhandled exception in interactive mode (the traceback stored in\\n     ``sys.last_traceback`` keeps the stack frame alive).  The first\\n     situation can only be remedied by explicitly breaking the cycles;\\n     the latter two situations can be resolved by storing ``None`` in\\n     ``sys.last_traceback``. Circular references which are garbage are\\n     detected when the option cycle detector is enabled (it\\'s on by\\n     default), but can only be cleaned up if there are no Python-\\n     level ``__del__()`` methods involved. Refer to the documentation\\n     for the ``gc`` module for more information about how\\n     ``__del__()`` methods are handled by the cycle detector,\\n     particularly the description of the ``garbage`` value.\\n\\n   Warning: Due to the precarious circumstances under which ``__del__()``\\n     methods are invoked, exceptions that occur during their execution\\n     are ignored, and a warning is printed to ``sys.stderr`` instead.\\n     Also, when ``__del__()`` is invoked in response to a module being\\n     deleted (e.g., when execution of the program is done), other\\n     globals referenced by the ``__del__()`` method may already have\\n     been deleted or in the process of being torn down (e.g. the\\n     import machinery shutting down).  For this reason, ``__del__()``\\n     methods should do the absolute minimum needed to maintain\\n     external invariants.  Starting with version 1.5, Python\\n     guarantees that globals whose name begins with a single\\n     underscore are deleted from their module before other globals are\\n     deleted; if no other references to such globals exist, this may\\n     help in assuring that imported modules are still available at the\\n     time when the ``__del__()`` method is called.\\n\\nobject.__repr__(self)\\n\\n   Called by the ``repr()`` built-in function to compute the\\n   \"official\" string representation of an object.  If at all possible,\\n   this should look like a valid Python expression that could be used\\n   to recreate an object with the same value (given an appropriate\\n   environment).  If this is not possible, a string of the form\\n   ``<...some useful description...>`` should be returned. The return\\n   value must be a string object. If a class defines ``__repr__()``\\n   but not ``__str__()``, then ``__repr__()`` is also used when an\\n   \"informal\" string representation of instances of that class is\\n   required.\\n\\n   This is typically used for debugging, so it is important that the\\n   representation is information-rich and unambiguous.\\n\\nobject.__str__(self)\\n\\n   Called by ``str(object)`` and the built-in functions ``format()``\\n   and ``print()`` to compute the \"informal\" or nicely printable\\n   string representation of an object.  The return value must be a\\n   *string* object.\\n\\n   This method differs from ``object.__repr__()`` in that there is no\\n   expectation that ``__str__()`` return a valid Python expression: a\\n   more convenient or concise representation can be used.\\n\\n   The default implementation defined by the built-in type ``object``\\n   calls ``object.__repr__()``.\\n\\nobject.__bytes__(self)\\n\\n   Called by ``bytes()`` to compute a byte-string representation of an\\n   object. This should return a ``bytes`` object.\\n\\nobject.__format__(self, format_spec)\\n\\n   Called by the ``format()`` built-in function (and by extension, the\\n   ``str.format()`` method of class ``str``) to produce a \"formatted\"\\n   string representation of an object. The ``format_spec`` argument is\\n   a string that contains a description of the formatting options\\n   desired. The interpretation of the ``format_spec`` argument is up\\n   to the type implementing ``__format__()``, however most classes\\n   will either delegate formatting to one of the built-in types, or\\n   use a similar formatting option syntax.\\n\\n   See *Format Specification Mini-Language* for a description of the\\n   standard formatting syntax.\\n\\n   The return value must be a string object.\\n\\nobject.__lt__(self, other)\\nobject.__le__(self, other)\\nobject.__eq__(self, other)\\nobject.__ne__(self, other)\\nobject.__gt__(self, other)\\nobject.__ge__(self, other)\\n\\n   These are the so-called \"rich comparison\" methods. The\\n   correspondence between operator symbols and method names is as\\n   follows: ``x<y`` calls ``x.__lt__(y)``, ``x<=y`` calls\\n   ``x.__le__(y)``, ``x==y`` calls ``x.__eq__(y)``, ``x!=y`` calls\\n   ``x.__ne__(y)``, ``x>y`` calls ``x.__gt__(y)``, and ``x>=y`` calls\\n   ``x.__ge__(y)``.\\n\\n   A rich comparison method may return the singleton\\n   ``NotImplemented`` if it does not implement the operation for a\\n   given pair of arguments. By convention, ``False`` and ``True`` are\\n   returned for a successful comparison. However, these methods can\\n   return any value, so if the comparison operator is used in a\\n   Boolean context (e.g., in the condition of an ``if`` statement),\\n   Python will call ``bool()`` on the value to determine if the result\\n   is true or false.\\n\\n   There are no implied relationships among the comparison operators.\\n   The truth of ``x==y`` does not imply that ``x!=y`` is false.\\n   Accordingly, when defining ``__eq__()``, one should also define\\n   ``__ne__()`` so that the operators will behave as expected.  See\\n   the paragraph on ``__hash__()`` for some important notes on\\n   creating *hashable* objects which support custom comparison\\n   operations and are usable as dictionary keys.\\n\\n   There are no swapped-argument versions of these methods (to be used\\n   when the left argument does not support the operation but the right\\n   argument does); rather, ``__lt__()`` and ``__gt__()`` are each\\n   other\\'s reflection, ``__le__()`` and ``__ge__()`` are each other\\'s\\n   reflection, and ``__eq__()`` and ``__ne__()`` are their own\\n   reflection.\\n\\n   Arguments to rich comparison methods are never coerced.\\n\\n   To automatically generate ordering operations from a single root\\n   operation, see ``functools.total_ordering()``.\\n\\nobject.__hash__(self)\\n\\n   Called by built-in function ``hash()`` and for operations on\\n   members of hashed collections including ``set``, ``frozenset``, and\\n   ``dict``.  ``__hash__()`` should return an integer.  The only\\n   required property is that objects which compare equal have the same\\n   hash value; it is advised to somehow mix together (e.g. using\\n   exclusive or) the hash values for the components of the object that\\n   also play a part in comparison of objects.\\n\\n   If a class does not define an ``__eq__()`` method it should not\\n   define a ``__hash__()`` operation either; if it defines\\n   ``__eq__()`` but not ``__hash__()``, its instances will not be\\n   usable as items in hashable collections.  If a class defines\\n   mutable objects and implements an ``__eq__()`` method, it should\\n   not implement ``__hash__()``, since the implementation of hashable\\n   collections requires that a key\\'s hash value is immutable (if the\\n   object\\'s hash value changes, it will be in the wrong hash bucket).\\n\\n   User-defined classes have ``__eq__()`` and ``__hash__()`` methods\\n   by default; with them, all objects compare unequal (except with\\n   themselves) and ``x.__hash__()`` returns an appropriate value such\\n   that ``x == y`` implies both that ``x is y`` and ``hash(x) ==\\n   hash(y)``.\\n\\n   A class that overrides ``__eq__()`` and does not define\\n   ``__hash__()`` will have its ``__hash__()`` implicitly set to\\n   ``None``.  When the ``__hash__()`` method of a class is ``None``,\\n   instances of the class will raise an appropriate ``TypeError`` when\\n   a program attempts to retrieve their hash value, and will also be\\n   correctly identified as unhashable when checking ``isinstance(obj,\\n   collections.Hashable``).\\n\\n   If a class that overrides ``__eq__()`` needs to retain the\\n   implementation of ``__hash__()`` from a parent class, the\\n   interpreter must be told this explicitly by setting ``__hash__ =\\n   <ParentClass>.__hash__``.\\n\\n   If a class that does not override ``__eq__()`` wishes to suppress\\n   hash support, it should include ``__hash__ = None`` in the class\\n   definition. A class which defines its own ``__hash__()`` that\\n   explicitly raises a ``TypeError`` would be incorrectly identified\\n   as hashable by an ``isinstance(obj, collections.Hashable)`` call.\\n\\n   Note: By default, the ``__hash__()`` values of str, bytes and datetime\\n     objects are \"salted\" with an unpredictable random value.\\n     Although they remain constant within an individual Python\\n     process, they are not predictable between repeated invocations of\\n     Python.This is intended to provide protection against a denial-\\n     of-service caused by carefully-chosen inputs that exploit the\\n     worst case performance of a dict insertion, O(n^2) complexity.\\n     See http://www.ocert.org/advisories/ocert-2011-003.html for\\n     details.Changing hash values affects the iteration order of\\n     dicts, sets and other mappings.  Python has never made guarantees\\n     about this ordering (and it typically varies between 32-bit and\\n     64-bit builds).See also ``PYTHONHASHSEED``.\\n\\n   Changed in version 3.3: Hash randomization is enabled by default.\\n\\nobject.__bool__(self)\\n\\n   Called to implement truth value testing and the built-in operation\\n   ``bool()``; should return ``False`` or ``True``.  When this method\\n   is not defined, ``__len__()`` is called, if it is defined, and the\\n   object is considered true if its result is nonzero.  If a class\\n   defines neither ``__len__()`` nor ``__bool__()``, all its instances\\n   are considered true.\\n\\n\\nCustomizing attribute access\\n============================\\n\\nThe following methods can be defined to customize the meaning of\\nattribute access (use of, assignment to, or deletion of ``x.name``)\\nfor class instances.\\n\\nobject.__getattr__(self, name)\\n\\n   Called when an attribute lookup has not found the attribute in the\\n   usual places (i.e. it is not an instance attribute nor is it found\\n   in the class tree for ``self``).  ``name`` is the attribute name.\\n   This method should return the (computed) attribute value or raise\\n   an ``AttributeError`` exception.\\n\\n   Note that if the attribute is found through the normal mechanism,\\n   ``__getattr__()`` is not called.  (This is an intentional asymmetry\\n   between ``__getattr__()`` and ``__setattr__()``.) This is done both\\n   for efficiency reasons and because otherwise ``__getattr__()``\\n   would have no way to access other attributes of the instance.  Note\\n   that at least for instance variables, you can fake total control by\\n   not inserting any values in the instance attribute dictionary (but\\n   instead inserting them in another object).  See the\\n   ``__getattribute__()`` method below for a way to actually get total\\n   control over attribute access.\\n\\nobject.__getattribute__(self, name)\\n\\n   Called unconditionally to implement attribute accesses for\\n   instances of the class. If the class also defines\\n   ``__getattr__()``, the latter will not be called unless\\n   ``__getattribute__()`` either calls it explicitly or raises an\\n   ``AttributeError``. This method should return the (computed)\\n   attribute value or raise an ``AttributeError`` exception. In order\\n   to avoid infinite recursion in this method, its implementation\\n   should always call the base class method with the same name to\\n   access any attributes it needs, for example,\\n   ``object.__getattribute__(self, name)``.\\n\\n   Note: This method may still be bypassed when looking up special methods\\n     as the result of implicit invocation via language syntax or\\n     built-in functions. See *Special method lookup*.\\n\\nobject.__setattr__(self, name, value)\\n\\n   Called when an attribute assignment is attempted.  This is called\\n   instead of the normal mechanism (i.e. store the value in the\\n   instance dictionary). *name* is the attribute name, *value* is the\\n   value to be assigned to it.\\n\\n   If ``__setattr__()`` wants to assign to an instance attribute, it\\n   should call the base class method with the same name, for example,\\n   ``object.__setattr__(self, name, value)``.\\n\\nobject.__delattr__(self, name)\\n\\n   Like ``__setattr__()`` but for attribute deletion instead of\\n   assignment.  This should only be implemented if ``del obj.name`` is\\n   meaningful for the object.\\n\\nobject.__dir__(self)\\n\\n   Called when ``dir()`` is called on the object. A sequence must be\\n   returned. ``dir()`` converts the returned sequence to a list and\\n   sorts it.\\n\\n\\nImplementing Descriptors\\n------------------------\\n\\nThe following methods only apply when an instance of the class\\ncontaining the method (a so-called *descriptor* class) appears in an\\n*owner* class (the descriptor must be in either the owner\\'s class\\ndictionary or in the class dictionary for one of its parents).  In the\\nexamples below, \"the attribute\" refers to the attribute whose name is\\nthe key of the property in the owner class\\' ``__dict__``.\\n\\nobject.__get__(self, instance, owner)\\n\\n   Called to get the attribute of the owner class (class attribute\\n   access) or of an instance of that class (instance attribute\\n   access). *owner* is always the owner class, while *instance* is the\\n   instance that the attribute was accessed through, or ``None`` when\\n   the attribute is accessed through the *owner*.  This method should\\n   return the (computed) attribute value or raise an\\n   ``AttributeError`` exception.\\n\\nobject.__set__(self, instance, value)\\n\\n   Called to set the attribute on an instance *instance* of the owner\\n   class to a new value, *value*.\\n\\nobject.__delete__(self, instance)\\n\\n   Called to delete the attribute on an instance *instance* of the\\n   owner class.\\n\\n\\nInvoking Descriptors\\n--------------------\\n\\nIn general, a descriptor is an object attribute with \"binding\\nbehavior\", one whose attribute access has been overridden by methods\\nin the descriptor protocol:  ``__get__()``, ``__set__()``, and\\n``__delete__()``. If any of those methods are defined for an object,\\nit is said to be a descriptor.\\n\\nThe default behavior for attribute access is to get, set, or delete\\nthe attribute from an object\\'s dictionary. For instance, ``a.x`` has a\\nlookup chain starting with ``a.__dict__[\\'x\\']``, then\\n``type(a).__dict__[\\'x\\']``, and continuing through the base classes of\\n``type(a)`` excluding metaclasses.\\n\\nHowever, if the looked-up value is an object defining one of the\\ndescriptor methods, then Python may override the default behavior and\\ninvoke the descriptor method instead.  Where this occurs in the\\nprecedence chain depends on which descriptor methods were defined and\\nhow they were called.\\n\\nThe starting point for descriptor invocation is a binding, ``a.x``.\\nHow the arguments are assembled depends on ``a``:\\n\\nDirect Call\\n   The simplest and least common call is when user code directly\\n   invokes a descriptor method:    ``x.__get__(a)``.\\n\\nInstance Binding\\n   If binding to an object instance, ``a.x`` is transformed into the\\n   call: ``type(a).__dict__[\\'x\\'].__get__(a, type(a))``.\\n\\nClass Binding\\n   If binding to a class, ``A.x`` is transformed into the call:\\n   ``A.__dict__[\\'x\\'].__get__(None, A)``.\\n\\nSuper Binding\\n   If ``a`` is an instance of ``super``, then the binding ``super(B,\\n   obj).m()`` searches ``obj.__class__.__mro__`` for the base class\\n   ``A`` immediately preceding ``B`` and then invokes the descriptor\\n   with the call: ``A.__dict__[\\'m\\'].__get__(obj, obj.__class__)``.\\n\\nFor instance bindings, the precedence of descriptor invocation depends\\non the which descriptor methods are defined.  A descriptor can define\\nany combination of ``__get__()``, ``__set__()`` and ``__delete__()``.\\nIf it does not define ``__get__()``, then accessing the attribute will\\nreturn the descriptor object itself unless there is a value in the\\nobject\\'s instance dictionary.  If the descriptor defines ``__set__()``\\nand/or ``__delete__()``, it is a data descriptor; if it defines\\nneither, it is a non-data descriptor.  Normally, data descriptors\\ndefine both ``__get__()`` and ``__set__()``, while non-data\\ndescriptors have just the ``__get__()`` method.  Data descriptors with\\n``__set__()`` and ``__get__()`` defined always override a redefinition\\nin an instance dictionary.  In contrast, non-data descriptors can be\\noverridden by instances.\\n\\nPython methods (including ``staticmethod()`` and ``classmethod()``)\\nare implemented as non-data descriptors.  Accordingly, instances can\\nredefine and override methods.  This allows individual instances to\\nacquire behaviors that differ from other instances of the same class.\\n\\nThe ``property()`` function is implemented as a data descriptor.\\nAccordingly, instances cannot override the behavior of a property.\\n\\n\\n__slots__\\n---------\\n\\nBy default, instances of classes have a dictionary for attribute\\nstorage.  This wastes space for objects having very few instance\\nvariables.  The space consumption can become acute when creating large\\nnumbers of instances.\\n\\nThe default can be overridden by defining *__slots__* in a class\\ndefinition. The *__slots__* declaration takes a sequence of instance\\nvariables and reserves just enough space in each instance to hold a\\nvalue for each variable.  Space is saved because *__dict__* is not\\ncreated for each instance.\\n\\nobject.__slots__\\n\\n   This class variable can be assigned a string, iterable, or sequence\\n   of strings with variable names used by instances.  If defined in a\\n   class, *__slots__* reserves space for the declared variables and\\n   prevents the automatic creation of *__dict__* and *__weakref__* for\\n   each instance.\\n\\n\\nNotes on using *__slots__*\\n~~~~~~~~~~~~~~~~~~~~~~~~~~\\n\\n* When inheriting from a class without *__slots__*, the *__dict__*\\n  attribute of that class will always be accessible, so a *__slots__*\\n  definition in the subclass is meaningless.\\n\\n* Without a *__dict__* variable, instances cannot be assigned new\\n  variables not listed in the *__slots__* definition.  Attempts to\\n  assign to an unlisted variable name raises ``AttributeError``. If\\n  dynamic assignment of new variables is desired, then add\\n  ``\\'__dict__\\'`` to the sequence of strings in the *__slots__*\\n  declaration.\\n\\n* Without a *__weakref__* variable for each instance, classes defining\\n  *__slots__* do not support weak references to its instances. If weak\\n  reference support is needed, then add ``\\'__weakref__\\'`` to the\\n  sequence of strings in the *__slots__* declaration.\\n\\n* *__slots__* are implemented at the class level by creating\\n  descriptors (*Implementing Descriptors*) for each variable name.  As\\n  a result, class attributes cannot be used to set default values for\\n  instance variables defined by *__slots__*; otherwise, the class\\n  attribute would overwrite the descriptor assignment.\\n\\n* The action of a *__slots__* declaration is limited to the class\\n  where it is defined.  As a result, subclasses will have a *__dict__*\\n  unless they also define *__slots__* (which must only contain names\\n  of any *additional* slots).\\n\\n* If a class defines a slot also defined in a base class, the instance\\n  variable defined by the base class slot is inaccessible (except by\\n  retrieving its descriptor directly from the base class). This\\n  renders the meaning of the program undefined.  In the future, a\\n  check may be added to prevent this.\\n\\n* Nonempty *__slots__* does not work for classes derived from\\n  \"variable-length\" built-in types such as ``int``, ``str`` and\\n  ``tuple``.\\n\\n* Any non-string iterable may be assigned to *__slots__*. Mappings may\\n  also be used; however, in the future, special meaning may be\\n  assigned to the values corresponding to each key.\\n\\n* *__class__* assignment works only if both classes have the same\\n  *__slots__*.\\n\\n\\nCustomizing class creation\\n==========================\\n\\nBy default, classes are constructed using ``type()``. The class body\\nis executed in a new namespace and the class name is bound locally to\\nthe result of ``type(name, bases, namespace)``.\\n\\nThe class creation process can be customised by passing the\\n``metaclass`` keyword argument in the class definition line, or by\\ninheriting from an existing class that included such an argument. In\\nthe following example, both ``MyClass`` and ``MySubclass`` are\\ninstances of ``Meta``:\\n\\n   class Meta(type):\\n       pass\\n\\n   class MyClass(metaclass=Meta):\\n       pass\\n\\n   class MySubclass(MyClass):\\n       pass\\n\\nAny other keyword arguments that are specified in the class definition\\nare passed through to all metaclass operations described below.\\n\\nWhen a class definition is executed, the following steps occur:\\n\\n* the appropriate metaclass is determined\\n\\n* the class namespace is prepared\\n\\n* the class body is executed\\n\\n* the class object is created\\n\\n\\nDetermining the appropriate metaclass\\n-------------------------------------\\n\\nThe appropriate metaclass for a class definition is determined as\\nfollows:\\n\\n* if no bases and no explicit metaclass are given, then ``type()`` is\\n  used\\n\\n* if an explicit metaclass is given and it is *not* an instance of\\n  ``type()``, then it is used directly as the metaclass\\n\\n* if an instance of ``type()`` is given as the explicit metaclass, or\\n  bases are defined, then the most derived metaclass is used\\n\\nThe most derived metaclass is selected from the explicitly specified\\nmetaclass (if any) and the metaclasses (i.e. ``type(cls)``) of all\\nspecified base classes. The most derived metaclass is one which is a\\nsubtype of *all* of these candidate metaclasses. If none of the\\ncandidate metaclasses meets that criterion, then the class definition\\nwill fail with ``TypeError``.\\n\\n\\nPreparing the class namespace\\n-----------------------------\\n\\nOnce the appropriate metaclass has been identified, then the class\\nnamespace is prepared. If the metaclass has a ``__prepare__``\\nattribute, it is called as ``namespace = metaclass.__prepare__(name,\\nbases, **kwds)`` (where the additional keyword arguments, if any, come\\nfrom the class definition).\\n\\nIf the metaclass has no ``__prepare__`` attribute, then the class\\nnamespace is initialised as an empty ``dict()`` instance.\\n\\nSee also:\\n\\n   **PEP 3115** - Metaclasses in Python 3000\\n      Introduced the ``__prepare__`` namespace hook\\n\\n\\nExecuting the class body\\n------------------------\\n\\nThe class body is executed (approximately) as ``exec(body, globals(),\\nnamespace)``. The key difference from a normal call to ``exec()`` is\\nthat lexical scoping allows the class body (including any methods) to\\nreference names from the current and outer scopes when the class\\ndefinition occurs inside a function.\\n\\nHowever, even when the class definition occurs inside the function,\\nmethods defined inside the class still cannot see names defined at the\\nclass scope. Class variables must be accessed through the first\\nparameter of instance or class methods, and cannot be accessed at all\\nfrom static methods.\\n\\n\\nCreating the class object\\n-------------------------\\n\\nOnce the class namespace has been populated by executing the class\\nbody, the class object is created by calling ``metaclass(name, bases,\\nnamespace, **kwds)`` (the additional keywords passed here are the same\\nas those passed to ``__prepare__``).\\n\\nThis class object is the one that will be referenced by the zero-\\nargument form of ``super()``. ``__class__`` is an implicit closure\\nreference created by the compiler if any methods in a class body refer\\nto either ``__class__`` or ``super``. This allows the zero argument\\nform of ``super()`` to correctly identify the class being defined\\nbased on lexical scoping, while the class or instance that was used to\\nmake the current call is identified based on the first argument passed\\nto the method.\\n\\nAfter the class object is created, it is passed to the class\\ndecorators included in the class definition (if any) and the resulting\\nobject is bound in the local namespace as the defined class.\\n\\nSee also:\\n\\n   **PEP 3135** - New super\\n      Describes the implicit ``__class__`` closure reference\\n\\n\\nMetaclass example\\n-----------------\\n\\nThe potential uses for metaclasses are boundless. Some ideas that have\\nbeen explored include logging, interface checking, automatic\\ndelegation, automatic property creation, proxies, frameworks, and\\nautomatic resource locking/synchronization.\\n\\nHere is an example of a metaclass that uses an\\n``collections.OrderedDict`` to remember the order that class members\\nwere defined:\\n\\n   class OrderedClass(type):\\n\\n        @classmethod\\n        def __prepare__(metacls, name, bases, **kwds):\\n           return collections.OrderedDict()\\n\\n        def __new__(cls, name, bases, namespace, **kwds):\\n           result = type.__new__(cls, name, bases, dict(namespace))\\n           result.members = tuple(namespace)\\n           return result\\n\\n   class A(metaclass=OrderedClass):\\n       def one(self): pass\\n       def two(self): pass\\n       def three(self): pass\\n       def four(self): pass\\n\\n   >>> A.members\\n   (\\'__module__\\', \\'one\\', \\'two\\', \\'three\\', \\'four\\')\\n\\nWhen the class definition for *A* gets executed, the process begins\\nwith calling the metaclass\\'s ``__prepare__()`` method which returns an\\nempty ``collections.OrderedDict``.  That mapping records the methods\\nand attributes of *A* as they are defined within the body of the class\\nstatement. Once those definitions are executed, the ordered dictionary\\nis fully populated and the metaclass\\'s ``__new__()`` method gets\\ninvoked.  That method builds the new type and it saves the ordered\\ndictionary keys in an attribute called ``members``.\\n\\n\\nCustomizing instance and subclass checks\\n========================================\\n\\nThe following methods are used to override the default behavior of the\\n``isinstance()`` and ``issubclass()`` built-in functions.\\n\\nIn particular, the metaclass ``abc.ABCMeta`` implements these methods\\nin order to allow the addition of Abstract Base Classes (ABCs) as\\n\"virtual base classes\" to any class or type (including built-in\\ntypes), including other ABCs.\\n\\nclass.__instancecheck__(self, instance)\\n\\n   Return true if *instance* should be considered a (direct or\\n   indirect) instance of *class*. If defined, called to implement\\n   ``isinstance(instance, class)``.\\n\\nclass.__subclasscheck__(self, subclass)\\n\\n   Return true if *subclass* should be considered a (direct or\\n   indirect) subclass of *class*.  If defined, called to implement\\n   ``issubclass(subclass, class)``.\\n\\nNote that these methods are looked up on the type (metaclass) of a\\nclass.  They cannot be defined as class methods in the actual class.\\nThis is consistent with the lookup of special methods that are called\\non instances, only in this case the instance is itself a class.\\n\\nSee also:\\n\\n   **PEP 3119** - Introducing Abstract Base Classes\\n      Includes the specification for customizing ``isinstance()`` and\\n      ``issubclass()`` behavior through ``__instancecheck__()`` and\\n      ``__subclasscheck__()``, with motivation for this functionality\\n      in the context of adding Abstract Base Classes (see the ``abc``\\n      module) to the language.\\n\\n\\nEmulating callable objects\\n==========================\\n\\nobject.__call__(self[, args...])\\n\\n   Called when the instance is \"called\" as a function; if this method\\n   is defined, ``x(arg1, arg2, ...)`` is a shorthand for\\n   ``x.__call__(arg1, arg2, ...)``.\\n\\n\\nEmulating container types\\n=========================\\n\\nThe following methods can be defined to implement container objects.\\nContainers usually are sequences (such as lists or tuples) or mappings\\n(like dictionaries), but can represent other containers as well.  The\\nfirst set of methods is used either to emulate a sequence or to\\nemulate a mapping; the difference is that for a sequence, the\\nallowable keys should be the integers *k* for which ``0 <= k < N``\\nwhere *N* is the length of the sequence, or slice objects, which\\ndefine a range of items.  It is also recommended that mappings provide\\nthe methods ``keys()``, ``values()``, ``items()``, ``get()``,\\n``clear()``, ``setdefault()``, ``pop()``, ``popitem()``, ``copy()``,\\nand ``update()`` behaving similar to those for Python\\'s standard\\ndictionary objects.  The ``collections`` module provides a\\n``MutableMapping`` abstract base class to help create those methods\\nfrom a base set of ``__getitem__()``, ``__setitem__()``,\\n``__delitem__()``, and ``keys()``. Mutable sequences should provide\\nmethods ``append()``, ``count()``, ``index()``, ``extend()``,\\n``insert()``, ``pop()``, ``remove()``, ``reverse()`` and ``sort()``,\\nlike Python standard list objects.  Finally, sequence types should\\nimplement addition (meaning concatenation) and multiplication (meaning\\nrepetition) by defining the methods ``__add__()``, ``__radd__()``,\\n``__iadd__()``, ``__mul__()``, ``__rmul__()`` and ``__imul__()``\\ndescribed below; they should not define other numerical operators.  It\\nis recommended that both mappings and sequences implement the\\n``__contains__()`` method to allow efficient use of the ``in``\\noperator; for mappings, ``in`` should search the mapping\\'s keys; for\\nsequences, it should search through the values.  It is further\\nrecommended that both mappings and sequences implement the\\n``__iter__()`` method to allow efficient iteration through the\\ncontainer; for mappings, ``__iter__()`` should be the same as\\n``keys()``; for sequences, it should iterate through the values.\\n\\nobject.__len__(self)\\n\\n   Called to implement the built-in function ``len()``.  Should return\\n   the length of the object, an integer ``>=`` 0.  Also, an object\\n   that doesn\\'t define a ``__bool__()`` method and whose ``__len__()``\\n   method returns zero is considered to be false in a Boolean context.\\n\\nNote: Slicing is done exclusively with the following three methods.  A\\n  call like\\n\\n     a[1:2] = b\\n\\n  is translated to\\n\\n     a[slice(1, 2, None)] = b\\n\\n  and so forth.  Missing slice items are always filled in with\\n  ``None``.\\n\\nobject.__getitem__(self, key)\\n\\n   Called to implement evaluation of ``self[key]``. For sequence\\n   types, the accepted keys should be integers and slice objects.\\n   Note that the special interpretation of negative indexes (if the\\n   class wishes to emulate a sequence type) is up to the\\n   ``__getitem__()`` method. If *key* is of an inappropriate type,\\n   ``TypeError`` may be raised; if of a value outside the set of\\n   indexes for the sequence (after any special interpretation of\\n   negative values), ``IndexError`` should be raised. For mapping\\n   types, if *key* is missing (not in the container), ``KeyError``\\n   should be raised.\\n\\n   Note: ``for`` loops expect that an ``IndexError`` will be raised for\\n     illegal indexes to allow proper detection of the end of the\\n     sequence.\\n\\nobject.__setitem__(self, key, value)\\n\\n   Called to implement assignment to ``self[key]``.  Same note as for\\n   ``__getitem__()``.  This should only be implemented for mappings if\\n   the objects support changes to the values for keys, or if new keys\\n   can be added, or for sequences if elements can be replaced.  The\\n   same exceptions should be raised for improper *key* values as for\\n   the ``__getitem__()`` method.\\n\\nobject.__delitem__(self, key)\\n\\n   Called to implement deletion of ``self[key]``.  Same note as for\\n   ``__getitem__()``.  This should only be implemented for mappings if\\n   the objects support removal of keys, or for sequences if elements\\n   can be removed from the sequence.  The same exceptions should be\\n   raised for improper *key* values as for the ``__getitem__()``\\n   method.\\n\\nobject.__iter__(self)\\n\\n   This method is called when an iterator is required for a container.\\n   This method should return a new iterator object that can iterate\\n   over all the objects in the container.  For mappings, it should\\n   iterate over the keys of the container, and should also be made\\n   available as the method ``keys()``.\\n\\n   Iterator objects also need to implement this method; they are\\n   required to return themselves.  For more information on iterator\\n   objects, see *Iterator Types*.\\n\\nobject.__reversed__(self)\\n\\n   Called (if present) by the ``reversed()`` built-in to implement\\n   reverse iteration.  It should return a new iterator object that\\n   iterates over all the objects in the container in reverse order.\\n\\n   If the ``__reversed__()`` method is not provided, the\\n   ``reversed()`` built-in will fall back to using the sequence\\n   protocol (``__len__()`` and ``__getitem__()``).  Objects that\\n   support the sequence protocol should only provide\\n   ``__reversed__()`` if they can provide an implementation that is\\n   more efficient than the one provided by ``reversed()``.\\n\\nThe membership test operators (``in`` and ``not in``) are normally\\nimplemented as an iteration through a sequence.  However, container\\nobjects can supply the following special method with a more efficient\\nimplementation, which also does not require the object be a sequence.\\n\\nobject.__contains__(self, item)\\n\\n   Called to implement membership test operators.  Should return true\\n   if *item* is in *self*, false otherwise.  For mapping objects, this\\n   should consider the keys of the mapping rather than the values or\\n   the key-item pairs.\\n\\n   For objects that don\\'t define ``__contains__()``, the membership\\n   test first tries iteration via ``__iter__()``, then the old\\n   sequence iteration protocol via ``__getitem__()``, see *this\\n   section in the language reference*.\\n\\n\\nEmulating numeric types\\n=======================\\n\\nThe following methods can be defined to emulate numeric objects.\\nMethods corresponding to operations that are not supported by the\\nparticular kind of number implemented (e.g., bitwise operations for\\nnon-integral numbers) should be left undefined.\\n\\nobject.__add__(self, other)\\nobject.__sub__(self, other)\\nobject.__mul__(self, other)\\nobject.__truediv__(self, other)\\nobject.__floordiv__(self, other)\\nobject.__mod__(self, other)\\nobject.__divmod__(self, other)\\nobject.__pow__(self, other[, modulo])\\nobject.__lshift__(self, other)\\nobject.__rshift__(self, other)\\nobject.__and__(self, other)\\nobject.__xor__(self, other)\\nobject.__or__(self, other)\\n\\n   These methods are called to implement the binary arithmetic\\n   operations (``+``, ``-``, ``*``, ``/``, ``//``, ``%``,\\n   ``divmod()``, ``pow()``, ``**``, ``<<``, ``>>``, ``&``, ``^``,\\n   ``|``).  For instance, to evaluate the expression ``x + y``, where\\n   *x* is an instance of a class that has an ``__add__()`` method,\\n   ``x.__add__(y)`` is called.  The ``__divmod__()`` method should be\\n   the equivalent to using ``__floordiv__()`` and ``__mod__()``; it\\n   should not be related to ``__truediv__()``.  Note that\\n   ``__pow__()`` should be defined to accept an optional third\\n   argument if the ternary version of the built-in ``pow()`` function\\n   is to be supported.\\n\\n   If one of those methods does not support the operation with the\\n   supplied arguments, it should return ``NotImplemented``.\\n\\nobject.__radd__(self, other)\\nobject.__rsub__(self, other)\\nobject.__rmul__(self, other)\\nobject.__rtruediv__(self, other)\\nobject.__rfloordiv__(self, other)\\nobject.__rmod__(self, other)\\nobject.__rdivmod__(self, other)\\nobject.__rpow__(self, other)\\nobject.__rlshift__(self, other)\\nobject.__rrshift__(self, other)\\nobject.__rand__(self, other)\\nobject.__rxor__(self, other)\\nobject.__ror__(self, other)\\n\\n   These methods are called to implement the binary arithmetic\\n   operations (``+``, ``-``, ``*``, ``/``, ``//``, ``%``,\\n   ``divmod()``, ``pow()``, ``**``, ``<<``, ``>>``, ``&``, ``^``,\\n   ``|``) with reflected (swapped) operands. These functions are only\\n   called if the left operand does not support the corresponding\\n   operation and the operands are of different types. [2]  For\\n   instance, to evaluate the expression ``x - y``, where *y* is an\\n   instance of a class that has an ``__rsub__()`` method,\\n   ``y.__rsub__(x)`` is called if ``x.__sub__(y)`` returns\\n   *NotImplemented*.\\n\\n   Note that ternary ``pow()`` will not try calling ``__rpow__()``\\n   (the coercion rules would become too complicated).\\n\\n   Note: If the right operand\\'s type is a subclass of the left operand\\'s\\n     type and that subclass provides the reflected method for the\\n     operation, this method will be called before the left operand\\'s\\n     non-reflected method.  This behavior allows subclasses to\\n     override their ancestors\\' operations.\\n\\nobject.__iadd__(self, other)\\nobject.__isub__(self, other)\\nobject.__imul__(self, other)\\nobject.__itruediv__(self, other)\\nobject.__ifloordiv__(self, other)\\nobject.__imod__(self, other)\\nobject.__ipow__(self, other[, modulo])\\nobject.__ilshift__(self, other)\\nobject.__irshift__(self, other)\\nobject.__iand__(self, other)\\nobject.__ixor__(self, other)\\nobject.__ior__(self, other)\\n\\n   These methods are called to implement the augmented arithmetic\\n   assignments (``+=``, ``-=``, ``*=``, ``/=``, ``//=``, ``%=``,\\n   ``**=``, ``<<=``, ``>>=``, ``&=``, ``^=``, ``|=``).  These methods\\n   should attempt to do the operation in-place (modifying *self*) and\\n   return the result (which could be, but does not have to be,\\n   *self*).  If a specific method is not defined, the augmented\\n   assignment falls back to the normal methods.  For instance, to\\n   execute the statement ``x += y``, where *x* is an instance of a\\n   class that has an ``__iadd__()`` method, ``x.__iadd__(y)`` is\\n   called.  If *x* is an instance of a class that does not define a\\n   ``__iadd__()`` method, ``x.__add__(y)`` and ``y.__radd__(x)`` are\\n   considered, as with the evaluation of ``x + y``.\\n\\nobject.__neg__(self)\\nobject.__pos__(self)\\nobject.__abs__(self)\\nobject.__invert__(self)\\n\\n   Called to implement the unary arithmetic operations (``-``, ``+``,\\n   ``abs()`` and ``~``).\\n\\nobject.__complex__(self)\\nobject.__int__(self)\\nobject.__float__(self)\\nobject.__round__(self[, n])\\n\\n   Called to implement the built-in functions ``complex()``,\\n   ``int()``, ``float()`` and ``round()``.  Should return a value of\\n   the appropriate type.\\n\\nobject.__index__(self)\\n\\n   Called to implement ``operator.index()``.  Also called whenever\\n   Python needs an integer object (such as in slicing, or in the\\n   built-in ``bin()``, ``hex()`` and ``oct()`` functions). Must return\\n   an integer.\\n\\n\\nWith Statement Context Managers\\n===============================\\n\\nA *context manager* is an object that defines the runtime context to\\nbe established when executing a ``with`` statement. The context\\nmanager handles the entry into, and the exit from, the desired runtime\\ncontext for the execution of the block of code.  Context managers are\\nnormally invoked using the ``with`` statement (described in section\\n*The with statement*), but can also be used by directly invoking their\\nmethods.\\n\\nTypical uses of context managers include saving and restoring various\\nkinds of global state, locking and unlocking resources, closing opened\\nfiles, etc.\\n\\nFor more information on context managers, see *Context Manager Types*.\\n\\nobject.__enter__(self)\\n\\n   Enter the runtime context related to this object. The ``with``\\n   statement will bind this method\\'s return value to the target(s)\\n   specified in the ``as`` clause of the statement, if any.\\n\\nobject.__exit__(self, exc_type, exc_value, traceback)\\n\\n   Exit the runtime context related to this object. The parameters\\n   describe the exception that caused the context to be exited. If the\\n   context was exited without an exception, all three arguments will\\n   be ``None``.\\n\\n   If an exception is supplied, and the method wishes to suppress the\\n   exception (i.e., prevent it from being propagated), it should\\n   return a true value. Otherwise, the exception will be processed\\n   normally upon exit from this method.\\n\\n   Note that ``__exit__()`` methods should not reraise the passed-in\\n   exception; this is the caller\\'s responsibility.\\n\\nSee also:\\n\\n   **PEP 0343** - The \"with\" statement\\n      The specification, background, and examples for the Python\\n      ``with`` statement.\\n\\n\\nSpecial method lookup\\n=====================\\n\\nFor custom classes, implicit invocations of special methods are only\\nguaranteed to work correctly if defined on an object\\'s type, not in\\nthe object\\'s instance dictionary.  That behaviour is the reason why\\nthe following code raises an exception:\\n\\n   >>> class C:\\n   ...     pass\\n   ...\\n   >>> c = C()\\n   >>> c.__len__ = lambda: 5\\n   >>> len(c)\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 1, in <module>\\n   TypeError: object of type \\'C\\' has no len()\\n\\nThe rationale behind this behaviour lies with a number of special\\nmethods such as ``__hash__()`` and ``__repr__()`` that are implemented\\nby all objects, including type objects. If the implicit lookup of\\nthese methods used the conventional lookup process, they would fail\\nwhen invoked on the type object itself:\\n\\n   >>> 1 .__hash__() == hash(1)\\n   True\\n   >>> int.__hash__() == hash(int)\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 1, in <module>\\n   TypeError: descriptor \\'__hash__\\' of \\'int\\' object needs an argument\\n\\nIncorrectly attempting to invoke an unbound method of a class in this\\nway is sometimes referred to as \\'metaclass confusion\\', and is avoided\\nby bypassing the instance when looking up special methods:\\n\\n   >>> type(1).__hash__(1) == hash(1)\\n   True\\n   >>> type(int).__hash__(int) == hash(int)\\n   True\\n\\nIn addition to bypassing any instance attributes in the interest of\\ncorrectness, implicit special method lookup generally also bypasses\\nthe ``__getattribute__()`` method even of the object\\'s metaclass:\\n\\n   >>> class Meta(type):\\n   ...    def __getattribute__(*args):\\n   ...       print(\"Metaclass getattribute invoked\")\\n   ...       return type.__getattribute__(*args)\\n   ...\\n   >>> class C(object, metaclass=Meta):\\n   ...     def __len__(self):\\n   ...         return 10\\n   ...     def __getattribute__(*args):\\n   ...         print(\"Class getattribute invoked\")\\n   ...         return object.__getattribute__(*args)\\n   ...\\n   >>> c = C()\\n   >>> c.__len__()                 # Explicit lookup via instance\\n   Class getattribute invoked\\n   10\\n   >>> type(c).__len__(c)          # Explicit lookup via type\\n   Metaclass getattribute invoked\\n   10\\n   >>> len(c)                      # Implicit lookup\\n   10\\n\\nBypassing the ``__getattribute__()`` machinery in this fashion\\nprovides significant scope for speed optimisations within the\\ninterpreter, at the cost of some flexibility in the handling of\\nspecial methods (the special method *must* be set on the class object\\nitself in order to be consistently invoked by the interpreter).\\n\\n-[ Footnotes ]-\\n\\n[1] It *is* possible in some cases to change an object\\'s type, under\\n    certain controlled conditions. It generally isn\\'t a good idea\\n    though, since it can lead to some very strange behaviour if it is\\n    handled incorrectly.\\n\\n[2] For operands of the same type, it is assumed that if the non-\\n    reflected method (such as ``__add__()``) fails the operation is\\n    not supported, which is why the reflected method is not called.\\n',\n'string-methods':'\\nString Methods\\n**************\\n\\nStrings implement all of the *common* sequence operations, along with\\nthe additional methods described below.\\n\\nStrings also support two styles of string formatting, one providing a\\nlarge degree of flexibility and customization (see ``str.format()``,\\n*Format String Syntax* and *String Formatting*) and the other based on\\nC ``printf`` style formatting that handles a narrower range of types\\nand is slightly harder to use correctly, but is often faster for the\\ncases it can handle (*printf-style String Formatting*).\\n\\nThe *Text Processing Services* section of the standard library covers\\na number of other modules that provide various text related utilities\\n(including regular expression support in the ``re`` module).\\n\\nstr.capitalize()\\n\\n   Return a copy of the string with its first character capitalized\\n   and the rest lowercased.\\n\\nstr.casefold()\\n\\n   Return a casefolded copy of the string. Casefolded strings may be\\n   used for caseless matching.\\n\\n   Casefolding is similar to lowercasing but more aggressive because\\n   it is intended to remove all case distinctions in a string. For\\n   example, the German lowercase letter ``\\'\\xc3\\x9f\\'`` is equivalent to\\n   ``\"ss\"``. Since it is already lowercase, ``lower()`` would do\\n   nothing to ``\\'\\xc3\\x9f\\'``; ``casefold()`` converts it to ``\"ss\"``.\\n\\n   The casefolding algorithm is described in section 3.13 of the\\n   Unicode Standard.\\n\\n   New in version 3.3.\\n\\nstr.center(width[, fillchar])\\n\\n   Return centered in a string of length *width*. Padding is done\\n   using the specified *fillchar* (default is a space).\\n\\nstr.count(sub[, start[, end]])\\n\\n   Return the number of non-overlapping occurrences of substring *sub*\\n   in the range [*start*, *end*].  Optional arguments *start* and\\n   *end* are interpreted as in slice notation.\\n\\nstr.encode(encoding=\"utf-8\", errors=\"strict\")\\n\\n   Return an encoded version of the string as a bytes object. Default\\n   encoding is ``\\'utf-8\\'``. *errors* may be given to set a different\\n   error handling scheme. The default for *errors* is ``\\'strict\\'``,\\n   meaning that encoding errors raise a ``UnicodeError``. Other\\n   possible values are ``\\'ignore\\'``, ``\\'replace\\'``,\\n   ``\\'xmlcharrefreplace\\'``, ``\\'backslashreplace\\'`` and any other name\\n   registered via ``codecs.register_error()``, see section *Codec Base\\n   Classes*. For a list of possible encodings, see section *Standard\\n   Encodings*.\\n\\n   Changed in version 3.1: Support for keyword arguments added.\\n\\nstr.endswith(suffix[, start[, end]])\\n\\n   Return ``True`` if the string ends with the specified *suffix*,\\n   otherwise return ``False``.  *suffix* can also be a tuple of\\n   suffixes to look for.  With optional *start*, test beginning at\\n   that position.  With optional *end*, stop comparing at that\\n   position.\\n\\nstr.expandtabs([tabsize])\\n\\n   Return a copy of the string where all tab characters are replaced\\n   by zero or more spaces, depending on the current column and the\\n   given tab size.  The column number is reset to zero after each\\n   newline occurring in the string. If *tabsize* is not given, a tab\\n   size of ``8`` characters is assumed.  This doesn\\'t understand other\\n   non-printing characters or escape sequences.\\n\\nstr.find(sub[, start[, end]])\\n\\n   Return the lowest index in the string where substring *sub* is\\n   found, such that *sub* is contained in the slice ``s[start:end]``.\\n   Optional arguments *start* and *end* are interpreted as in slice\\n   notation.  Return ``-1`` if *sub* is not found.\\n\\n   Note: The ``find()`` method should be used only if you need to know the\\n     position of *sub*.  To check if *sub* is a substring or not, use\\n     the ``in`` operator:\\n\\n        >>> \\'Py\\' in \\'Python\\'\\n        True\\n\\nstr.format(*args, **kwargs)\\n\\n   Perform a string formatting operation.  The string on which this\\n   method is called can contain literal text or replacement fields\\n   delimited by braces ``{}``.  Each replacement field contains either\\n   the numeric index of a positional argument, or the name of a\\n   keyword argument.  Returns a copy of the string where each\\n   replacement field is replaced with the string value of the\\n   corresponding argument.\\n\\n   >>> \"The sum of 1 + 2 is {0}\".format(1+2)\\n   \\'The sum of 1 + 2 is 3\\'\\n\\n   See *Format String Syntax* for a description of the various\\n   formatting options that can be specified in format strings.\\n\\nstr.format_map(mapping)\\n\\n   Similar to ``str.format(**mapping)``, except that ``mapping`` is\\n   used directly and not copied to a ``dict`` .  This is useful if for\\n   example ``mapping`` is a dict subclass:\\n\\n   >>> class Default(dict):\\n   ...     def __missing__(self, key):\\n   ...         return key\\n   ...\\n   >>> \\'{name} was born in {country}\\'.format_map(Default(name=\\'Guido\\'))\\n   \\'Guido was born in country\\'\\n\\n   New in version 3.2.\\n\\nstr.index(sub[, start[, end]])\\n\\n   Like ``find()``, but raise ``ValueError`` when the substring is not\\n   found.\\n\\nstr.isalnum()\\n\\n   Return true if all characters in the string are alphanumeric and\\n   there is at least one character, false otherwise.  A character\\n   ``c`` is alphanumeric if one of the following returns ``True``:\\n   ``c.isalpha()``, ``c.isdecimal()``, ``c.isdigit()``, or\\n   ``c.isnumeric()``.\\n\\nstr.isalpha()\\n\\n   Return true if all characters in the string are alphabetic and\\n   there is at least one character, false otherwise.  Alphabetic\\n   characters are those characters defined in the Unicode character\\n   database as \"Letter\", i.e., those with general category property\\n   being one of \"Lm\", \"Lt\", \"Lu\", \"Ll\", or \"Lo\".  Note that this is\\n   different from the \"Alphabetic\" property defined in the Unicode\\n   Standard.\\n\\nstr.isdecimal()\\n\\n   Return true if all characters in the string are decimal characters\\n   and there is at least one character, false otherwise. Decimal\\n   characters are those from general category \"Nd\". This category\\n   includes digit characters, and all characters that can be used to\\n   form decimal-radix numbers, e.g. U+0660, ARABIC-INDIC DIGIT ZERO.\\n\\nstr.isdigit()\\n\\n   Return true if all characters in the string are digits and there is\\n   at least one character, false otherwise.  Digits include decimal\\n   characters and digits that need special handling, such as the\\n   compatibility superscript digits.  Formally, a digit is a character\\n   that has the property value Numeric_Type=Digit or\\n   Numeric_Type=Decimal.\\n\\nstr.isidentifier()\\n\\n   Return true if the string is a valid identifier according to the\\n   language definition, section *Identifiers and keywords*.\\n\\nstr.islower()\\n\\n   Return true if all cased characters [4] in the string are lowercase\\n   and there is at least one cased character, false otherwise.\\n\\nstr.isnumeric()\\n\\n   Return true if all characters in the string are numeric characters,\\n   and there is at least one character, false otherwise. Numeric\\n   characters include digit characters, and all characters that have\\n   the Unicode numeric value property, e.g. U+2155, VULGAR FRACTION\\n   ONE FIFTH.  Formally, numeric characters are those with the\\n   property value Numeric_Type=Digit, Numeric_Type=Decimal or\\n   Numeric_Type=Numeric.\\n\\nstr.isprintable()\\n\\n   Return true if all characters in the string are printable or the\\n   string is empty, false otherwise.  Nonprintable characters are\\n   those characters defined in the Unicode character database as\\n   \"Other\" or \"Separator\", excepting the ASCII space (0x20) which is\\n   considered printable.  (Note that printable characters in this\\n   context are those which should not be escaped when ``repr()`` is\\n   invoked on a string.  It has no bearing on the handling of strings\\n   written to ``sys.stdout`` or ``sys.stderr``.)\\n\\nstr.isspace()\\n\\n   Return true if there are only whitespace characters in the string\\n   and there is at least one character, false otherwise.  Whitespace\\n   characters  are those characters defined in the Unicode character\\n   database as \"Other\" or \"Separator\" and those with bidirectional\\n   property being one of \"WS\", \"B\", or \"S\".\\n\\nstr.istitle()\\n\\n   Return true if the string is a titlecased string and there is at\\n   least one character, for example uppercase characters may only\\n   follow uncased characters and lowercase characters only cased ones.\\n   Return false otherwise.\\n\\nstr.isupper()\\n\\n   Return true if all cased characters [4] in the string are uppercase\\n   and there is at least one cased character, false otherwise.\\n\\nstr.join(iterable)\\n\\n   Return a string which is the concatenation of the strings in the\\n   *iterable* *iterable*.  A ``TypeError`` will be raised if there are\\n   any non-string values in *iterable*, including ``bytes`` objects.\\n   The separator between elements is the string providing this method.\\n\\nstr.ljust(width[, fillchar])\\n\\n   Return the string left justified in a string of length *width*.\\n   Padding is done using the specified *fillchar* (default is a\\n   space).  The original string is returned if *width* is less than or\\n   equal to ``len(s)``.\\n\\nstr.lower()\\n\\n   Return a copy of the string with all the cased characters [4]\\n   converted to lowercase.\\n\\n   The lowercasing algorithm used is described in section 3.13 of the\\n   Unicode Standard.\\n\\nstr.lstrip([chars])\\n\\n   Return a copy of the string with leading characters removed.  The\\n   *chars* argument is a string specifying the set of characters to be\\n   removed.  If omitted or ``None``, the *chars* argument defaults to\\n   removing whitespace.  The *chars* argument is not a prefix; rather,\\n   all combinations of its values are stripped:\\n\\n   >>> \\'   spacious   \\'.lstrip()\\n   \\'spacious   \\'\\n   >>> \\'www.example.com\\'.lstrip(\\'cmowz.\\')\\n   \\'example.com\\'\\n\\nstatic str.maketrans(x[, y[, z]])\\n\\n   This static method returns a translation table usable for\\n   ``str.translate()``.\\n\\n   If there is only one argument, it must be a dictionary mapping\\n   Unicode ordinals (integers) or characters (strings of length 1) to\\n   Unicode ordinals, strings (of arbitrary lengths) or None.\\n   Character keys will then be converted to ordinals.\\n\\n   If there are two arguments, they must be strings of equal length,\\n   and in the resulting dictionary, each character in x will be mapped\\n   to the character at the same position in y.  If there is a third\\n   argument, it must be a string, whose characters will be mapped to\\n   None in the result.\\n\\nstr.partition(sep)\\n\\n   Split the string at the first occurrence of *sep*, and return a\\n   3-tuple containing the part before the separator, the separator\\n   itself, and the part after the separator.  If the separator is not\\n   found, return a 3-tuple containing the string itself, followed by\\n   two empty strings.\\n\\nstr.replace(old, new[, count])\\n\\n   Return a copy of the string with all occurrences of substring *old*\\n   replaced by *new*.  If the optional argument *count* is given, only\\n   the first *count* occurrences are replaced.\\n\\nstr.rfind(sub[, start[, end]])\\n\\n   Return the highest index in the string where substring *sub* is\\n   found, such that *sub* is contained within ``s[start:end]``.\\n   Optional arguments *start* and *end* are interpreted as in slice\\n   notation.  Return ``-1`` on failure.\\n\\nstr.rindex(sub[, start[, end]])\\n\\n   Like ``rfind()`` but raises ``ValueError`` when the substring *sub*\\n   is not found.\\n\\nstr.rjust(width[, fillchar])\\n\\n   Return the string right justified in a string of length *width*.\\n   Padding is done using the specified *fillchar* (default is a\\n   space). The original string is returned if *width* is less than or\\n   equal to ``len(s)``.\\n\\nstr.rpartition(sep)\\n\\n   Split the string at the last occurrence of *sep*, and return a\\n   3-tuple containing the part before the separator, the separator\\n   itself, and the part after the separator.  If the separator is not\\n   found, return a 3-tuple containing two empty strings, followed by\\n   the string itself.\\n\\nstr.rsplit(sep=None, maxsplit=-1)\\n\\n   Return a list of the words in the string, using *sep* as the\\n   delimiter string. If *maxsplit* is given, at most *maxsplit* splits\\n   are done, the *rightmost* ones.  If *sep* is not specified or\\n   ``None``, any whitespace string is a separator.  Except for\\n   splitting from the right, ``rsplit()`` behaves like ``split()``\\n   which is described in detail below.\\n\\nstr.rstrip([chars])\\n\\n   Return a copy of the string with trailing characters removed.  The\\n   *chars* argument is a string specifying the set of characters to be\\n   removed.  If omitted or ``None``, the *chars* argument defaults to\\n   removing whitespace.  The *chars* argument is not a suffix; rather,\\n   all combinations of its values are stripped:\\n\\n   >>> \\'   spacious   \\'.rstrip()\\n   \\'   spacious\\'\\n   >>> \\'mississippi\\'.rstrip(\\'ipz\\')\\n   \\'mississ\\'\\n\\nstr.split(sep=None, maxsplit=-1)\\n\\n   Return a list of the words in the string, using *sep* as the\\n   delimiter string.  If *maxsplit* is given, at most *maxsplit*\\n   splits are done (thus, the list will have at most ``maxsplit+1``\\n   elements).  If *maxsplit* is not specified or ``-1``, then there is\\n   no limit on the number of splits (all possible splits are made).\\n\\n   If *sep* is given, consecutive delimiters are not grouped together\\n   and are deemed to delimit empty strings (for example,\\n   ``\\'1,,2\\'.split(\\',\\')`` returns ``[\\'1\\', \\'\\', \\'2\\']``).  The *sep*\\n   argument may consist of multiple characters (for example,\\n   ``\\'1<>2<>3\\'.split(\\'<>\\')`` returns ``[\\'1\\', \\'2\\', \\'3\\']``). Splitting\\n   an empty string with a specified separator returns ``[\\'\\']``.\\n\\n   If *sep* is not specified or is ``None``, a different splitting\\n   algorithm is applied: runs of consecutive whitespace are regarded\\n   as a single separator, and the result will contain no empty strings\\n   at the start or end if the string has leading or trailing\\n   whitespace.  Consequently, splitting an empty string or a string\\n   consisting of just whitespace with a ``None`` separator returns\\n   ``[]``.\\n\\n   For example, ``\\' 1  2   3  \\'.split()`` returns ``[\\'1\\', \\'2\\', \\'3\\']``,\\n   and ``\\'  1  2   3  \\'.split(None, 1)`` returns ``[\\'1\\', \\'2   3  \\']``.\\n\\nstr.splitlines([keepends])\\n\\n   Return a list of the lines in the string, breaking at line\\n   boundaries. This method uses the *universal newlines* approach to\\n   splitting lines. Line breaks are not included in the resulting list\\n   unless *keepends* is given and true.\\n\\n   For example, ``\\'ab c\\\\n\\\\nde fg\\\\rkl\\\\r\\\\n\\'.splitlines()`` returns\\n   ``[\\'ab c\\', \\'\\', \\'de fg\\', \\'kl\\']``, while the same call with\\n   ``splitlines(True)`` returns ``[\\'ab c\\\\n\\', \\'\\\\n\\', \\'de fg\\\\r\\',\\n   \\'kl\\\\r\\\\n\\']``.\\n\\n   Unlike ``split()`` when a delimiter string *sep* is given, this\\n   method returns an empty list for the empty string, and a terminal\\n   line break does not result in an extra line.\\n\\nstr.startswith(prefix[, start[, end]])\\n\\n   Return ``True`` if string starts with the *prefix*, otherwise\\n   return ``False``. *prefix* can also be a tuple of prefixes to look\\n   for.  With optional *start*, test string beginning at that\\n   position.  With optional *end*, stop comparing string at that\\n   position.\\n\\nstr.strip([chars])\\n\\n   Return a copy of the string with the leading and trailing\\n   characters removed. The *chars* argument is a string specifying the\\n   set of characters to be removed. If omitted or ``None``, the\\n   *chars* argument defaults to removing whitespace. The *chars*\\n   argument is not a prefix or suffix; rather, all combinations of its\\n   values are stripped:\\n\\n   >>> \\'   spacious   \\'.strip()\\n   \\'spacious\\'\\n   >>> \\'www.example.com\\'.strip(\\'cmowz.\\')\\n   \\'example\\'\\n\\nstr.swapcase()\\n\\n   Return a copy of the string with uppercase characters converted to\\n   lowercase and vice versa. Note that it is not necessarily true that\\n   ``s.swapcase().swapcase() == s``.\\n\\nstr.title()\\n\\n   Return a titlecased version of the string where words start with an\\n   uppercase character and the remaining characters are lowercase.\\n\\n   The algorithm uses a simple language-independent definition of a\\n   word as groups of consecutive letters.  The definition works in\\n   many contexts but it means that apostrophes in contractions and\\n   possessives form word boundaries, which may not be the desired\\n   result:\\n\\n      >>> \"they\\'re bill\\'s friends from the UK\".title()\\n      \"They\\'Re Bill\\'S Friends From The Uk\"\\n\\n   A workaround for apostrophes can be constructed using regular\\n   expressions:\\n\\n      >>> import re\\n      >>> def titlecase(s):\\n      ...     return re.sub(r\"[A-Za-z]+(\\'[A-Za-z]+)?\",\\n      ...                   lambda mo: mo.group(0)[0].upper() +\\n      ...                              mo.group(0)[1:].lower(),\\n      ...                   s)\\n      ...\\n      >>> titlecase(\"they\\'re bill\\'s friends.\")\\n      \"They\\'re Bill\\'s Friends.\"\\n\\nstr.translate(map)\\n\\n   Return a copy of the *s* where all characters have been mapped\\n   through the *map* which must be a dictionary of Unicode ordinals\\n   (integers) to Unicode ordinals, strings or ``None``.  Unmapped\\n   characters are left untouched. Characters mapped to ``None`` are\\n   deleted.\\n\\n   You can use ``str.maketrans()`` to create a translation map from\\n   character-to-character mappings in different formats.\\n\\n   Note: An even more flexible approach is to create a custom character\\n     mapping codec using the ``codecs`` module (see\\n     ``encodings.cp1251`` for an example).\\n\\nstr.upper()\\n\\n   Return a copy of the string with all the cased characters [4]\\n   converted to uppercase.  Note that ``str.upper().isupper()`` might\\n   be ``False`` if ``s`` contains uncased characters or if the Unicode\\n   category of the resulting character(s) is not \"Lu\" (Letter,\\n   uppercase), but e.g. \"Lt\" (Letter, titlecase).\\n\\n   The uppercasing algorithm used is described in section 3.13 of the\\n   Unicode Standard.\\n\\nstr.zfill(width)\\n\\n   Return the numeric string left filled with zeros in a string of\\n   length *width*.  A sign prefix is handled correctly.  The original\\n   string is returned if *width* is less than or equal to ``len(s)``.\\n',\n'strings':'\\nString and Bytes literals\\n*************************\\n\\nString literals are described by the following lexical definitions:\\n\\n   stringliteral   ::= [stringprefix](shortstring | longstring)\\n   stringprefix    ::= \"r\" | \"u\" | \"R\" | \"U\"\\n   shortstring     ::= \"\\'\" shortstringitem* \"\\'\" | \\'\"\\' shortstringitem* \\'\"\\'\\n   longstring      ::= \"\\'\\'\\'\" longstringitem* \"\\'\\'\\'\" | \\'\"\"\"\\' longstringitem* \\'\"\"\"\\'\\n   shortstringitem ::= shortstringchar | stringescapeseq\\n   longstringitem  ::= longstringchar | stringescapeseq\\n   shortstringchar ::= <any source character except \"\\\\\" or newline or the quote>\\n   longstringchar  ::= <any source character except \"\\\\\">\\n   stringescapeseq ::= \"\\\\\" <any source character>\\n\\n   bytesliteral   ::= bytesprefix(shortbytes | longbytes)\\n   bytesprefix    ::= \"b\" | \"B\" | \"br\" | \"Br\" | \"bR\" | \"BR\" | \"rb\" | \"rB\" | \"Rb\" | \"RB\"\\n   shortbytes     ::= \"\\'\" shortbytesitem* \"\\'\" | \\'\"\\' shortbytesitem* \\'\"\\'\\n   longbytes      ::= \"\\'\\'\\'\" longbytesitem* \"\\'\\'\\'\" | \\'\"\"\"\\' longbytesitem* \\'\"\"\"\\'\\n   shortbytesitem ::= shortbyteschar | bytesescapeseq\\n   longbytesitem  ::= longbyteschar | bytesescapeseq\\n   shortbyteschar ::= <any ASCII character except \"\\\\\" or newline or the quote>\\n   longbyteschar  ::= <any ASCII character except \"\\\\\">\\n   bytesescapeseq ::= \"\\\\\" <any ASCII character>\\n\\nOne syntactic restriction not indicated by these productions is that\\nwhitespace is not allowed between the ``stringprefix`` or\\n``bytesprefix`` and the rest of the literal. The source character set\\nis defined by the encoding declaration; it is UTF-8 if no encoding\\ndeclaration is given in the source file; see section *Encoding\\ndeclarations*.\\n\\nIn plain English: Both types of literals can be enclosed in matching\\nsingle quotes (``\\'``) or double quotes (``\"``).  They can also be\\nenclosed in matching groups of three single or double quotes (these\\nare generally referred to as *triple-quoted strings*).  The backslash\\n(``\\\\``) character is used to escape characters that otherwise have a\\nspecial meaning, such as newline, backslash itself, or the quote\\ncharacter.\\n\\nBytes literals are always prefixed with ``\\'b\\'`` or ``\\'B\\'``; they\\nproduce an instance of the ``bytes`` type instead of the ``str`` type.\\nThey may only contain ASCII characters; bytes with a numeric value of\\n128 or greater must be expressed with escapes.\\n\\nAs of Python 3.3 it is possible again to prefix unicode strings with a\\n``u`` prefix to simplify maintenance of dual 2.x and 3.x codebases.\\n\\nBoth string and bytes literals may optionally be prefixed with a\\nletter ``\\'r\\'`` or ``\\'R\\'``; such strings are called *raw strings* and\\ntreat backslashes as literal characters.  As a result, in string\\nliterals, ``\\'\\\\U\\'`` and ``\\'\\\\u\\'`` escapes in raw strings are not treated\\nspecially. Given that Python 2.x\\'s raw unicode literals behave\\ndifferently than Python 3.x\\'s the ``\\'ur\\'`` syntax is not supported.\\n\\n   New in version 3.3: The ``\\'rb\\'`` prefix of raw bytes literals has\\n   been added as a synonym of ``\\'br\\'``.\\n\\n   New in version 3.3: Support for the unicode legacy literal\\n   (``u\\'value\\'``) was reintroduced to simplify the maintenance of dual\\n   Python 2.x and 3.x codebases. See **PEP 414** for more information.\\n\\nIn triple-quoted strings, unescaped newlines and quotes are allowed\\n(and are retained), except that three unescaped quotes in a row\\nterminate the string.  (A \"quote\" is the character used to open the\\nstring, i.e. either ``\\'`` or ``\"``.)\\n\\nUnless an ``\\'r\\'`` or ``\\'R\\'`` prefix is present, escape sequences in\\nstrings are interpreted according to rules similar to those used by\\nStandard C.  The recognized escape sequences are:\\n\\n+-------------------+-----------------------------------+---------+\\n| Escape Sequence   | Meaning                           | Notes   |\\n+===================+===================================+=========+\\n| ``\\\\newline``      | Backslash and newline ignored     |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\\\\\``            | Backslash (``\\\\``)                 |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\\\'``            | Single quote (``\\'``)              |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\\"``            | Double quote (``\"``)              |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\a``            | ASCII Bell (BEL)                  |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\b``            | ASCII Backspace (BS)              |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\f``            | ASCII Formfeed (FF)               |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\n``            | ASCII Linefeed (LF)               |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\r``            | ASCII Carriage Return (CR)        |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\t``            | ASCII Horizontal Tab (TAB)        |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\v``            | ASCII Vertical Tab (VT)           |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\ooo``          | Character with octal value *ooo*  | (1,3)   |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\xhh``          | Character with hex value *hh*     | (2,3)   |\\n+-------------------+-----------------------------------+---------+\\n\\nEscape sequences only recognized in string literals are:\\n\\n+-------------------+-----------------------------------+---------+\\n| Escape Sequence   | Meaning                           | Notes   |\\n+===================+===================================+=========+\\n| ``\\\\N{name}``      | Character named *name* in the     | (4)     |\\n|                   | Unicode database                  |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\uxxxx``        | Character with 16-bit hex value   | (5)     |\\n|                   | *xxxx*                            |         |\\n+-------------------+-----------------------------------+---------+\\n| ``\\\\Uxxxxxxxx``    | Character with 32-bit hex value   | (6)     |\\n|                   | *xxxxxxxx*                        |         |\\n+-------------------+-----------------------------------+---------+\\n\\nNotes:\\n\\n1. As in Standard C, up to three octal digits are accepted.\\n\\n2. Unlike in Standard C, exactly two hex digits are required.\\n\\n3. In a bytes literal, hexadecimal and octal escapes denote the byte\\n   with the given value. In a string literal, these escapes denote a\\n   Unicode character with the given value.\\n\\n4. Changed in version 3.3: Support for name aliases [1] has been\\n   added.\\n\\n5. Individual code units which form parts of a surrogate pair can be\\n   encoded using this escape sequence.  Exactly four hex digits are\\n   required.\\n\\n6. Any Unicode character can be encoded this way.  Exactly eight hex\\n   digits are required.\\n\\nUnlike Standard C, all unrecognized escape sequences are left in the\\nstring unchanged, i.e., *the backslash is left in the string*.  (This\\nbehavior is useful when debugging: if an escape sequence is mistyped,\\nthe resulting output is more easily recognized as broken.)  It is also\\nimportant to note that the escape sequences only recognized in string\\nliterals fall into the category of unrecognized escapes for bytes\\nliterals.\\n\\nEven in a raw string, string quotes can be escaped with a backslash,\\nbut the backslash remains in the string; for example, ``r\"\\\\\"\"`` is a\\nvalid string literal consisting of two characters: a backslash and a\\ndouble quote; ``r\"\\\\\"`` is not a valid string literal (even a raw\\nstring cannot end in an odd number of backslashes).  Specifically, *a\\nraw string cannot end in a single backslash* (since the backslash\\nwould escape the following quote character).  Note also that a single\\nbackslash followed by a newline is interpreted as those two characters\\nas part of the string, *not* as a line continuation.\\n',\n'subscriptions':'\\nSubscriptions\\n*************\\n\\nA subscription selects an item of a sequence (string, tuple or list)\\nor mapping (dictionary) object:\\n\\n   subscription ::= primary \"[\" expression_list \"]\"\\n\\nThe primary must evaluate to an object that supports subscription,\\ne.g. a list or dictionary.  User-defined objects can support\\nsubscription by defining a ``__getitem__()`` method.\\n\\nFor built-in objects, there are two types of objects that support\\nsubscription:\\n\\nIf the primary is a mapping, the expression list must evaluate to an\\nobject whose value is one of the keys of the mapping, and the\\nsubscription selects the value in the mapping that corresponds to that\\nkey.  (The expression list is a tuple except if it has exactly one\\nitem.)\\n\\nIf the primary is a sequence, the expression (list) must evaluate to\\nan integer or a slice (as discussed in the following section).\\n\\nThe formal syntax makes no special provision for negative indices in\\nsequences; however, built-in sequences all provide a ``__getitem__()``\\nmethod that interprets negative indices by adding the length of the\\nsequence to the index (so that ``x[-1]`` selects the last item of\\n``x``).  The resulting value must be a nonnegative integer less than\\nthe number of items in the sequence, and the subscription selects the\\nitem whose index is that value (counting from zero). Since the support\\nfor negative indices and slicing occurs in the object\\'s\\n``__getitem__()`` method, subclasses overriding this method will need\\nto explicitly add that support.\\n\\nA string\\'s items are characters.  A character is not a separate data\\ntype but a string of exactly one character.\\n',\n'truth':\"\\nTruth Value Testing\\n*******************\\n\\nAny object can be tested for truth value, for use in an ``if`` or\\n``while`` condition or as operand of the Boolean operations below. The\\nfollowing values are considered false:\\n\\n* ``None``\\n\\n* ``False``\\n\\n* zero of any numeric type, for example, ``0``, ``0.0``, ``0j``.\\n\\n* any empty sequence, for example, ``''``, ``()``, ``[]``.\\n\\n* any empty mapping, for example, ``{}``.\\n\\n* instances of user-defined classes, if the class defines a\\n  ``__bool__()`` or ``__len__()`` method, when that method returns the\\n  integer zero or ``bool`` value ``False``. [1]\\n\\nAll other values are considered true --- so objects of many types are\\nalways true.\\n\\nOperations and built-in functions that have a Boolean result always\\nreturn ``0`` or ``False`` for false and ``1`` or ``True`` for true,\\nunless otherwise stated. (Important exception: the Boolean operations\\n``or`` and ``and`` always return one of their operands.)\\n\",\n'try':'\\nThe ``try`` statement\\n*********************\\n\\nThe ``try`` statement specifies exception handlers and/or cleanup code\\nfor a group of statements:\\n\\n   try_stmt  ::= try1_stmt | try2_stmt\\n   try1_stmt ::= \"try\" \":\" suite\\n                 (\"except\" [expression [\"as\" target]] \":\" suite)+\\n                 [\"else\" \":\" suite]\\n                 [\"finally\" \":\" suite]\\n   try2_stmt ::= \"try\" \":\" suite\\n                 \"finally\" \":\" suite\\n\\nThe ``except`` clause(s) specify one or more exception handlers. When\\nno exception occurs in the ``try`` clause, no exception handler is\\nexecuted. When an exception occurs in the ``try`` suite, a search for\\nan exception handler is started.  This search inspects the except\\nclauses in turn until one is found that matches the exception.  An\\nexpression-less except clause, if present, must be last; it matches\\nany exception.  For an except clause with an expression, that\\nexpression is evaluated, and the clause matches the exception if the\\nresulting object is \"compatible\" with the exception.  An object is\\ncompatible with an exception if it is the class or a base class of the\\nexception object or a tuple containing an item compatible with the\\nexception.\\n\\nIf no except clause matches the exception, the search for an exception\\nhandler continues in the surrounding code and on the invocation stack.\\n[1]\\n\\nIf the evaluation of an expression in the header of an except clause\\nraises an exception, the original search for a handler is canceled and\\na search starts for the new exception in the surrounding code and on\\nthe call stack (it is treated as if the entire ``try`` statement\\nraised the exception).\\n\\nWhen a matching except clause is found, the exception is assigned to\\nthe target specified after the ``as`` keyword in that except clause,\\nif present, and the except clause\\'s suite is executed.  All except\\nclauses must have an executable block.  When the end of this block is\\nreached, execution continues normally after the entire try statement.\\n(This means that if two nested handlers exist for the same exception,\\nand the exception occurs in the try clause of the inner handler, the\\nouter handler will not handle the exception.)\\n\\nWhen an exception has been assigned using ``as target``, it is cleared\\nat the end of the except clause.  This is as if\\n\\n   except E as N:\\n       foo\\n\\nwas translated to\\n\\n   except E as N:\\n       try:\\n           foo\\n       finally:\\n           del N\\n\\nThis means the exception must be assigned to a different name to be\\nable to refer to it after the except clause.  Exceptions are cleared\\nbecause with the traceback attached to them, they form a reference\\ncycle with the stack frame, keeping all locals in that frame alive\\nuntil the next garbage collection occurs.\\n\\nBefore an except clause\\'s suite is executed, details about the\\nexception are stored in the ``sys`` module and can be access via\\n``sys.exc_info()``. ``sys.exc_info()`` returns a 3-tuple consisting of\\nthe exception class, the exception instance and a traceback object\\n(see section *The standard type hierarchy*) identifying the point in\\nthe program where the exception occurred.  ``sys.exc_info()`` values\\nare restored to their previous values (before the call) when returning\\nfrom a function that handled an exception.\\n\\nThe optional ``else`` clause is executed if and when control flows off\\nthe end of the ``try`` clause. [2] Exceptions in the ``else`` clause\\nare not handled by the preceding ``except`` clauses.\\n\\nIf ``finally`` is present, it specifies a \\'cleanup\\' handler.  The\\n``try`` clause is executed, including any ``except`` and ``else``\\nclauses.  If an exception occurs in any of the clauses and is not\\nhandled, the exception is temporarily saved. The ``finally`` clause is\\nexecuted.  If there is a saved exception it is re-raised at the end of\\nthe ``finally`` clause.  If the ``finally`` clause raises another\\nexception, the saved exception is set as the context of the new\\nexception. If the ``finally`` clause executes a ``return`` or\\n``break`` statement, the saved exception is discarded:\\n\\n   def f():\\n       try:\\n           1/0\\n       finally:\\n           return 42\\n\\n   >>> f()\\n   42\\n\\nThe exception information is not available to the program during\\nexecution of the ``finally`` clause.\\n\\nWhen a ``return``, ``break`` or ``continue`` statement is executed in\\nthe ``try`` suite of a ``try``...``finally`` statement, the\\n``finally`` clause is also executed \\'on the way out.\\' A ``continue``\\nstatement is illegal in the ``finally`` clause. (The reason is a\\nproblem with the current implementation --- this restriction may be\\nlifted in the future).\\n\\nAdditional information on exceptions can be found in section\\n*Exceptions*, and information on using the ``raise`` statement to\\ngenerate exceptions may be found in section *The raise statement*.\\n',\n'types':'\\nThe standard type hierarchy\\n***************************\\n\\nBelow is a list of the types that are built into Python.  Extension\\nmodules (written in C, Java, or other languages, depending on the\\nimplementation) can define additional types.  Future versions of\\nPython may add types to the type hierarchy (e.g., rational numbers,\\nefficiently stored arrays of integers, etc.), although such additions\\nwill often be provided via the standard library instead.\\n\\nSome of the type descriptions below contain a paragraph listing\\n\\'special attributes.\\'  These are attributes that provide access to the\\nimplementation and are not intended for general use.  Their definition\\nmay change in the future.\\n\\nNone\\n   This type has a single value.  There is a single object with this\\n   value. This object is accessed through the built-in name ``None``.\\n   It is used to signify the absence of a value in many situations,\\n   e.g., it is returned from functions that don\\'t explicitly return\\n   anything. Its truth value is false.\\n\\nNotImplemented\\n   This type has a single value.  There is a single object with this\\n   value. This object is accessed through the built-in name\\n   ``NotImplemented``. Numeric methods and rich comparison methods may\\n   return this value if they do not implement the operation for the\\n   operands provided.  (The interpreter will then try the reflected\\n   operation, or some other fallback, depending on the operator.)  Its\\n   truth value is true.\\n\\nEllipsis\\n   This type has a single value.  There is a single object with this\\n   value. This object is accessed through the literal ``...`` or the\\n   built-in name ``Ellipsis``.  Its truth value is true.\\n\\n``numbers.Number``\\n   These are created by numeric literals and returned as results by\\n   arithmetic operators and arithmetic built-in functions.  Numeric\\n   objects are immutable; once created their value never changes.\\n   Python numbers are of course strongly related to mathematical\\n   numbers, but subject to the limitations of numerical representation\\n   in computers.\\n\\n   Python distinguishes between integers, floating point numbers, and\\n   complex numbers:\\n\\n   ``numbers.Integral``\\n      These represent elements from the mathematical set of integers\\n      (positive and negative).\\n\\n      There are two types of integers:\\n\\n      Integers (``int``)\\n\\n         These represent numbers in an unlimited range, subject to\\n         available (virtual) memory only.  For the purpose of shift\\n         and mask operations, a binary representation is assumed, and\\n         negative numbers are represented in a variant of 2\\'s\\n         complement which gives the illusion of an infinite string of\\n         sign bits extending to the left.\\n\\n      Booleans (``bool``)\\n         These represent the truth values False and True.  The two\\n         objects representing the values False and True are the only\\n         Boolean objects. The Boolean type is a subtype of the integer\\n         type, and Boolean values behave like the values 0 and 1,\\n         respectively, in almost all contexts, the exception being\\n         that when converted to a string, the strings ``\"False\"`` or\\n         ``\"True\"`` are returned, respectively.\\n\\n      The rules for integer representation are intended to give the\\n      most meaningful interpretation of shift and mask operations\\n      involving negative integers.\\n\\n   ``numbers.Real`` (``float``)\\n      These represent machine-level double precision floating point\\n      numbers. You are at the mercy of the underlying machine\\n      architecture (and C or Java implementation) for the accepted\\n      range and handling of overflow. Python does not support single-\\n      precision floating point numbers; the savings in processor and\\n      memory usage that are usually the reason for using these is\\n      dwarfed by the overhead of using objects in Python, so there is\\n      no reason to complicate the language with two kinds of floating\\n      point numbers.\\n\\n   ``numbers.Complex`` (``complex``)\\n      These represent complex numbers as a pair of machine-level\\n      double precision floating point numbers.  The same caveats apply\\n      as for floating point numbers. The real and imaginary parts of a\\n      complex number ``z`` can be retrieved through the read-only\\n      attributes ``z.real`` and ``z.imag``.\\n\\nSequences\\n   These represent finite ordered sets indexed by non-negative\\n   numbers. The built-in function ``len()`` returns the number of\\n   items of a sequence. When the length of a sequence is *n*, the\\n   index set contains the numbers 0, 1, ..., *n*-1.  Item *i* of\\n   sequence *a* is selected by ``a[i]``.\\n\\n   Sequences also support slicing: ``a[i:j]`` selects all items with\\n   index *k* such that *i* ``<=`` *k* ``<`` *j*.  When used as an\\n   expression, a slice is a sequence of the same type.  This implies\\n   that the index set is renumbered so that it starts at 0.\\n\\n   Some sequences also support \"extended slicing\" with a third \"step\"\\n   parameter: ``a[i:j:k]`` selects all items of *a* with index *x*\\n   where ``x = i + n*k``, *n* ``>=`` ``0`` and *i* ``<=`` *x* ``<``\\n   *j*.\\n\\n   Sequences are distinguished according to their mutability:\\n\\n   Immutable sequences\\n      An object of an immutable sequence type cannot change once it is\\n      created.  (If the object contains references to other objects,\\n      these other objects may be mutable and may be changed; however,\\n      the collection of objects directly referenced by an immutable\\n      object cannot change.)\\n\\n      The following types are immutable sequences:\\n\\n      Strings\\n         A string is a sequence of values that represent Unicode\\n         codepoints. All the codepoints in range ``U+0000 - U+10FFFF``\\n         can be represented in a string.  Python doesn\\'t have a\\n         ``chr`` type, and every character in the string is\\n         represented as a string object with length ``1``.  The built-\\n         in function ``ord()`` converts a character to its codepoint\\n         (as an integer); ``chr()`` converts an integer in range ``0 -\\n         10FFFF`` to the corresponding character. ``str.encode()`` can\\n         be used to convert a ``str`` to ``bytes`` using the given\\n         encoding, and ``bytes.decode()`` can be used to achieve the\\n         opposite.\\n\\n      Tuples\\n         The items of a tuple are arbitrary Python objects. Tuples of\\n         two or more items are formed by comma-separated lists of\\n         expressions.  A tuple of one item (a \\'singleton\\') can be\\n         formed by affixing a comma to an expression (an expression by\\n         itself does not create a tuple, since parentheses must be\\n         usable for grouping of expressions).  An empty tuple can be\\n         formed by an empty pair of parentheses.\\n\\n      Bytes\\n         A bytes object is an immutable array.  The items are 8-bit\\n         bytes, represented by integers in the range 0 <= x < 256.\\n         Bytes literals (like ``b\\'abc\\'``) and the built-in function\\n         ``bytes()`` can be used to construct bytes objects.  Also,\\n         bytes objects can be decoded to strings via the ``decode()``\\n         method.\\n\\n   Mutable sequences\\n      Mutable sequences can be changed after they are created.  The\\n      subscription and slicing notations can be used as the target of\\n      assignment and ``del`` (delete) statements.\\n\\n      There are currently two intrinsic mutable sequence types:\\n\\n      Lists\\n         The items of a list are arbitrary Python objects.  Lists are\\n         formed by placing a comma-separated list of expressions in\\n         square brackets. (Note that there are no special cases needed\\n         to form lists of length 0 or 1.)\\n\\n      Byte Arrays\\n         A bytearray object is a mutable array. They are created by\\n         the built-in ``bytearray()`` constructor.  Aside from being\\n         mutable (and hence unhashable), byte arrays otherwise provide\\n         the same interface and functionality as immutable bytes\\n         objects.\\n\\n      The extension module ``array`` provides an additional example of\\n      a mutable sequence type, as does the ``collections`` module.\\n\\nSet types\\n   These represent unordered, finite sets of unique, immutable\\n   objects. As such, they cannot be indexed by any subscript. However,\\n   they can be iterated over, and the built-in function ``len()``\\n   returns the number of items in a set. Common uses for sets are fast\\n   membership testing, removing duplicates from a sequence, and\\n   computing mathematical operations such as intersection, union,\\n   difference, and symmetric difference.\\n\\n   For set elements, the same immutability rules apply as for\\n   dictionary keys. Note that numeric types obey the normal rules for\\n   numeric comparison: if two numbers compare equal (e.g., ``1`` and\\n   ``1.0``), only one of them can be contained in a set.\\n\\n   There are currently two intrinsic set types:\\n\\n   Sets\\n      These represent a mutable set. They are created by the built-in\\n      ``set()`` constructor and can be modified afterwards by several\\n      methods, such as ``add()``.\\n\\n   Frozen sets\\n      These represent an immutable set.  They are created by the\\n      built-in ``frozenset()`` constructor.  As a frozenset is\\n      immutable and *hashable*, it can be used again as an element of\\n      another set, or as a dictionary key.\\n\\nMappings\\n   These represent finite sets of objects indexed by arbitrary index\\n   sets. The subscript notation ``a[k]`` selects the item indexed by\\n   ``k`` from the mapping ``a``; this can be used in expressions and\\n   as the target of assignments or ``del`` statements. The built-in\\n   function ``len()`` returns the number of items in a mapping.\\n\\n   There is currently a single intrinsic mapping type:\\n\\n   Dictionaries\\n      These represent finite sets of objects indexed by nearly\\n      arbitrary values.  The only types of values not acceptable as\\n      keys are values containing lists or dictionaries or other\\n      mutable types that are compared by value rather than by object\\n      identity, the reason being that the efficient implementation of\\n      dictionaries requires a key\\'s hash value to remain constant.\\n      Numeric types used for keys obey the normal rules for numeric\\n      comparison: if two numbers compare equal (e.g., ``1`` and\\n      ``1.0``) then they can be used interchangeably to index the same\\n      dictionary entry.\\n\\n      Dictionaries are mutable; they can be created by the ``{...}``\\n      notation (see section *Dictionary displays*).\\n\\n      The extension modules ``dbm.ndbm`` and ``dbm.gnu`` provide\\n      additional examples of mapping types, as does the\\n      ``collections`` module.\\n\\nCallable types\\n   These are the types to which the function call operation (see\\n   section *Calls*) can be applied:\\n\\n   User-defined functions\\n      A user-defined function object is created by a function\\n      definition (see section *Function definitions*).  It should be\\n      called with an argument list containing the same number of items\\n      as the function\\'s formal parameter list.\\n\\n      Special attributes:\\n\\n      +---------------------------+---------------------------------+-------------+\\n      | Attribute                 | Meaning                         |             |\\n      +===========================+=================================+=============+\\n      | ``__doc__``               | The function\\'s documentation    | Writable    |\\n      |                           | string, or ``None`` if          |             |\\n      |                           | unavailable                     |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__name__``              | The function\\'s name             | Writable    |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__qualname__``          | The function\\'s *qualified name* | Writable    |\\n      |                           | New in version 3.3.             |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__module__``            | The name of the module the      | Writable    |\\n      |                           | function was defined in, or     |             |\\n      |                           | ``None`` if unavailable.        |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__defaults__``          | A tuple containing default      | Writable    |\\n      |                           | argument values for those       |             |\\n      |                           | arguments that have defaults,   |             |\\n      |                           | or ``None`` if no arguments     |             |\\n      |                           | have a default value            |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__code__``              | The code object representing    | Writable    |\\n      |                           | the compiled function body.     |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__globals__``           | A reference to the dictionary   | Read-only   |\\n      |                           | that holds the function\\'s       |             |\\n      |                           | global variables --- the global |             |\\n      |                           | namespace of the module in      |             |\\n      |                           | which the function was defined. |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__dict__``              | The namespace supporting        | Writable    |\\n      |                           | arbitrary function attributes.  |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__closure__``           | ``None`` or a tuple of cells    | Read-only   |\\n      |                           | that contain bindings for the   |             |\\n      |                           | function\\'s free variables.      |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__annotations__``       | A dict containing annotations   | Writable    |\\n      |                           | of parameters.  The keys of the |             |\\n      |                           | dict are the parameter names,   |             |\\n      |                           | or ``\\'return\\'`` for the return  |             |\\n      |                           | annotation, if provided.        |             |\\n      +---------------------------+---------------------------------+-------------+\\n      | ``__kwdefaults__``        | A dict containing defaults for  | Writable    |\\n      |                           | keyword-only parameters.        |             |\\n      +---------------------------+---------------------------------+-------------+\\n\\n      Most of the attributes labelled \"Writable\" check the type of the\\n      assigned value.\\n\\n      Function objects also support getting and setting arbitrary\\n      attributes, which can be used, for example, to attach metadata\\n      to functions.  Regular attribute dot-notation is used to get and\\n      set such attributes. *Note that the current implementation only\\n      supports function attributes on user-defined functions. Function\\n      attributes on built-in functions may be supported in the\\n      future.*\\n\\n      Additional information about a function\\'s definition can be\\n      retrieved from its code object; see the description of internal\\n      types below.\\n\\n   Instance methods\\n      An instance method object combines a class, a class instance and\\n      any callable object (normally a user-defined function).\\n\\n      Special read-only attributes: ``__self__`` is the class instance\\n      object, ``__func__`` is the function object; ``__doc__`` is the\\n      method\\'s documentation (same as ``__func__.__doc__``);\\n      ``__name__`` is the method name (same as ``__func__.__name__``);\\n      ``__module__`` is the name of the module the method was defined\\n      in, or ``None`` if unavailable.\\n\\n      Methods also support accessing (but not setting) the arbitrary\\n      function attributes on the underlying function object.\\n\\n      User-defined method objects may be created when getting an\\n      attribute of a class (perhaps via an instance of that class), if\\n      that attribute is a user-defined function object or a class\\n      method object.\\n\\n      When an instance method object is created by retrieving a user-\\n      defined function object from a class via one of its instances,\\n      its ``__self__`` attribute is the instance, and the method\\n      object is said to be bound.  The new method\\'s ``__func__``\\n      attribute is the original function object.\\n\\n      When a user-defined method object is created by retrieving\\n      another method object from a class or instance, the behaviour is\\n      the same as for a function object, except that the ``__func__``\\n      attribute of the new instance is not the original method object\\n      but its ``__func__`` attribute.\\n\\n      When an instance method object is created by retrieving a class\\n      method object from a class or instance, its ``__self__``\\n      attribute is the class itself, and its ``__func__`` attribute is\\n      the function object underlying the class method.\\n\\n      When an instance method object is called, the underlying\\n      function (``__func__``) is called, inserting the class instance\\n      (``__self__``) in front of the argument list.  For instance,\\n      when ``C`` is a class which contains a definition for a function\\n      ``f()``, and ``x`` is an instance of ``C``, calling ``x.f(1)``\\n      is equivalent to calling ``C.f(x, 1)``.\\n\\n      When an instance method object is derived from a class method\\n      object, the \"class instance\" stored in ``__self__`` will\\n      actually be the class itself, so that calling either ``x.f(1)``\\n      or ``C.f(1)`` is equivalent to calling ``f(C,1)`` where ``f`` is\\n      the underlying function.\\n\\n      Note that the transformation from function object to instance\\n      method object happens each time the attribute is retrieved from\\n      the instance.  In some cases, a fruitful optimization is to\\n      assign the attribute to a local variable and call that local\\n      variable. Also notice that this transformation only happens for\\n      user-defined functions; other callable objects (and all non-\\n      callable objects) are retrieved without transformation.  It is\\n      also important to note that user-defined functions which are\\n      attributes of a class instance are not converted to bound\\n      methods; this *only* happens when the function is an attribute\\n      of the class.\\n\\n   Generator functions\\n      A function or method which uses the ``yield`` statement (see\\n      section *The yield statement*) is called a *generator function*.\\n      Such a function, when called, always returns an iterator object\\n      which can be used to execute the body of the function:  calling\\n      the iterator\\'s ``iterator__next__()`` method will cause the\\n      function to execute until it provides a value using the\\n      ``yield`` statement.  When the function executes a ``return``\\n      statement or falls off the end, a ``StopIteration`` exception is\\n      raised and the iterator will have reached the end of the set of\\n      values to be returned.\\n\\n   Built-in functions\\n      A built-in function object is a wrapper around a C function.\\n      Examples of built-in functions are ``len()`` and ``math.sin()``\\n      (``math`` is a standard built-in module). The number and type of\\n      the arguments are determined by the C function. Special read-\\n      only attributes: ``__doc__`` is the function\\'s documentation\\n      string, or ``None`` if unavailable; ``__name__`` is the\\n      function\\'s name; ``__self__`` is set to ``None`` (but see the\\n      next item); ``__module__`` is the name of the module the\\n      function was defined in or ``None`` if unavailable.\\n\\n   Built-in methods\\n      This is really a different disguise of a built-in function, this\\n      time containing an object passed to the C function as an\\n      implicit extra argument.  An example of a built-in method is\\n      ``alist.append()``, assuming *alist* is a list object. In this\\n      case, the special read-only attribute ``__self__`` is set to the\\n      object denoted by *alist*.\\n\\n   Classes\\n      Classes are callable.  These objects normally act as factories\\n      for new instances of themselves, but variations are possible for\\n      class types that override ``__new__()``.  The arguments of the\\n      call are passed to ``__new__()`` and, in the typical case, to\\n      ``__init__()`` to initialize the new instance.\\n\\n   Class Instances\\n      Instances of arbitrary classes can be made callable by defining\\n      a ``__call__()`` method in their class.\\n\\nModules\\n   Modules are a basic organizational unit of Python code, and are\\n   created by the *import system* as invoked either by the ``import``\\n   statement (see ``import``), or by calling functions such as\\n   ``importlib.import_module()`` and built-in ``__import__()``.  A\\n   module object has a namespace implemented by a dictionary object\\n   (this is the dictionary referenced by the ``__globals__`` attribute\\n   of functions defined in the module).  Attribute references are\\n   translated to lookups in this dictionary, e.g., ``m.x`` is\\n   equivalent to ``m.__dict__[\"x\"]``. A module object does not contain\\n   the code object used to initialize the module (since it isn\\'t\\n   needed once the initialization is done).\\n\\n   Attribute assignment updates the module\\'s namespace dictionary,\\n   e.g., ``m.x = 1`` is equivalent to ``m.__dict__[\"x\"] = 1``.\\n\\n   Special read-only attribute: ``__dict__`` is the module\\'s namespace\\n   as a dictionary object.\\n\\n   **CPython implementation detail:** Because of the way CPython\\n   clears module dictionaries, the module dictionary will be cleared\\n   when the module falls out of scope even if the dictionary still has\\n   live references.  To avoid this, copy the dictionary or keep the\\n   module around while using its dictionary directly.\\n\\n   Predefined (writable) attributes: ``__name__`` is the module\\'s\\n   name; ``__doc__`` is the module\\'s documentation string, or ``None``\\n   if unavailable; ``__file__`` is the pathname of the file from which\\n   the module was loaded, if it was loaded from a file. The\\n   ``__file__`` attribute may be missing for certain types of modules,\\n   such as C modules that are statically linked into the interpreter;\\n   for extension modules loaded dynamically from a shared library, it\\n   is the pathname of the shared library file.\\n\\nCustom classes\\n   Custom class types are typically created by class definitions (see\\n   section *Class definitions*).  A class has a namespace implemented\\n   by a dictionary object. Class attribute references are translated\\n   to lookups in this dictionary, e.g., ``C.x`` is translated to\\n   ``C.__dict__[\"x\"]`` (although there are a number of hooks which\\n   allow for other means of locating attributes). When the attribute\\n   name is not found there, the attribute search continues in the base\\n   classes. This search of the base classes uses the C3 method\\n   resolution order which behaves correctly even in the presence of\\n   \\'diamond\\' inheritance structures where there are multiple\\n   inheritance paths leading back to a common ancestor. Additional\\n   details on the C3 MRO used by Python can be found in the\\n   documentation accompanying the 2.3 release at\\n   http://www.python.org/download/releases/2.3/mro/.\\n\\n   When a class attribute reference (for class ``C``, say) would yield\\n   a class method object, it is transformed into an instance method\\n   object whose ``__self__`` attributes is ``C``.  When it would yield\\n   a static method object, it is transformed into the object wrapped\\n   by the static method object. See section *Implementing Descriptors*\\n   for another way in which attributes retrieved from a class may\\n   differ from those actually contained in its ``__dict__``.\\n\\n   Class attribute assignments update the class\\'s dictionary, never\\n   the dictionary of a base class.\\n\\n   A class object can be called (see above) to yield a class instance\\n   (see below).\\n\\n   Special attributes: ``__name__`` is the class name; ``__module__``\\n   is the module name in which the class was defined; ``__dict__`` is\\n   the dictionary containing the class\\'s namespace; ``__bases__`` is a\\n   tuple (possibly empty or a singleton) containing the base classes,\\n   in the order of their occurrence in the base class list;\\n   ``__doc__`` is the class\\'s documentation string, or None if\\n   undefined.\\n\\nClass instances\\n   A class instance is created by calling a class object (see above).\\n   A class instance has a namespace implemented as a dictionary which\\n   is the first place in which attribute references are searched.\\n   When an attribute is not found there, and the instance\\'s class has\\n   an attribute by that name, the search continues with the class\\n   attributes.  If a class attribute is found that is a user-defined\\n   function object, it is transformed into an instance method object\\n   whose ``__self__`` attribute is the instance.  Static method and\\n   class method objects are also transformed; see above under\\n   \"Classes\".  See section *Implementing Descriptors* for another way\\n   in which attributes of a class retrieved via its instances may\\n   differ from the objects actually stored in the class\\'s\\n   ``__dict__``.  If no class attribute is found, and the object\\'s\\n   class has a ``__getattr__()`` method, that is called to satisfy the\\n   lookup.\\n\\n   Attribute assignments and deletions update the instance\\'s\\n   dictionary, never a class\\'s dictionary.  If the class has a\\n   ``__setattr__()`` or ``__delattr__()`` method, this is called\\n   instead of updating the instance dictionary directly.\\n\\n   Class instances can pretend to be numbers, sequences, or mappings\\n   if they have methods with certain special names.  See section\\n   *Special method names*.\\n\\n   Special attributes: ``__dict__`` is the attribute dictionary;\\n   ``__class__`` is the instance\\'s class.\\n\\nI/O objects (also known as file objects)\\n   A *file object* represents an open file.  Various shortcuts are\\n   available to create file objects: the ``open()`` built-in function,\\n   and also ``os.popen()``, ``os.fdopen()``, and the ``makefile()``\\n   method of socket objects (and perhaps by other functions or methods\\n   provided by extension modules).\\n\\n   The objects ``sys.stdin``, ``sys.stdout`` and ``sys.stderr`` are\\n   initialized to file objects corresponding to the interpreter\\'s\\n   standard input, output and error streams; they are all open in text\\n   mode and therefore follow the interface defined by the\\n   ``io.TextIOBase`` abstract class.\\n\\nInternal types\\n   A few types used internally by the interpreter are exposed to the\\n   user. Their definitions may change with future versions of the\\n   interpreter, but they are mentioned here for completeness.\\n\\n   Code objects\\n      Code objects represent *byte-compiled* executable Python code,\\n      or *bytecode*. The difference between a code object and a\\n      function object is that the function object contains an explicit\\n      reference to the function\\'s globals (the module in which it was\\n      defined), while a code object contains no context; also the\\n      default argument values are stored in the function object, not\\n      in the code object (because they represent values calculated at\\n      run-time).  Unlike function objects, code objects are immutable\\n      and contain no references (directly or indirectly) to mutable\\n      objects.\\n\\n      Special read-only attributes: ``co_name`` gives the function\\n      name; ``co_argcount`` is the number of positional arguments\\n      (including arguments with default values); ``co_nlocals`` is the\\n      number of local variables used by the function (including\\n      arguments); ``co_varnames`` is a tuple containing the names of\\n      the local variables (starting with the argument names);\\n      ``co_cellvars`` is a tuple containing the names of local\\n      variables that are referenced by nested functions;\\n      ``co_freevars`` is a tuple containing the names of free\\n      variables; ``co_code`` is a string representing the sequence of\\n      bytecode instructions; ``co_consts`` is a tuple containing the\\n      literals used by the bytecode; ``co_names`` is a tuple\\n      containing the names used by the bytecode; ``co_filename`` is\\n      the filename from which the code was compiled;\\n      ``co_firstlineno`` is the first line number of the function;\\n      ``co_lnotab`` is a string encoding the mapping from bytecode\\n      offsets to line numbers (for details see the source code of the\\n      interpreter); ``co_stacksize`` is the required stack size\\n      (including local variables); ``co_flags`` is an integer encoding\\n      a number of flags for the interpreter.\\n\\n      The following flag bits are defined for ``co_flags``: bit\\n      ``0x04`` is set if the function uses the ``*arguments`` syntax\\n      to accept an arbitrary number of positional arguments; bit\\n      ``0x08`` is set if the function uses the ``**keywords`` syntax\\n      to accept arbitrary keyword arguments; bit ``0x20`` is set if\\n      the function is a generator.\\n\\n      Future feature declarations (``from __future__ import\\n      division``) also use bits in ``co_flags`` to indicate whether a\\n      code object was compiled with a particular feature enabled: bit\\n      ``0x2000`` is set if the function was compiled with future\\n      division enabled; bits ``0x10`` and ``0x1000`` were used in\\n      earlier versions of Python.\\n\\n      Other bits in ``co_flags`` are reserved for internal use.\\n\\n      If a code object represents a function, the first item in\\n      ``co_consts`` is the documentation string of the function, or\\n      ``None`` if undefined.\\n\\n   Frame objects\\n      Frame objects represent execution frames.  They may occur in\\n      traceback objects (see below).\\n\\n      Special read-only attributes: ``f_back`` is to the previous\\n      stack frame (towards the caller), or ``None`` if this is the\\n      bottom stack frame; ``f_code`` is the code object being executed\\n      in this frame; ``f_locals`` is the dictionary used to look up\\n      local variables; ``f_globals`` is used for global variables;\\n      ``f_builtins`` is used for built-in (intrinsic) names;\\n      ``f_lasti`` gives the precise instruction (this is an index into\\n      the bytecode string of the code object).\\n\\n      Special writable attributes: ``f_trace``, if not ``None``, is a\\n      function called at the start of each source code line (this is\\n      used by the debugger); ``f_lineno`` is the current line number\\n      of the frame --- writing to this from within a trace function\\n      jumps to the given line (only for the bottom-most frame).  A\\n      debugger can implement a Jump command (aka Set Next Statement)\\n      by writing to f_lineno.\\n\\n   Traceback objects\\n      Traceback objects represent a stack trace of an exception.  A\\n      traceback object is created when an exception occurs.  When the\\n      search for an exception handler unwinds the execution stack, at\\n      each unwound level a traceback object is inserted in front of\\n      the current traceback.  When an exception handler is entered,\\n      the stack trace is made available to the program. (See section\\n      *The try statement*.) It is accessible as the third item of the\\n      tuple returned by ``sys.exc_info()``. When the program contains\\n      no suitable handler, the stack trace is written (nicely\\n      formatted) to the standard error stream; if the interpreter is\\n      interactive, it is also made available to the user as\\n      ``sys.last_traceback``.\\n\\n      Special read-only attributes: ``tb_next`` is the next level in\\n      the stack trace (towards the frame where the exception\\n      occurred), or ``None`` if there is no next level; ``tb_frame``\\n      points to the execution frame of the current level;\\n      ``tb_lineno`` gives the line number where the exception\\n      occurred; ``tb_lasti`` indicates the precise instruction.  The\\n      line number and last instruction in the traceback may differ\\n      from the line number of its frame object if the exception\\n      occurred in a ``try`` statement with no matching except clause\\n      or with a finally clause.\\n\\n   Slice objects\\n      Slice objects are used to represent slices for ``__getitem__()``\\n      methods.  They are also created by the built-in ``slice()``\\n      function.\\n\\n      Special read-only attributes: ``start`` is the lower bound;\\n      ``stop`` is the upper bound; ``step`` is the step value; each is\\n      ``None`` if omitted. These attributes can have any type.\\n\\n      Slice objects support one method:\\n\\n      slice.indices(self, length)\\n\\n         This method takes a single integer argument *length* and\\n         computes information about the slice that the slice object\\n         would describe if applied to a sequence of *length* items.\\n         It returns a tuple of three integers; respectively these are\\n         the *start* and *stop* indices and the *step* or stride\\n         length of the slice. Missing or out-of-bounds indices are\\n         handled in a manner consistent with regular slices.\\n\\n   Static method objects\\n      Static method objects provide a way of defeating the\\n      transformation of function objects to method objects described\\n      above. A static method object is a wrapper around any other\\n      object, usually a user-defined method object. When a static\\n      method object is retrieved from a class or a class instance, the\\n      object actually returned is the wrapped object, which is not\\n      subject to any further transformation. Static method objects are\\n      not themselves callable, although the objects they wrap usually\\n      are. Static method objects are created by the built-in\\n      ``staticmethod()`` constructor.\\n\\n   Class method objects\\n      A class method object, like a static method object, is a wrapper\\n      around another object that alters the way in which that object\\n      is retrieved from classes and class instances. The behaviour of\\n      class method objects upon such retrieval is described above,\\n      under \"User-defined methods\". Class method objects are created\\n      by the built-in ``classmethod()`` constructor.\\n',\n'typesfunctions':'\\nFunctions\\n*********\\n\\nFunction objects are created by function definitions.  The only\\noperation on a function object is to call it: ``func(argument-list)``.\\n\\nThere are really two flavors of function objects: built-in functions\\nand user-defined functions.  Both support the same operation (to call\\nthe function), but the implementation is different, hence the\\ndifferent object types.\\n\\nSee *Function definitions* for more information.\\n',\n'typesmapping':'\\nMapping Types --- ``dict``\\n**************************\\n\\nA *mapping* object maps *hashable* values to arbitrary objects.\\nMappings are mutable objects.  There is currently only one standard\\nmapping type, the *dictionary*.  (For other containers see the built-\\nin ``list``, ``set``, and ``tuple`` classes, and the ``collections``\\nmodule.)\\n\\nA dictionary\\'s keys are *almost* arbitrary values.  Values that are\\nnot *hashable*, that is, values containing lists, dictionaries or\\nother mutable types (that are compared by value rather than by object\\nidentity) may not be used as keys.  Numeric types used for keys obey\\nthe normal rules for numeric comparison: if two numbers compare equal\\n(such as ``1`` and ``1.0``) then they can be used interchangeably to\\nindex the same dictionary entry.  (Note however, that since computers\\nstore floating-point numbers as approximations it is usually unwise to\\nuse them as dictionary keys.)\\n\\nDictionaries can be created by placing a comma-separated list of\\n``key: value`` pairs within braces, for example: ``{\\'jack\\': 4098,\\n\\'sjoerd\\': 4127}`` or ``{4098: \\'jack\\', 4127: \\'sjoerd\\'}``, or by the\\n``dict`` constructor.\\n\\nclass class dict(**kwarg)\\nclass class dict(mapping, **kwarg)\\nclass class dict(iterable, **kwarg)\\n\\n   Return a new dictionary initialized from an optional positional\\n   argument and a possibly empty set of keyword arguments.\\n\\n   If no positional argument is given, an empty dictionary is created.\\n   If a positional argument is given and it is a mapping object, a\\n   dictionary is created with the same key-value pairs as the mapping\\n   object.  Otherwise, the positional argument must be an *iterator*\\n   object.  Each item in the iterable must itself be an iterator with\\n   exactly two objects.  The first object of each item becomes a key\\n   in the new dictionary, and the second object the corresponding\\n   value.  If a key occurs more than once, the last value for that key\\n   becomes the corresponding value in the new dictionary.\\n\\n   If keyword arguments are given, the keyword arguments and their\\n   values are added to the dictionary created from the positional\\n   argument.  If a key being added is already present, the value from\\n   the keyword argument replaces the value from the positional\\n   argument.\\n\\n   To illustrate, the following examples all return a dictionary equal\\n   to ``{\"one\": 1, \"two\": 2, \"three\": 3}``:\\n\\n      >>> a = dict(one=1, two=2, three=3)\\n      >>> b = {\\'one\\': 1, \\'two\\': 2, \\'three\\': 3}\\n      >>> c = dict(zip([\\'one\\', \\'two\\', \\'three\\'], [1, 2, 3]))\\n      >>> d = dict([(\\'two\\', 2), (\\'one\\', 1), (\\'three\\', 3)])\\n      >>> e = dict({\\'three\\': 3, \\'one\\': 1, \\'two\\': 2})\\n      >>> a == b == c == d == e\\n      True\\n\\n   Providing keyword arguments as in the first example only works for\\n   keys that are valid Python identifiers.  Otherwise, any valid keys\\n   can be used.\\n\\n   These are the operations that dictionaries support (and therefore,\\n   custom mapping types should support too):\\n\\n   len(d)\\n\\n      Return the number of items in the dictionary *d*.\\n\\n   d[key]\\n\\n      Return the item of *d* with key *key*.  Raises a ``KeyError`` if\\n      *key* is not in the map.\\n\\n      If a subclass of dict defines a method ``__missing__()``, if the\\n      key *key* is not present, the ``d[key]`` operation calls that\\n      method with the key *key* as argument.  The ``d[key]`` operation\\n      then returns or raises whatever is returned or raised by the\\n      ``__missing__(key)`` call if the key is not present. No other\\n      operations or methods invoke ``__missing__()``. If\\n      ``__missing__()`` is not defined, ``KeyError`` is raised.\\n      ``__missing__()`` must be a method; it cannot be an instance\\n      variable:\\n\\n         >>> class Counter(dict):\\n         ...     def __missing__(self, key):\\n         ...         return 0\\n         >>> c = Counter()\\n         >>> c[\\'red\\']\\n         0\\n         >>> c[\\'red\\'] += 1\\n         >>> c[\\'red\\']\\n         1\\n\\n      See ``collections.Counter`` for a complete implementation\\n      including other methods helpful for accumulating and managing\\n      tallies.\\n\\n   d[key] = value\\n\\n      Set ``d[key]`` to *value*.\\n\\n   del d[key]\\n\\n      Remove ``d[key]`` from *d*.  Raises a ``KeyError`` if *key* is\\n      not in the map.\\n\\n   key in d\\n\\n      Return ``True`` if *d* has a key *key*, else ``False``.\\n\\n   key not in d\\n\\n      Equivalent to ``not key in d``.\\n\\n   iter(d)\\n\\n      Return an iterator over the keys of the dictionary.  This is a\\n      shortcut for ``iter(d.keys())``.\\n\\n   clear()\\n\\n      Remove all items from the dictionary.\\n\\n   copy()\\n\\n      Return a shallow copy of the dictionary.\\n\\n   classmethod fromkeys(seq[, value])\\n\\n      Create a new dictionary with keys from *seq* and values set to\\n      *value*.\\n\\n      ``fromkeys()`` is a class method that returns a new dictionary.\\n      *value* defaults to ``None``.\\n\\n   get(key[, default])\\n\\n      Return the value for *key* if *key* is in the dictionary, else\\n      *default*. If *default* is not given, it defaults to ``None``,\\n      so that this method never raises a ``KeyError``.\\n\\n   items()\\n\\n      Return a new view of the dictionary\\'s items (``(key, value)``\\n      pairs). See the *documentation of view objects*.\\n\\n   keys()\\n\\n      Return a new view of the dictionary\\'s keys.  See the\\n      *documentation of view objects*.\\n\\n   pop(key[, default])\\n\\n      If *key* is in the dictionary, remove it and return its value,\\n      else return *default*.  If *default* is not given and *key* is\\n      not in the dictionary, a ``KeyError`` is raised.\\n\\n   popitem()\\n\\n      Remove and return an arbitrary ``(key, value)`` pair from the\\n      dictionary.\\n\\n      ``popitem()`` is useful to destructively iterate over a\\n      dictionary, as often used in set algorithms.  If the dictionary\\n      is empty, calling ``popitem()`` raises a ``KeyError``.\\n\\n   setdefault(key[, default])\\n\\n      If *key* is in the dictionary, return its value.  If not, insert\\n      *key* with a value of *default* and return *default*.  *default*\\n      defaults to ``None``.\\n\\n   update([other])\\n\\n      Update the dictionary with the key/value pairs from *other*,\\n      overwriting existing keys.  Return ``None``.\\n\\n      ``update()`` accepts either another dictionary object or an\\n      iterable of key/value pairs (as tuples or other iterables of\\n      length two).  If keyword arguments are specified, the dictionary\\n      is then updated with those key/value pairs: ``d.update(red=1,\\n      blue=2)``.\\n\\n   values()\\n\\n      Return a new view of the dictionary\\'s values.  See the\\n      *documentation of view objects*.\\n\\nSee also:\\n\\n   ``types.MappingProxyType`` can be used to create a read-only view\\n   of a ``dict``.\\n\\n\\nDictionary view objects\\n=======================\\n\\nThe objects returned by ``dict.keys()``, ``dict.values()`` and\\n``dict.items()`` are *view objects*.  They provide a dynamic view on\\nthe dictionary\\'s entries, which means that when the dictionary\\nchanges, the view reflects these changes.\\n\\nDictionary views can be iterated over to yield their respective data,\\nand support membership tests:\\n\\nlen(dictview)\\n\\n   Return the number of entries in the dictionary.\\n\\niter(dictview)\\n\\n   Return an iterator over the keys, values or items (represented as\\n   tuples of ``(key, value)``) in the dictionary.\\n\\n   Keys and values are iterated over in an arbitrary order which is\\n   non-random, varies across Python implementations, and depends on\\n   the dictionary\\'s history of insertions and deletions. If keys,\\n   values and items views are iterated over with no intervening\\n   modifications to the dictionary, the order of items will directly\\n   correspond.  This allows the creation of ``(value, key)`` pairs\\n   using ``zip()``: ``pairs = zip(d.values(), d.keys())``.  Another\\n   way to create the same list is ``pairs = [(v, k) for (k, v) in\\n   d.items()]``.\\n\\n   Iterating views while adding or deleting entries in the dictionary\\n   may raise a ``RuntimeError`` or fail to iterate over all entries.\\n\\nx in dictview\\n\\n   Return ``True`` if *x* is in the underlying dictionary\\'s keys,\\n   values or items (in the latter case, *x* should be a ``(key,\\n   value)`` tuple).\\n\\nKeys views are set-like since their entries are unique and hashable.\\nIf all values are hashable, so that ``(key, value)`` pairs are unique\\nand hashable, then the items view is also set-like.  (Values views are\\nnot treated as set-like since the entries are generally not unique.)\\nFor set-like views, all of the operations defined for the abstract\\nbase class ``collections.abc.Set`` are available (for example, ``==``,\\n``<``, or ``^``).\\n\\nAn example of dictionary view usage:\\n\\n   >>> dishes = {\\'eggs\\': 2, \\'sausage\\': 1, \\'bacon\\': 1, \\'spam\\': 500}\\n   >>> keys = dishes.keys()\\n   >>> values = dishes.values()\\n\\n   >>> # iteration\\n   >>> n = 0\\n   >>> for val in values:\\n   ...     n += val\\n   >>> print(n)\\n   504\\n\\n   >>> # keys and values are iterated over in the same order\\n   >>> list(keys)\\n   [\\'eggs\\', \\'bacon\\', \\'sausage\\', \\'spam\\']\\n   >>> list(values)\\n   [2, 1, 1, 500]\\n\\n   >>> # view objects are dynamic and reflect dict changes\\n   >>> del dishes[\\'eggs\\']\\n   >>> del dishes[\\'sausage\\']\\n   >>> list(keys)\\n   [\\'spam\\', \\'bacon\\']\\n\\n   >>> # set operations\\n   >>> keys & {\\'eggs\\', \\'bacon\\', \\'salad\\'}\\n   {\\'bacon\\'}\\n   >>> keys ^ {\\'sausage\\', \\'juice\\'}\\n   {\\'juice\\', \\'sausage\\', \\'bacon\\', \\'spam\\'}\\n',\n'typesmethods':'\\nMethods\\n*******\\n\\nMethods are functions that are called using the attribute notation.\\nThere are two flavors: built-in methods (such as ``append()`` on\\nlists) and class instance methods.  Built-in methods are described\\nwith the types that support them.\\n\\nIf you access a method (a function defined in a class namespace)\\nthrough an instance, you get a special object: a *bound method* (also\\ncalled *instance method*) object. When called, it will add the\\n``self`` argument to the argument list.  Bound methods have two\\nspecial read-only attributes: ``m.__self__`` is the object on which\\nthe method operates, and ``m.__func__`` is the function implementing\\nthe method.  Calling ``m(arg-1, arg-2, ..., arg-n)`` is completely\\nequivalent to calling ``m.__func__(m.__self__, arg-1, arg-2, ...,\\narg-n)``.\\n\\nLike function objects, bound method objects support getting arbitrary\\nattributes.  However, since method attributes are actually stored on\\nthe underlying function object (``meth.__func__``), setting method\\nattributes on bound methods is disallowed.  Attempting to set an\\nattribute on a method results in an ``AttributeError`` being raised.\\nIn order to set a method attribute, you need to explicitly set it on\\nthe underlying function object:\\n\\n   >>> class C:\\n   ...     def method(self):\\n   ...         pass\\n   ...\\n   >>> c = C()\\n   >>> c.method.whoami = \\'my name is method\\'  # can\\'t set on the method\\n   Traceback (most recent call last):\\n     File \"<stdin>\", line 1, in <module>\\n   AttributeError: \\'method\\' object has no attribute \\'whoami\\'\\n   >>> c.method.__func__.whoami = \\'my name is method\\'\\n   >>> c.method.whoami\\n   \\'my name is method\\'\\n\\nSee *The standard type hierarchy* for more information.\\n',\n'typesmodules':\"\\nModules\\n*******\\n\\nThe only special operation on a module is attribute access:\\n``m.name``, where *m* is a module and *name* accesses a name defined\\nin *m*'s symbol table. Module attributes can be assigned to.  (Note\\nthat the ``import`` statement is not, strictly speaking, an operation\\non a module object; ``import foo`` does not require a module object\\nnamed *foo* to exist, rather it requires an (external) *definition*\\nfor a module named *foo* somewhere.)\\n\\nA special attribute of every module is ``__dict__``. This is the\\ndictionary containing the module's symbol table. Modifying this\\ndictionary will actually change the module's symbol table, but direct\\nassignment to the ``__dict__`` attribute is not possible (you can\\nwrite ``m.__dict__['a'] = 1``, which defines ``m.a`` to be ``1``, but\\nyou can't write ``m.__dict__ = {}``).  Modifying ``__dict__`` directly\\nis not recommended.\\n\\nModules built into the interpreter are written like this: ``<module\\n'sys' (built-in)>``.  If loaded from a file, they are written as\\n``<module 'os' from '/usr/local/lib/pythonX.Y/os.pyc'>``.\\n\",\n'typesseq':'\\nSequence Types --- ``list``, ``tuple``, ``range``\\n*************************************************\\n\\nThere are three basic sequence types: lists, tuples, and range\\nobjects. Additional sequence types tailored for processing of *binary\\ndata* and *text strings* are described in dedicated sections.\\n\\n\\nCommon Sequence Operations\\n==========================\\n\\nThe operations in the following table are supported by most sequence\\ntypes, both mutable and immutable. The ``collections.abc.Sequence``\\nABC is provided to make it easier to correctly implement these\\noperations on custom sequence types.\\n\\nThis table lists the sequence operations sorted in ascending priority\\n(operations in the same box have the same priority).  In the table,\\n*s* and *t* are sequences of the same type, *n*, *i*, *j* and *k* are\\nintegers and *x* is an arbitrary object that meets any type and value\\nrestrictions imposed by *s*.\\n\\nThe ``in`` and ``not in`` operations have the same priorities as the\\ncomparison operations. The ``+`` (concatenation) and ``*``\\n(repetition) operations have the same priority as the corresponding\\nnumeric operations.\\n\\n+----------------------------+----------------------------------+------------+\\n| Operation                  | Result                           | Notes      |\\n+============================+==================================+============+\\n| ``x in s``                 | ``True`` if an item of *s* is    | (1)        |\\n|                            | equal to *x*, else ``False``     |            |\\n+----------------------------+----------------------------------+------------+\\n| ``x not in s``             | ``False`` if an item of *s* is   | (1)        |\\n|                            | equal to *x*, else ``True``      |            |\\n+----------------------------+----------------------------------+------------+\\n| ``s + t``                  | the concatenation of *s* and *t* | (6)(7)     |\\n+----------------------------+----------------------------------+------------+\\n| ``s * n`` or ``n * s``     | *n* shallow copies of *s*        | (2)(7)     |\\n|                            | concatenated                     |            |\\n+----------------------------+----------------------------------+------------+\\n| ``s[i]``                   | *i*th item of *s*, origin 0      | (3)        |\\n+----------------------------+----------------------------------+------------+\\n| ``s[i:j]``                 | slice of *s* from *i* to *j*     | (3)(4)     |\\n+----------------------------+----------------------------------+------------+\\n| ``s[i:j:k]``               | slice of *s* from *i* to *j*     | (3)(5)     |\\n|                            | with step *k*                    |            |\\n+----------------------------+----------------------------------+------------+\\n| ``len(s)``                 | length of *s*                    |            |\\n+----------------------------+----------------------------------+------------+\\n| ``min(s)``                 | smallest item of *s*             |            |\\n+----------------------------+----------------------------------+------------+\\n| ``max(s)``                 | largest item of *s*              |            |\\n+----------------------------+----------------------------------+------------+\\n| ``s.index(x[, i[, j]])``   | index of the first occurence of  | (8)        |\\n|                            | *x* in *s* (at or after index    |            |\\n|                            | *i* and before index *j*)        |            |\\n+----------------------------+----------------------------------+------------+\\n| ``s.count(x)``             | total number of occurences of    |            |\\n|                            | *x* in *s*                       |            |\\n+----------------------------+----------------------------------+------------+\\n\\nSequences of the same type also support comparisons.  In particular,\\ntuples and lists are compared lexicographically by comparing\\ncorresponding elements. This means that to compare equal, every\\nelement must compare equal and the two sequences must be of the same\\ntype and have the same length.  (For full details see *Comparisons* in\\nthe language reference.)\\n\\nNotes:\\n\\n1. While the ``in`` and ``not in`` operations are used only for simple\\n   containment testing in the general case, some specialised sequences\\n   (such as ``str``, ``bytes`` and ``bytearray``) also use them for\\n   subsequence testing:\\n\\n      >>> \"gg\" in \"eggs\"\\n      True\\n\\n2. Values of *n* less than ``0`` are treated as ``0`` (which yields an\\n   empty sequence of the same type as *s*).  Note also that the copies\\n   are shallow; nested structures are not copied.  This often haunts\\n   new Python programmers; consider:\\n\\n      >>> lists = [[]] * 3\\n      >>> lists\\n      [[], [], []]\\n      >>> lists[0].append(3)\\n      >>> lists\\n      [[3], [3], [3]]\\n\\n   What has happened is that ``[[]]`` is a one-element list containing\\n   an empty list, so all three elements of ``[[]] * 3`` are (pointers\\n   to) this single empty list.  Modifying any of the elements of\\n   ``lists`` modifies this single list. You can create a list of\\n   different lists this way:\\n\\n      >>> lists = [[] for i in range(3)]\\n      >>> lists[0].append(3)\\n      >>> lists[1].append(5)\\n      >>> lists[2].append(7)\\n      >>> lists\\n      [[3], [5], [7]]\\n\\n3. If *i* or *j* is negative, the index is relative to the end of the\\n   string: ``len(s) + i`` or ``len(s) + j`` is substituted.  But note\\n   that ``-0`` is still ``0``.\\n\\n4. The slice of *s* from *i* to *j* is defined as the sequence of\\n   items with index *k* such that ``i <= k < j``.  If *i* or *j* is\\n   greater than ``len(s)``, use ``len(s)``.  If *i* is omitted or\\n   ``None``, use ``0``.  If *j* is omitted or ``None``, use\\n   ``len(s)``.  If *i* is greater than or equal to *j*, the slice is\\n   empty.\\n\\n5. The slice of *s* from *i* to *j* with step *k* is defined as the\\n   sequence of items with index  ``x = i + n*k`` such that ``0 <= n <\\n   (j-i)/k``.  In other words, the indices are ``i``, ``i+k``,\\n   ``i+2*k``, ``i+3*k`` and so on, stopping when *j* is reached (but\\n   never including *j*).  If *i* or *j* is greater than ``len(s)``,\\n   use ``len(s)``.  If *i* or *j* are omitted or ``None``, they become\\n   \"end\" values (which end depends on the sign of *k*).  Note, *k*\\n   cannot be zero. If *k* is ``None``, it is treated like ``1``.\\n\\n6. Concatenating immutable sequences always results in a new object.\\n   This means that building up a sequence by repeated concatenation\\n   will have a quadratic runtime cost in the total sequence length.\\n   To get a linear runtime cost, you must switch to one of the\\n   alternatives below:\\n\\n   * if concatenating ``str`` objects, you can build a list and use\\n     ``str.join()`` at the end or else write to a ``io.StringIO``\\n     instance and retrieve its value when complete\\n\\n   * if concatenating ``bytes`` objects, you can similarly use\\n     ``bytes.join()`` or ``io.BytesIO``, or you can do in-place\\n     concatenation with a ``bytearray`` object.  ``bytearray`` objects\\n     are mutable and have an efficient overallocation mechanism\\n\\n   * if concatenating ``tuple`` objects, extend a ``list`` instead\\n\\n   * for other types, investigate the relevant class documentation\\n\\n7. Some sequence types (such as ``range``) only support item sequences\\n   that follow specific patterns, and hence don\\'t support sequence\\n   concatenation or repetition.\\n\\n8. ``index`` raises ``ValueError`` when *x* is not found in *s*. When\\n   supported, the additional arguments to the index method allow\\n   efficient searching of subsections of the sequence. Passing the\\n   extra arguments is roughly equivalent to using ``s[i:j].index(x)``,\\n   only without copying any data and with the returned index being\\n   relative to the start of the sequence rather than the start of the\\n   slice.\\n\\n\\nImmutable Sequence Types\\n========================\\n\\nThe only operation that immutable sequence types generally implement\\nthat is not also implemented by mutable sequence types is support for\\nthe ``hash()`` built-in.\\n\\nThis support allows immutable sequences, such as ``tuple`` instances,\\nto be used as ``dict`` keys and stored in ``set`` and ``frozenset``\\ninstances.\\n\\nAttempting to hash an immutable sequence that contains unhashable\\nvalues will result in ``TypeError``.\\n\\n\\nMutable Sequence Types\\n======================\\n\\nThe operations in the following table are defined on mutable sequence\\ntypes. The ``collections.abc.MutableSequence`` ABC is provided to make\\nit easier to correctly implement these operations on custom sequence\\ntypes.\\n\\nIn the table *s* is an instance of a mutable sequence type, *t* is any\\niterable object and *x* is an arbitrary object that meets any type and\\nvalue restrictions imposed by *s* (for example, ``bytearray`` only\\naccepts integers that meet the value restriction ``0 <= x <= 255``).\\n\\n+--------------------------------+----------------------------------+-----------------------+\\n| Operation                      | Result                           | Notes                 |\\n+================================+==================================+=======================+\\n| ``s[i] = x``                   | item *i* of *s* is replaced by   |                       |\\n|                                | *x*                              |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s[i:j] = t``                 | slice of *s* from *i* to *j* is  |                       |\\n|                                | replaced by the contents of the  |                       |\\n|                                | iterable *t*                     |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``del s[i:j]``                 | same as ``s[i:j] = []``          |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s[i:j:k] = t``               | the elements of ``s[i:j:k]`` are | (1)                   |\\n|                                | replaced by those of *t*         |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``del s[i:j:k]``               | removes the elements of          |                       |\\n|                                | ``s[i:j:k]`` from the list       |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.append(x)``                | appends *x* to the end of the    |                       |\\n|                                | sequence (same as                |                       |\\n|                                | ``s[len(s):len(s)] = [x]``)      |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.clear()``                  | removes all items from ``s``     | (5)                   |\\n|                                | (same as ``del s[:]``)           |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.copy()``                   | creates a shallow copy of ``s``  | (5)                   |\\n|                                | (same as ``s[:]``)               |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.extend(t)``                | extends *s* with the contents of |                       |\\n|                                | *t* (same as ``s[len(s):len(s)]  |                       |\\n|                                | = t``)                           |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.insert(i, x)``             | inserts *x* into *s* at the      |                       |\\n|                                | index given by *i* (same as      |                       |\\n|                                | ``s[i:i] = [x]``)                |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.pop([i])``                 | retrieves the item at *i* and    | (2)                   |\\n|                                | also removes it from *s*         |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.remove(x)``                | remove the first item from *s*   | (3)                   |\\n|                                | where ``s[i] == x``              |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.reverse()``                | reverses the items of *s* in     | (4)                   |\\n|                                | place                            |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n\\nNotes:\\n\\n1. *t* must have the same length as the slice it is replacing.\\n\\n2. The optional argument *i* defaults to ``-1``, so that by default\\n   the last item is removed and returned.\\n\\n3. ``remove`` raises ``ValueError`` when *x* is not found in *s*.\\n\\n4. The ``reverse()`` method modifies the sequence in place for economy\\n   of space when reversing a large sequence.  To remind users that it\\n   operates by side effect, it does not return the reversed sequence.\\n\\n5. ``clear()`` and ``copy()`` are included for consistency with the\\n   interfaces of mutable containers that don\\'t support slicing\\n   operations (such as ``dict`` and ``set``)\\n\\n   New in version 3.3: ``clear()`` and ``copy()`` methods.\\n\\n\\nLists\\n=====\\n\\nLists are mutable sequences, typically used to store collections of\\nhomogeneous items (where the precise degree of similarity will vary by\\napplication).\\n\\nclass class list([iterable])\\n\\n   Lists may be constructed in several ways:\\n\\n   * Using a pair of square brackets to denote the empty list: ``[]``\\n\\n   * Using square brackets, separating items with commas: ``[a]``,\\n     ``[a, b, c]``\\n\\n   * Using a list comprehension: ``[x for x in iterable]``\\n\\n   * Using the type constructor: ``list()`` or ``list(iterable)``\\n\\n   The constructor builds a list whose items are the same and in the\\n   same order as *iterable*\\'s items.  *iterable* may be either a\\n   sequence, a container that supports iteration, or an iterator\\n   object.  If *iterable* is already a list, a copy is made and\\n   returned, similar to ``iterable[:]``. For example, ``list(\\'abc\\')``\\n   returns ``[\\'a\\', \\'b\\', \\'c\\']`` and ``list( (1, 2, 3) )`` returns ``[1,\\n   2, 3]``. If no argument is given, the constructor creates a new\\n   empty list, ``[]``.\\n\\n   Many other operations also produce lists, including the\\n   ``sorted()`` built-in.\\n\\n   Lists implement all of the *common* and *mutable* sequence\\n   operations. Lists also provide the following additional method:\\n\\n   sort(*, key=None, reverse=None)\\n\\n      This method sorts the list in place, using only ``<``\\n      comparisons between items. Exceptions are not suppressed - if\\n      any comparison operations fail, the entire sort operation will\\n      fail (and the list will likely be left in a partially modified\\n      state).\\n\\n      *key* specifies a function of one argument that is used to\\n      extract a comparison key from each list element (for example,\\n      ``key=str.lower``). The key corresponding to each item in the\\n      list is calculated once and then used for the entire sorting\\n      process. The default value of ``None`` means that list items are\\n      sorted directly without calculating a separate key value.\\n\\n      The ``functools.cmp_to_key()`` utility is available to convert a\\n      2.x style *cmp* function to a *key* function.\\n\\n      *reverse* is a boolean value.  If set to ``True``, then the list\\n      elements are sorted as if each comparison were reversed.\\n\\n      This method modifies the sequence in place for economy of space\\n      when sorting a large sequence.  To remind users that it operates\\n      by side effect, it does not return the sorted sequence (use\\n      ``sorted()`` to explicitly request a new sorted list instance).\\n\\n      The ``sort()`` method is guaranteed to be stable.  A sort is\\n      stable if it guarantees not to change the relative order of\\n      elements that compare equal --- this is helpful for sorting in\\n      multiple passes (for example, sort by department, then by salary\\n      grade).\\n\\n      **CPython implementation detail:** While a list is being sorted,\\n      the effect of attempting to mutate, or even inspect, the list is\\n      undefined.  The C implementation of Python makes the list appear\\n      empty for the duration, and raises ``ValueError`` if it can\\n      detect that the list has been mutated during a sort.\\n\\n\\nTuples\\n======\\n\\nTuples are immutable sequences, typically used to store collections of\\nheterogeneous data (such as the 2-tuples produced by the\\n``enumerate()`` built-in). Tuples are also used for cases where an\\nimmutable sequence of homogeneous data is needed (such as allowing\\nstorage in a ``set`` or ``dict`` instance).\\n\\nclass class tuple([iterable])\\n\\n   Tuples may be constructed in a number of ways:\\n\\n   * Using a pair of parentheses to denote the empty tuple: ``()``\\n\\n   * Using a trailing comma for a singleton tuple: ``a,`` or ``(a,)``\\n\\n   * Separating items with commas: ``a, b, c`` or ``(a, b, c)``\\n\\n   * Using the ``tuple()`` built-in: ``tuple()`` or\\n     ``tuple(iterable)``\\n\\n   The constructor builds a tuple whose items are the same and in the\\n   same order as *iterable*\\'s items.  *iterable* may be either a\\n   sequence, a container that supports iteration, or an iterator\\n   object.  If *iterable* is already a tuple, it is returned\\n   unchanged. For example, ``tuple(\\'abc\\')`` returns ``(\\'a\\', \\'b\\',\\n   \\'c\\')`` and ``tuple( [1, 2, 3] )`` returns ``(1, 2, 3)``. If no\\n   argument is given, the constructor creates a new empty tuple,\\n   ``()``.\\n\\n   Note that it is actually the comma which makes a tuple, not the\\n   parentheses. The parentheses are optional, except in the empty\\n   tuple case, or when they are needed to avoid syntactic ambiguity.\\n   For example, ``f(a, b, c)`` is a function call with three\\n   arguments, while ``f((a, b, c))`` is a function call with a 3-tuple\\n   as the sole argument.\\n\\n   Tuples implement all of the *common* sequence operations.\\n\\nFor heterogeneous collections of data where access by name is clearer\\nthan access by index, ``collections.namedtuple()`` may be a more\\nappropriate choice than a simple tuple object.\\n\\n\\nRanges\\n======\\n\\nThe ``range`` type represents an immutable sequence of numbers and is\\ncommonly used for looping a specific number of times in ``for`` loops.\\n\\nclass class range(stop)\\nclass class range(start, stop[, step])\\n\\n   The arguments to the range constructor must be integers (either\\n   built-in ``int`` or any object that implements the ``__index__``\\n   special method).  If the *step* argument is omitted, it defaults to\\n   ``1``. If the *start* argument is omitted, it defaults to ``0``. If\\n   *step* is zero, ``ValueError`` is raised.\\n\\n   For a positive *step*, the contents of a range ``r`` are determined\\n   by the formula ``r[i] = start + step*i`` where ``i >= 0`` and\\n   ``r[i] < stop``.\\n\\n   For a negative *step*, the contents of the range are still\\n   determined by the formula ``r[i] = start + step*i``, but the\\n   constraints are ``i >= 0`` and ``r[i] > stop``.\\n\\n   A range object will be empty if ``r[0]`` does not meet the value\\n   constraint. Ranges do support negative indices, but these are\\n   interpreted as indexing from the end of the sequence determined by\\n   the positive indices.\\n\\n   Ranges containing absolute values larger than ``sys.maxsize`` are\\n   permitted but some features (such as ``len()``) may raise\\n   ``OverflowError``.\\n\\n   Range examples:\\n\\n      >>> list(range(10))\\n      [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]\\n      >>> list(range(1, 11))\\n      [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]\\n      >>> list(range(0, 30, 5))\\n      [0, 5, 10, 15, 20, 25]\\n      >>> list(range(0, 10, 3))\\n      [0, 3, 6, 9]\\n      >>> list(range(0, -10, -1))\\n      [0, -1, -2, -3, -4, -5, -6, -7, -8, -9]\\n      >>> list(range(0))\\n      []\\n      >>> list(range(1, 0))\\n      []\\n\\n   Ranges implement all of the *common* sequence operations except\\n   concatenation and repetition (due to the fact that range objects\\n   can only represent sequences that follow a strict pattern and\\n   repetition and concatenation will usually violate that pattern).\\n\\nThe advantage of the ``range`` type over a regular ``list`` or\\n``tuple`` is that a ``range`` object will always take the same (small)\\namount of memory, no matter the size of the range it represents (as it\\nonly stores the ``start``, ``stop`` and ``step`` values, calculating\\nindividual items and subranges as needed).\\n\\nRange objects implement the ``collections.Sequence`` ABC, and provide\\nfeatures such as containment tests, element index lookup, slicing and\\nsupport for negative indices (see *Sequence Types --- list, tuple,\\nrange*):\\n\\n>>> r = range(0, 20, 2)\\n>>> r\\nrange(0, 20, 2)\\n>>> 11 in r\\nFalse\\n>>> 10 in r\\nTrue\\n>>> r.index(10)\\n5\\n>>> r[5]\\n10\\n>>> r[:5]\\nrange(0, 10, 2)\\n>>> r[-1]\\n18\\n\\nTesting range objects for equality with ``==`` and ``!=`` compares\\nthem as sequences.  That is, two range objects are considered equal if\\nthey represent the same sequence of values.  (Note that two range\\nobjects that compare equal might have different ``start``, ``stop``\\nand ``step`` attributes, for example ``range(0) == range(2, 1, 3)`` or\\n``range(0, 3, 2) == range(0, 4, 2)``.)\\n\\nChanged in version 3.2: Implement the Sequence ABC. Support slicing\\nand negative indices. Test ``int`` objects for membership in constant\\ntime instead of iterating through all items.\\n\\nChanged in version 3.3: Define \\'==\\' and \\'!=\\' to compare range objects\\nbased on the sequence of values they define (instead of comparing\\nbased on object identity).\\n\\nNew in version 3.3: The ``start``, ``stop`` and ``step`` attributes.\\n',\n'typesseq-mutable':\"\\nMutable Sequence Types\\n**********************\\n\\nThe operations in the following table are defined on mutable sequence\\ntypes. The ``collections.abc.MutableSequence`` ABC is provided to make\\nit easier to correctly implement these operations on custom sequence\\ntypes.\\n\\nIn the table *s* is an instance of a mutable sequence type, *t* is any\\niterable object and *x* is an arbitrary object that meets any type and\\nvalue restrictions imposed by *s* (for example, ``bytearray`` only\\naccepts integers that meet the value restriction ``0 <= x <= 255``).\\n\\n+--------------------------------+----------------------------------+-----------------------+\\n| Operation                      | Result                           | Notes                 |\\n+================================+==================================+=======================+\\n| ``s[i] = x``                   | item *i* of *s* is replaced by   |                       |\\n|                                | *x*                              |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s[i:j] = t``                 | slice of *s* from *i* to *j* is  |                       |\\n|                                | replaced by the contents of the  |                       |\\n|                                | iterable *t*                     |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``del s[i:j]``                 | same as ``s[i:j] = []``          |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s[i:j:k] = t``               | the elements of ``s[i:j:k]`` are | (1)                   |\\n|                                | replaced by those of *t*         |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``del s[i:j:k]``               | removes the elements of          |                       |\\n|                                | ``s[i:j:k]`` from the list       |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.append(x)``                | appends *x* to the end of the    |                       |\\n|                                | sequence (same as                |                       |\\n|                                | ``s[len(s):len(s)] = [x]``)      |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.clear()``                  | removes all items from ``s``     | (5)                   |\\n|                                | (same as ``del s[:]``)           |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.copy()``                   | creates a shallow copy of ``s``  | (5)                   |\\n|                                | (same as ``s[:]``)               |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.extend(t)``                | extends *s* with the contents of |                       |\\n|                                | *t* (same as ``s[len(s):len(s)]  |                       |\\n|                                | = t``)                           |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.insert(i, x)``             | inserts *x* into *s* at the      |                       |\\n|                                | index given by *i* (same as      |                       |\\n|                                | ``s[i:i] = [x]``)                |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.pop([i])``                 | retrieves the item at *i* and    | (2)                   |\\n|                                | also removes it from *s*         |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.remove(x)``                | remove the first item from *s*   | (3)                   |\\n|                                | where ``s[i] == x``              |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n| ``s.reverse()``                | reverses the items of *s* in     | (4)                   |\\n|                                | place                            |                       |\\n+--------------------------------+----------------------------------+-----------------------+\\n\\nNotes:\\n\\n1. *t* must have the same length as the slice it is replacing.\\n\\n2. The optional argument *i* defaults to ``-1``, so that by default\\n   the last item is removed and returned.\\n\\n3. ``remove`` raises ``ValueError`` when *x* is not found in *s*.\\n\\n4. The ``reverse()`` method modifies the sequence in place for economy\\n   of space when reversing a large sequence.  To remind users that it\\n   operates by side effect, it does not return the reversed sequence.\\n\\n5. ``clear()`` and ``copy()`` are included for consistency with the\\n   interfaces of mutable containers that don't support slicing\\n   operations (such as ``dict`` and ``set``)\\n\\n   New in version 3.3: ``clear()`` and ``copy()`` methods.\\n\",\n'unary':'\\nUnary arithmetic and bitwise operations\\n***************************************\\n\\nAll unary arithmetic and bitwise operations have the same priority:\\n\\n   u_expr ::= power | \"-\" u_expr | \"+\" u_expr | \"~\" u_expr\\n\\nThe unary ``-`` (minus) operator yields the negation of its numeric\\nargument.\\n\\nThe unary ``+`` (plus) operator yields its numeric argument unchanged.\\n\\nThe unary ``~`` (invert) operator yields the bitwise inversion of its\\ninteger argument.  The bitwise inversion of ``x`` is defined as\\n``-(x+1)``.  It only applies to integral numbers.\\n\\nIn all three cases, if the argument does not have the proper type, a\\n``TypeError`` exception is raised.\\n',\n'while':'\\nThe ``while`` statement\\n***********************\\n\\nThe ``while`` statement is used for repeated execution as long as an\\nexpression is true:\\n\\n   while_stmt ::= \"while\" expression \":\" suite\\n                  [\"else\" \":\" suite]\\n\\nThis repeatedly tests the expression and, if it is true, executes the\\nfirst suite; if the expression is false (which may be the first time\\nit is tested) the suite of the ``else`` clause, if present, is\\nexecuted and the loop terminates.\\n\\nA ``break`` statement executed in the first suite terminates the loop\\nwithout executing the ``else`` clause\\'s suite.  A ``continue``\\nstatement executed in the first suite skips the rest of the suite and\\ngoes back to testing the expression.\\n',\n'with':'\\nThe ``with`` statement\\n**********************\\n\\nThe ``with`` statement is used to wrap the execution of a block with\\nmethods defined by a context manager (see section *With Statement\\nContext Managers*). This allows common\\n``try``...``except``...``finally`` usage patterns to be encapsulated\\nfor convenient reuse.\\n\\n   with_stmt ::= \"with\" with_item (\",\" with_item)* \":\" suite\\n   with_item ::= expression [\"as\" target]\\n\\nThe execution of the ``with`` statement with one \"item\" proceeds as\\nfollows:\\n\\n1. The context expression (the expression given in the ``with_item``)\\n   is evaluated to obtain a context manager.\\n\\n2. The context manager\\'s ``__exit__()`` is loaded for later use.\\n\\n3. The context manager\\'s ``__enter__()`` method is invoked.\\n\\n4. If a target was included in the ``with`` statement, the return\\n   value from ``__enter__()`` is assigned to it.\\n\\n   Note: The ``with`` statement guarantees that if the ``__enter__()``\\n     method returns without an error, then ``__exit__()`` will always\\n     be called. Thus, if an error occurs during the assignment to the\\n     target list, it will be treated the same as an error occurring\\n     within the suite would be. See step 6 below.\\n\\n5. The suite is executed.\\n\\n6. The context manager\\'s ``__exit__()`` method is invoked.  If an\\n   exception caused the suite to be exited, its type, value, and\\n   traceback are passed as arguments to ``__exit__()``. Otherwise,\\n   three ``None`` arguments are supplied.\\n\\n   If the suite was exited due to an exception, and the return value\\n   from the ``__exit__()`` method was false, the exception is\\n   reraised.  If the return value was true, the exception is\\n   suppressed, and execution continues with the statement following\\n   the ``with`` statement.\\n\\n   If the suite was exited for any reason other than an exception, the\\n   return value from ``__exit__()`` is ignored, and execution proceeds\\n   at the normal location for the kind of exit that was taken.\\n\\nWith more than one item, the context managers are processed as if\\nmultiple ``with`` statements were nested:\\n\\n   with A() as a, B() as b:\\n       suite\\n\\nis equivalent to\\n\\n   with A() as a:\\n       with B() as b:\\n           suite\\n\\nChanged in version 3.1: Support for multiple context expressions.\\n\\nSee also:\\n\\n   **PEP 0343** - The \"with\" statement\\n      The specification, background, and examples for the Python\\n      ``with`` statement.\\n',\n'yield':'\\nThe ``yield`` statement\\n***********************\\n\\n   yield_stmt ::= yield_expression\\n\\nThe ``yield`` statement is only used when defining a generator\\nfunction, and is only used in the body of the generator function.\\nUsing a ``yield`` statement in a function definition is sufficient to\\ncause that definition to create a generator function instead of a\\nnormal function.\\n\\nWhen a generator function is called, it returns an iterator known as a\\ngenerator iterator, or more commonly, a generator.  The body of the\\ngenerator function is executed by calling the ``next()`` function on\\nthe generator repeatedly until it raises an exception.\\n\\nWhen a ``yield`` statement is executed, the state of the generator is\\nfrozen and the value of ``expression_list`` is returned to\\n``next()``\\'s caller.  By \"frozen\" we mean that all local state is\\nretained, including the current bindings of local variables, the\\ninstruction pointer, and the internal evaluation stack: enough\\ninformation is saved so that the next time ``next()`` is invoked, the\\nfunction can proceed exactly as if the ``yield`` statement were just\\nanother external call.\\n\\nThe ``yield`` statement is allowed in the ``try`` clause of a ``try``\\n...  ``finally`` construct.  If the generator is not resumed before it\\nis finalized (by reaching a zero reference count or by being garbage\\ncollected), the generator-iterator\\'s ``close()`` method will be\\ncalled, allowing any pending ``finally`` clauses to execute.\\n\\nWhen ``yield from <expr>`` is used, it treats the supplied expression\\nas a subiterator, producing values from it until the underlying\\niterator is exhausted.\\n\\n   Changed in version 3.3: Added ``yield from <expr>`` to delegate\\n   control flow to a subiterator\\n\\nFor full details of ``yield`` semantics, refer to the *Yield\\nexpressions* section.\\n\\nSee also:\\n\\n   **PEP 0255** - Simple Generators\\n      The proposal for adding generators and the ``yield`` statement\\n      to Python.\\n\\n   **PEP 0342** - Coroutines via Enhanced Generators\\n      The proposal to enhance the API and syntax of generators, making\\n      them usable as simple coroutines.\\n\\n   **PEP 0380** - Syntax for Delegating to a Subgenerator\\n      The proposal to introduce the ``yield_from`` syntax, making\\n      delegation to sub-generators easy.\\n'}\n", []], "pydoc_data": [".py", "", [], 1], "tempfile": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__all__=[\n\"NamedTemporaryFile\",\"TemporaryFile\",\n\"SpooledTemporaryFile\",\"TemporaryDirectory\",\n\"mkstemp\",\"mkdtemp\",\n\"mktemp\",\n\"TMP_MAX\",\"gettempprefix\",\n\"tempdir\",\"gettempdir\"\n]\n\n\n\n\nimport warnings as _warnings\nimport sys as _sys\nimport io as _io\nimport os as _os\nimport errno as _errno\nfrom random import Random as _Random\n\ntry :\n import fcntl as _fcntl\nexcept ImportError:\n def _set_cloexec(fd):\n  pass\nelse :\n def _set_cloexec(fd):\n  try :\n   flags=_fcntl. fcntl(fd,_fcntl. F_GETFD,0)\n  except OSError:\n   pass\n  else :\n  \n   flags |=_fcntl. FD_CLOEXEC\n   _fcntl. fcntl(fd,_fcntl. F_SETFD,flags)\n   \n   \ntry :\n import _thread\nexcept ImportError:\n import _dummy_thread as _thread\n_allocate_lock=_thread. allocate_lock\n\n_text_openflags=_os. O_RDWR |_os. O_CREAT |_os. O_EXCL\nif hasattr(_os,'O_NOINHERIT'):\n _text_openflags |=_os. O_NOINHERIT\nif hasattr(_os,'O_NOFOLLOW'):\n _text_openflags |=_os. O_NOFOLLOW\n \n_bin_openflags=_text_openflags\nif hasattr(_os,'O_BINARY'):\n _bin_openflags |=_os. O_BINARY\n \nif hasattr(_os,'TMP_MAX'):\n TMP_MAX=_os. TMP_MAX\nelse :\n TMP_MAX=10000\n \n \n \ntemplate=\"tmp\"\n\n\n\n_once_lock=_allocate_lock()\n\nif hasattr(_os,\"lstat\"):\n _stat=_os. lstat\nelif hasattr(_os,\"stat\"):\n _stat=_os. stat\nelse :\n\n\n def _stat(fn):\n  f=open(fn)\n  f. close()\n  \ndef _exists(fn):\n try :\n  _stat(fn)\n except OSError:\n  return False\n else :\n  return True\n  \nclass _RandomNameSequence:\n ''\n\n\n\n\n \n \n characters=\"abcdefghijklmnopqrstuvwxyz0123456789_\"\n \n @property\n def rng(self):\n  cur_pid=_os. getpid()\n  if cur_pid !=getattr(self,'_rng_pid',None ):\n   self. _rng=_Random()\n   self. _rng_pid=cur_pid\n  return self. _rng\n  \n def __iter__(self):\n  return self\n  \n def __next__(self):\n  c=self. characters\n  choose=self. rng. choice\n  letters=[choose(c)for dummy in\"123456\"]\n  return''. join(letters)\n  \ndef _candidate_tempdir_list():\n ''\n \n \n dirlist=[]\n \n \n for envname in'TMPDIR','TEMP','TMP':\n  dirname=_os. getenv(envname)\n  if dirname:dirlist. append(dirname)\n  \n  \n if _os. name =='nt':\n  dirlist. extend([r'c:\\temp',r'c:\\tmp',r'\\temp',r'\\tmp'])\n else :\n  dirlist. extend(['/tmp','/var/tmp','/usr/tmp'])\n  \n  \n try :\n  dirlist. append(_os. getcwd())\n except (AttributeError,OSError):\n  dirlist. append(_os. curdir)\n  \n return dirlist\n \ndef _get_default_tempdir():\n ''\n\n\n\n\n\n \n \n namer=_RandomNameSequence()\n dirlist=_candidate_tempdir_list()\n \n for dir in dirlist:\n  if dir !=_os. curdir:\n   dir=_os. path. normcase(_os. path. abspath(dir))\n   \n  for seq in range(100):\n   name=next(namer)\n   filename=_os. path. join(dir,name)\n   try :\n    fd=_os. open(filename,_bin_openflags,0o600)\n    try :\n     try :\n      with _io. open(fd,'wb',closefd=False )as fp:\n       fp. write(b'blat')\n     finally :\n      _os. close(fd)\n    finally :\n     _os. unlink(filename)\n    return dir\n   except FileExistsError:\n    pass\n   except OSError:\n    break\n raise FileNotFoundError(_errno. ENOENT,\n \"No usable temporary directory found in %s\"%\n dirlist)\n \n_name_sequence=None\n\ndef _get_candidate_names():\n ''\n \n global _name_sequence\n if _name_sequence is None :\n  _once_lock. acquire()\n  try :\n   if _name_sequence is None :\n    _name_sequence=_RandomNameSequence()\n  finally :\n   _once_lock. release()\n return _name_sequence\n \n \ndef _mkstemp_inner(dir,pre,suf,flags):\n ''\n \n names=_get_candidate_names()\n \n for seq in range(TMP_MAX):\n  name=next(names)\n  file=_os. path. join(dir,pre+name+suf)\n  try :\n   fd=_os. open(file,flags,0o600)\n   _set_cloexec(fd)\n   return (fd,_os. path. abspath(file))\n  except FileExistsError:\n   continue\n  except PermissionError:\n  \n  \n   if _os. name =='nt':\n    continue\n   else :\n    raise\n    \n raise FileExistsError(_errno. EEXIST,\n \"No usable temporary file name found\")\n \n \n \n \ndef gettempprefix():\n ''\n return template\n \ntempdir=None\n\ndef gettempdir():\n ''\n global tempdir\n if tempdir is None :\n  _once_lock. acquire()\n  try :\n   if tempdir is None :\n    tempdir=_get_default_tempdir()\n  finally :\n   _once_lock. release()\n return tempdir\n \ndef mkstemp(suffix=\"\",prefix=template,dir=None ,text=False ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n if dir is None :\n  dir=gettempdir()\n  \n if text:\n  flags=_text_openflags\n else :\n  flags=_bin_openflags\n  \n return _mkstemp_inner(dir,prefix,suffix,flags)\n \n \ndef mkdtemp(suffix=\"\",prefix=template,dir=None ):\n ''\n\n\n\n\n\n\n\n\n\n \n \n if dir is None :\n  dir=gettempdir()\n  \n names=_get_candidate_names()\n \n for seq in range(TMP_MAX):\n  name=next(names)\n  file=_os. path. join(dir,prefix+name+suffix)\n  try :\n   _os. mkdir(file,0o700)\n   return file\n  except FileExistsError:\n   continue\n   \n raise FileExistsError(_errno. EEXIST,\n \"No usable temporary directory name found\")\n \ndef mktemp(suffix=\"\",prefix=template,dir=None ):\n ''\n\n\n\n\n\n\n\n\n\n \n \n \n \n \n \n if dir is None :\n  dir=gettempdir()\n  \n names=_get_candidate_names()\n for seq in range(TMP_MAX):\n  name=next(names)\n  file=_os. path. join(dir,prefix+name+suffix)\n  if not _exists(file):\n   return file\n   \n raise FileExistsError(_errno. EEXIST,\n \"No usable temporary filename found\")\n \n \nclass _TemporaryFileWrapper:\n ''\n\n\n\n\n \n \n def __init__(self,file,name,delete=True ):\n  self. file=file\n  self. name=name\n  self. close_called=False\n  self. delete=delete\n  \n def __getattr__(self,name):\n \n \n \n  file=self. __dict__['file']\n  a=getattr(file,name)\n  if not isinstance(a,int):\n   setattr(self,name,a)\n  return a\n  \n  \n  \n def __enter__(self):\n  self. file. __enter__()\n  return self\n  \n  \n def __iter__(self):\n  return iter(self. file)\n  \n  \n  \n  \n if _os. name !='nt':\n \n \n \n \n \n  unlink=_os. unlink\n  \n  def close(self):\n   if not self. close_called:\n    self. close_called=True\n    self. file. close()\n    if self. delete:\n     self. unlink(self. name)\n     \n  def __del__(self):\n   self. close()\n   \n   \n   \n  def __exit__(self,exc,value,tb):\n   result=self. file. __exit__(exc,value,tb)\n   self. close()\n   return result\n else :\n  def __exit__(self,exc,value,tb):\n   self. file. __exit__(exc,value,tb)\n   \n   \ndef NamedTemporaryFile(mode='w+b',buffering=-1,encoding=None ,\nnewline=None ,suffix=\"\",prefix=template,\ndir=None ,delete=True ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n if dir is None :\n  dir=gettempdir()\n  \n flags=_bin_openflags\n \n \n \n if _os. name =='nt'and delete:\n  flags |=_os. O_TEMPORARY\n  \n (fd,name)=_mkstemp_inner(dir,prefix,suffix,flags)\n file=_io. open(fd,mode,buffering=buffering,\n newline=newline,encoding=encoding)\n \n return _TemporaryFileWrapper(file,name,delete)\n \nif _os. name !='posix'or _os. sys. platform =='cygwin':\n\n\n TemporaryFile=NamedTemporaryFile\n \nelse :\n def TemporaryFile(mode='w+b',buffering=-1,encoding=None ,\n newline=None ,suffix=\"\",prefix=template,\n dir=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if dir is None :\n   dir=gettempdir()\n   \n  flags=_bin_openflags\n  \n  (fd,name)=_mkstemp_inner(dir,prefix,suffix,flags)\n  try :\n   _os. unlink(name)\n   return _io. open(fd,mode,buffering=buffering,\n   newline=newline,encoding=encoding)\n  except :\n   _os. close(fd)\n   raise\n   \nclass SpooledTemporaryFile:\n ''\n\n\n \n _rolled=False\n \n def __init__(self,max_size=0,mode='w+b',buffering=-1,\n encoding=None ,newline=None ,\n suffix=\"\",prefix=template,dir=None ):\n  if'b'in mode:\n   self. _file=_io. BytesIO()\n  else :\n  \n  \n  \n   self. _file=_io. StringIO(newline=\"\\n\")\n  self. _max_size=max_size\n  self. _rolled=False\n  self. _TemporaryFileArgs={'mode':mode,'buffering':buffering,\n  'suffix':suffix,'prefix':prefix,\n  'encoding':encoding,'newline':newline,\n  'dir':dir}\n  \n def _check(self,file):\n  if self. _rolled:return\n  max_size=self. _max_size\n  if max_size and file. tell()>max_size:\n   self. rollover()\n   \n def rollover(self):\n  if self. _rolled:return\n  file=self. _file\n  newfile=self. _file=TemporaryFile(**self. _TemporaryFileArgs)\n  del self. _TemporaryFileArgs\n  \n  newfile. write(file. getvalue())\n  newfile. seek(file. tell(),0)\n  \n  self. _rolled=True\n  \n  \n  \n  \n  \n  \n  \n def __enter__(self):\n  if self. _file. closed:\n   raise ValueError(\"Cannot enter context with closed file\")\n  return self\n  \n def __exit__(self,exc,value,tb):\n  self. _file. close()\n  \n  \n def __iter__(self):\n  return self. _file. __iter__()\n  \n def close(self):\n  self. _file. close()\n  \n @property\n def closed(self):\n  return self. _file. closed\n  \n @property\n def encoding(self):\n  try :\n   return self. _file. encoding\n  except AttributeError:\n   if'b'in self. _TemporaryFileArgs['mode']:\n    raise\n   return self. _TemporaryFileArgs['encoding']\n   \n def fileno(self):\n  self. rollover()\n  return self. _file. fileno()\n  \n def flush(self):\n  self. _file. flush()\n  \n def isatty(self):\n  return self. _file. isatty()\n  \n @property\n def mode(self):\n  try :\n   return self. _file. mode\n  except AttributeError:\n   return self. _TemporaryFileArgs['mode']\n   \n @property\n def name(self):\n  try :\n   return self. _file. name\n  except AttributeError:\n   return None\n   \n @property\n def newlines(self):\n  try :\n   return self. _file. newlines\n  except AttributeError:\n   if'b'in self. _TemporaryFileArgs['mode']:\n    raise\n   return self. _TemporaryFileArgs['newline']\n   \n def read(self,*args):\n  return self. _file. read(*args)\n  \n def readline(self,*args):\n  return self. _file. readline(*args)\n  \n def readlines(self,*args):\n  return self. _file. readlines(*args)\n  \n def seek(self,*args):\n  self. _file. seek(*args)\n  \n @property\n def softspace(self):\n  return self. _file. softspace\n  \n def tell(self):\n  return self. _file. tell()\n  \n def truncate(self,size=None ):\n  if size is None :\n   self. _file. truncate()\n  else :\n   if size >self. _max_size:\n    self. rollover()\n   self. _file. truncate(size)\n   \n def write(self,s):\n  file=self. _file\n  rv=file. write(s)\n  self. _check(file)\n  return rv\n  \n def writelines(self,iterable):\n  file=self. _file\n  rv=file. writelines(iterable)\n  self. _check(file)\n  return rv\n  \n  \nclass TemporaryDirectory(object):\n ''\n\n\n\n\n\n\n\n\n \n \n def __init__(self,suffix=\"\",prefix=template,dir=None ):\n  self. _closed=False\n  self. name=None\n  self. name=mkdtemp(suffix,prefix,dir)\n  \n def __repr__(self):\n  return\"<{} {!r}>\". format(self. __class__. __name__,self. name)\n  \n def __enter__(self):\n  return self. name\n  \n def cleanup(self,_warn=False ):\n  if self. name and not self. _closed:\n   try :\n    self. _rmtree(self. name)\n   except (TypeError,AttributeError)as ex:\n   \n   \n   \n    if\"None\"not in str(ex):\n     raise\n    print(\"ERROR: {!r} while cleaning up {!r}\". format(ex,self,),\n    file=_sys. stderr)\n    return\n   self. _closed=True\n   if _warn:\n    self. _warn(\"Implicitly cleaning up {!r}\". format(self),\n    ResourceWarning)\n    \n def __exit__(self,exc,value,tb):\n  self. cleanup()\n  \n def __del__(self):\n \n  self. cleanup(_warn=True )\n  \n  \n  \n  \n  \n _listdir=staticmethod(_os. listdir)\n _path_join=staticmethod(_os. path. join)\n _isdir=staticmethod(_os. path. isdir)\n _islink=staticmethod(_os. path. islink)\n _remove=staticmethod(_os. remove)\n _rmdir=staticmethod(_os. rmdir)\n _os_error=OSError\n _warn=_warnings. warn\n \n def _rmtree(self,path):\n \n \n  for name in self. _listdir(path):\n   fullname=self. _path_join(path,name)\n   try :\n    isdir=self. _isdir(fullname)and not self. _islink(fullname)\n   except self. _os_error:\n    isdir=False\n   if isdir:\n    self. _rmtree(fullname)\n   else :\n    try :\n     self. _remove(fullname)\n    except self. _os_error:\n     pass\n  try :\n   self. _rmdir(path)\n  except self. _os_error:\n   pass\n", ["_dummy_thread", "_thread", "errno", "fcntl", "io", "os", "random", "sys", "warnings"]], "_struct": [".py", "\n\n\n\n\n\n\n\n\n\n\n\"\"\"Functions to convert between Python values and C structs.\nPython strings are used to hold the data representing the C struct\nand also as format strings to describe the layout of data in the C struct.\n\nThe optional first format char indicates byte order, size and alignment:\n @: native order, size & alignment (default)\n =: native order, std. size & alignment\n <: little-endian, std. size & alignment\n >: big-endian, std. size & alignment\n !: same as >\n\nThe remaining chars indicate types of args and must match exactly;\nthese can be preceded by a decimal repeat count:\n   x: pad byte (no data);\n   c:char;\n   b:signed byte;\n   B:unsigned byte;\n   h:short;\n   H:unsigned short;\n   i:int;\n   I:unsigned int;\n   l:long;\n   L:unsigned long;\n   f:float;\n   d:double.\nSpecial cases (preceding decimal count indicates length):\n   s:string (array of char); p: pascal string (with count byte).\nSpecial case (only available in native format):\n   P:an integer type that is wide enough to hold a pointer.\nSpecial case (not in native mode unless 'long long' in platform C):\n   q:long long;\n   Q:unsigned long long\nWhitespace between formats is ignored.\n\nThe variable struct.error is an exception raised on errors.\"\"\"\n\nimport math,sys\n\n\nclass StructError(Exception):\n pass\nerror=StructError\ndef unpack_int(data,index,size,le):\n bytes=[b for b in data[index:index+size]]\n if le =='little':\n  bytes. reverse()\n number=0\n for b in bytes:\n  number=number <<8 |b\n return int(number)\n \ndef unpack_signed_int(data,index,size,le):\n number=unpack_int(data,index,size,le)\n max=2 **(size *8)\n if number >2 **(size *8 -1)-1:\n  number=int(-1 *(max -number))\n return number\n \nINFINITY=1e200 *1e200\nNAN=INFINITY /INFINITY\n\ndef unpack_char(data,index,size,le):\n return data[index:index+size]\n \ndef pack_int(number,size,le):\n x=number\n res=[]\n for i in range(size):\n  res. append(x&0xff)\n  x >>=8\n if le =='big':\n  res. reverse()\n return bytes(res)\n \ndef pack_signed_int(number,size,le):\n if not isinstance(number,int):\n  raise StructError(\"argument for i,I,l,L,q,Q,h,H must be integer\")\n if number >2 **(8 *size -1)-1 or number <-1 *2 **(8 *size -1):\n  raise OverflowError(\"Number:%i too large to convert\"%number)\n return pack_int(number,size,le)\n \ndef pack_unsigned_int(number,size,le):\n if not isinstance(number,int):\n  raise StructError(\"argument for i,I,l,L,q,Q,h,H must be integer\")\n if number <0:\n  raise TypeError(\"can't convert negative long to unsigned\")\n if number >2 **(8 *size)-1:\n  raise OverflowError(\"Number:%i too large to convert\"%number)\n return pack_int(number,size,le)\n \ndef pack_char(char,size,le):\n return bytes(char)\n \ndef isinf(x):\n return x !=0.0 and x /2 ==x\ndef isnan(v):\n return v !=v *1.0 or (v ==1.0 and v ==2.0)\n \ndef pack_float(x,size,le):\n unsigned=float_pack(x,size)\n result=[]\n for i in range(size):\n  result. append((unsigned >>(i *8))&0xFF)\n if le ==\"big\":\n  result. reverse()\n return bytes(result)\n \ndef unpack_float(data,index,size,le):\n binary=[data[i]for i in range(index,index+size)]\n if le ==\"big\":\n  binary. reverse()\n unsigned=0\n for i in range(size):\n  unsigned |=binary[i]<<(i *8)\n return float_unpack(unsigned,size,le)\n \ndef round_to_nearest(x):\n ''\n\n\n\n\n\n\n\n\n \n int_part=int(x)\n frac_part=x -int_part\n if frac_part >0.5 or frac_part ==0.5 and int_part&1 ==1:\n  int_part +=1\n return int_part\n \ndef float_unpack(Q,size,le):\n ''\n \n \n if size ==8:\n  MIN_EXP=-1021\n  MAX_EXP=1024\n  MANT_DIG=53\n  BITS=64\n elif size ==4:\n  MIN_EXP=-125\n  MAX_EXP=128\n  MANT_DIG=24\n  BITS=32\n else :\n  raise ValueError(\"invalid size value\")\n  \n if Q >>BITS:\n  raise ValueError(\"input out of range\")\n  \n  \n sign=Q >>BITS -1\n exp=(Q&((1 <<BITS -1)-(1 <<MANT_DIG -1)))>>MANT_DIG -1\n mant=Q&((1 <<MANT_DIG -1)-1)\n \n if exp ==MAX_EXP -MIN_EXP+2:\n \n  result=float('nan')if mant else float('inf')\n elif exp ==0:\n \n  result=math. ldexp(float(mant),MIN_EXP -MANT_DIG)\n else :\n \n  mant +=1 <<MANT_DIG -1\n  result=math. ldexp(float(mant),exp+MIN_EXP -MANT_DIG -1)\n return -result if sign else result\n \n \ndef float_pack(x,size):\n ''\n \n \n if size ==8:\n  MIN_EXP=-1021\n  MAX_EXP=1024\n  MANT_DIG=53\n  BITS=64\n elif size ==4:\n  MIN_EXP=-125\n  MAX_EXP=128\n  MANT_DIG=24\n  BITS=32\n else :\n  raise ValueError(\"invalid size value\")\n  \n sign=math. copysign(1.0,x)<0.0\n if math. isinf(x):\n  mant=0\n  exp=MAX_EXP -MIN_EXP+2\n elif math. isnan(x):\n  mant=1 <<(MANT_DIG -2)\n  exp=MAX_EXP -MIN_EXP+2\n elif x ==0.0:\n  mant=0\n  exp=0\n else :\n  m,e=math. frexp(abs(x))\n  exp=e -(MIN_EXP -1)\n  if exp >0:\n  \n   mant=round_to_nearest(m *(1 <<MANT_DIG))\n   mant -=1 <<MANT_DIG -1\n  else :\n  \n   if exp+MANT_DIG -1 >=0:\n    mant=round_to_nearest(m *(1 <<exp+MANT_DIG -1))\n   else :\n    mant=0\n   exp=0\n   \n   \n  assert 0 <=mant <=1 <<MANT_DIG -1\n  if mant ==1 <<MANT_DIG -1:\n   mant=0\n   exp +=1\n   \n   \n   \n  if exp >=MAX_EXP -MIN_EXP+2:\n   raise OverflowError(\"float too large to pack in this format\")\n   \n   \n assert 0 <=mant <1 <<MANT_DIG -1\n assert 0 <=exp <=MAX_EXP -MIN_EXP+2\n assert 0 <=sign <=1\n return ((sign <<BITS -1)|(exp <<MANT_DIG -1))|mant\n \n \nbig_endian_format={\n'x':{'size':1,'alignment':0,'pack':None ,'unpack':None },\n'b':{'size':1,'alignment':0,'pack':pack_signed_int,'unpack':unpack_signed_int},\n'B':{'size':1,'alignment':0,'pack':pack_unsigned_int,'unpack':unpack_int},\n'c':{'size':1,'alignment':0,'pack':pack_char,'unpack':unpack_char},\n's':{'size':1,'alignment':0,'pack':None ,'unpack':None },\n'p':{'size':1,'alignment':0,'pack':None ,'unpack':None },\n'h':{'size':2,'alignment':0,'pack':pack_signed_int,'unpack':unpack_signed_int},\n'H':{'size':2,'alignment':0,'pack':pack_unsigned_int,'unpack':unpack_int},\n'i':{'size':4,'alignment':0,'pack':pack_signed_int,'unpack':unpack_signed_int},\n'I':{'size':4,'alignment':0,'pack':pack_unsigned_int,'unpack':unpack_int},\n'l':{'size':4,'alignment':0,'pack':pack_signed_int,'unpack':unpack_signed_int},\n'L':{'size':4,'alignment':0,'pack':pack_unsigned_int,'unpack':unpack_int},\n'q':{'size':8,'alignment':0,'pack':pack_signed_int,'unpack':unpack_signed_int},\n'Q':{'size':8,'alignment':0,'pack':pack_unsigned_int,'unpack':unpack_int},\n'f':{'size':4,'alignment':0,'pack':pack_float,'unpack':unpack_float},\n'd':{'size':8,'alignment':0,'pack':pack_float,'unpack':unpack_float},\n}\ndefault=big_endian_format\nformatmode={'<':(default,'little'),\n'>':(default,'big'),\n'!':(default,'big'),\n'=':(default,sys. byteorder),\n'@':(default,sys. byteorder)\n}\n\ndef getmode(fmt):\n try :\n  formatdef,endianness=formatmode[fmt[0]]\n  alignment=fmt[0]not in formatmode or fmt[0]=='@'\n  index=1\n except (IndexError,KeyError):\n  formatdef,endianness=formatmode['@']\n  alignment=True\n  index=0\n return formatdef,endianness,index,alignment\n \ndef getNum(fmt,i):\n num=None\n cur=fmt[i]\n while ('0'<=cur)and (cur <='9'):\n  if num ==None :\n   num=int(cur)\n  else :\n   num=10 *num+int(cur)\n  i +=1\n  cur=fmt[i]\n return num,i\n \ndef calcsize(fmt):\n ''\n\n \n \n formatdef,endianness,i,alignment=getmode(fmt)\n num=0\n result=0\n while i <len(fmt):\n  num,i=getNum(fmt,i)\n  cur=fmt[i]\n  try :\n   format=formatdef[cur]\n  except KeyError:\n   raise StructError(\"%s is not a valid format\"%cur)\n  if num !=None :\n   result +=num *format['size']\n  else :\n  \n  \n   if alignment and result:\n    result +=format['size']-result %format['size']\n   result +=format['size']\n  num=0\n  i +=1\n return result\n \ndef pack(fmt,*args):\n ''\n\n \n formatdef,endianness,i,alignment=getmode(fmt)\n args=list(args)\n n_args=len(args)\n result=[]\n while i <len(fmt):\n  num,i=getNum(fmt,i)\n  cur=fmt[i]\n  try :\n   format=formatdef[cur]\n  except KeyError:\n   raise StructError(\"%s is not a valid format\"%cur)\n  if num ==None :\n   num_s=0\n   num=1\n  else :\n   num_s=num\n   \n  if cur =='x':\n   result +=[b'\\0'*num]\n  elif cur =='s':\n   if isinstance(args[0],bytes):\n    padding=num -len(args[0])\n    result +=[args[0][:num]+b'\\0'*padding]\n    args. pop(0)\n   else :\n    raise StructError(\"arg for string format not a string\")\n  elif cur =='p':\n   if isinstance(args[0],bytes):\n    padding=num -len(args[0])-1\n    \n    if padding >0:\n     result +=[bytes([len(args[0])])+args[0][:num -1]+b'\\0'*padding]\n    else :\n     if num <255:\n      result +=[bytes([num -1])+args[0][:num -1]]\n     else :\n      result +=[bytes([255])+args[0][:num -1]]\n    args. pop(0)\n   else :\n    raise StructError(\"arg for string format not a string\")\n    \n  else :\n   if len(args)<num:\n    raise StructError(\"insufficient arguments to pack\")\n   for var in args[:num]:\n   \n    if len(result)and alignment:\n     padding=format['size']-len(result)%format['size']\n     result +=[bytes([0])]*padding\n    result +=[format['pack'](var,format['size'],endianness)]\n   args=args[num:]\n  num=None\n  i +=1\n if len(args)!=0:\n  raise StructError(\"too many arguments for pack format\")\n return b''. join(result)\n \ndef unpack(fmt,data):\n ''\n\n\n \n formatdef,endianness,i,alignment=getmode(fmt)\n j=0\n num=0\n result=[]\n length=calcsize(fmt)\n if length !=len(data):\n  raise StructError(\"unpack str size does not match format\")\n while i <len(fmt):\n  num,i=getNum(fmt,i)\n  cur=fmt[i]\n  i +=1\n  try :\n   format=formatdef[cur]\n  except KeyError:\n   raise StructError(\"%s is not a valid format\"%cur)\n   \n  if not num:\n   num=1\n   \n  if cur =='x':\n   j +=num\n  elif cur =='s':\n   result. append(data[j:j+num])\n   j +=num\n  elif cur =='p':\n   n=data[j]\n   if n >=num:\n    n=num -1\n   result. append(data[j+1:j+n+1])\n   j +=num\n  else :\n  \n   if j >0 and alignment:\n    padding=format['size']-j %format['size']\n    j +=padding\n   for n in range(num):\n    result +=[format['unpack'](data,j,format['size'],endianness)]\n    j +=format['size']\n    \n return tuple(result)\n \ndef pack_into(fmt,buf,offset,*args):\n data=pack(fmt,*args)\n buf[offset:offset+len(data)]=data\n \ndef unpack_from(fmt,buf,offset=0):\n size=calcsize(fmt)\n data=buf[offset:offset+size]\n if len(data)!=size:\n  raise error(\"unpack_from requires a buffer of at least %d bytes\"\n  %(size,))\n return unpack(fmt,data)\n \ndef _clearcache():\n ''\n \n \nclass Struct:\n\n def __init__(self,fmt):\n  self. format=fmt\n  \n def pack(self,*args):\n  return pack(self. format,*args)\n  \n def pack_into(self,*args):\n  return pack_into(self. format,*args)\n  \n def unpack(self,*args):\n  return unpack(self. format,*args)\n  \n def unpack_from(self,*args):\n  return unpack_from(self. format,*args)\n  \nif __name__ =='__main__':\n t=pack('Bf',1,2)\n print(t,len(t))\n print(unpack('Bf',t))\n print(calcsize('Bf'))\n \n", ["math", "sys"]], "browser.highlight": [".py", "import keyword\nimport _jsre as re\n\nfrom browser import html\n\nletters='abcdefghijklmnopqrstuvwxyz'\nletters +=letters. upper()+'_'\ndigits='0123456789'\n\nbuiltin_funcs=\"\"\"abs|dict|help|min|setattr|\nall|dir|hex|next|slice|\nany|divmod|id|object|sorted|\nascii|enumerate|input|oct|staticmethod|\nbin|eval|int|open|str|\nbool|exec|isinstance|ord|sum|\nbytearray|filter|issubclass|pow|super|\nbytes|float|iter|print|tuple|\ncallable|format|len|property|type|\nchr|frozenset|list|range|vars|\nclassmethod|getattr|locals|repr|zip|\ncompile|globals|map|reversed|__import__|\ncomplex|hasattr|max|round|\ndelattr|hash|memoryview|set|\n\"\"\"\n\nkw_pattern='^('+'|'. join(keyword. kwlist)+')$'\nbf_pattern='^('+builtin_funcs. replace(\"\\n\",\"\")+')$'\n\ndef escape(txt):\n txt=txt. replace('<','&lt;')\n txt=txt. replace('>','&gt;')\n return txt\n \ndef highlight(txt):\n res=html. PRE()\n i=0\n name=''\n while i <len(txt):\n  car=txt[i]\n  if car in [\"'\",'\"']:\n   found_match=False\n   k=i+1\n   while k <len(txt):\n    if txt[k]==car:\n     nb_as=0\n     j=k -1\n     while True :\n      if txt[j]=='\\\\':\n       nb_as +=1\n       j -=1\n      else :\n       break\n     if nb_as %2 ==0:\n      res <=name+html. SPAN(escape(txt[i:k+1]),\n      Class=\"python-string\")\n      i=k\n      name=''\n      found_match=True\n      break\n    k +=1\n   if not found_match:\n    name +=car\n  elif car =='#':\n   end=txt. find('\\n',i)\n   if end ==-1:\n    res <=html. SPAN(escape(txt[i:]),Class=\"python-comment\")\n    break\n   else :\n    res <=html. SPAN(escape(txt[i:end]),Class=\"python-comment\")\n    i=end -1\n  elif car in letters:\n   name +=car\n  elif car in digits and name:\n   name +=car\n  else :\n   if name:\n    if re. search(kw_pattern,name):\n     res <=html. SPAN(name,Class=\"python-keyword\")\n    elif re. search(bf_pattern,name):\n     res <=html. SPAN(name,Class=\"python-builtin\")\n    else :\n     res <=name\n    name=''\n   res <=car\n  i +=1\n res <=name\n return res", ["_jsre", "browser", "browser.html", "keyword"]], "copy": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nimport types\nimport weakref\nfrom copyreg import dispatch_table\nimport builtins\n\nclass Error(Exception):\n pass\nerror=Error\n\n\n\n\n\n\n\nPyStringMap=None\n\n__all__=[\"Error\",\"copy\",\"deepcopy\"]\n\ndef copy(x):\n ''\n\n\n \n \n cls=type(x)\n \n copier=_copy_dispatch. get(cls)\n if copier:\n  return copier(x)\n  \n copier=getattr(cls,\"__copy__\",None )\n if copier:\n  return copier(x)\n  \n reductor=dispatch_table. get(cls)\n if reductor:\n  rv=reductor(x)\n else :\n  reductor=getattr(x,\"__reduce_ex__\",None )\n  if reductor:\n   rv=reductor(2)\n  else :\n   reductor=getattr(x,\"__reduce__\",None )\n   if reductor:\n    rv=reductor()\n   else :\n    raise Error(\"un(shallow)copyable object of type %s\"%cls)\n    \n return _reconstruct(x,rv,0)\n \n \n_copy_dispatch=d={}\n\ndef _copy_immutable(x):\n return x\nfor t in (type(None ),int,float,bool,str,tuple,\nfrozenset,type,range,\ntypes. BuiltinFunctionType,type(Ellipsis),\ntypes. FunctionType,weakref. ref):\n d[t]=_copy_immutable\nt=getattr(types,\"CodeType\",None )\nif t is not None :\n d[t]=_copy_immutable\nfor name in (\"complex\",\"unicode\"):\n t=getattr(builtins,name,None )\n if t is not None :\n  d[t]=_copy_immutable\n  \ndef _copy_with_constructor(x):\n return type(x)(x)\nfor t in (list,dict,set):\n d[t]=_copy_with_constructor\n \ndef _copy_with_copy_method(x):\n return x. copy()\nif PyStringMap is not None :\n d[PyStringMap]=_copy_with_copy_method\n \ndel d\n\ndef deepcopy(x,memo=None ,_nil=[]):\n ''\n\n\n \n \n if memo is None :\n  memo={}\n  \n d=id(x)\n y=memo. get(d,_nil)\n if y is not _nil:\n  return y\n  \n cls=type(x)\n \n copier=_deepcopy_dispatch. get(cls)\n if copier:\n  y=copier(x,memo)\n else :\n  try :\n   issc=issubclass(cls,type)\n  except TypeError:\n   issc=0\n  if issc:\n   y=_deepcopy_atomic(x,memo)\n  else :\n   copier=getattr(x,\"__deepcopy__\",None )\n   if copier:\n    y=copier(memo)\n   else :\n    reductor=dispatch_table. get(cls)\n    if reductor:\n     rv=reductor(x)\n    else :\n     reductor=getattr(x,\"__reduce_ex__\",None )\n     if reductor:\n      rv=reductor(2)\n     else :\n      reductor=getattr(x,\"__reduce__\",None )\n      if reductor:\n       rv=reductor()\n      else :\n       raise Error(\n       \"un(deep)copyable object of type %s\"%cls)\n    y=_reconstruct(x,rv,1,memo)\n    \n    \n if y is not x:\n  memo[d]=y\n  _keep_alive(x,memo)\n return y\n \n_deepcopy_dispatch=d={}\n\ndef _deepcopy_atomic(x,memo):\n return x\nd[type(None )]=_deepcopy_atomic\nd[type(Ellipsis)]=_deepcopy_atomic\nd[int]=_deepcopy_atomic\nd[float]=_deepcopy_atomic\nd[bool]=_deepcopy_atomic\ntry :\n d[complex]=_deepcopy_atomic\nexcept NameError:\n pass\nd[bytes]=_deepcopy_atomic\nd[str]=_deepcopy_atomic\ntry :\n d[types. CodeType]=_deepcopy_atomic\nexcept AttributeError:\n pass\nd[type]=_deepcopy_atomic\nd[range]=_deepcopy_atomic\nd[types. BuiltinFunctionType]=_deepcopy_atomic\nd[types. FunctionType]=_deepcopy_atomic\nd[weakref. ref]=_deepcopy_atomic\n\ndef _deepcopy_list(x,memo):\n y=[]\n memo[id(x)]=y\n for a in x:\n  y. append(deepcopy(a,memo))\n return y\nd[list]=_deepcopy_list\n\ndef _deepcopy_tuple(x,memo):\n y=[]\n for a in x:\n  y. append(deepcopy(a,memo))\n  \n  \n try :\n  return memo[id(x)]\n except KeyError:\n  pass\n for i in range(len(x)):\n  if x[i]is not y[i]:\n   y=tuple(y)\n   break\n else :\n  y=x\n return y\nd[tuple]=_deepcopy_tuple\n\ndef _deepcopy_dict(x,memo):\n y={}\n memo[id(x)]=y\n for key,value in x. items():\n  y[deepcopy(key,memo)]=deepcopy(value,memo)\n return y\nd[dict]=_deepcopy_dict\nif PyStringMap is not None :\n d[PyStringMap]=_deepcopy_dict\n \ndef _deepcopy_method(x,memo):\n return type(x)(x. __func__,deepcopy(x. __self__,memo))\n_deepcopy_dispatch[types. MethodType]=_deepcopy_method\n\ndef _keep_alive(x,memo):\n ''\n\n\n\n\n\n\n\n \n try :\n  memo[id(memo)]. append(x)\n except KeyError:\n \n  memo[id(memo)]=[x]\n  \ndef _reconstruct(x,info,deep,memo=None ):\n if isinstance(info,str):\n  return x\n assert isinstance(info,tuple)\n if memo is None :\n  memo={}\n n=len(info)\n assert n in (2,3,4,5)\n callable,args=info[:2]\n if n >2:\n  state=info[2]\n else :\n  state={}\n if n >3:\n  listiter=info[3]\n else :\n  listiter=None\n if n >4:\n  dictiter=info[4]\n else :\n  dictiter=None\n if deep:\n  args=deepcopy(args,memo)\n y=callable(*args)\n memo[id(x)]=y\n \n if state:\n  if deep:\n   state=deepcopy(state,memo)\n  if hasattr(y,'__setstate__'):\n   y. __setstate__(state)\n  else :\n   if isinstance(state,tuple)and len(state)==2:\n    state,slotstate=state\n   else :\n    slotstate=None\n   if state is not None :\n    y. __dict__. update(state)\n   if slotstate is not None :\n    for key,value in slotstate. items():\n     setattr(y,key,value)\n     \n if listiter is not None :\n  for item in listiter:\n   if deep:\n    item=deepcopy(item,memo)\n   y. append(item)\n if dictiter is not None :\n  for key,value in dictiter:\n   if deep:\n    key=deepcopy(key,memo)\n    value=deepcopy(value,memo)\n   y[key]=value\n return y\n \ndel d\n\ndel types\n\n\nclass _EmptyClass:\n pass\n", ["builtins", "copyreg", "types", "weakref"]], "urllib": [".py", "", [], 1], "reprlib": [".py", "''\n\n__all__=[\"Repr\",\"repr\",\"recursive_repr\"]\n\nimport builtins\nfrom itertools import islice\ntry :\n from _thread import get_ident\nexcept ImportError:\n from _dummy_thread import get_ident\n \ndef recursive_repr(fillvalue='...'):\n ''\n \n def decorating_function(user_function):\n  repr_running=set()\n  \n  def wrapper(self):\n   key=id(self),get_ident()\n   if key in repr_running:\n    return fillvalue\n   repr_running. add(key)\n   try :\n    result=user_function(self)\n   finally :\n    repr_running. discard(key)\n   return result\n   \n   \n  wrapper. __module__=getattr(user_function,'__module__')\n  wrapper. __doc__=getattr(user_function,'__doc__')\n  wrapper. __name__=getattr(user_function,'__name__')\n  wrapper. __annotations__=getattr(user_function,'__annotations__',{})\n  return wrapper\n  \n return decorating_function\n \nclass Repr:\n\n def __init__(self):\n  self. maxlevel=6\n  self. maxtuple=6\n  self. maxlist=6\n  self. maxarray=5\n  self. maxdict=4\n  self. maxset=6\n  self. maxfrozenset=6\n  self. maxdeque=6\n  self. maxstring=30\n  self. maxlong=40\n  self. maxother=30\n  \n def repr(self,x):\n  return self. repr1(x,self. maxlevel)\n  \n def repr1(self,x,level):\n  typename=type(x). __name__\n  if' 'in typename:\n   parts=typename. split()\n   typename='_'. join(parts)\n  if hasattr(self,'repr_'+typename):\n   return getattr(self,'repr_'+typename)(x,level)\n  else :\n   return self. repr_instance(x,level)\n   \n def _repr_iterable(self,x,level,left,right,maxiter,trail=''):\n  n=len(x)\n  if level <=0 and n:\n   s='...'\n  else :\n   newlevel=level -1\n   repr1=self. repr1\n   pieces=[repr1(elem,newlevel)for elem in islice(x,maxiter)]\n   if n >maxiter:pieces. append('...')\n   s=', '. join(pieces)\n   if n ==1 and trail:right=trail+right\n  return'%s%s%s'%(left,s,right)\n  \n def repr_tuple(self,x,level):\n  return self. _repr_iterable(x,level,'(',')',self. maxtuple,',')\n  \n def repr_list(self,x,level):\n  return self. _repr_iterable(x,level,'[',']',self. maxlist)\n  \n def repr_array(self,x,level):\n  header=\"array('%s', [\"%x. typecode\n  return self. _repr_iterable(x,level,header,'])',self. maxarray)\n  \n def repr_set(self,x,level):\n  x=_possibly_sorted(x)\n  return self. _repr_iterable(x,level,'set([','])',self. maxset)\n  \n def repr_frozenset(self,x,level):\n  x=_possibly_sorted(x)\n  return self. _repr_iterable(x,level,'frozenset([','])',\n  self. maxfrozenset)\n  \n def repr_deque(self,x,level):\n  return self. _repr_iterable(x,level,'deque([','])',self. maxdeque)\n  \n def repr_dict(self,x,level):\n  n=len(x)\n  if n ==0:return'{}'\n  if level <=0:return'{...}'\n  newlevel=level -1\n  repr1=self. repr1\n  pieces=[]\n  for key in islice(_possibly_sorted(x),self. maxdict):\n   keyrepr=repr1(key,newlevel)\n   valrepr=repr1(x[key],newlevel)\n   pieces. append('%s: %s'%(keyrepr,valrepr))\n  if n >self. maxdict:pieces. append('...')\n  s=', '. join(pieces)\n  return'{%s}'%(s,)\n  \n def repr_str(self,x,level):\n  s=builtins. repr(x[:self. maxstring])\n  if len(s)>self. maxstring:\n   i=max(0,(self. maxstring -3)//2)\n   j=max(0,self. maxstring -3 -i)\n   s=builtins. repr(x[:i]+x[len(x)-j:])\n   s=s[:i]+'...'+s[len(s)-j:]\n  return s\n  \n def repr_int(self,x,level):\n  s=builtins. repr(x)\n  if len(s)>self. maxlong:\n   i=max(0,(self. maxlong -3)//2)\n   j=max(0,self. maxlong -3 -i)\n   s=s[:i]+'...'+s[len(s)-j:]\n  return s\n  \n def repr_instance(self,x,level):\n  try :\n   s=builtins. repr(x)\n   \n   \n  except Exception:\n   return'<%s instance at %x>'%(x. __class__. __name__,id(x))\n  if len(s)>self. maxother:\n   i=max(0,(self. maxother -3)//2)\n   j=max(0,self. maxother -3 -i)\n   s=s[:i]+'...'+s[len(s)-j:]\n  return s\n  \n  \ndef _possibly_sorted(x):\n\n\n\n try :\n  return sorted(x)\n except Exception:\n  return list(x)\n  \naRepr=Repr()\nrepr=aRepr. repr\n", ["_dummy_thread", "_thread", "builtins", "itertools"]], "queue": [".py", "''\n\ntry :\n import threading\nexcept ImportError:\n import dummy_threading as threading\nfrom collections import deque\nfrom heapq import heappush,heappop\ntry :\n from time import monotonic as time\nexcept ImportError:\n from time import time\n \n__all__=['Empty','Full','Queue','PriorityQueue','LifoQueue']\n\nclass Empty(Exception):\n ''\n pass\n \nclass Full(Exception):\n ''\n pass\n \nclass Queue:\n ''\n\n\n \n \n def __init__(self,maxsize=0):\n  self. maxsize=maxsize\n  self. _init(maxsize)\n  \n  \n  \n  \n  \n  self. mutex=threading. Lock()\n  \n  \n  \n  self. not_empty=threading. Condition(self. mutex)\n  \n  \n  \n  self. not_full=threading. Condition(self. mutex)\n  \n  \n  \n  self. all_tasks_done=threading. Condition(self. mutex)\n  self. unfinished_tasks=0\n  \n def task_done(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n  \n  with self. all_tasks_done:\n   unfinished=self. unfinished_tasks -1\n   if unfinished <=0:\n    if unfinished <0:\n     raise ValueError('task_done() called too many times')\n    self. all_tasks_done. notify_all()\n   self. unfinished_tasks=unfinished\n   \n def join(self):\n  ''\n\n\n\n\n\n\n  \n  with self. all_tasks_done:\n   while self. unfinished_tasks:\n    self. all_tasks_done. wait()\n    \n def qsize(self):\n  ''\n  with self. mutex:\n   return self. _qsize()\n   \n def empty(self):\n  ''\n\n\n\n\n\n\n\n\n  \n  with self. mutex:\n   return not self. _qsize()\n   \n def full(self):\n  ''\n\n\n\n\n\n  \n  with self. mutex:\n   return 0 <self. maxsize <=self. _qsize()\n   \n def put(self,item,block=True ,timeout=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  with self. not_full:\n   if self. maxsize >0:\n    if not block:\n     if self. _qsize()>=self. maxsize:\n      raise Full\n    elif timeout is None :\n     while self. _qsize()>=self. maxsize:\n      self. not_full. wait()\n    elif timeout <0:\n     raise ValueError(\"'timeout' must be a non-negative number\")\n    else :\n     endtime=time()+timeout\n     while self. _qsize()>=self. maxsize:\n      remaining=endtime -time()\n      if remaining <=0.0:\n       raise Full\n      self. not_full. wait(remaining)\n   self. _put(item)\n   self. unfinished_tasks +=1\n   self. not_empty. notify()\n   \n def get(self,block=True ,timeout=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  with self. not_empty:\n   if not block:\n    if not self. _qsize():\n     raise Empty\n   elif timeout is None :\n    while not self. _qsize():\n     self. not_empty. wait()\n   elif timeout <0:\n    raise ValueError(\"'timeout' must be a non-negative number\")\n   else :\n    endtime=time()+timeout\n    while not self. _qsize():\n     remaining=endtime -time()\n     if remaining <=0.0:\n      raise Empty\n     self. not_empty. wait(remaining)\n   item=self. _get()\n   self. not_full. notify()\n   return item\n   \n def put_nowait(self,item):\n  ''\n\n\n\n  \n  return self. put(item,block=False )\n  \n def get_nowait(self):\n  ''\n\n\n\n  \n  return self. get(block=False )\n  \n  \n  \n  \n  \n  \n def _init(self,maxsize):\n  self. queue=deque()\n  \n def _qsize(self):\n  return len(self. queue)\n  \n  \n def _put(self,item):\n  self. queue. append(item)\n  \n  \n def _get(self):\n  return self. queue. popleft()\n  \n  \nclass PriorityQueue(Queue):\n ''\n\n\n \n \n def _init(self,maxsize):\n  self. queue=[]\n  \n def _qsize(self):\n  return len(self. queue)\n  \n def _put(self,item):\n  heappush(self. queue,item)\n  \n def _get(self):\n  return heappop(self. queue)\n  \n  \nclass LifoQueue(Queue):\n ''\n \n def _init(self,maxsize):\n  self. queue=[]\n  \n def _qsize(self):\n  return len(self. queue)\n  \n def _put(self,item):\n  self. queue. append(item)\n  \n def _get(self):\n  return self. queue. pop()\n", ["collections", "dummy_threading", "heapq", "threading", "time"]], "tokenize": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__author__='Ka-Ping Yee <ping@lfw.org>'\n__credits__=('GvR, ESR, Tim Peters, Thomas Wouters, Fred Drake, '\n'Skip Montanaro, Raymond Hettinger, Trent Nelson, '\n'Michael Foord')\nimport builtins\nimport re\nimport sys\nfrom token import *\nfrom codecs import lookup,BOM_UTF8\nimport collections\nfrom io import TextIOWrapper\ncookie_re=re. compile(r'^[ \\t\\f]*#.*coding[:=][ \\t]*([-\\w.]+)',re. ASCII)\n\nimport token\n__all__=token. __all__+[\"COMMENT\",\"tokenize\",\"detect_encoding\",\n\"NL\",\"untokenize\",\"ENCODING\",\"TokenInfo\"]\ndel token\n\nCOMMENT=N_TOKENS\ntok_name[COMMENT]='COMMENT'\nNL=N_TOKENS+1\ntok_name[NL]='NL'\nENCODING=N_TOKENS+2\ntok_name[ENCODING]='ENCODING'\nN_TOKENS +=3\nEXACT_TOKEN_TYPES={\n'(':LPAR,\n')':RPAR,\n'[':LSQB,\n']':RSQB,\n':':COLON,\n',':COMMA,\n';':SEMI,\n'+':PLUS,\n'-':MINUS,\n'*':STAR,\n'/':SLASH,\n'|':VBAR,\n'&':AMPER,\n'<':LESS,\n'>':GREATER,\n'=':EQUAL,\n'.':DOT,\n'%':PERCENT,\n'{':LBRACE,\n'}':RBRACE,\n'==':EQEQUAL,\n'!=':NOTEQUAL,\n'<=':LESSEQUAL,\n'>=':GREATEREQUAL,\n'~':TILDE,\n'^':CIRCUMFLEX,\n'<<':LEFTSHIFT,\n'>>':RIGHTSHIFT,\n'**':DOUBLESTAR,\n'+=':PLUSEQUAL,\n'-=':MINEQUAL,\n'*=':STAREQUAL,\n'/=':SLASHEQUAL,\n'%=':PERCENTEQUAL,\n'&=':AMPEREQUAL,\n'|=':VBAREQUAL,\n'^=':CIRCUMFLEXEQUAL,\n'<<=':LEFTSHIFTEQUAL,\n'>>=':RIGHTSHIFTEQUAL,\n'**=':DOUBLESTAREQUAL,\n'//':DOUBLESLASH,\n'//=':DOUBLESLASHEQUAL,\n'@':AT\n}\n\nclass TokenInfo(collections. namedtuple('TokenInfo','type string start end line')):\n def __repr__(self):\n  annotated_type='%d (%s)'%(self. type,tok_name[self. type])\n  return ('TokenInfo(type=%s, string=%r, start=%r, end=%r, line=%r)'%\n  self. _replace(type=annotated_type))\n  \n @property\n def exact_type(self):\n  if self. type ==OP and self. string in EXACT_TOKEN_TYPES:\n   return EXACT_TOKEN_TYPES[self. string]\n  else :\n   return self. type\n   \ndef group(*choices):return'('+'|'. join(choices)+')'\ndef any(*choices):return group(*choices)+'*'\ndef maybe(*choices):return group(*choices)+'?'\n\n\n\nWhitespace=r'[ \\f\\t]*'\nComment=r'#[^\\r\\n]*'\nIgnore=Whitespace+any(r'\\\\\\r?\\n'+Whitespace)+maybe(Comment)\nName=r'\\w+'\n\nHexnumber=r'0[xX][0-9a-fA-F]+'\nBinnumber=r'0[bB][01]+'\nOctnumber=r'0[oO][0-7]+'\nDecnumber=r'(?:0+|[1-9][0-9]*)'\nIntnumber=group(Hexnumber,Binnumber,Octnumber,Decnumber)\nExponent=r'[eE][-+]?[0-9]+'\nPointfloat=group(r'[0-9]+\\.[0-9]*',r'\\.[0-9]+')+maybe(Exponent)\nExpfloat=r'[0-9]+'+Exponent\nFloatnumber=group(Pointfloat,Expfloat)\nImagnumber=group(r'[0-9]+[jJ]',Floatnumber+r'[jJ]')\nNumber=group(Imagnumber,Floatnumber,Intnumber)\n\nStringPrefix=r'(?:[bB][rR]?|[rR][bB]?|[uU])?'\n\n\nSingle=r\"[^'\\\\]*(?:\\\\.[^'\\\\]*)*'\"\n\nDouble=r'[^\"\\\\]*(?:\\\\.[^\"\\\\]*)*\"'\n\nSingle3=r\"[^'\\\\]*(?:(?:\\\\.|'(?!''))[^'\\\\]*)*'''\"\n\nDouble3=r'[^\"\\\\]*(?:(?:\\\\.|\"(?!\"\"))[^\"\\\\]*)*\"\"\"'\nTriple=group(StringPrefix+\"'''\",StringPrefix+'\"\"\"')\n\nString=group(StringPrefix+r\"'[^\\n'\\\\]*(?:\\\\.[^\\n'\\\\]*)*'\",\nStringPrefix+r'\"[^\\n\"\\\\]*(?:\\\\.[^\\n\"\\\\]*)*\"')\n\n\n\n\nOperator=group(r\"\\*\\*=?\",r\">>=?\",r\"<<=?\",r\"!=\",\nr\"//=?\",r\"->\",\nr\"[+\\-*/%&|^=<>]=?\",\nr\"~\")\n\nBracket='[][(){}]'\nSpecial=group(r'\\r?\\n',r'\\.\\.\\.',r'[:;.,@]')\nFunny=group(Operator,Bracket,Special)\n\nPlainToken=group(Number,Funny,String,Name)\nToken=Ignore+PlainToken\n\n\nContStr=group(StringPrefix+r\"'[^\\n'\\\\]*(?:\\\\.[^\\n'\\\\]*)*\"+\ngroup(\"'\",r'\\\\\\r?\\n'),\nStringPrefix+r'\"[^\\n\"\\\\]*(?:\\\\.[^\\n\"\\\\]*)*'+\ngroup('\"',r'\\\\\\r?\\n'))\nPseudoExtras=group(r'\\\\\\r?\\n|\\Z',Comment,Triple)\nPseudoToken=Whitespace+group(PseudoExtras,Number,Funny,ContStr,Name)\n\ndef _compile(expr):\n return re. compile(expr,re. UNICODE)\n \nendpats={\"'\":Single,'\"':Double,\n\"'''\":Single3,'\"\"\"':Double3,\n\"r'''\":Single3,'r\"\"\"':Double3,\n\"b'''\":Single3,'b\"\"\"':Double3,\n\"R'''\":Single3,'R\"\"\"':Double3,\n\"B'''\":Single3,'B\"\"\"':Double3,\n\"br'''\":Single3,'br\"\"\"':Double3,\n\"bR'''\":Single3,'bR\"\"\"':Double3,\n\"Br'''\":Single3,'Br\"\"\"':Double3,\n\"BR'''\":Single3,'BR\"\"\"':Double3,\n\"rb'''\":Single3,'rb\"\"\"':Double3,\n\"Rb'''\":Single3,'Rb\"\"\"':Double3,\n\"rB'''\":Single3,'rB\"\"\"':Double3,\n\"RB'''\":Single3,'RB\"\"\"':Double3,\n\"u'''\":Single3,'u\"\"\"':Double3,\n\"R'''\":Single3,'R\"\"\"':Double3,\n\"U'''\":Single3,'U\"\"\"':Double3,\n'r':None ,'R':None ,'b':None ,'B':None ,\n'u':None ,'U':None }\n\ntriple_quoted={}\nfor t in (\"'''\",'\"\"\"',\n\"r'''\",'r\"\"\"',\"R'''\",'R\"\"\"',\n\"b'''\",'b\"\"\"',\"B'''\",'B\"\"\"',\n\"br'''\",'br\"\"\"',\"Br'''\",'Br\"\"\"',\n\"bR'''\",'bR\"\"\"',\"BR'''\",'BR\"\"\"',\n\"rb'''\",'rb\"\"\"',\"rB'''\",'rB\"\"\"',\n\"Rb'''\",'Rb\"\"\"',\"RB'''\",'RB\"\"\"',\n\"u'''\",'u\"\"\"',\"U'''\",'U\"\"\"',\n):\n triple_quoted[t]=t\nsingle_quoted={}\nfor t in (\"'\",'\"',\n\"r'\",'r\"',\"R'\",'R\"',\n\"b'\",'b\"',\"B'\",'B\"',\n\"br'\",'br\"',\"Br'\",'Br\"',\n\"bR'\",'bR\"',\"BR'\",'BR\"',\n\"rb'\",'rb\"',\"rB'\",'rB\"',\n\"Rb'\",'Rb\"',\"RB'\",'RB\"',\n\"u'\",'u\"',\"U'\",'U\"',\n):\n single_quoted[t]=t\n \ntabsize=8\n\nclass TokenError(Exception):pass\n\nclass StopTokenizing(Exception):pass\n\n\nclass Untokenizer:\n\n def __init__(self):\n  self. tokens=[]\n  self. prev_row=1\n  self. prev_col=0\n  self. encoding=None\n  \n def add_whitespace(self,start):\n  row,col=start\n  assert row <=self. prev_row\n  col_offset=col -self. prev_col\n  if col_offset:\n   self. tokens. append(\" \"*col_offset)\n   \n def untokenize(self,iterable):\n  for t in iterable:\n   if len(t)==2:\n    self. compat(t,iterable)\n    break\n   tok_type,token,start,end,line=t\n   if tok_type ==ENCODING:\n    self. encoding=token\n    continue\n   self. add_whitespace(start)\n   self. tokens. append(token)\n   self. prev_row,self. prev_col=end\n   if tok_type in (NEWLINE,NL):\n    self. prev_row +=1\n    self. prev_col=0\n  return\"\". join(self. tokens)\n  \n def compat(self,token,iterable):\n  startline=False\n  indents=[]\n  toks_append=self. tokens. append\n  toknum,tokval=token\n  \n  if toknum in (NAME,NUMBER):\n   tokval +=' '\n  if toknum in (NEWLINE,NL):\n   startline=True\n  prevstring=False\n  for tok in iterable:\n   toknum,tokval=tok[:2]\n   if toknum ==ENCODING:\n    self. encoding=tokval\n    continue\n    \n   if toknum in (NAME,NUMBER):\n    tokval +=' '\n    \n    \n   if toknum ==STRING:\n    if prevstring:\n     tokval=' '+tokval\n    prevstring=True\n   else :\n    prevstring=False\n    \n   if toknum ==INDENT:\n    indents. append(tokval)\n    continue\n   elif toknum ==DEDENT:\n    indents. pop()\n    continue\n   elif toknum in (NEWLINE,NL):\n    startline=True\n   elif startline and indents:\n    toks_append(indents[-1])\n    startline=False\n   toks_append(tokval)\n   \n   \ndef untokenize(iterable):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n ut=Untokenizer()\n out=ut. untokenize(iterable)\n if ut. encoding is not None :\n  out=out. encode(ut. encoding)\n return out\n \n \ndef _get_normal_name(orig_enc):\n ''\n \n enc=orig_enc[:12]. lower(). replace(\"_\",\"-\")\n if enc ==\"utf-8\"or enc. startswith(\"utf-8-\"):\n  return\"utf-8\"\n if enc in (\"latin-1\",\"iso-8859-1\",\"iso-latin-1\")or enc. startswith((\"latin-1-\",\"iso-8859-1-\",\"iso-latin-1-\")):\n  return\"iso-8859-1\"\n return orig_enc\n \ndef detect_encoding(readline):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n try :\n  filename=readline. __self__. name\n except AttributeError:\n  filename=None\n bom_found=False\n encoding=None\n default='utf-8'\n def read_or_stop():\n  try :\n   return readline()\n  except StopIteration:\n   return b''\n   \n def find_cookie(line):\n  try :\n  \n  \n  \n   line_string=line. decode('utf-8')\n  except UnicodeDecodeError:\n   msg=\"invalid or missing encoding declaration\"\n   if filename is not None :\n    msg='{} for {!r}'. format(msg,filename)\n   raise SyntaxError(msg)\n   \n  match=cookie_re. match(line_string)\n  if not match:\n   return None\n  encoding=_get_normal_name(match. group(1))\n  try :\n   codec=lookup(encoding)\n  except LookupError:\n  \n   if filename is None :\n    msg=\"unknown encoding: \"+encoding\n   else :\n    msg=\"unknown encoding for {!r}: {}\". format(filename,\n    encoding)\n   raise SyntaxError(msg)\n   \n  if bom_found:\n   if encoding !='utf-8':\n   \n    if filename is None :\n     msg='encoding problem: utf-8'\n    else :\n     msg='encoding problem for {!r}: utf-8'. format(filename)\n    raise SyntaxError(msg)\n   encoding +='-sig'\n  return encoding\n  \n first=read_or_stop()\n if first. startswith(BOM_UTF8):\n  bom_found=True\n  first=first[3:]\n  default='utf-8-sig'\n if not first:\n  return default,[]\n  \n encoding=find_cookie(first)\n if encoding:\n  return encoding,[first]\n  \n second=read_or_stop()\n if not second:\n  return default,[first]\n  \n encoding=find_cookie(second)\n if encoding:\n  return encoding,[first,second]\n  \n return default,[first,second]\n \n \ndef open(filename):\n ''\n\n \n buffer=builtins. open(filename,'rb')\n encoding,lines=detect_encoding(buffer. readline)\n buffer. seek(0)\n text=TextIOWrapper(buffer,encoding,line_buffering=True )\n text. mode='r'\n return text\n \n \ndef tokenize(readline):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n from itertools import chain,repeat\n encoding,consumed=detect_encoding(readline)\n rl_gen=iter(readline,b\"\")\n empty=repeat(b\"\")\n return _tokenize(chain(consumed,rl_gen,empty). __next__,encoding)\n \n \ndef _tokenize(readline,encoding):\n lnum=parenlev=continued=0\n numchars='0123456789'\n contstr,needcont='',0\n contline=None\n indents=[0]\n \n if encoding is not None :\n  if encoding ==\"utf-8-sig\":\n  \n   encoding=\"utf-8\"\n  yield TokenInfo(ENCODING,encoding,(0,0),(0,0),'')\n while True :\n  try :\n   line=readline()\n  except StopIteration:\n   line=b''\n   \n  if encoding is not None :\n   line=line. decode(encoding)\n  lnum +=1\n  pos,max=0,len(line)\n  \n  if contstr:\n   if not line:\n    raise TokenError(\"EOF in multi-line string\",strstart)\n   endmatch=endprog. match(line)\n   if endmatch:\n    pos=end=endmatch. end(0)\n    yield TokenInfo(STRING,contstr+line[:end],\n    strstart,(lnum,end),contline+line)\n    contstr,needcont='',0\n    contline=None\n   elif needcont and line[-2:]!='\\\\\\n'and line[-3:]!='\\\\\\r\\n':\n    yield TokenInfo(ERRORTOKEN,contstr+line,\n    strstart,(lnum,len(line)),contline)\n    contstr=''\n    contline=None\n    continue\n   else :\n    contstr=contstr+line\n    contline=contline+line\n    continue\n    \n  elif parenlev ==0 and not continued:\n   if not line:break\n   column=0\n   while pos <max:\n    if line[pos]==' ':\n     column +=1\n    elif line[pos]=='\\t':\n     column=(column //tabsize+1)*tabsize\n    elif line[pos]=='\\f':\n     column=0\n    else :\n     break\n    pos +=1\n   if pos ==max:\n    break\n    \n   if line[pos]in'#\\r\\n':\n    if line[pos]=='#':\n     comment_token=line[pos:]. rstrip('\\r\\n')\n     nl_pos=pos+len(comment_token)\n     yield TokenInfo(COMMENT,comment_token,\n     (lnum,pos),(lnum,pos+len(comment_token)),line)\n     yield TokenInfo(NL,line[nl_pos:],\n     (lnum,nl_pos),(lnum,len(line)),line)\n    else :\n     yield TokenInfo((NL,COMMENT)[line[pos]=='#'],line[pos:],\n     (lnum,pos),(lnum,len(line)),line)\n    continue\n    \n   if column >indents[-1]:\n    indents. append(column)\n    yield TokenInfo(INDENT,line[:pos],(lnum,0),(lnum,pos),line)\n   while column <indents[-1]:\n    if column not in indents:\n     raise IndentationError(\n     \"unindent does not match any outer indentation level\",\n     (\"<tokenize>\",lnum,pos,line))\n    indents=indents[:-1]\n    yield TokenInfo(DEDENT,'',(lnum,pos),(lnum,pos),line)\n    \n  else :\n   if not line:\n    raise TokenError(\"EOF in multi-line statement\",(lnum,0))\n   continued=0\n   \n  while pos <max:\n   pseudomatch=_compile(PseudoToken). match(line,pos)\n   if pseudomatch:\n    start,end=pseudomatch. span(1)\n    spos,epos,pos=(lnum,start),(lnum,end),end\n    if start ==end:\n     continue\n    token,initial=line[start:end],line[start]\n    \n    if (initial in numchars or\n    (initial =='.'and token !='.'and token !='...')):\n     yield TokenInfo(NUMBER,token,spos,epos,line)\n    elif initial in'\\r\\n':\n     yield TokenInfo(NL if parenlev >0 else NEWLINE,\n     token,spos,epos,line)\n    elif initial =='#':\n     assert not token. endswith(\"\\n\")\n     yield TokenInfo(COMMENT,token,spos,epos,line)\n    elif token in triple_quoted:\n     endprog=_compile(endpats[token])\n     endmatch=endprog. match(line,pos)\n     if endmatch:\n      pos=endmatch. end(0)\n      token=line[start:pos]\n      yield TokenInfo(STRING,token,spos,(lnum,pos),line)\n     else :\n      strstart=(lnum,start)\n      contstr=line[start:]\n      contline=line\n      break\n    elif initial in single_quoted or    token[:2]in single_quoted or    token[:3]in single_quoted:\n     if token[-1]=='\\n':\n      strstart=(lnum,start)\n      endprog=_compile(endpats[initial]or\n      endpats[token[1]]or\n      endpats[token[2]])\n      contstr,needcont=line[start:],1\n      contline=line\n      break\n     else :\n      yield TokenInfo(STRING,token,spos,epos,line)\n    elif initial. isidentifier():\n     yield TokenInfo(NAME,token,spos,epos,line)\n    elif initial =='\\\\':\n     continued=1\n    else :\n     if initial in'([{':\n      parenlev +=1\n     elif initial in')]}':\n      parenlev -=1\n     yield TokenInfo(OP,token,spos,epos,line)\n   else :\n    yield TokenInfo(ERRORTOKEN,line[pos],\n    (lnum,pos),(lnum,pos+1),line)\n    pos +=1\n    \n for indent in indents[1:]:\n  yield TokenInfo(DEDENT,'',(lnum,0),(lnum,0),'')\n yield TokenInfo(ENDMARKER,'',(lnum,0),(lnum,0),'')\n \n \n \n \ndef generate_tokens(readline):\n return _tokenize(readline,None )\n \ndef main():\n import argparse\n \n \n def perror(message):\n  print(message,file=sys. stderr)\n  \n def error(message,filename=None ,location=None ):\n  if location:\n   args=(filename,)+location+(message,)\n   perror(\"%s:%d:%d: error: %s\"%args)\n  elif filename:\n   perror(\"%s: error: %s\"%(filename,message))\n  else :\n   perror(\"error: %s\"%message)\n  sys. exit(1)\n  \n  \n parser=argparse. ArgumentParser(prog='python -m tokenize')\n parser. add_argument(dest='filename',nargs='?',\n metavar='filename.py',\n help='the file to tokenize; defaults to stdin')\n parser. add_argument('-e','--exact',dest='exact',action='store_true',\n help='display token names using the exact type')\n args=parser. parse_args()\n \n try :\n \n  if args. filename:\n   filename=args. filename\n   with builtins. open(filename,'rb')as f:\n    tokens=list(tokenize(f. readline))\n  else :\n   filename=\"<stdin>\"\n   tokens=_tokenize(sys. stdin. readline,None )\n   \n   \n  for token in tokens:\n   token_type=token. type\n   if args. exact:\n    token_type=token. exact_type\n   token_range=\"%d,%d-%d,%d:\"%(token. start+token. end)\n   print(\"%-20s%-15s%-15r\"%\n   (token_range,tok_name[token_type],token. string))\n except IndentationError as err:\n  line,column=err. args[1][1:3]\n  error(err. args[0],filename,(line,column))\n except TokenError as err:\n  line,column=err. args[1]\n  error(err. args[0],filename,(line,column))\n except SyntaxError as err:\n  error(err,filename)\n except IOError as err:\n  error(err)\n except KeyboardInterrupt:\n  print(\"interrupted\\n\")\n except Exception as err:\n  perror(\"unexpected error: %s\"%err)\n  raise\n  \nif __name__ ==\"__main__\":\n main()\n", ["argparse", "builtins", "codecs", "collections", "io", "itertools", "re", "sys", "token"]], "codeop": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nimport __future__\n\n_features=[getattr(__future__,fname)\nfor fname in __future__. all_feature_names]\n\n__all__=[\"compile_command\",\"Compile\",\"CommandCompiler\"]\n\nPyCF_DONT_IMPLY_DEDENT=0x200\n\ndef _maybe_compile(compiler,source,filename,symbol):\n\n for line in source. split(\"\\n\"):\n  line=line. strip()\n  if line and line[0]!='#':\n   break\n else :\n  if symbol !=\"eval\":\n   source=\"pass\"\n   \n err=err1=err2=None\n code=code1=code2=None\n \n try :\n  code=compiler(source,filename,symbol)\n except SyntaxError as err:\n  pass\n  \n try :\n  code1=compiler(source+\"\\n\",filename,symbol)\n except SyntaxError as e:\n  err1=e\n  \n try :\n  code2=compiler(source+\"\\n\\n\",filename,symbol)\n except SyntaxError as e:\n  err2=e\n  \n if code:\n  return code\n if not code1 and repr(err1)==repr(err2):\n  raise err1\n  \ndef _compile(source,filename,symbol):\n return compile(source,filename,symbol,PyCF_DONT_IMPLY_DEDENT)\n \ndef compile_command(source,filename=\"<input>\",symbol=\"single\"):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n return _maybe_compile(_compile,source,filename,symbol)\n \nclass Compile:\n ''\n\n\n \n def __init__(self):\n  self. flags=PyCF_DONT_IMPLY_DEDENT\n  \n def __call__(self,source,filename,symbol):\n  codeob=compile(source,filename,symbol,self. flags,1)\n  for feature in _features:\n   if codeob. co_flags&feature. compiler_flag:\n    self. flags |=feature. compiler_flag\n  return codeob\n  \nclass CommandCompiler:\n ''\n\n\n\n \n \n def __init__(self,):\n  self. compiler=Compile()\n  \n def __call__(self,source,filename=\"<input>\",symbol=\"single\"):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  return _maybe_compile(self. compiler,source,filename,symbol)\n", ["__future__"]], "socket": [".py", "\n\n\n\"\"\"\\\nThis module provides socket operations and some related functions.\nOn Unix, it supports IP (Internet Protocol) and Unix domain sockets.\nOn other systems, it only supports IP. Functions specific for a\nsocket are available as methods of the socket object.\n\nFunctions:\n\nsocket() -- create a new socket object\nsocketpair() -- create a pair of new socket objects [*]\nfromfd() -- create a socket object from an open file descriptor [*]\nfromshare() -- create a socket object from data received from socket.share() [*]\ngethostname() -- return the current hostname\ngethostbyname() -- map a hostname to its IP number\ngethostbyaddr() -- map an IP number or hostname to DNS info\ngetservbyname() -- map a service name and a protocol name to a port number\ngetprotobyname() -- map a protocol name (e.g. 'tcp') to a number\nntohs(), ntohl() -- convert 16, 32 bit int from network to host byte order\nhtons(), htonl() -- convert 16, 32 bit int from host to network byte order\ninet_aton() -- convert IP addr string (123.45.67.89) to 32-bit packed format\ninet_ntoa() -- convert 32-bit packed format IP to string (123.45.67.89)\nsocket.getdefaulttimeout() -- get the default timeout value\nsocket.setdefaulttimeout() -- set the default timeout value\ncreate_connection() -- connects to an address, with an optional timeout and\n                       optional source address.\n\n [*] not available on all platforms!\n\nSpecial objects:\n\nSocketType -- type object for socket objects\nerror -- exception raised for I/O errors\nhas_ipv6 -- boolean value indicating if IPv6 is supported\n\nInteger constants:\n\nAF_INET, AF_UNIX -- socket domains (first argument to socket() call)\nSOCK_STREAM, SOCK_DGRAM, SOCK_RAW -- socket types (second argument)\n\nMany other constants may be defined; these may be used in calls to\nthe setsockopt() and getsockopt() methods.\n\"\"\"\n\nimport _socket\nfrom _socket import *\n\nimport os,sys,io\n\ntry :\n import errno\nexcept ImportError:\n errno=None\nEBADF=getattr(errno,'EBADF',9)\nEAGAIN=getattr(errno,'EAGAIN',11)\nEWOULDBLOCK=getattr(errno,'EWOULDBLOCK',11)\n\n__all__=[\"getfqdn\",\"create_connection\"]\n__all__. extend(os. _get_exports_list(_socket))\n\n\n_realsocket=socket\n\n\nif sys. platform. lower(). startswith(\"win\"):\n errorTab={}\n errorTab[10004]=\"The operation was interrupted.\"\n errorTab[10009]=\"A bad file handle was passed.\"\n errorTab[10013]=\"Permission denied.\"\n errorTab[10014]=\"A fault occurred on the network??\"\n errorTab[10022]=\"An invalid operation was attempted.\"\n errorTab[10035]=\"The socket operation would block\"\n errorTab[10036]=\"A blocking operation is already in progress.\"\n errorTab[10048]=\"The network address is in use.\"\n errorTab[10054]=\"The connection has been reset.\"\n errorTab[10058]=\"The network has been shut down.\"\n errorTab[10060]=\"The operation timed out.\"\n errorTab[10061]=\"Connection refused.\"\n errorTab[10063]=\"The name is too long.\"\n errorTab[10064]=\"The host is down.\"\n errorTab[10065]=\"The host is unreachable.\"\n __all__. append(\"errorTab\")\n \n \nclass socket(_socket. socket):\n\n ''\n \n __slots__=[\"__weakref__\",\"_io_refs\",\"_closed\"]\n \n def __init__(self,family=AF_INET,type=SOCK_STREAM,proto=0,fileno=None ):\n  _socket. socket. __init__(self,family,type,proto,fileno)\n  self. _io_refs=0\n  self. _closed=False\n  \n def __enter__(self):\n  return self\n  \n def __exit__(self,*args):\n  if not self. _closed:\n   self. close()\n   \n def __repr__(self):\n  ''\n  s=_socket. socket. __repr__(self)\n  if s. startswith(\"<socket object\"):\n   s=\"<%s.%s%s%s\"%(self. __class__. __module__,\n   self. __class__. __name__,\n   getattr(self,'_closed',False )and\" [closed] \"or\"\",\n   s[7:])\n  return s\n  \n def __getstate__(self):\n  raise TypeError(\"Cannot serialize socket object\")\n  \n def dup(self):\n  ''\n\n\n  \n  fd=dup(self. fileno())\n  sock=self. __class__(self. family,self. type,self. proto,fileno=fd)\n  sock. settimeout(self. gettimeout())\n  return sock\n  \n def accept(self):\n  ''\n\n\n\n\n  \n  fd,addr=self. _accept()\n  sock=socket(self. family,self. type,self. proto,fileno=fd)\n  \n  \n  \n  if getdefaulttimeout()is None and self. gettimeout():\n   sock. setblocking(True )\n  return sock,addr\n  \n def makefile(self,mode=\"r\",buffering=None ,*,\n encoding=None ,errors=None ,newline=None ):\n  ''\n\n\n\n\n  \n  for c in mode:\n   if c not in {\"r\",\"w\",\"b\"}:\n    raise ValueError(\"invalid mode %r (only r, w, b allowed)\")\n  writing=\"w\"in mode\n  reading=\"r\"in mode or not writing\n  assert reading or writing\n  binary=\"b\"in mode\n  rawmode=\"\"\n  if reading:\n   rawmode +=\"r\"\n  if writing:\n   rawmode +=\"w\"\n  raw=SocketIO(self,rawmode)\n  self. _io_refs +=1\n  if buffering is None :\n   buffering=-1\n  if buffering <0:\n   buffering=io. DEFAULT_BUFFER_SIZE\n  if buffering ==0:\n   if not binary:\n    raise ValueError(\"unbuffered streams must be binary\")\n   return raw\n  if reading and writing:\n   buffer=io. BufferedRWPair(raw,raw,buffering)\n  elif reading:\n   buffer=io. BufferedReader(raw,buffering)\n  else :\n   assert writing\n   buffer=io. BufferedWriter(raw,buffering)\n  if binary:\n   return buffer\n  text=io. TextIOWrapper(buffer,encoding,errors,newline)\n  text. mode=mode\n  return text\n  \n def _decref_socketios(self):\n  if self. _io_refs >0:\n   self. _io_refs -=1\n  if self. _closed:\n   self. close()\n   \n def _real_close(self,_ss=_socket. socket):\n \n  _ss. close(self)\n  \n def close(self):\n \n  self. _closed=True\n  if self. _io_refs <=0:\n   self. _real_close()\n   \n def detach(self):\n  ''\n\n\n\n\n  \n  self. _closed=True\n  return super(). detach()\n  \ndef fromfd(fd,family,type,proto=0):\n ''\n\n\n\n \n nfd=dup(fd)\n return socket(family,type,proto,nfd)\n \nif hasattr(_socket. socket,\"share\"):\n def fromshare(info):\n  ''\n\n\n\n  \n  return socket(0,0,0,info)\n  \nif hasattr(_socket,\"socketpair\"):\n\n def socketpair(family=None ,type=SOCK_STREAM,proto=0):\n  ''\n\n\n\n\n\n  \n  if family is None :\n   try :\n    family=AF_UNIX\n   except NameError:\n    family=AF_INET\n  a,b=_socket. socketpair(family,type,proto)\n  a=socket(family,type,proto,a. detach())\n  b=socket(family,type,proto,b. detach())\n  return a,b\n  \n  \n_blocking_errnos={EAGAIN,EWOULDBLOCK}\n\nclass SocketIO(io. RawIOBase):\n\n ''\n\n\n\n \n \n \n \n \n \n \n \n \n \n \n def __init__(self,sock,mode):\n  if mode not in (\"r\",\"w\",\"rw\",\"rb\",\"wb\",\"rwb\"):\n   raise ValueError(\"invalid mode: %r\"%mode)\n  io. RawIOBase. __init__(self)\n  self. _sock=sock\n  if\"b\"not in mode:\n   mode +=\"b\"\n  self. _mode=mode\n  self. _reading=\"r\"in mode\n  self. _writing=\"w\"in mode\n  self. _timeout_occurred=False\n  \n def readinto(self,b):\n  ''\n\n\n\n\n\n  \n  self. _checkClosed()\n  self. _checkReadable()\n  if self. _timeout_occurred:\n   raise IOError(\"cannot read from timed out object\")\n  while True :\n   try :\n    return self. _sock. recv_into(b)\n   except timeout:\n    self. _timeout_occurred=True\n    raise\n   except InterruptedError:\n    continue\n   except error as e:\n    if e. args[0]in _blocking_errnos:\n     return None\n    raise\n    \n def write(self,b):\n  ''\n\n\n\n  \n  self. _checkClosed()\n  self. _checkWritable()\n  try :\n   return self. _sock. send(b)\n  except error as e:\n  \n   if e. args[0]in _blocking_errnos:\n    return None\n   raise\n   \n def readable(self):\n  ''\n  \n  if self. closed:\n   raise ValueError(\"I/O operation on closed socket.\")\n  return self. _reading\n  \n def writable(self):\n  ''\n  \n  if self. closed:\n   raise ValueError(\"I/O operation on closed socket.\")\n  return self. _writing\n  \n def seekable(self):\n  ''\n  \n  if self. closed:\n   raise ValueError(\"I/O operation on closed socket.\")\n  return super(). seekable()\n  \n def fileno(self):\n  ''\n  \n  self. _checkClosed()\n  return self. _sock. fileno()\n  \n @property\n def name(self):\n  if not self. closed:\n   return self. fileno()\n  else :\n   return -1\n   \n @property\n def mode(self):\n  return self. _mode\n  \n def close(self):\n  ''\n\n  \n  if self. closed:\n   return\n  io. RawIOBase. close(self)\n  self. _sock. _decref_socketios()\n  self. _sock=None\n  \n  \ndef getfqdn(name=''):\n ''\n\n\n\n\n\n\n \n name=name. strip()\n if not name or name =='0.0.0.0':\n  name=gethostname()\n try :\n  hostname,aliases,ipaddrs=gethostbyaddr(name)\n except error:\n  pass\n else :\n  aliases. insert(0,hostname)\n  for name in aliases:\n   if'.'in name:\n    break\n  else :\n   name=hostname\n return name\n \n \n_GLOBAL_DEFAULT_TIMEOUT=object()\n\ndef create_connection(address,timeout=_GLOBAL_DEFAULT_TIMEOUT,\nsource_address=None ):\n ''\n\n\n\n\n\n\n\n\n\n \n \n host,port=address\n err=None\n for res in getaddrinfo(host,port,0,SOCK_STREAM):\n  af,socktype,proto,canonname,sa=res\n  sock=None\n  try :\n   sock=socket(af,socktype,proto)\n   if timeout is not _GLOBAL_DEFAULT_TIMEOUT:\n    sock. settimeout(timeout)\n   if source_address:\n    sock. bind(source_address)\n   sock. connect(sa)\n   return sock\n   \n  except error as _:\n   err=_\n   if sock is not None :\n    sock. close()\n    \n if err is not None :\n  raise err\n else :\n  raise error(\"getaddrinfo returns an empty list\")\n", ["_socket", "errno", "io", "os", "sys"]], "browser.session_storage": [".py", "\nimport sys\nfrom browser import window\nfrom . local_storage import LocalStorage\n\nhas_session_storage=hasattr(window,'sessionStorage')\n\nclass SessionStorage(LocalStorage):\n\n storage_type=\"session_storage\"\n \n def __init__(self):\n  if not has_session_storage:\n   raise EnvironmentError(\"SessionStorage not available\")\n  self. store=window. sessionStorage\n  \nif has_session_storage:\n storage=SessionStorage()\n", ["browser", "browser.local_storage", "sys"]], "builtins": [".js", "var $module = (function(){\n    var obj = {__class__: __BRYTHON__.module, __name__: 'builtins'},\n        builtin_names = ['ArithmeticError', 'AssertionError', 'AttributeError',\n    'BaseException', 'BlockingIOError', 'BrokenPipeError', 'BufferError',\n    'BytesWarning', 'ChildProcessError', 'ConnectionAbortedError',\n    'ConnectionError', 'ConnectionRefusedError', 'ConnectionResetError',\n    'DeprecationWarning', 'EOFError', 'Ellipsis', 'EnvironmentError', 'Exception',\n    'False', 'FileExistsError', 'FileNotFoundError', 'FloatingPointError',\n    'FutureWarning', 'GeneratorExit', 'IOError', 'ImportError', 'ImportWarning',\n    'IndentationError', 'IndexError', 'InterruptedError', 'IsADirectoryError',\n    'KeyError', 'KeyboardInterrupt', 'LookupError', 'MemoryError', 'NameError',\n    'None', 'NotADirectoryError', 'NotImplemented', 'NotImplementedError',\n    'OSError', 'OverflowError', 'PendingDeprecationWarning', 'PermissionError',\n    'ProcessLookupError', 'ReferenceError', 'ResourceWarning', 'RuntimeError',\n    'RuntimeWarning', 'StopIteration', 'SyntaxError', 'SyntaxWarning',\n    'SystemError', 'SystemExit', 'TabError', 'TimeoutError', 'True', 'TypeError',\n    'UnboundLocalError', 'UnicodeDecodeError', 'UnicodeEncodeError',\n    'UnicodeError', 'UnicodeTranslateError', 'UnicodeWarning', 'UserWarning',\n    'ValueError', 'Warning', 'WindowsError', 'ZeroDivisionError', '_',\n    '__build_class__', '__debug__', '__doc__', '__import__', '__name__',\n    '__package__', 'abs', 'all', 'any', 'ascii', 'bin', 'bool', 'bytearray',\n    'bytes','callable', 'chr', 'classmethod', 'compile', 'complex', 'copyright',\n    'credits','delattr', 'dict', 'dir', 'divmod', 'enumerate', 'eval', 'exec',\n    'exit', 'filter', 'float', 'format', 'frozenset', 'getattr', 'globals',\n    'hasattr', 'hash', 'help', 'hex', 'id', 'input', 'int', 'isinstance',\n    'issubclass', 'iter', 'len', 'license', 'list', 'locals', 'map', 'max',\n    'memoryview', 'min', 'next', 'object', 'oct', 'open', 'ord', 'pow', 'print',\n    'property', 'quit', 'range', 'repr', 'reversed', 'round', 'set', 'setattr',\n    'slice', 'sorted', 'staticmethod', 'str', 'sum', 'super', 'tuple', 'type',\n    'vars', 'zip']\n    for(var i = 0, len = builtin_names.length; i < len; i++){\n        try{eval(\"obj['\" + builtin_names[i] + \"'] = __BRYTHON__.builtins.\" +\n            builtin_names[i])}\n        catch(err){if (__BRYTHON__.$debug) {console.log(err)}}\n    }\n    return obj\n})()\n"], "pprint": [".py", "\n\n\n\n\n\n\n\n\n\n\"\"\"Support to pretty-print lists, tuples, & dictionaries recursively.\n\nVery simple, but useful, especially in debugging data structures.\n\nClasses\n-------\n\nPrettyPrinter()\n    Handle pretty-printing operations onto a stream using a configured\n    set of formatting parameters.\n\nFunctions\n---------\n\npformat()\n    Format a Python object into a pretty-printed representation.\n\npprint()\n    Pretty-print a Python object to a stream [default is sys.stdout].\n\nsaferepr()\n    Generate a 'standard' repr()-like value, but protect against recursive\n    data structures.\n\n\"\"\"\n\nimport sys as _sys\nfrom collections import OrderedDict as _OrderedDict\nfrom io import StringIO as _StringIO\n\n__all__=[\"pprint\",\"pformat\",\"isreadable\",\"isrecursive\",\"saferepr\",\n\"PrettyPrinter\"]\n\n\n_commajoin=\", \". join\n_id=id\n_len=len\n_type=type\n\n\ndef pprint(object,stream=None ,indent=1,width=80,depth=None ):\n ''\n printer=PrettyPrinter(\n stream=stream,indent=indent,width=width,depth=depth)\n printer. pprint(object)\n \ndef pformat(object,indent=1,width=80,depth=None ):\n ''\n return PrettyPrinter(indent=indent,width=width,depth=depth). pformat(object)\n \ndef saferepr(object):\n ''\n return _safe_repr(object,{},None ,0)[0]\n \ndef isreadable(object):\n ''\n return _safe_repr(object,{},None ,0)[1]\n \ndef isrecursive(object):\n ''\n return _safe_repr(object,{},None ,0)[2]\n \nclass _safe_key:\n ''\n\n\n\n\n\n\n \n \n __slots__=['obj']\n \n def __init__(self,obj):\n  self. obj=obj\n  \n def __lt__(self,other):\n  try :\n   rv=self. obj. __lt__(other. obj)\n  except TypeError:\n   rv=NotImplemented\n   \n  if rv is NotImplemented:\n   rv=(str(type(self. obj)),id(self. obj))<   (str(type(other. obj)),id(other. obj))\n  return rv\n  \ndef _safe_tuple(t):\n ''\n return _safe_key(t[0]),_safe_key(t[1])\n \nclass PrettyPrinter:\n def __init__(self,indent=1,width=80,depth=None ,stream=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  indent=int(indent)\n  width=int(width)\n  assert indent >=0,\"indent must be >= 0\"\n  assert depth is None or depth >0,\"depth must be > 0\"\n  assert width,\"width must be != 0\"\n  self. _depth=depth\n  self. _indent_per_level=indent\n  self. _width=width\n  if stream is not None :\n   self. _stream=stream\n  else :\n   self. _stream=_sys. stdout\n   \n def pprint(self,object):\n  self. _format(object,self. _stream,0,0,{},0)\n  self. _stream. write(\"\\n\")\n  \n def pformat(self,object):\n  sio=_StringIO()\n  self. _format(object,sio,0,0,{},0)\n  return sio. getvalue()\n  \n def isrecursive(self,object):\n  return self. format(object,{},0,0)[2]\n  \n def isreadable(self,object):\n  s,readable,recursive=self. format(object,{},0,0)\n  return readable and not recursive\n  \n def _format(self,object,stream,indent,allowance,context,level):\n  level=level+1\n  import sys\n  sys. stderr. write(str(object))\n  objid=_id(object)\n  if objid in context:\n   stream. write(_recursion(object))\n   self. _recursive=True\n   self. _readable=False\n   return\n  rep=self. _repr(object,context,level -1)\n  typ=_type(object)\n  sepLines=_len(rep)>(self. _width -1 -indent -allowance)\n  write=stream. write\n  \n  if self. _depth and level >self. _depth:\n   write(rep)\n   return\n   \n  if sepLines:\n   r=getattr(typ,\"__repr__\",None )\n   if issubclass(typ,dict):\n    write('{')\n    if self. _indent_per_level >1:\n     write((self. _indent_per_level -1)*' ')\n    length=_len(object)\n    if length:\n     context[objid]=1\n     indent=indent+self. _indent_per_level\n     if issubclass(typ,_OrderedDict):\n      items=list(object. items())\n     else :\n      items=sorted(object. items(),key=_safe_tuple)\n     key,ent=items[0]\n     rep=self. _repr(key,context,level)\n     write(rep)\n     write(': ')\n     self. _format(ent,stream,indent+_len(rep)+2,\n     allowance+1,context,level)\n     if length >1:\n      for key,ent in items[1:]:\n       rep=self. _repr(key,context,level)\n       write(',\\n%s%s: '%(' '*indent,rep))\n       self. _format(ent,stream,indent+_len(rep)+2,\n       allowance+1,context,level)\n     indent=indent -self. _indent_per_level\n     del context[objid]\n    write('}')\n    return\n    \n   if ((issubclass(typ,list)and r is list. __repr__)or\n   (issubclass(typ,tuple)and r is tuple. __repr__)or\n   (issubclass(typ,set)and r is set. __repr__)or\n   (issubclass(typ,frozenset)and r is frozenset. __repr__)\n   ):\n    length=_len(object)\n    if issubclass(typ,list):\n     write('[')\n     endchar=']'\n    elif issubclass(typ,tuple):\n     write('(')\n     endchar=')'\n    else :\n     if not length:\n      write(rep)\n      return\n     if typ is set:\n      write('{')\n      endchar='}'\n     else :\n      write(typ. __name__)\n      write('({')\n      endchar='})'\n      indent +=len(typ. __name__)+1\n     object=sorted(object,key=_safe_key)\n    if self. _indent_per_level >1:\n     write((self. _indent_per_level -1)*' ')\n    if length:\n     context[objid]=1\n     indent=indent+self. _indent_per_level\n     self. _format(object[0],stream,indent,allowance+1,\n     context,level)\n     if length >1:\n      for ent in object[1:]:\n       write(',\\n'+' '*indent)\n       self. _format(ent,stream,indent,\n       allowance+1,context,level)\n     indent=indent -self. _indent_per_level\n     del context[objid]\n    if issubclass(typ,tuple)and length ==1:\n     write(',')\n    write(endchar)\n    return\n    \n  write(rep)\n  \n def _repr(self,object,context,level):\n  repr,readable,recursive=self. format(object,context. copy(),\n  self. _depth,level)\n  if not readable:\n   self. _readable=False\n  if recursive:\n   self. _recursive=True\n  return repr\n  \n def format(self,object,context,maxlevels,level):\n  ''\n\n\n  \n  return _safe_repr(object,context,maxlevels,level)\n  \n  \n  \n  \ndef _safe_repr(object,context,maxlevels,level):\n typ=_type(object)\n if typ is str:\n  if'locale'not in _sys. modules:\n   return repr(object),True ,False\n  if\"'\"in object and'\"'not in object:\n   closure='\"'\n   quotes={'\"':'\\\\\"'}\n  else :\n   closure=\"'\"\n   quotes={\"'\":\"\\\\'\"}\n  qget=quotes. get\n  sio=_StringIO()\n  write=sio. write\n  for char in object:\n   if char. isalpha():\n    write(char)\n   else :\n    write(qget(char,repr(char)[1:-1]))\n  return (\"%s%s%s\"%(closure,sio. getvalue(),closure)),True ,False\n  \n r=getattr(typ,\"__repr__\",None )\n if issubclass(typ,dict)and r is dict. __repr__:\n  if not object:\n   return\"{}\",True ,False\n  objid=_id(object)\n  if maxlevels and level >=maxlevels:\n   return\"{...}\",False ,objid in context\n  if objid in context:\n   return _recursion(object),False ,True\n  context[objid]=1\n  readable=True\n  recursive=False\n  components=[]\n  append=components. append\n  level +=1\n  saferepr=_safe_repr\n  items=sorted(object. items(),key=_safe_tuple)\n  for k,v in items:\n   krepr,kreadable,krecur=saferepr(k,context,maxlevels,level)\n   vrepr,vreadable,vrecur=saferepr(v,context,maxlevels,level)\n   append(\"%s: %s\"%(krepr,vrepr))\n   readable=readable and kreadable and vreadable\n   if krecur or vrecur:\n    recursive=True\n  del context[objid]\n  return\"{%s}\"%_commajoin(components),readable,recursive\n  \n if (issubclass(typ,list)and r is list. __repr__)or (issubclass(typ,tuple)and r is tuple. __repr__):\n  if issubclass(typ,list):\n   if not object:\n    return\"[]\",True ,False\n   format=\"[%s]\"\n  elif _len(object)==1:\n   format=\"(%s,)\"\n  else :\n   if not object:\n    return\"()\",True ,False\n   format=\"(%s)\"\n  objid=_id(object)\n  if maxlevels and level >=maxlevels:\n   return format %\"...\",False ,objid in context\n  if objid in context:\n   return _recursion(object),False ,True\n  context[objid]=1\n  readable=True\n  recursive=False\n  components=[]\n  append=components. append\n  level +=1\n  for o in object:\n   orepr,oreadable,orecur=_safe_repr(o,context,maxlevels,level)\n   append(orepr)\n   if not oreadable:\n    readable=False\n   if orecur:\n    recursive=True\n  del context[objid]\n  return format %_commajoin(components),readable,recursive\n  \n rep=repr(object)\n return rep,(rep and not rep. startswith('<')),False\n \n \ndef _recursion(object):\n return (\"<Recursion on %s with id=%s>\"\n %(_type(object). __name__,_id(object)))\n \n \ndef _perfcheck(object=None ):\n import time\n if object is None :\n  object=[(\"string\",(1,2),[3,4],{5:6,7:8})]*100000\n p=PrettyPrinter()\n t1=time. time()\n _safe_repr(object,{},None ,0)\n t2=time. time()\n p. pformat(object)\n t3=time. time()\n print(\"_safe_repr:\",t2 -t1)\n print(\"pformat:\",t3 -t2)\n \nif __name__ ==\"__main__\":\n _perfcheck()\n", ["collections", "io", "sys", "time"]], "urllib.error": [".py", "class HTTPError(Exception):pass", []], "unittest.main": [".py", "''\n\nimport sys\nimport optparse\nimport os\n\nfrom . import loader,runner\nfrom . signals import installHandler\n\n__unittest=True\n\nFAILFAST=\"  -f, --failfast   Stop on first failure\\n\"\nCATCHBREAK=\"  -c, --catch      Catch control-C and display results\\n\"\nBUFFEROUTPUT=\"  -b, --buffer     Buffer stdout and stderr during test runs\\n\"\n\nUSAGE_AS_MAIN=\"\"\"\\\nUsage: %(progName)s [options] [tests]\n\nOptions:\n  -h, --help       Show this message\n  -v, --verbose    Verbose output\n  -q, --quiet      Minimal output\n%(failfast)s%(catchbreak)s%(buffer)s\nExamples:\n  %(progName)s test_module               - run tests from test_module\n  %(progName)s module.TestClass          - run tests from module.TestClass\n  %(progName)s module.Class.test_method  - run specified test method\n\n[tests] can be a list of any number of test modules, classes and test\nmethods.\n\nAlternative Usage: %(progName)s discover [options]\n\nOptions:\n  -v, --verbose    Verbose output\n%(failfast)s%(catchbreak)s%(buffer)s  -s directory     Directory to start discovery ('.' default)\n  -p pattern       Pattern to match test files ('test*.py' default)\n  -t directory     Top level directory of project (default to\n                   start directory)\n\nFor test discovery all test modules must be importable from the top\nlevel directory of the project.\n\"\"\"\n\nUSAGE_FROM_MODULE=\"\"\"\\\nUsage: %(progName)s [options] [test] [...]\n\nOptions:\n  -h, --help       Show this message\n  -v, --verbose    Verbose output\n  -q, --quiet      Minimal output\n%(failfast)s%(catchbreak)s%(buffer)s\nExamples:\n  %(progName)s                               - run default set of tests\n  %(progName)s MyTestSuite                   - run suite 'MyTestSuite'\n  %(progName)s MyTestCase.testSomething      - run MyTestCase.testSomething\n  %(progName)s MyTestCase                    - run all 'test*' test methods\n                                               in MyTestCase\n\"\"\"\n\ndef _convert_name(name):\n\n\n\n\n if os. path. isfile(name)and name. lower(). endswith('.py'):\n  if os. path. isabs(name):\n   rel_path=os. path. relpath(name,os. getcwd())\n   if os. path. isabs(rel_path)or rel_path. startswith(os. pardir):\n    return name\n   name=rel_path\n   \n   \n  return name[:-3]. replace('\\\\','.'). replace('/','.')\n return name\n \ndef _convert_names(names):\n return [_convert_name(name)for name in names]\n \n \nclass TestProgram(object):\n ''\n\n \n USAGE=USAGE_FROM_MODULE\n \n \n failfast=catchbreak=buffer=progName=warnings=None\n \n def __init__(self,module='__main__',defaultTest=None ,argv=None ,\n testRunner=None ,testLoader=loader. defaultTestLoader,\n exit=True ,verbosity=1,failfast=None ,catchbreak=None ,\n buffer=None ,warnings=None ):\n  if isinstance(module,str):\n   self. module=__import__(module)\n   for part in module. split('.')[1:]:\n    self. module=getattr(self. module,part)\n  else :\n   self. module=module\n  if argv is None :\n   argv=sys. argv\n   \n  self. exit=exit\n  self. failfast=failfast\n  self. catchbreak=catchbreak\n  self. verbosity=verbosity\n  self. buffer=buffer\n  if warnings is None and not sys. warnoptions:\n  \n  \n  \n   self. warnings='default'\n  else :\n  \n  \n  \n  \n  \n   self. warnings=warnings\n  self. defaultTest=defaultTest\n  self. testRunner=testRunner\n  self. testLoader=testLoader\n  self. progName=os. path. basename(argv[0])\n  self. parseArgs(argv)\n  self. runTests()\n  \n def usageExit(self,msg=None ):\n  if msg:\n   print(msg)\n  usage={'progName':self. progName,'catchbreak':'','failfast':'',\n  'buffer':''}\n  if self. failfast !=False :\n   usage['failfast']=FAILFAST\n  if self. catchbreak !=False :\n   usage['catchbreak']=CATCHBREAK\n  if self. buffer !=False :\n   usage['buffer']=BUFFEROUTPUT\n  print(self. USAGE %usage)\n  sys. exit(2)\n  \n def parseArgs(self,argv):\n  if ((len(argv)>1 and argv[1]. lower()=='discover')or\n  (len(argv)==1 and self. module is None )):\n   self. _do_discovery(argv[2:])\n   return\n   \n  parser=self. _getOptParser()\n  options,args=parser. parse_args(argv[1:])\n  self. _setAttributesFromOptions(options)\n  \n  if len(args)==0 and self. module is None :\n  \n  \n  \n   self. _do_discovery(argv[1:])\n   return\n   \n  if len(args)==0 and self. defaultTest is None :\n  \n   self. testNames=None\n  elif len(args)>0:\n   self. testNames=_convert_names(args)\n   if __name__ =='__main__':\n   \n    self. module=None\n  else :\n   self. testNames=(self. defaultTest,)\n  self. createTests()\n  \n def createTests(self):\n  if self. testNames is None :\n   self. test=self. testLoader. loadTestsFromModule(self. module)\n  else :\n   self. test=self. testLoader. loadTestsFromNames(self. testNames,\n   self. module)\n   \n def _getOptParser(self):\n  import optparse\n  parser=optparse. OptionParser()\n  parser. prog=self. progName\n  parser. add_option('-v','--verbose',dest='verbose',default=False ,\n  help='Verbose output',action='store_true')\n  parser. add_option('-q','--quiet',dest='quiet',default=False ,\n  help='Quiet output',action='store_true')\n  \n  if self. failfast !=False :\n   parser. add_option('-f','--failfast',dest='failfast',default=False ,\n   help='Stop on first fail or error',\n   action='store_true')\n  if self. catchbreak !=False :\n   parser. add_option('-c','--catch',dest='catchbreak',default=False ,\n   help='Catch ctrl-C and display results so far',\n   action='store_true')\n  if self. buffer !=False :\n   parser. add_option('-b','--buffer',dest='buffer',default=False ,\n   help='Buffer stdout and stderr during tests',\n   action='store_true')\n  return parser\n  \n def _setAttributesFromOptions(self,options):\n \n \n  if self. failfast is None :\n   self. failfast=options. failfast\n  if self. catchbreak is None :\n   self. catchbreak=options. catchbreak\n  if self. buffer is None :\n   self. buffer=options. buffer\n   \n  if options. verbose:\n   self. verbosity=2\n  elif options. quiet:\n   self. verbosity=0\n   \n def _addDiscoveryOptions(self,parser):\n  parser. add_option('-s','--start-directory',dest='start',default='.',\n  help=\"Directory to start discovery ('.' default)\")\n  parser. add_option('-p','--pattern',dest='pattern',default='test*.py',\n  help=\"Pattern to match tests ('test*.py' default)\")\n  parser. add_option('-t','--top-level-directory',dest='top',default=None ,\n  help='Top level directory of project (defaults to start directory)')\n  \n def _do_discovery(self,argv,Loader=None ):\n  if Loader is None :\n   Loader=lambda :self. testLoader\n   \n   \n  self. progName='%s discover'%self. progName\n  parser=self. _getOptParser()\n  self. _addDiscoveryOptions(parser)\n  \n  options,args=parser. parse_args(argv)\n  if len(args)>3:\n   self. usageExit()\n   \n  for name,value in zip(('start','pattern','top'),args):\n   setattr(options,name,value)\n   \n  self. _setAttributesFromOptions(options)\n  \n  start_dir=options. start\n  pattern=options. pattern\n  top_level_dir=options. top\n  \n  loader=Loader()\n  self. test=loader. discover(start_dir,pattern,top_level_dir)\n  \n def runTests(self):\n  if self. catchbreak:\n   installHandler()\n  if self. testRunner is None :\n   self. testRunner=runner. TextTestRunner\n  if isinstance(self. testRunner,type):\n   try :\n    testRunner=self. testRunner(verbosity=self. verbosity,\n    failfast=self. failfast,\n    buffer=self. buffer,\n    warnings=self. warnings)\n   except TypeError:\n   \n    testRunner=self. testRunner()\n  else :\n  \n   testRunner=self. testRunner\n  self. result=testRunner. run(self. test)\n  if self. exit:\n   sys. exit(not self. result. wasSuccessful())\n   \nmain=TestProgram\n", ["optparse", "os", "sys", "unittest", "unittest.loader", "unittest.runner", "unittest.signals"]], "collections.abc": [".py", "\n\n\n\"\"\"Abstract Base Classes (ABCs) for collections, according to PEP 3119.\n\nUnit tests are in test_collections.\n\"\"\"\n\nfrom abc import ABCMeta,abstractmethod\nimport sys\n\n__all__=[\"Hashable\",\"Iterable\",\"Iterator\",\n\"Sized\",\"Container\",\"Callable\",\n\"Set\",\"MutableSet\",\n\"Mapping\",\"MutableMapping\",\n\"MappingView\",\"KeysView\",\"ItemsView\",\"ValuesView\",\n\"Sequence\",\"MutableSequence\",\n\"ByteString\",\n]\n\n\n\n\n\n\n\n\nbytes_iterator=type(iter(b''))\nbytearray_iterator=type(iter(bytearray()))\n\ndict_keyiterator=type(iter({}. keys()))\ndict_valueiterator=type(iter({}. values()))\ndict_itemiterator=type(iter({}. items()))\nlist_iterator=type(iter([]))\nlist_reverseiterator=type(iter(reversed([])))\nrange_iterator=type(iter(range(0)))\nset_iterator=type(iter(set()))\nstr_iterator=type(iter(\"\"))\ntuple_iterator=type(iter(()))\nzip_iterator=type(iter(zip()))\n\ndict_keys=type({}. keys())\ndict_values=type({}. values())\ndict_items=type({}. items())\n\nmappingproxy=type(type. __dict__)\n\n\n\nclass Hashable(metaclass=ABCMeta):\n\n __slots__=()\n \n @abstractmethod\n def __hash__(self):\n  return 0\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Hashable:\n   for B in C. __mro__:\n    if\"__hash__\"in B. __dict__:\n     if B. __dict__[\"__hash__\"]:\n      return True\n     break\n  return NotImplemented\n  \n  \nclass Iterable(metaclass=ABCMeta):\n\n __slots__=()\n \n @abstractmethod\n def __iter__(self):\n  while False :\n   yield None\n   \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Iterable:\n   if any(\"__iter__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \nclass Iterator(Iterable):\n\n __slots__=()\n \n @abstractmethod\n def __next__(self):\n  raise StopIteration\n  \n def __iter__(self):\n  return self\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Iterator:\n   if (any(\"__next__\"in B. __dict__ for B in C. __mro__)and\n   any(\"__iter__\"in B. __dict__ for B in C. __mro__)):\n    return True\n  return NotImplemented\n  \nIterator. register(bytes_iterator)\nIterator. register(bytearray_iterator)\n\nIterator. register(dict_keyiterator)\nIterator. register(dict_valueiterator)\nIterator. register(dict_itemiterator)\nIterator. register(list_iterator)\nIterator. register(list_reverseiterator)\nIterator. register(range_iterator)\nIterator. register(set_iterator)\nIterator. register(str_iterator)\nIterator. register(tuple_iterator)\nIterator. register(zip_iterator)\n\nclass Sized(metaclass=ABCMeta):\n\n __slots__=()\n \n @abstractmethod\n def __len__(self):\n  return 0\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Sized:\n   if any(\"__len__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \nclass Container(metaclass=ABCMeta):\n\n __slots__=()\n \n @abstractmethod\n def __contains__(self,x):\n  return False\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Container:\n   if any(\"__contains__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \nclass Callable(metaclass=ABCMeta):\n\n __slots__=()\n \n @abstractmethod\n def __call__(self,*args,**kwds):\n  return False\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Callable:\n   if any(\"__call__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \n  \n  \n  \nclass Set(Sized,Iterable,Container):\n\n ''\n\n\n\n\n\n\n\n \n \n __slots__=()\n \n def __le__(self,other):\n  if not isinstance(other,Set):\n   return NotImplemented\n  if len(self)>len(other):\n   return False\n  for elem in self:\n   if elem not in other:\n    return False\n  return True\n  \n def __lt__(self,other):\n  if not isinstance(other,Set):\n   return NotImplemented\n  return len(self)<len(other)and self. __le__(other)\n  \n def __gt__(self,other):\n  if not isinstance(other,Set):\n   return NotImplemented\n  return other <self\n  \n def __ge__(self,other):\n  if not isinstance(other,Set):\n   return NotImplemented\n  return other <=self\n  \n def __eq__(self,other):\n  if not isinstance(other,Set):\n   return NotImplemented\n  return len(self)==len(other)and self. __le__(other)\n  \n def __ne__(self,other):\n  return not (self ==other)\n  \n @classmethod\n def _from_iterable(cls,it):\n  ''\n\n\n\n  \n  return cls(it)\n  \n def __and__(self,other):\n  if not isinstance(other,Iterable):\n   return NotImplemented\n  return self. _from_iterable(value for value in other if value in self)\n  \n def isdisjoint(self,other):\n  for value in other:\n   if value in self:\n    return False\n  return True\n  \n def __or__(self,other):\n  if not isinstance(other,Iterable):\n   return NotImplemented\n  chain=(e for s in (self,other)for e in s)\n  return self. _from_iterable(chain)\n  \n def __sub__(self,other):\n  if not isinstance(other,Set):\n   if not isinstance(other,Iterable):\n    return NotImplemented\n   other=self. _from_iterable(other)\n  return self. _from_iterable(value for value in self\n  if value not in other)\n  \n def __xor__(self,other):\n  if not isinstance(other,Set):\n   if not isinstance(other,Iterable):\n    return NotImplemented\n   other=self. _from_iterable(other)\n  return (self -other)|(other -self)\n  \n def _hash(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  MAX=sys. maxsize\n  MASK=2 *MAX+1\n  n=len(self)\n  h=1927868237 *(n+1)\n  h &=MASK\n  for x in self:\n   hx=hash(x)\n   h ^=(hx ^(hx <<16)^89869747)*3644798167\n   h &=MASK\n  h=h *69069+907133923\n  h &=MASK\n  if h >MAX:\n   h -=MASK+1\n  if h ==-1:\n   h=590923713\n  return h\n  \nSet. register(frozenset)\n\n\nclass MutableSet(Set):\n\n __slots__=()\n \n @abstractmethod\n def add(self,value):\n  ''\n  raise NotImplementedError\n  \n @abstractmethod\n def discard(self,value):\n  ''\n  raise NotImplementedError\n  \n def remove(self,value):\n  ''\n  if value not in self:\n   raise KeyError(value)\n  self. discard(value)\n  \n def pop(self):\n  ''\n  it=iter(self)\n  try :\n   value=next(it)\n  except StopIteration:\n   raise KeyError\n  self. discard(value)\n  return value\n  \n def clear(self):\n  ''\n  try :\n   while True :\n    self. pop()\n  except KeyError:\n   pass\n   \n def __ior__(self,it):\n  for value in it:\n   self. add(value)\n  return self\n  \n def __iand__(self,it):\n  for value in (self -it):\n   self. discard(value)\n  return self\n  \n def __ixor__(self,it):\n  if it is self:\n   self. clear()\n  else :\n   if not isinstance(it,Set):\n    it=self. _from_iterable(it)\n   for value in it:\n    if value in self:\n     self. discard(value)\n    else :\n     self. add(value)\n  return self\n  \n def __isub__(self,it):\n  if it is self:\n   self. clear()\n  else :\n   for value in it:\n    self. discard(value)\n  return self\n  \nMutableSet. register(set)\n\n\n\n\n\nclass Mapping(Sized,Iterable,Container):\n\n __slots__=()\n \n @abstractmethod\n def __getitem__(self,key):\n  raise KeyError\n  \n def get(self,key,default=None ):\n  try :\n   return self[key]\n  except KeyError:\n   return default\n   \n def __contains__(self,key):\n  try :\n   self[key]\n  except KeyError:\n   return False\n  else :\n   return True\n   \n def keys(self):\n  return KeysView(self)\n  \n def items(self):\n  return ItemsView(self)\n  \n def values(self):\n  return ValuesView(self)\n  \n def __eq__(self,other):\n  if not isinstance(other,Mapping):\n   return NotImplemented\n  return dict(self. items())==dict(other. items())\n  \n def __ne__(self,other):\n  return not (self ==other)\n  \nMapping. register(mappingproxy)\n\n\nclass MappingView(Sized):\n\n def __init__(self,mapping):\n  self. _mapping=mapping\n  \n def __len__(self):\n  return len(self. _mapping)\n  \n def __repr__(self):\n  return'{0.__class__.__name__}({0._mapping!r})'. format(self)\n  \n  \nclass KeysView(MappingView,Set):\n\n @classmethod\n def _from_iterable(self,it):\n  return set(it)\n  \n def __contains__(self,key):\n  return key in self. _mapping\n  \n def __iter__(self):\n  for key in self. _mapping:\n   yield key\n   \nKeysView. register(dict_keys)\n\n\nclass ItemsView(MappingView,Set):\n\n @classmethod\n def _from_iterable(self,it):\n  return set(it)\n  \n def __contains__(self,item):\n  key,value=item\n  try :\n   v=self. _mapping[key]\n  except KeyError:\n   return False\n  else :\n   return v ==value\n   \n def __iter__(self):\n  for key in self. _mapping:\n   yield (key,self. _mapping[key])\n   \nItemsView. register(dict_items)\n\n\nclass ValuesView(MappingView):\n\n def __contains__(self,value):\n  for key in self. _mapping:\n   if value ==self. _mapping[key]:\n    return True\n  return False\n  \n def __iter__(self):\n  for key in self. _mapping:\n   yield self. _mapping[key]\n   \nValuesView. register(dict_values)\n\n\nclass MutableMapping(Mapping):\n\n __slots__=()\n \n @abstractmethod\n def __setitem__(self,key,value):\n  raise KeyError\n  \n @abstractmethod\n def __delitem__(self,key):\n  raise KeyError\n  \n __marker=object()\n \n def pop(self,key,default=__marker):\n  try :\n   value=self[key]\n  except KeyError:\n   if default is self. __marker:\n    raise\n   return default\n  else :\n   del self[key]\n   return value\n   \n def popitem(self):\n  try :\n   key=next(iter(self))\n  except StopIteration:\n   raise KeyError\n  value=self[key]\n  del self[key]\n  return key,value\n  \n def clear(self):\n  try :\n   while True :\n    self. popitem()\n  except KeyError:\n   pass\n   \n def update(*args,**kwds):\n  if len(args)>2:\n   raise TypeError(\"update() takes at most 2 positional \"\n   \"arguments ({} given)\". format(len(args)))\n  elif not args:\n   raise TypeError(\"update() takes at least 1 argument (0 given)\")\n  self=args[0]\n  other=args[1]if len(args)>=2 else ()\n  \n  if isinstance(other,Mapping):\n   for key in other:\n    self[key]=other[key]\n  elif hasattr(other,\"keys\"):\n   for key in other. keys():\n    self[key]=other[key]\n  else :\n   for key,value in other:\n    self[key]=value\n  for key,value in kwds. items():\n   self[key]=value\n   \n def setdefault(self,key,default=None ):\n  try :\n   return self[key]\n  except KeyError:\n   self[key]=default\n  return default\n  \nMutableMapping. register(dict)\n\n\n\n\n\nclass Sequence(Sized,Iterable,Container):\n\n ''\n\n\n\n \n \n __slots__=()\n \n @abstractmethod\n def __getitem__(self,index):\n  raise IndexError\n  \n def __iter__(self):\n  i=0\n  try :\n   while True :\n    v=self[i]\n    yield v\n    i +=1\n  except IndexError:\n   return\n   \n def __contains__(self,value):\n  for v in self:\n   if v ==value:\n    return True\n  return False\n  \n def __reversed__(self):\n  for i in reversed(range(len(self))):\n   yield self[i]\n   \n def index(self,value):\n  for i,v in enumerate(self):\n   if v ==value:\n    return i\n  raise ValueError\n  \n def count(self,value):\n  return sum(1 for v in self if v ==value)\n  \nSequence. register(tuple)\nSequence. register(str)\nSequence. register(range)\n\n\nclass ByteString(Sequence):\n\n ''\n\n\n \n \n __slots__=()\n \nByteString. register(bytes)\nByteString. register(bytearray)\n\n\nclass MutableSequence(Sequence):\n\n __slots__=()\n \n @abstractmethod\n def __setitem__(self,index,value):\n  raise IndexError\n  \n @abstractmethod\n def __delitem__(self,index):\n  raise IndexError\n  \n @abstractmethod\n def insert(self,index,value):\n  raise IndexError\n  \n def append(self,value):\n  self. insert(len(self),value)\n  \n def clear(self):\n  try :\n   while True :\n    self. pop()\n  except IndexError:\n   pass\n   \n def reverse(self):\n  n=len(self)\n  for i in range(n //2):\n   self[i],self[n -i -1]=self[n -i -1],self[i]\n   \n def extend(self,values):\n  for v in values:\n   self. append(v)\n   \n def pop(self,index=-1):\n  v=self[index]\n  del self[index]\n  return v\n  \n def remove(self,value):\n  del self[self. index(value)]\n  \n def __iadd__(self,values):\n  self. extend(values)\n  return self\n  \nMutableSequence. register(list)\nMutableSequence. register(bytearray)\n", ["abc", "sys"]], "collections": [".py", "\n\nfrom _collections import deque,defaultdict\n\n\n\n__all__=['deque','defaultdict','namedtuple','UserDict','UserList',\n'UserString','Counter','OrderedDict']\n\n\n\n\n\n\nfrom _abcoll import MutableMapping\n\n\n\nfrom collections. abc import *\nimport collections. abc\n__all__ +=collections. abc. __all__\n\nfrom _collections import deque,defaultdict,namedtuple\nfrom operator import itemgetter as _itemgetter\nfrom keyword import iskeyword as _iskeyword\nimport sys as _sys\nimport heapq as _heapq\n\n\nfrom itertools import repeat as _repeat,chain as _chain,starmap as _starmap\nfrom reprlib import recursive_repr as _recursive_repr\n\nclass Set(set):\n pass\n \nclass Sequence(list):\n pass\n \ndef _proxy(obj):\n return obj\n \n \n \n \n \nclass _Link(object):\n __slots__='prev','next','key','__weakref__'\n \nclass OrderedDict(dict):\n ''\n \n \n \n \n \n \n \n \n \n \n \n \n \n def __init__(self,*args,**kwds):\n  ''\n\n\n\n  \n  if len(args)>1:\n   raise TypeError('expected at most 1 arguments, got %d'%len(args))\n  try :\n   self. __root\n  except AttributeError:\n   self. __hardroot=_Link()\n   self. __root=root=_proxy(self. __hardroot)\n   root. prev=root. next=root\n   self. __map={}\n  self. __update(*args,**kwds)\n  \n def __setitem__(self,key,value,\n dict_setitem=dict. __setitem__,proxy=_proxy,Link=_Link):\n  ''\n  \n  \n  if key not in self:\n   self. __map[key]=link=Link()\n   root=self. __root\n   last=root. prev\n   link. prev,link. next,link. key=last,root,key\n   last. next=link\n   root. prev=proxy(link)\n  dict_setitem(self,key,value)\n  \n def __delitem__(self,key,dict_delitem=dict. __delitem__):\n  ''\n  \n  \n  dict_delitem(self,key)\n  link=self. __map. pop(key)\n  link_prev=link. prev\n  link_next=link. next\n  link_prev. next=link_next\n  link_next. prev=link_prev\n  \n def __iter__(self):\n  ''\n  \n  root=self. __root\n  curr=root. next\n  while curr is not root:\n   yield curr. key\n   curr=curr. next\n   \n def __reversed__(self):\n  ''\n  \n  root=self. __root\n  curr=root. prev\n  while curr is not root:\n   yield curr. key\n   curr=curr. prev\n   \n def clear(self):\n  ''\n  root=self. __root\n  root. prev=root. next=root\n  self. __map. clear()\n  dict. clear(self)\n  \n def popitem(self,last=True ):\n  ''\n\n\n  \n  if not self:\n   raise KeyError('dictionary is empty')\n  root=self. __root\n  if last:\n   link=root. prev\n   link_prev=link. prev\n   link_prev. next=root\n   root. prev=link_prev\n  else :\n   link=root. next\n   link_next=link. next\n   root. next=link_next\n   link_next. prev=root\n  key=link. key\n  del self. __map[key]\n  value=dict. pop(self,key)\n  return key,value\n  \n def move_to_end(self,key,last=True ):\n  ''\n\n\n\n\n  \n  link=self. __map[key]\n  link_prev=link. prev\n  link_next=link. next\n  link_prev. next=link_next\n  link_next. prev=link_prev\n  root=self. __root\n  if last:\n   last=root. prev\n   link. prev=last\n   link. next=root\n   last. next=root. prev=link\n  else :\n   first=root. next\n   link. prev=root\n   link. next=first\n   root. next=first. prev=link\n   \n def __sizeof__(self):\n  sizeof=_sys. getsizeof\n  n=len(self)+1\n  size=sizeof(self. __dict__)\n  size +=sizeof(self. __map)*2\n  size +=sizeof(self. __hardroot)*n\n  size +=sizeof(self. __root)*n\n  return size\n  \n  \n update=__update=MutableMapping. update\n keys=MutableMapping. keys\n values=MutableMapping. values\n items=MutableMapping. items\n __ne__=MutableMapping. __ne__\n \n __marker=object()\n \n def pop(self,key,default=__marker):\n  ''\n\n\n\n  \n  if key in self:\n   result=self[key]\n   del self[key]\n   return result\n  if default is self. __marker:\n   raise KeyError(key)\n  return default\n  \n def setdefault(self,key,default=None ):\n  ''\n  if key in self:\n   return self[key]\n  self[key]=default\n  return default\n  \n  \n  \n def __repr__(self):\n  ''\n  if not self:\n   return'%s()'%(self. __class__. __name__,)\n  return'%s(%r)'%(self. __class__. __name__,list(self. items()))\n  \n def __reduce__(self):\n  ''\n  items=[[k,self[k]]for k in self]\n  inst_dict=vars(self). copy()\n  for k in vars(OrderedDict()):\n   inst_dict. pop(k,None )\n  if inst_dict:\n   return (self. __class__,(items,),inst_dict)\n  return self. __class__,(items,)\n  \n def copy(self):\n  ''\n  return self. __class__(self)\n  \n @classmethod\n def fromkeys(cls,iterable,value=None ):\n  ''\n\n\n  \n  self=cls()\n  for key in iterable:\n   self[key]=value\n  return self\n  \n def __eq__(self,other):\n  ''\n\n\n  \n  if isinstance(other,OrderedDict):\n   return len(self)==len(other)and   all(p ==q for p,q in zip(self. items(),other. items()))\n  return dict. __eq__(self,other)\n  \n  \n  \n  \n  \n  \n  \ndef _count_elements(mapping,iterable):\n ''\n mapping_get=mapping. get\n for elem in iterable:\n  mapping[elem]=mapping_get(elem,0)+1\n  \n  \n  \n  \n  \n  \nclass Counter(dict):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n \n \n \n \n \n def __init__(self,iterable=None ,**kwds):\n  ''\n\n\n\n\n\n\n\n\n  \n  \n  dict. __init__(self)\n  self. update(iterable,**kwds)\n  \n def __missing__(self,key):\n  ''\n  \n  return 0\n  \n def most_common(self,n=None ):\n  ''\n\n\n\n\n\n  \n  \n  if n is None :\n   return sorted(self. items(),key=_itemgetter(1),reverse=True )\n  return _heapq. nlargest(n,self. items(),key=_itemgetter(1))\n  \n def elements(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  return _chain. from_iterable(_starmap(_repeat,self. items()))\n  \n  \n  \n @classmethod\n def fromkeys(cls,iterable,v=None ):\n \n \n  raise NotImplementedError(\n  'Counter.fromkeys() is undefined.  Use Counter(iterable) instead.')\n  \n def update(self,iterable=None ,**kwds):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  \n  \n  \n  \n  \n  \n  \n  if iterable is not None :\n   if isinstance(iterable,Mapping):\n    if self:\n     self_get=self. get\n     for elem,count in iterable. items():\n      self[elem]=count+self_get(elem,0)\n    else :\n     super(). update(iterable)\n   else :\n    _count_elements(self,iterable)\n  if kwds:\n   self. update(kwds)\n   \n def subtract(self,iterable=None ,**kwds):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if iterable is not None :\n   self_get=self. get\n   if isinstance(iterable,Mapping):\n    for elem,count in iterable. items():\n     self[elem]=self_get(elem,0)-count\n   else :\n    for elem in iterable:\n     self[elem]=self_get(elem,0)-1\n  if kwds:\n   self. subtract(kwds)\n   \n def copy(self):\n  ''\n  return self. __class__(self)\n  \n def __reduce__(self):\n  return self. __class__,(dict(self),)\n  \n def __delitem__(self,elem):\n  ''\n  if elem in self:\n   super(). __delitem__(elem)\n   \n def __repr__(self):\n  if not self:\n   return'%s()'%self. __class__. __name__\n  try :\n   items=', '. join(map('%r: %r'. __mod__,self. most_common()))\n   return'%s({%s})'%(self. __class__. __name__,items)\n  except TypeError:\n  \n   return'{0}({1!r})'. format(self. __class__. __name__,dict(self))\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n def __add__(self,other):\n  ''\n\n\n\n\n  \n  if not isinstance(other,Counter):\n   return NotImplemented\n  result=Counter()\n  for elem,count in self. items():\n   newcount=count+other[elem]\n   if newcount >0:\n    result[elem]=newcount\n  for elem,count in other. items():\n   if elem not in self and count >0:\n    result[elem]=count\n  return result\n  \n def __sub__(self,other):\n  ''\n\n\n\n\n  \n  if not isinstance(other,Counter):\n   return NotImplemented\n  result=Counter()\n  for elem,count in self. items():\n   newcount=count -other[elem]\n   if newcount >0:\n    result[elem]=newcount\n  for elem,count in other. items():\n   if elem not in self and count <0:\n    result[elem]=0 -count\n  return result\n  \n def __or__(self,other):\n  ''\n\n\n\n\n  \n  if not isinstance(other,Counter):\n   return NotImplemented\n  result=Counter()\n  for elem,count in self. items():\n   other_count=other[elem]\n   newcount=other_count if count <other_count else count\n   if newcount >0:\n    result[elem]=newcount\n  for elem,count in other. items():\n   if elem not in self and count >0:\n    result[elem]=count\n  return result\n  \n def __and__(self,other):\n  ''\n\n\n\n\n  \n  if not isinstance(other,Counter):\n   return NotImplemented\n  result=Counter()\n  for elem,count in self. items():\n   other_count=other[elem]\n   newcount=count if count <other_count else other_count\n   if newcount >0:\n    result[elem]=newcount\n  return result\n  \n  \n  \n  \n  \n  \nclass ChainMap(MutableMapping):\n ''\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,*maps):\n  ''\n\n\n  \n  self. maps=list(maps)or [{}]\n  \n def __missing__(self,key):\n  raise KeyError(key)\n  \n def __getitem__(self,key):\n  for mapping in self. maps:\n   try :\n    return mapping[key]\n   except KeyError:\n    pass\n  return self. __missing__(key)\n  \n def get(self,key,default=None ):\n  return self[key]if key in self else default\n  \n def __len__(self):\n  return len(set(). union(*self. maps))\n  \n def __iter__(self):\n  return iter(set(). union(*self. maps))\n  \n def __contains__(self,key):\n  return any(key in m for m in self. maps)\n  \n def __bool__(self):\n  return any(self. maps)\n  \n  \n  \n def __repr__(self):\n  return'{0.__class__.__name__}({1})'. format(\n  self,', '. join(map(repr,self. maps)))\n  \n def __repr__(self):\n  return','. join(str(_map)for _map in self. maps)\n  \n @classmethod\n def fromkeys(cls,iterable,*args):\n  ''\n  return cls(dict. fromkeys(iterable,*args))\n  \n def copy(self):\n  ''\n  return self. __class__(self. maps[0]. copy(),*self. maps[1:])\n  \n __copy__=copy\n \n def new_child(self):\n  ''\n  return self. __class__({},*self. maps)\n  \n @property\n def parents(self):\n  ''\n  return self. __class__(*self. maps[1:])\n  \n def __setitem__(self,key,value):\n  self. maps[0][key]=value\n  \n def __delitem__(self,key):\n  try :\n   del self. maps[0][key]\n  except KeyError:\n   raise KeyError('Key not found in the first mapping: {!r}'. format(key))\n   \n def popitem(self):\n  ''\n  try :\n   return self. maps[0]. popitem()\n  except KeyError:\n   raise KeyError('No keys found in the first mapping.')\n   \n def pop(self,key,*args):\n  ''\n  try :\n   return self. maps[0]. pop(key,*args)\n  except KeyError:\n  \n   raise KeyError('Key not found in the first mapping: %s'%key)\n   \n def clear(self):\n  ''\n  self. maps[0]. clear()\n  \n  \n  \n  \n  \n  \nclass UserDict(MutableMapping):\n\n\n def __init__(self,dict=None ,**kwargs):\n  self. data={}\n  if dict is not None :\n   self. update(dict)\n  if len(kwargs):\n   self. update(kwargs)\n def __len__(self):return len(self. data)\n def __getitem__(self,key):\n  if key in self. data:\n   return self. data[key]\n  if hasattr(self. __class__,\"__missing__\"):\n   return self. __class__. __missing__(self,key)\n  raise KeyError(key)\n def __setitem__(self,key,item):self. data[key]=item\n def __delitem__(self,key):del self. data[key]\n def __iter__(self):\n  return iter(self. data)\n  \n  \n def __contains__(self,key):\n  return key in self. data\n  \n  \n def __repr__(self):return repr(self. data)\n def copy(self):\n  if self. __class__ is UserDict:\n   return UserDict(self. data. copy())\n  import copy\n  data=self. data\n  try :\n   self. data={}\n   c=copy. copy(self)\n  finally :\n   self. data=data\n  c. update(self)\n  return c\n @classmethod\n def fromkeys(cls,iterable,value=None ):\n  d=cls()\n  for key in iterable:\n   d[key]=value\n  return d\n  \n  \n  \n  \n  \nclass UserList(MutableSequence):\n ''\n def __init__(self,initlist=None ):\n  self. data=[]\n  if initlist is not None :\n  \n   if type(initlist)==type(self. data):\n    self. data[:]=initlist\n   elif isinstance(initlist,UserList):\n    self. data[:]=initlist. data[:]\n   else :\n    self. data=list(initlist)\n def __repr__(self):return repr(self. data)\n def __lt__(self,other):return self. data <self. __cast(other)\n def __le__(self,other):return self. data <=self. __cast(other)\n def __eq__(self,other):return self. data ==self. __cast(other)\n def __ne__(self,other):return self. data !=self. __cast(other)\n def __gt__(self,other):return self. data >self. __cast(other)\n def __ge__(self,other):return self. data >=self. __cast(other)\n def __cast(self,other):\n  return other. data if isinstance(other,UserList)else other\n def __contains__(self,item):return item in self. data\n def __len__(self):return len(self. data)\n def __getitem__(self,i):return self. data[i]\n def __setitem__(self,i,item):self. data[i]=item\n def __delitem__(self,i):del self. data[i]\n def __add__(self,other):\n  if isinstance(other,UserList):\n   return self. __class__(self. data+other. data)\n  elif isinstance(other,type(self. data)):\n   return self. __class__(self. data+other)\n  return self. __class__(self. data+list(other))\n def __radd__(self,other):\n  if isinstance(other,UserList):\n   return self. __class__(other. data+self. data)\n  elif isinstance(other,type(self. data)):\n   return self. __class__(other+self. data)\n  return self. __class__(list(other)+self. data)\n def __iadd__(self,other):\n  if isinstance(other,UserList):\n   self. data +=other. data\n  elif isinstance(other,type(self. data)):\n   self. data +=other\n  else :\n   self. data +=list(other)\n  return self\n def __mul__(self,n):\n  return self. __class__(self. data *n)\n __rmul__=__mul__\n def __imul__(self,n):\n  self. data *=n\n  return self\n def append(self,item):self. data. append(item)\n def insert(self,i,item):self. data. insert(i,item)\n def pop(self,i=-1):return self. data. pop(i)\n def remove(self,item):self. data. remove(item)\n def clear(self):self. data. clear()\n def copy(self):return self. __class__(self)\n def count(self,item):return self. data. count(item)\n def index(self,item,*args):return self. data. index(item,*args)\n def reverse(self):self. data. reverse()\n def sort(self,*args,**kwds):self. data. sort(*args,**kwds)\n def extend(self,other):\n  if isinstance(other,UserList):\n   self. data. extend(other. data)\n  else :\n   self. data. extend(other)\n   \n   \n   \n   \n   \n   \n   \nclass UserString(Sequence):\n def __init__(self,seq):\n  if isinstance(seq,str):\n   self. data=seq\n  elif isinstance(seq,UserString):\n   self. data=seq. data[:]\n  else :\n   self. data=str(seq)\n def __str__(self):return str(self. data)\n def __repr__(self):return repr(self. data)\n def __int__(self):return int(self. data)\n def __float__(self):return float(self. data)\n def __complex__(self):return complex(self. data)\n def __hash__(self):return hash(self. data)\n \n def __eq__(self,string):\n  if isinstance(string,UserString):\n   return self. data ==string. data\n  return self. data ==string\n def __ne__(self,string):\n  if isinstance(string,UserString):\n   return self. data !=string. data\n  return self. data !=string\n def __lt__(self,string):\n  if isinstance(string,UserString):\n   return self. data <string. data\n  return self. data <string\n def __le__(self,string):\n  if isinstance(string,UserString):\n   return self. data <=string. data\n  return self. data <=string\n def __gt__(self,string):\n  if isinstance(string,UserString):\n   return self. data >string. data\n  return self. data >string\n def __ge__(self,string):\n  if isinstance(string,UserString):\n   return self. data >=string. data\n  return self. data >=string\n  \n def __contains__(self,char):\n  if isinstance(char,UserString):\n   char=char. data\n  return char in self. data\n  \n def __len__(self):return len(self. data)\n def __getitem__(self,index):return self. __class__(self. data[index])\n def __add__(self,other):\n  if isinstance(other,UserString):\n   return self. __class__(self. data+other. data)\n  elif isinstance(other,str):\n   return self. __class__(self. data+other)\n  return self. __class__(self. data+str(other))\n def __radd__(self,other):\n  if isinstance(other,str):\n   return self. __class__(other+self. data)\n  return self. __class__(str(other)+self. data)\n def __mul__(self,n):\n  return self. __class__(self. data *n)\n __rmul__=__mul__\n def __mod__(self,args):\n  return self. __class__(self. data %args)\n  \n  \n def capitalize(self):return self. __class__(self. data. capitalize())\n def center(self,width,*args):\n  return self. __class__(self. data. center(width,*args))\n def count(self,sub,start=0,end=_sys. maxsize):\n  if isinstance(sub,UserString):\n   sub=sub. data\n  return self. data. count(sub,start,end)\n def encode(self,encoding=None ,errors=None ):\n  if encoding:\n   if errors:\n    return self. __class__(self. data. encode(encoding,errors))\n   return self. __class__(self. data. encode(encoding))\n  return self. __class__(self. data. encode())\n def endswith(self,suffix,start=0,end=_sys. maxsize):\n  return self. data. endswith(suffix,start,end)\n def expandtabs(self,tabsize=8):\n  return self. __class__(self. data. expandtabs(tabsize))\n def find(self,sub,start=0,end=_sys. maxsize):\n  if isinstance(sub,UserString):\n   sub=sub. data\n  return self. data. find(sub,start,end)\n def format(self,*args,**kwds):\n  return self. data. format(*args,**kwds)\n def index(self,sub,start=0,end=_sys. maxsize):\n  return self. data. index(sub,start,end)\n def isalpha(self):return self. data. isalpha()\n def isalnum(self):return self. data. isalnum()\n def isdecimal(self):return self. data. isdecimal()\n def isdigit(self):return self. data. isdigit()\n def isidentifier(self):return self. data. isidentifier()\n def islower(self):return self. data. islower()\n def isnumeric(self):return self. data. isnumeric()\n def isspace(self):return self. data. isspace()\n def istitle(self):return self. data. istitle()\n def isupper(self):return self. data. isupper()\n def join(self,seq):return self. data. join(seq)\n def ljust(self,width,*args):\n  return self. __class__(self. data. ljust(width,*args))\n def lower(self):return self. __class__(self. data. lower())\n def lstrip(self,chars=None ):return self. __class__(self. data. lstrip(chars))\n def partition(self,sep):\n  return self. data. partition(sep)\n def replace(self,old,new,maxsplit=-1):\n  if isinstance(old,UserString):\n   old=old. data\n  if isinstance(new,UserString):\n   new=new. data\n  return self. __class__(self. data. replace(old,new,maxsplit))\n def rfind(self,sub,start=0,end=_sys. maxsize):\n  if isinstance(sub,UserString):\n   sub=sub. data\n  return self. data. rfind(sub,start,end)\n def rindex(self,sub,start=0,end=_sys. maxsize):\n  return self. data. rindex(sub,start,end)\n def rjust(self,width,*args):\n  return self. __class__(self. data. rjust(width,*args))\n def rpartition(self,sep):\n  return self. data. rpartition(sep)\n def rstrip(self,chars=None ):\n  return self. __class__(self. data. rstrip(chars))\n def split(self,sep=None ,maxsplit=-1):\n  return self. data. split(sep,maxsplit)\n def rsplit(self,sep=None ,maxsplit=-1):\n  return self. data. rsplit(sep,maxsplit)\n def splitlines(self,keepends=False ):return self. data. splitlines(keepends)\n def startswith(self,prefix,start=0,end=_sys. maxsize):\n  return self. data. startswith(prefix,start,end)\n def strip(self,chars=None ):return self. __class__(self. data. strip(chars))\n def swapcase(self):return self. __class__(self. data. swapcase())\n def title(self):return self. __class__(self. data. title())\n def translate(self,*args):\n  return self. __class__(self. data. translate(*args))\n def upper(self):return self. __class__(self. data. upper())\n def zfill(self,width):return self. __class__(self. data. zfill(width))\n", ["_abcoll", "_collections", "collections.abc", "copy", "heapq", "itertools", "keyword", "operator", "reprlib", "sys"], 1], "_collections": [".py", "\n\n\n\n\n\n\n\n\n\nimport operator\n\n\n\ndef _thread_ident():\n return -1\n \n \nn=30\nLFTLNK=n\nRGTLNK=n+1\nBLOCKSIZ=n+2\n\n\n\n\n\n\n\n\nclass deque:\n\n def __new__(cls,iterable=(),*args,**kw):\n \n \n  self=object. __new__(cls,*args,**kw)\n  self. clear()\n  return self\n  \n def __init__(self,iterable=(),maxlen=None ):\n  object. __init__(self)\n  self. clear()\n  if maxlen is not None :\n   if maxlen <0:\n    raise ValueError(\"maxlen must be non-negative\")\n  self. _maxlen=maxlen\n  add=self. append\n  for elem in iterable:\n   add(elem)\n   \n @property\n def maxlen(self):\n  return self. _maxlen\n  \n def clear(self):\n  self. right=self. left=[None ]*BLOCKSIZ\n  self. rightndx=n //2\n  self. leftndx=n //2+1\n  self. length=0\n  self. state=0\n  \n def append(self,x):\n  self. state +=1\n  self. rightndx +=1\n  if self. rightndx ==n:\n   newblock=[None ]*BLOCKSIZ\n   self. right[RGTLNK]=newblock\n   newblock[LFTLNK]=self. right\n   self. right=newblock\n   self. rightndx=0\n  self. length +=1\n  self. right[self. rightndx]=x\n  if self. maxlen is not None and self. length >self. maxlen:\n   self. popleft()\n   \n def appendleft(self,x):\n  self. state +=1\n  self. leftndx -=1\n  if self. leftndx ==-1:\n   newblock=[None ]*BLOCKSIZ\n   self. left[LFTLNK]=newblock\n   newblock[RGTLNK]=self. left\n   self. left=newblock\n   self. leftndx=n -1\n  self. length +=1\n  self. left[self. leftndx]=x\n  if self. maxlen is not None and self. length >self. maxlen:\n   self. pop()\n   \n def extend(self,iterable):\n  if iterable is self:\n   iterable=list(iterable)\n  for elem in iterable:\n   self. append(elem)\n   \n def extendleft(self,iterable):\n  if iterable is self:\n   iterable=list(iterable)\n  for elem in iterable:\n   self. appendleft(elem)\n   \n def pop(self):\n  if self. left is self. right and self. leftndx >self. rightndx:\n  \n   raise IndexError(\"pop from an empty deque\")\n  x=self. right[self. rightndx]\n  self. right[self. rightndx]=None\n  self. length -=1\n  self. rightndx -=1\n  self. state +=1\n  if self. rightndx ==-1:\n   prevblock=self. right[LFTLNK]\n   if prevblock is None :\n   \n    self. rightndx=n //2\n    self. leftndx=n //2+1\n   else :\n    prevblock[RGTLNK]=None\n    self. right[LFTLNK]=None\n    self. right=prevblock\n    self. rightndx=n -1\n  return x\n  \n def popleft(self):\n  if self. left is self. right and self. leftndx >self. rightndx:\n  \n   raise IndexError(\"pop from an empty deque\")\n  x=self. left[self. leftndx]\n  self. left[self. leftndx]=None\n  self. length -=1\n  self. leftndx +=1\n  self. state +=1\n  if self. leftndx ==n:\n   prevblock=self. left[RGTLNK]\n   if prevblock is None :\n   \n    self. rightndx=n //2\n    self. leftndx=n //2+1\n   else :\n    prevblock[LFTLNK]=None\n    self. left[RGTLNK]=None\n    self. left=prevblock\n    self. leftndx=0\n  return x\n  \n def count(self,value):\n  c=0\n  for item in self:\n   if item ==value:\n    c +=1\n  return c\n  \n def remove(self,value):\n \n  for i in range(len(self)):\n   if self[i]==value:\n    del self[i]\n    return\n  raise ValueError(\"deque.remove(x): x not in deque\")\n  \n def rotate(self,n=1):\n  length=len(self)\n  if length ==0:\n   return\n  halflen=(length+1)>>1\n  if n >halflen or n <-halflen:\n   n %=length\n   if n >halflen:\n    n -=length\n   elif n <-halflen:\n    n +=length\n  while n >0:\n   self. appendleft(self. pop())\n   n -=1\n  while n <0:\n   self. append(self. popleft())\n   n +=1\n   \n def reverse(self):\n  ''\n  leftblock=self. left\n  rightblock=self. right\n  leftindex=self. leftndx\n  rightindex=self. rightndx\n  for i in range(self. length //2):\n  \n   assert leftblock !=rightblock or leftindex <rightindex\n   \n   \n   (rightblock[rightindex],leftblock[leftindex])=(\n   leftblock[leftindex],rightblock[rightindex])\n   \n   \n   leftindex +=1\n   if leftindex ==n:\n    leftblock=leftblock[RGTLNK]\n    assert leftblock is not None\n    leftindex=0\n    \n    \n   rightindex -=1\n   if rightindex ==-1:\n    rightblock=rightblock[LFTLNK]\n    assert rightblock is not None\n    rightindex=n -1\n    \n def __repr__(self):\n  threadlocalattr='__repr'+str(_thread_ident())\n  if threadlocalattr in self. __dict__:\n   return'deque([...])'\n  else :\n   self. __dict__[threadlocalattr]=True\n   try :\n    if self. maxlen is not None :\n     return'deque(%r, maxlen=%s)'%(list(self),self. maxlen)\n    else :\n     return'deque(%r)'%(list(self),)\n   finally :\n    del self. __dict__[threadlocalattr]\n    \n def __iter__(self):\n  return deque_iterator(self,self. _iter_impl)\n  \n def _iter_impl(self,original_state,giveup):\n  if self. state !=original_state:\n   giveup()\n  block=self. left\n  while block:\n   l,r=0,n\n   if block is self. left:\n    l=self. leftndx\n   if block is self. right:\n    r=self. rightndx+1\n   for elem in block[l:r]:\n    yield elem\n    if self. state !=original_state:\n     giveup()\n   block=block[RGTLNK]\n   \n def __reversed__(self):\n  return deque_iterator(self,self. _reversed_impl)\n  \n def _reversed_impl(self,original_state,giveup):\n  if self. state !=original_state:\n   giveup()\n  block=self. right\n  while block:\n   l,r=0,n\n   if block is self. left:\n    l=self. leftndx\n   if block is self. right:\n    r=self. rightndx+1\n   for elem in reversed(block[l:r]):\n    yield elem\n    if self. state !=original_state:\n     giveup()\n   block=block[LFTLNK]\n   \n def __len__(self):\n \n \n \n \n \n \n  return self. length\n  \n def __getref(self,index):\n  if index >=0:\n   block=self. left\n   while block:\n    l,r=0,n\n    if block is self. left:\n     l=self. leftndx\n    if block is self. right:\n     r=self. rightndx+1\n    span=r -l\n    if index <span:\n     return block,l+index\n    index -=span\n    block=block[RGTLNK]\n  else :\n   block=self. right\n   while block:\n    l,r=0,n\n    if block is self. left:\n     l=self. leftndx\n    if block is self. right:\n     r=self. rightndx+1\n    negative_span=l -r\n    if index >=negative_span:\n     return block,r+index\n    index -=negative_span\n    block=block[LFTLNK]\n  raise IndexError(\"deque index out of range\")\n  \n def __getitem__(self,index):\n  block,index=self. __getref(index)\n  return block[index]\n  \n def __setitem__(self,index,value):\n  block,index=self. __getref(index)\n  block[index]=value\n  \n def __delitem__(self,index):\n  length=len(self)\n  if index >=0:\n   if index >=length:\n    raise IndexError(\"deque index out of range\")\n   self. rotate(-index)\n   self. popleft()\n   self. rotate(index)\n  else :\n  \n   index=index ^(2 **31)\n   if index >=length:\n    raise IndexError(\"deque index out of range\")\n   self. rotate(index)\n   self. pop()\n   self. rotate(-index)\n   \n def __reduce_ex__(self,proto):\n  return type(self),(list(self),self. maxlen)\n  \n def __hash__(self):\n \n  raise TypeError(\"deque objects are unhashable\")\n  \n def __copy__(self):\n  return self. __class__(self,self. maxlen)\n  \n  \n def __eq__(self,other):\n  if isinstance(other,deque):\n   return list(self)==list(other)\n  else :\n   return NotImplemented\n   \n def __ne__(self,other):\n  if isinstance(other,deque):\n   return list(self)!=list(other)\n  else :\n   return NotImplemented\n   \n def __lt__(self,other):\n  if isinstance(other,deque):\n   return list(self)<list(other)\n  else :\n   return NotImplemented\n   \n def __le__(self,other):\n  if isinstance(other,deque):\n   return list(self)<=list(other)\n  else :\n   return NotImplemented\n   \n def __gt__(self,other):\n  if isinstance(other,deque):\n   return list(self)>list(other)\n  else :\n   return NotImplemented\n   \n def __ge__(self,other):\n  if isinstance(other,deque):\n   return list(self)>=list(other)\n  else :\n   return NotImplemented\n   \n def __iadd__(self,other):\n  self. extend(other)\n  return self\n  \n  \nclass deque_iterator(object):\n\n def __init__(self,deq,itergen):\n  self. counter=len(deq)\n  def giveup():\n   self. counter=0\n   \n   raise RuntimeError(\"deque mutated during iteration\")\n  self. _gen=itergen(deq. state,giveup)\n  \n def __next__(self):\n  res=self. _gen. __next__()\n  self. counter -=1\n  return res\n  \n def __iter__(self):\n  return self\n  \nclass defaultdict(dict):\n\n def __init__(self,*args,**kwds):\n  if len(args)>0:\n   default_factory=args[0]\n   args=args[1:]\n   if not callable(default_factory)and default_factory is not None :\n    raise TypeError(\"first argument must be callable\")\n  else :\n   default_factory=None\n  dict. __init__(self,args,kwds)\n  self. default_factory=default_factory\n  self. update(args,kwds)\n  super(defaultdict,self). __init__(*args,**kwds)\n  \n def __missing__(self,key):\n \n  if self. default_factory is None :\n   raise KeyError(key)\n  self[key]=value=self. default_factory()\n  return value\n  \n def __repr__(self,recurse=set()):\n  if id(self)in recurse:\n   return\"defaultdict(...)\"\n  try :\n   recurse. add(id(self))\n   return\"defaultdict(%s, %s)\"%(repr(self. default_factory),super(defaultdict,self). __repr__())\n  finally :\n   recurse. remove(id(self))\n   \n def copy(self):\n  return type(self)(self. default_factory,self)\n  \n def __copy__(self):\n  return self. copy()\n  \n def __reduce__(self):\n \n \n \n \n \n \n \n \n \n \n \n  return (type(self),(self. default_factory,),None ,None ,self. items())\n  \nfrom operator import itemgetter as _itemgetter\nfrom keyword import iskeyword as _iskeyword\nimport sys as _sys\n\ndef namedtuple(typename,field_names,verbose=False ,rename=False ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n \n if isinstance(field_names,str):\n  field_names=field_names. replace(',',' '). split()\n field_names=tuple(map(str,field_names))\n if rename:\n  names=list(field_names)\n  seen=set()\n  for i,name in enumerate(names):\n   if (not min(c. isalnum()or c =='_'for c in name)or _iskeyword(name)\n   or not name or name[0]. isdigit()or name. startswith('_')\n   or name in seen):\n    names[i]='_%d'%i\n   seen. add(name)\n  field_names=tuple(names)\n for name in (typename,)+field_names:\n  if not min(c. isalnum()or c =='_'for c in name):\n   raise ValueError('Type names and field names can only contain alphanumeric characters and underscores: %r'%name)\n  if _iskeyword(name):\n   raise ValueError('Type names and field names cannot be a keyword: %r'%name)\n  if name[0]. isdigit():\n   raise ValueError('Type names and field names cannot start with a number: %r'%name)\n seen_names=set()\n for name in field_names:\n  if name. startswith('_')and not rename:\n   raise ValueError('Field names cannot start with an underscore: %r'%name)\n  if name in seen_names:\n   raise ValueError('Encountered duplicate field name: %r'%name)\n  seen_names. add(name)\n  \n  \n numfields=len(field_names)\n argtxt=repr(field_names). replace(\"'\",\"\")[1:-1]\n reprtxt=', '. join('%s=%%r'%name for name in field_names)\n \n template='''class %(typename)s(tuple):\n        '%(typename)s(%(argtxt)s)' \\n\n        __slots__ = () \\n\n        _fields = %(field_names)r \\n\n        def __new__(_cls, %(argtxt)s):\n            return tuple.__new__(_cls, (%(argtxt)s)) \\n\n        @classmethod\n        def _make(cls, iterable, new=tuple.__new__, len=len):\n            'Make a new %(typename)s object from a sequence or iterable'\n            result = new(cls, iterable)\n            if len(result) != %(numfields)d:\n                raise TypeError('Expected %(numfields)d arguments, got %%d' %% len(result))\n            return result \\n\n        def __repr__(self):\n            return '%(typename)s(%(reprtxt)s)' %% self \\n\n        def _asdict(self):\n            'Return a new dict which maps field names to their values'\n            return dict(zip(self._fields, self)) \\n\n        def _replace(_self, **kwds):\n            'Return a new %(typename)s object replacing specified fields with new values'\n            result = _self._make(map(kwds.pop, %(field_names)r, _self))\n            if kwds:\n                raise ValueError('Got unexpected field names: %%r' %% kwds.keys())\n            return result \\n\n        def __getnewargs__(self):\n            return tuple(self) \\n\\n'''%locals()\n for i,name in enumerate(field_names):\n  template +='        %s = _property(_itemgetter(%d))\\n'%(name,i)\n  \n if verbose:\n  print(template)\n  \n  \n namespace=dict(_itemgetter=_itemgetter,__name__='namedtuple_%s'%typename,\n _property=property,_tuple=tuple)\n try :\n  exec(template,namespace)\n except SyntaxError as e:\n  raise SyntaxError(e. message+':\\n'+template)\n result=namespace[typename]\n \n \n \n \n \n try :\n  result. __module__=_sys. _getframe(1). f_globals. get('__name__','__main__')\n except (AttributeError,ValueError):\n  pass\n  \n return result\n \nif __name__ =='__main__':\n Point=namedtuple('Point',['x','y'])\n p=Point(11,y=22)\n print(p[0]+p[1])\n x,y=p\n print(x,y)\n print(p. x+p. y)\n print(p)\n", ["keyword", "operator", "sys"]], "browser.ajax": [".py", "from _ajax import *\n\nclass Request:\n\n def __init__(self,url,method=\"GET\",headers={},\n data=None ,sync=False ,timeout=None ):\n  self. req=ajax1()\n  self. req. open(method,url,not sync)\n  self. method=method\n  self. headers=headers\n  self. req. timeout_secs=timeout\n  if timeout is not None :\n   if not isinstance(timeout,[int,float]):\n    raise ValueError('timeout is not a number')\n   self. _timeout()\n  self. req. bind(\"complete\",self. _complete)\n  \n  self. ct_set=False\n  for key,value in self. headers. items():\n   self. req. set_header(key,value)\n   if key. lower()=='content-type':\n    self. ct_set=True\n  if not self. ct_set:\n   if self. method ==\"POST\":\n    self. req. set_header(\"Content-Type\",\n    \"application/x-www-form-urlencoded\")\n  if data is None :\n   self. req. send()\n  else :\n   self. req. send(data)\n   \n def _complete(self):\n  ''\n\n\n  \n  if hasattr(self,\"timer\"):\n  \n   self. req. clearTimeout(self. timer)\n   del self. timer\n  if 200 <=self. req. status <300:\n   return self. _success()\n  return self. _error()\n  \n def _error(self):\n  ''\n\n  \n  error=getattr(self,\"error\",None )\n  if error is not None :\n   self. req. text=self. req. responseText\n   error. __func__(self. req)\n   \n def _success(self):\n  ''\n\n  \n  success=getattr(self,\"success\",None )\n  if success is not None :\n   self. req. text=self. req. responseText\n   success. __func__(self. req)\n   \n def _timeout(self):\n  ''\n\n\n  \n  timeout_method=getattr(self,\"timeout\",None )\n  if timeout_method is not None :\n   def func(*args):\n    return timeout_method. __func__(self. req)\n   self. req. set_timeout(self. req. timeout_secs,func)\n", ["_ajax"]], "unittest.runner": [".py", "''\n\nimport sys\nimport time\nimport warnings\n\nfrom . import result\nfrom . signals import registerResult\n\n__unittest=True\n\n\nclass _WritelnDecorator(object):\n ''\n def __init__(self,stream):\n  self. stream=stream\n  \n def __getattr__(self,attr):\n  if attr in ('stream','__getstate__'):\n   raise AttributeError(attr)\n  return getattr(self. stream,attr)\n  \n def writeln(self,arg=None ):\n  if arg:\n   self. write(arg)\n  self. write('\\n')\n  \n  \nclass TextTestResult(result. TestResult):\n ''\n\n\n \n separator1='='*70\n separator2='-'*70\n \n def __init__(self,stream,descriptions,verbosity):\n  super(TextTestResult,self). __init__(stream,descriptions,verbosity)\n  self. stream=stream\n  self. showAll=verbosity >1\n  self. dots=verbosity ==1\n  self. descriptions=descriptions\n  \n def getDescription(self,test):\n  doc_first_line=test. shortDescription()\n  if self. descriptions and doc_first_line:\n   return'\\n'. join((str(test),doc_first_line))\n  else :\n   return str(test)\n   \n def startTest(self,test):\n  super(TextTestResult,self). startTest(test)\n  if self. showAll:\n   self. stream. write(self. getDescription(test))\n   self. stream. write(\" ... \")\n   self. stream. flush()\n   \n def addSuccess(self,test):\n  super(TextTestResult,self). addSuccess(test)\n  if self. showAll:\n   self. stream. writeln(\"ok\")\n  elif self. dots:\n   self. stream. write('.')\n   self. stream. flush()\n   \n def addError(self,test,err):\n  super(TextTestResult,self). addError(test,err)\n  if self. showAll:\n   self. stream. writeln(\"ERROR\")\n  elif self. dots:\n   self. stream. write('E')\n   self. stream. flush()\n   \n def addFailure(self,test,err):\n  super(TextTestResult,self). addFailure(test,err)\n  if self. showAll:\n   self. stream. writeln(\"FAIL\")\n  elif self. dots:\n   self. stream. write('F')\n   self. stream. flush()\n   \n def addSkip(self,test,reason):\n  super(TextTestResult,self). addSkip(test,reason)\n  if self. showAll:\n   self. stream. writeln(\"skipped {0!r}\". format(reason))\n  elif self. dots:\n   self. stream. write(\"s\")\n   self. stream. flush()\n   \n def addExpectedFailure(self,test,err):\n  super(TextTestResult,self). addExpectedFailure(test,err)\n  if self. showAll:\n   self. stream. writeln(\"expected failure\")\n  elif self. dots:\n   self. stream. write(\"x\")\n   self. stream. flush()\n   \n def addUnexpectedSuccess(self,test):\n  super(TextTestResult,self). addUnexpectedSuccess(test)\n  if self. showAll:\n   self. stream. writeln(\"unexpected success\")\n  elif self. dots:\n   self. stream. write(\"u\")\n   self. stream. flush()\n   \n def printErrors(self):\n  if self. dots or self. showAll:\n   self. stream. writeln()\n  self. printErrorList('ERROR',self. errors)\n  self. printErrorList('FAIL',self. failures)\n  \n def printErrorList(self,flavour,errors):\n  for test,err in errors:\n   self. stream. writeln(self. separator1)\n   self. stream. writeln(\"%s: %s\"%(flavour,self. getDescription(test)))\n   self. stream. writeln(self. separator2)\n   self. stream. writeln(\"%s\"%err)\n   \n   \nclass TextTestRunner(object):\n ''\n\n\n\n \n resultclass=TextTestResult\n \n def __init__(self,stream=None ,descriptions=True ,verbosity=1,\n failfast=False ,buffer=False ,resultclass=None ,warnings=None ):\n  if stream is None :\n   stream=sys. stderr\n  self. stream=_WritelnDecorator(stream)\n  self. descriptions=descriptions\n  self. verbosity=verbosity\n  self. failfast=failfast\n  self. buffer=buffer\n  self. warnings=warnings\n  if resultclass is not None :\n   self. resultclass=resultclass\n   \n def _makeResult(self):\n  return self. resultclass(self. stream,self. descriptions,self. verbosity)\n  \n def run(self,test):\n  ''\n  result=self. _makeResult()\n  registerResult(result)\n  result. failfast=self. failfast\n  result. buffer=self. buffer\n  with warnings. catch_warnings():\n  \n   if self. warnings:\n   \n    warnings. simplefilter(self. warnings)\n    \n    \n    \n    \n    \n    if self. warnings in ['default','always']:\n     warnings. filterwarnings('module',\n     category=DeprecationWarning,\n     message='Please use assert\\w+ instead.')\n   startTime=time. time()\n   startTestRun=getattr(result,'startTestRun',None )\n   if startTestRun is not None :\n    startTestRun()\n   try :\n    test(result)\n   finally :\n    stopTestRun=getattr(result,'stopTestRun',None )\n    if stopTestRun is not None :\n     stopTestRun()\n   stopTime=time. time()\n  timeTaken=stopTime -startTime\n  result. printErrors()\n  if hasattr(result,'separator2'):\n   self. stream. writeln(result. separator2)\n  run=result. testsRun\n  self. stream. writeln(\"Ran %d test%s in %.3fs\"%\n  (run,run !=1 and\"s\"or\"\",timeTaken))\n  self. stream. writeln()\n  \n  expectedFails=unexpectedSuccesses=skipped=0\n  try :\n   results=map(len,(result. expectedFailures,\n   result. unexpectedSuccesses,\n   result. skipped))\n  except AttributeError:\n   pass\n  else :\n   expectedFails,unexpectedSuccesses,skipped=results\n   \n  infos=[]\n  if not result. wasSuccessful():\n   self. stream. write(\"FAILED\")\n   failed,errored=len(result. failures),len(result. errors)\n   if failed:\n    infos. append(\"failures=%d\"%failed)\n   if errored:\n    infos. append(\"errors=%d\"%errored)\n  else :\n   self. stream. write(\"OK\")\n  if skipped:\n   infos. append(\"skipped=%d\"%skipped)\n  if expectedFails:\n   infos. append(\"expected failures=%d\"%expectedFails)\n  if unexpectedSuccesses:\n   infos. append(\"unexpected successes=%d\"%unexpectedSuccesses)\n  if infos:\n   self. stream. writeln(\" (%s)\"%(\", \". join(infos),))\n  else :\n   self. stream. write(\"\\n\")\n  return result\n", ["sys", "time", "unittest", "unittest.result", "unittest.signals", "warnings"]], "_imp": [".py", "''\n\n\nclass __loader__(object):pass\n\ndef _fix_co_filename(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:_fix_co_filename'))\n \ndef acquire_lock(*args,**kw):\n ''\n\n\n \n pass\n \n \ndef extension_suffixes(*args,**kw):\n ''\n return ['.pyd']\n \ndef get_frozen_object(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:get_frozen_object'))\n \ndef init_builtin(module,*args,**kw):\n return __import__(module)\n \ndef init_frozen(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:init_frozen'))\n \ndef is_builtin(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:is_builtin'))\n \ndef is_frozen(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:is_frozen'))\n \ndef is_frozen_package(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:is_frozen_package'))\n \ndef load_dynamic(*args,**kw):\n raise NotImplementedError(\"%s:not implemented\"%('_imp.py:load_dynamic'))\n \ndef lock_held(*args,**kw):\n ''\n \n \n return False\n \n \ndef release_lock(*args,**kw):\n ''\n \n \n pass\n \n", []], "weakref": [".py", "''\n\n\n\n\n\n\n\n\n\n\nfrom _weakref import (\ngetweakrefcount,\ngetweakrefs,\nref,\nproxy,\nCallableProxyType,\nProxyType,\nReferenceType)\n\nfrom _weakrefset import WeakSet,_IterationGuard\n\nimport collections\n\nProxyTypes=(ProxyType,CallableProxyType)\n\n__all__=[\"ref\",\"proxy\",\"getweakrefcount\",\"getweakrefs\",\n\"WeakKeyDictionary\",\"ReferenceType\",\"ProxyType\",\n\"CallableProxyType\",\"ProxyTypes\",\"WeakValueDictionary\",\n\"WeakSet\"]\n\n\nclass WeakValueDictionary(collections. MutableMapping):\n ''\n\n\n\n \n \n \n \n \n \n \n def __init__(self,*args,**kw):\n  def remove(wr,selfref=ref(self)):\n   self=selfref()\n   if self is not None :\n    if self. _iterating:\n     self. _pending_removals. append(wr. key)\n    else :\n     del self. data[wr. key]\n  self. _remove=remove\n  \n  self. _pending_removals=[]\n  self. _iterating=set()\n  self. data=d={}\n  self. update(*args,**kw)\n  \n def _commit_removals(self):\n  l=self. _pending_removals\n  d=self. data\n  \n  \n  while l:\n   del d[l. pop()]\n   \n def __getitem__(self,key):\n  o=self. data[key]()\n  if o is None :\n   raise KeyError(key)\n  else :\n   return o\n   \n def __delitem__(self,key):\n  if self. _pending_removals:\n   self. _commit_removals()\n  del self. data[key]\n  \n def __len__(self):\n  return len(self. data)-len(self. _pending_removals)\n  \n def __contains__(self,key):\n  try :\n   o=self. data[key]()\n  except KeyError:\n   return False\n  return o is not None\n  \n def __repr__(self):\n  return\"<WeakValueDictionary at %s>\"%id(self)\n  \n def __setitem__(self,key,value):\n  if self. _pending_removals:\n   self. _commit_removals()\n  self. data[key]=KeyedRef(value,self. _remove,key)\n  \n def copy(self):\n  new=WeakValueDictionary()\n  for key,wr in self. data. items():\n   o=wr()\n   if o is not None :\n    new[key]=o\n  return new\n  \n __copy__=copy\n \n def __deepcopy__(self,memo):\n  from copy import deepcopy\n  new=self. __class__()\n  for key,wr in self. data. items():\n   o=wr()\n   if o is not None :\n    new[deepcopy(key,memo)]=o\n  return new\n  \n def get(self,key,default=None ):\n  try :\n   wr=self. data[key]\n  except KeyError:\n   return default\n  else :\n   o=wr()\n   if o is None :\n   \n    return default\n   else :\n    return o\n    \n def items(self):\n  with _IterationGuard(self):\n   for k,wr in self. data. items():\n    v=wr()\n    if v is not None :\n     yield k,v\n     \n def keys(self):\n  with _IterationGuard(self):\n   for k,wr in self. data. items():\n    if wr()is not None :\n     yield k\n     \n __iter__=keys\n \n def itervaluerefs(self):\n  ''\n\n\n\n\n\n\n\n  \n  with _IterationGuard(self):\n   for wr in self. data. values():\n    yield wr\n    \n def values(self):\n  with _IterationGuard(self):\n   for wr in self. data. values():\n    obj=wr()\n    if obj is not None :\n     yield obj\n     \n def popitem(self):\n  if self. _pending_removals:\n   self. _commit_removals()\n  while True :\n   key,wr=self. data. popitem()\n   o=wr()\n   if o is not None :\n    return key,o\n    \n def pop(self,key,*args):\n  if self. _pending_removals:\n   self. _commit_removals()\n  try :\n   o=self. data. pop(key)()\n  except KeyError:\n   if args:\n    return args[0]\n   raise\n  if o is None :\n   raise KeyError(key)\n  else :\n   return o\n   \n def setdefault(self,key,default=None ):\n  try :\n   wr=self. data[key]\n  except KeyError:\n   if self. _pending_removals:\n    self. _commit_removals()\n   self. data[key]=KeyedRef(default,self. _remove,key)\n   return default\n  else :\n   return wr()\n   \n def update(self,dict=None ,**kwargs):\n  if self. _pending_removals:\n   self. _commit_removals()\n  d=self. data\n  if dict is not None :\n   if not hasattr(dict,\"items\"):\n    dict=type({})(dict)\n   for key,o in dict. items():\n    d[key]=KeyedRef(o,self. _remove,key)\n  if len(kwargs):\n   self. update(kwargs)\n   \n def valuerefs(self):\n  ''\n\n\n\n\n\n\n\n  \n  return list(self. data. values())\n  \n  \nclass KeyedRef(ref):\n ''\n\n\n\n\n\n\n \n \n __slots__=\"key\",\n \n def __new__(type,ob,callback,key):\n  self=ref. __new__(type,ob,callback)\n  self. key=key\n  return self\n  \n def __init__(self,ob,callback,key):\n  super(). __init__(ob,callback)\n  \n  \nclass WeakKeyDictionary(collections. MutableMapping):\n ''\n\n\n\n\n\n\n\n \n \n def __init__(self,dict=None ):\n  self. data={}\n  def remove(k,selfref=ref(self)):\n   self=selfref()\n   if self is not None :\n    if self. _iterating:\n     self. _pending_removals. append(k)\n    else :\n     del self. data[k]\n  self. _remove=remove\n  \n  self. _pending_removals=[]\n  self. _iterating=set()\n  if dict is not None :\n   self. update(dict)\n   \n def _commit_removals(self):\n \n \n \n \n  l=self. _pending_removals\n  d=self. data\n  while l:\n   try :\n    del d[l. pop()]\n   except KeyError:\n    pass\n    \n def __delitem__(self,key):\n  del self. data[ref(key)]\n  \n def __getitem__(self,key):\n  return self. data[ref(key)]\n  \n def __len__(self):\n  return len(self. data)-len(self. _pending_removals)\n  \n def __repr__(self):\n  return\"<WeakKeyDictionary at %s>\"%id(self)\n  \n def __setitem__(self,key,value):\n  self. data[ref(key,self. _remove)]=value\n  \n def copy(self):\n  new=WeakKeyDictionary()\n  for key,value in self. data. items():\n   o=key()\n   if o is not None :\n    new[o]=value\n  return new\n  \n __copy__=copy\n \n def __deepcopy__(self,memo):\n  from copy import deepcopy\n  new=self. __class__()\n  for key,value in self. data. items():\n   o=key()\n   if o is not None :\n    new[o]=deepcopy(value,memo)\n  return new\n  \n def get(self,key,default=None ):\n  return self. data. get(ref(key),default)\n  \n def __contains__(self,key):\n  try :\n   wr=ref(key)\n  except TypeError:\n   return False\n  return wr in self. data\n  \n def items(self):\n  with _IterationGuard(self):\n   for wr,value in self. data. items():\n    key=wr()\n    if key is not None :\n     yield key,value\n     \n def keys(self):\n  with _IterationGuard(self):\n   for wr in self. data:\n    obj=wr()\n    if obj is not None :\n     yield obj\n     \n __iter__=keys\n \n def values(self):\n  with _IterationGuard(self):\n   for wr,value in self. data. items():\n    if wr()is not None :\n     yield value\n     \n def keyrefs(self):\n  ''\n\n\n\n\n\n\n\n  \n  return list(self. data)\n  \n def popitem(self):\n  while True :\n   key,value=self. data. popitem()\n   o=key()\n   if o is not None :\n    return o,value\n    \n def pop(self,key,*args):\n  return self. data. pop(ref(key),*args)\n  \n def setdefault(self,key,default=None ):\n  return self. data. setdefault(ref(key,self. _remove),default)\n  \n def update(self,dict=None ,**kwargs):\n  d=self. data\n  if dict is not None :\n   if not hasattr(dict,\"items\"):\n    dict=type({})(dict)\n   for key,value in dict. items():\n    d[ref(key,self. _remove)]=value\n  if len(kwargs):\n   self. update(kwargs)\n", ["_weakref", "_weakrefset", "collections", "copy"]], "_threading_local": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfrom weakref import ref\nfrom contextlib import contextmanager\n\n__all__=[\"local\"]\n\n\n\n\n\n\n\n\n\n\n\nclass _localimpl:\n ''\n __slots__='key','dicts','localargs','locallock','__weakref__'\n \n def __init__(self):\n \n \n \n  self. key='_threading_local._localimpl.'+str(id(self))\n  \n  self. dicts={}\n  \n def get_dict(self):\n  ''\n  \n  thread=current_thread()\n  return self. dicts[id(thread)][1]\n  \n def create_dict(self):\n  ''\n  localdict={}\n  key=self. key\n  thread=current_thread()\n  idt=id(thread)\n  def local_deleted(_,key=key):\n  \n   thread=wrthread()\n   if thread is not None :\n    del thread. __dict__[key]\n  def thread_deleted(_,idt=idt):\n  \n  \n  \n  \n   local=wrlocal()\n   if local is not None :\n    dct=local. dicts. pop(idt)\n  wrlocal=ref(self,local_deleted)\n  wrthread=ref(thread,thread_deleted)\n  thread. __dict__[key]=wrlocal\n  self. dicts[idt]=wrthread,localdict\n  return localdict\n  \n  \n@contextmanager\ndef _patch(self):\n impl=object. __getattribute__(self,'_local__impl')\n try :\n  dct=impl. get_dict()\n except KeyError:\n  dct=impl. create_dict()\n  args,kw=impl. localargs\n  self. __init__(*args,**kw)\n with impl. locallock:\n  object. __setattr__(self,'__dict__',dct)\n  yield\n  \n  \nclass local:\n __slots__='_local__impl','__dict__'\n \n def __new__(cls,*args,**kw):\n  if (args or kw)and (cls. __init__ is object. __init__):\n   raise TypeError(\"Initialization arguments are not supported\")\n  self=object. __new__(cls)\n  impl=_localimpl()\n  impl. localargs=(args,kw)\n  impl. locallock=RLock()\n  object. __setattr__(self,'_local__impl',impl)\n  \n  \n  \n  impl. create_dict()\n  return self\n  \n def __getattribute__(self,name):\n  with _patch(self):\n   return object. __getattribute__(self,name)\n   \n def __setattr__(self,name,value):\n  if name =='__dict__':\n   raise AttributeError(\n   \"%r object attribute '__dict__' is read-only\"\n   %self. __class__. __name__)\n  with _patch(self):\n   return object. __setattr__(self,name,value)\n   \n def __delattr__(self,name):\n  if name =='__dict__':\n   raise AttributeError(\n   \"%r object attribute '__dict__' is read-only\"\n   %self. __class__. __name__)\n  with _patch(self):\n   return object. __delattr__(self,name)\n   \n   \nfrom threading import current_thread,RLock\n", ["contextlib", "threading", "weakref"]], "abc": [".py", "\n\n\n\"\"\"Abstract Base Classes (ABCs) according to PEP 3119.\"\"\"\n\nfrom _weakrefset import WeakSet\n\ndef abstractmethod(funcobj):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n funcobj. __isabstractmethod__=True\n return funcobj\n \n \nclass abstractclassmethod(classmethod):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n __isabstractmethod__=True\n \n def __init__(self,callable):\n  callable. __isabstractmethod__=True\n  super(). __init__(callable)\n  \n  \nclass abstractstaticmethod(staticmethod):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n __isabstractmethod__=True\n \n def __init__(self,callable):\n  callable. __isabstractmethod__=True\n  super(). __init__(callable)\n  \n  \nclass abstractproperty(property):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n __isabstractmethod__=True\n \n \nclass ABCMeta(type):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n \n \n _abc_invalidation_counter=0\n \n def __new__(mcls,name,bases,namespace):\n  cls=super(). __new__(mcls,name,bases,namespace)\n  \n  abstracts={name\n  for name,value in namespace. items()\n  if getattr(value,\"__isabstractmethod__\",False )}\n  for base in bases:\n   for name in getattr(base,\"__abstractmethods__\",set()):\n    value=getattr(cls,name,None )\n    if getattr(value,\"__isabstractmethod__\",False ):\n     abstracts. add(name)\n  cls. __abstractmethods__=frozenset(abstracts)\n  \n  cls. _abc_registry=WeakSet()\n  cls. _abc_cache=WeakSet()\n  cls. _abc_negative_cache=WeakSet()\n  cls. _abc_negative_cache_version=ABCMeta. _abc_invalidation_counter\n  return cls\n  \n def register(cls,subclass):\n  ''\n\n\n  \n  if not isinstance(subclass,type):\n   raise TypeError(\"Can only register classes\")\n  if issubclass(subclass,cls):\n   return subclass\n   \n   \n  if issubclass(cls,subclass):\n  \n   raise RuntimeError(\"Refusing to create an inheritance cycle\")\n  cls. _abc_registry. add(subclass)\n  ABCMeta. _abc_invalidation_counter +=1\n  return subclass\n  \n def _dump_registry(cls,file=None ):\n  ''\n  print(\"Class: %s.%s\"%(cls. __module__,cls. __name__),file=file)\n  print(\"Inv.counter: %s\"%ABCMeta. _abc_invalidation_counter,file=file)\n  for name in sorted(cls. __dict__. keys()):\n   if name. startswith(\"_abc_\"):\n    value=getattr(cls,name)\n    print(\"%s: %r\"%(name,value),file=file)\n    \n def __instancecheck__(cls,instance):\n  ''\n  \n  subclass=instance. __class__\n  if subclass in cls. _abc_cache:\n   return True\n  subtype=type(instance)\n  if subtype is subclass:\n   if (cls. _abc_negative_cache_version ==\n   ABCMeta. _abc_invalidation_counter and\n   subclass in cls. _abc_negative_cache):\n    return False\n    \n   return cls. __subclasscheck__(subclass)\n  return any(cls. __subclasscheck__(c)for c in {subclass,subtype})\n  \n def __subclasscheck__(cls,subclass):\n  ''\n  \n  if subclass in cls. _abc_cache:\n   return True\n   \n  if cls. _abc_negative_cache_version <ABCMeta. _abc_invalidation_counter:\n  \n   cls. _abc_negative_cache=WeakSet()\n   cls. _abc_negative_cache_version=ABCMeta. _abc_invalidation_counter\n  elif subclass in cls. _abc_negative_cache:\n   return False\n   \n  ok=cls. __subclasshook__(subclass)\n  if ok is not NotImplemented:\n   assert isinstance(ok,bool)\n   if ok:\n    cls. _abc_cache. add(subclass)\n   else :\n    cls. _abc_negative_cache. add(subclass)\n   return ok\n   \n  if cls in getattr(subclass,'__mro__',()):\n   cls. _abc_cache. add(subclass)\n   return True\n   \n  for rcls in cls. _abc_registry:\n   if issubclass(subclass,rcls):\n    cls. _abc_cache. add(subclass)\n    return True\n    \n  for scls in cls. __subclasses__():\n   if issubclass(subclass,scls):\n    cls. _abc_cache. add(subclass)\n    return True\n    \n  cls. _abc_negative_cache. add(subclass)\n  return False\n", ["_weakrefset"]], "unittest.case": [".py", "''\n\nimport sys\nimport functools\nimport difflib\nimport pprint\nimport re\nimport warnings\nimport collections\n\nfrom . import result\nfrom . util import (strclass,safe_repr,_count_diff_all_purpose,\n_count_diff_hashable)\n\n__unittest=True\n\n\nDIFF_OMITTED=('\\nDiff is %s characters long. '\n'Set self.maxDiff to None to see it.')\n\nclass SkipTest(Exception):\n ''\n\n\n\n\n \n \nclass _ExpectedFailure(Exception):\n ''\n\n\n\n \n \n def __init__(self,exc_info):\n  super(_ExpectedFailure,self). __init__()\n  self. exc_info=exc_info\n  \nclass _UnexpectedSuccess(Exception):\n ''\n\n \n \n \nclass _Outcome(object):\n def __init__(self):\n  self. success=True\n  self. skipped=None\n  self. unexpectedSuccess=None\n  self. expectedFailure=None\n  self. errors=[]\n  self. failures=[]\n  \n  \ndef _id(obj):\n return obj\n \ndef skip(reason):\n ''\n\n \n def decorator(test_item):\n  if not isinstance(test_item,type):\n   @functools. wraps(test_item)\n   def skip_wrapper(*args,**kwargs):\n    raise SkipTest(reason)\n   test_item=skip_wrapper\n   \n  test_item. __unittest_skip__=True\n  test_item. __unittest_skip_why__=reason\n  return test_item\n return decorator\n \ndef skipIf(condition,reason):\n ''\n\n \n if condition:\n  return skip(reason)\n return _id\n \ndef skipUnless(condition,reason):\n ''\n\n \n if not condition:\n  return skip(reason)\n return _id\n \n \ndef expectedFailure(func):\n @functools. wraps(func)\n def wrapper(*args,**kwargs):\n  try :\n   func(*args,**kwargs)\n  except Exception:\n   raise _ExpectedFailure(sys. exc_info())\n  raise _UnexpectedSuccess\n return wrapper\n \n \nclass _AssertRaisesBaseContext(object):\n\n def __init__(self,expected,test_case,callable_obj=None ,\n expected_regex=None ):\n  self. expected=expected\n  self. test_case=test_case\n  if callable_obj is not None :\n   try :\n    self. obj_name=callable_obj. __name__\n   except AttributeError:\n    self. obj_name=str(callable_obj)\n  else :\n   self. obj_name=None\n  if isinstance(expected_regex,(bytes,str)):\n   expected_regex=re. compile(expected_regex)\n  self. expected_regex=expected_regex\n  self. msg=None\n  \n def _raiseFailure(self,standardMsg):\n  msg=self. test_case. _formatMessage(self. msg,standardMsg)\n  raise self. test_case. failureException(msg)\n  \n def handle(self,name,callable_obj,args,kwargs):\n  ''\n\n\n\n  \n  if callable_obj is None :\n   self. msg=kwargs. pop('msg',None )\n   return self\n  with self:\n   callable_obj(*args,**kwargs)\n   \n   \n   \nclass _AssertRaisesContext(_AssertRaisesBaseContext):\n ''\n \n def __enter__(self):\n  return self\n  \n def __exit__(self,exc_type,exc_value,tb):\n  if exc_type is None :\n   try :\n    exc_name=self. expected. __name__\n   except AttributeError:\n    exc_name=str(self. expected)\n   if self. obj_name:\n    self. _raiseFailure(\"{} not raised by {}\". format(exc_name,\n    self. obj_name))\n   else :\n    self. _raiseFailure(\"{} not raised\". format(exc_name))\n  if not issubclass(exc_type,self. expected):\n  \n   return False\n   \n  self. exception=exc_value. with_traceback(None )\n  if self. expected_regex is None :\n   return True\n   \n  expected_regex=self. expected_regex\n  if not expected_regex. search(str(exc_value)):\n   self. _raiseFailure('\"{}\" does not match \"{}\"'. format(\n   expected_regex. pattern,str(exc_value)))\n  return True\n  \n  \nclass _AssertWarnsContext(_AssertRaisesBaseContext):\n ''\n \n def __enter__(self):\n \n \n  for v in sys. modules. values():\n   if getattr(v,'__warningregistry__',None ):\n    v. __warningregistry__={}\n  self. warnings_manager=warnings. catch_warnings(record=True )\n  self. warnings=self. warnings_manager. __enter__()\n  warnings. simplefilter(\"always\",self. expected)\n  return self\n  \n def __exit__(self,exc_type,exc_value,tb):\n  self. warnings_manager. __exit__(exc_type,exc_value,tb)\n  if exc_type is not None :\n  \n   return\n  try :\n   exc_name=self. expected. __name__\n  except AttributeError:\n   exc_name=str(self. expected)\n  first_matching=None\n  for m in self. warnings:\n   w=m. message\n   if not isinstance(w,self. expected):\n    continue\n   if first_matching is None :\n    first_matching=w\n   if (self. expected_regex is not None and\n   not self. expected_regex. search(str(w))):\n    continue\n    \n   self. warning=w\n   self. filename=m. filename\n   self. lineno=m. lineno\n   return\n   \n  if first_matching is not None :\n   self. _raiseFailure('\"{}\" does not match \"{}\"'. format(\n   self. expected_regex. pattern,str(first_matching)))\n  if self. obj_name:\n   self. _raiseFailure(\"{} not triggered by {}\". format(exc_name,\n   self. obj_name))\n  else :\n   self. _raiseFailure(\"{} not triggered\". format(exc_name))\n   \n   \nclass TestCase(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n failureException=AssertionError\n \n longMessage=True\n \n maxDiff=80 *8\n \n \n \n _diffThreshold=2 **16\n \n \n \n _classSetupFailed=False\n \n def __init__(self,methodName='runTest'):\n  ''\n\n\n  \n  self. _testMethodName=methodName\n  self. _outcomeForDoCleanups=None\n  self. _testMethodDoc='No test'\n  try :\n   testMethod=getattr(self,methodName)\n  except AttributeError:\n   if methodName !='runTest':\n   \n   \n    raise ValueError(\"no such test method in %s: %s\"%\n    (self. __class__,methodName))\n  else :\n   self. _testMethodDoc=testMethod. __doc__\n  self. _cleanups=[]\n  \n  \n  \n  \n  self. _type_equality_funcs={}\n  self. addTypeEqualityFunc(dict,'assertDictEqual')\n  self. addTypeEqualityFunc(list,'assertListEqual')\n  self. addTypeEqualityFunc(tuple,'assertTupleEqual')\n  self. addTypeEqualityFunc(set,'assertSetEqual')\n  self. addTypeEqualityFunc(frozenset,'assertSetEqual')\n  self. addTypeEqualityFunc(str,'assertMultiLineEqual')\n  \n def addTypeEqualityFunc(self,typeobj,function):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  self. _type_equality_funcs[typeobj]=function\n  \n def addCleanup(self,function,*args,**kwargs):\n  ''\n\n\n\n  \n  self. _cleanups. append((function,args,kwargs))\n  \n def setUp(self):\n  ''\n  pass\n  \n def tearDown(self):\n  ''\n  pass\n  \n @classmethod\n def setUpClass(cls):\n  ''\n  \n @classmethod\n def tearDownClass(cls):\n  ''\n  \n def countTestCases(self):\n  return 1\n  \n def defaultTestResult(self):\n  return result. TestResult()\n  \n def shortDescription(self):\n  ''\n\n\n\n\n  \n  doc=self. _testMethodDoc\n  return doc and doc. split(\"\\n\")[0]. strip()or None\n  \n  \n def id(self):\n  return\"%s.%s\"%(strclass(self. __class__),self. _testMethodName)\n  \n def __eq__(self,other):\n  if type(self)is not type(other):\n   return NotImplemented\n   \n  return self. _testMethodName ==other. _testMethodName\n  \n def __hash__(self):\n  return hash((type(self),self. _testMethodName))\n  \n def __str__(self):\n  return\"%s (%s)\"%(self. _testMethodName,strclass(self. __class__))\n  \n def __repr__(self):\n  return\"<%s testMethod=%s>\"%  (strclass(self. __class__),self. _testMethodName)\n  \n def _addSkip(self,result,reason):\n  addSkip=getattr(result,'addSkip',None )\n  if addSkip is not None :\n   addSkip(self,reason)\n  else :\n   warnings. warn(\"TestResult has no addSkip method, skips not reported\",\n   RuntimeWarning,2)\n   result. addSuccess(self)\n   \n def _executeTestPart(self,function,outcome,isTest=False ):\n  try :\n   function()\n  except KeyboardInterrupt:\n   raise\n  except SkipTest as e:\n   outcome. success=False\n   outcome. skipped=str(e)\n  except _UnexpectedSuccess:\n   exc_info=sys. exc_info()\n   outcome. success=False\n   if isTest:\n    outcome. unexpectedSuccess=exc_info\n   else :\n    outcome. errors. append(exc_info)\n  except _ExpectedFailure:\n   outcome. success=False\n   exc_info=sys. exc_info()\n   if isTest:\n    outcome. expectedFailure=exc_info\n   else :\n    outcome. errors. append(exc_info)\n  except self. failureException:\n   outcome. success=False\n   outcome. failures. append(sys. exc_info())\n   exc_info=sys. exc_info()\n  except :\n   outcome. success=False\n   outcome. errors. append(sys. exc_info())\n   \n def run(self,result=None ):\n  orig_result=result\n  if result is None :\n   result=self. defaultTestResult()\n   startTestRun=getattr(result,'startTestRun',None )\n   if startTestRun is not None :\n    startTestRun()\n    \n  result. startTest(self)\n  \n  testMethod=getattr(self,self. _testMethodName)\n  if (getattr(self. __class__,\"__unittest_skip__\",False )or\n  getattr(testMethod,\"__unittest_skip__\",False )):\n  \n   try :\n    skip_why=(getattr(self. __class__,'__unittest_skip_why__','')\n    or getattr(testMethod,'__unittest_skip_why__',''))\n    self. _addSkip(result,skip_why)\n   finally :\n    result. stopTest(self)\n   return\n  try :\n   outcome=_Outcome()\n   self. _outcomeForDoCleanups=outcome\n   \n   self. _executeTestPart(self. setUp,outcome)\n   if outcome. success:\n    self. _executeTestPart(testMethod,outcome,isTest=True )\n    self. _executeTestPart(self. tearDown,outcome)\n    \n   self. doCleanups()\n   if outcome. success:\n    result. addSuccess(self)\n   else :\n    if outcome. skipped is not None :\n     self. _addSkip(result,outcome. skipped)\n    for exc_info in outcome. errors:\n     result. addError(self,exc_info)\n    for exc_info in outcome. failures:\n     result. addFailure(self,exc_info)\n    if outcome. unexpectedSuccess is not None :\n     addUnexpectedSuccess=getattr(result,'addUnexpectedSuccess',None )\n     if addUnexpectedSuccess is not None :\n      addUnexpectedSuccess(self)\n     else :\n      warnings. warn(\"TestResult has no addUnexpectedSuccess method, reporting as failures\",\n      RuntimeWarning)\n      result. addFailure(self,outcome. unexpectedSuccess)\n      \n    if outcome. expectedFailure is not None :\n     addExpectedFailure=getattr(result,'addExpectedFailure',None )\n     if addExpectedFailure is not None :\n      addExpectedFailure(self,outcome. expectedFailure)\n     else :\n      warnings. warn(\"TestResult has no addExpectedFailure method, reporting as passes\",\n      RuntimeWarning)\n      result. addSuccess(self)\n   return result\n  finally :\n   result. stopTest(self)\n   if orig_result is None :\n    stopTestRun=getattr(result,'stopTestRun',None )\n    if stopTestRun is not None :\n     stopTestRun()\n     \n def doCleanups(self):\n  ''\n  \n  outcome=self. _outcomeForDoCleanups or _Outcome()\n  while self. _cleanups:\n   function,args,kwargs=self. _cleanups. pop()\n   part=lambda :function(*args,**kwargs)\n   self. _executeTestPart(part,outcome)\n   \n   \n   \n  return outcome. success\n  \n def __call__(self,*args,**kwds):\n  return self. run(*args,**kwds)\n  \n def debug(self):\n  ''\n  self. setUp()\n  getattr(self,self. _testMethodName)()\n  self. tearDown()\n  while self. _cleanups:\n   function,args,kwargs=self. _cleanups. pop(-1)\n   function(*args,**kwargs)\n   \n def skipTest(self,reason):\n  ''\n  raise SkipTest(reason)\n  \n def fail(self,msg=None ):\n  ''\n  raise self. failureException(msg)\n  \n def assertFalse(self,expr,msg=None ):\n  ''\n  if expr:\n   msg=self. _formatMessage(msg,\"%s is not false\"%safe_repr(expr))\n   raise self. failureException(msg)\n   \n def assertTrue(self,expr,msg=None ):\n  ''\n  if not expr:\n   msg=self. _formatMessage(msg,\"%s is not true\"%safe_repr(expr))\n   raise self. failureException(msg)\n   \n def _formatMessage(self,msg,standardMsg):\n  ''\n\n\n\n\n\n\n\n  \n  if not self. longMessage:\n   return msg or standardMsg\n  if msg is None :\n   return standardMsg\n  try :\n  \n  \n   return'%s : %s'%(standardMsg,msg)\n  except UnicodeDecodeError:\n   return'%s : %s'%(safe_repr(standardMsg),safe_repr(msg))\n   \n def assertRaises(self,excClass,callableObj=None ,*args,**kwargs):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  context=_AssertRaisesContext(excClass,self,callableObj)\n  return context. handle('assertRaises',callableObj,args,kwargs)\n  \n def assertWarns(self,expected_warning,callable_obj=None ,*args,**kwargs):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  context=_AssertWarnsContext(expected_warning,self,callable_obj)\n  return context. handle('assertWarns',callable_obj,args,kwargs)\n  \n def _getAssertEqualityFunc(self,first,second):\n  ''\n\n\n\n\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  if type(first)is type(second):\n   asserter=self. _type_equality_funcs. get(type(first))\n   if asserter is not None :\n    if isinstance(asserter,str):\n     asserter=getattr(self,asserter)\n    return asserter\n    \n  return self. _baseAssertEqual\n  \n def _baseAssertEqual(self,first,second,msg=None ):\n  ''\n  if not first ==second:\n   standardMsg='%s != %s'%(safe_repr(first),safe_repr(second))\n   msg=self. _formatMessage(msg,standardMsg)\n   raise self. failureException(msg)\n   \n def assertEqual(self,first,second,msg=None ):\n  ''\n\n  \n  assertion_func=self. _getAssertEqualityFunc(first,second)\n  assertion_func(first,second,msg=msg)\n  \n def assertNotEqual(self,first,second,msg=None ):\n  ''\n\n  \n  if not first !=second:\n   msg=self. _formatMessage(msg,'%s == %s'%(safe_repr(first),\n   safe_repr(second)))\n   raise self. failureException(msg)\n   \n def assertAlmostEqual(self,first,second,places=None ,msg=None ,\n delta=None ):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  if first ==second:\n  \n   return\n  if delta is not None and places is not None :\n   raise TypeError(\"specify delta or places not both\")\n   \n  if delta is not None :\n   if abs(first -second)<=delta:\n    return\n    \n   standardMsg='%s != %s within %s delta'%(safe_repr(first),\n   safe_repr(second),\n   safe_repr(delta))\n  else :\n   if places is None :\n    places=7\n    \n   if round(abs(second -first),places)==0:\n    return\n    \n   standardMsg='%s != %s within %r places'%(safe_repr(first),\n   safe_repr(second),\n   places)\n  msg=self. _formatMessage(msg,standardMsg)\n  raise self. failureException(msg)\n  \n def assertNotAlmostEqual(self,first,second,places=None ,msg=None ,\n delta=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  if delta is not None and places is not None :\n   raise TypeError(\"specify delta or places not both\")\n  if delta is not None :\n   if not (first ==second)and abs(first -second)>delta:\n    return\n   standardMsg='%s == %s within %s delta'%(safe_repr(first),\n   safe_repr(second),\n   safe_repr(delta))\n  else :\n   if places is None :\n    places=7\n   if not (first ==second)and round(abs(second -first),places)!=0:\n    return\n   standardMsg='%s == %s within %r places'%(safe_repr(first),\n   safe_repr(second),\n   places)\n   \n  msg=self. _formatMessage(msg,standardMsg)\n  raise self. failureException(msg)\n  \n  \n def assertSequenceEqual(self,seq1,seq2,msg=None ,seq_type=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n  \n  if seq_type is not None :\n   seq_type_name=seq_type. __name__\n   if not isinstance(seq1,seq_type):\n    raise self. failureException('First sequence is not a %s: %s'\n    %(seq_type_name,safe_repr(seq1)))\n   if not isinstance(seq2,seq_type):\n    raise self. failureException('Second sequence is not a %s: %s'\n    %(seq_type_name,safe_repr(seq2)))\n  else :\n   seq_type_name=\"sequence\"\n   \n  differing=None\n  try :\n   len1=len(seq1)\n  except (TypeError,NotImplementedError):\n   differing='First %s has no length.    Non-sequence?'%(\n   seq_type_name)\n   \n  if differing is None :\n   try :\n    len2=len(seq2)\n   except (TypeError,NotImplementedError):\n    differing='Second %s has no length.    Non-sequence?'%(\n    seq_type_name)\n    \n  if differing is None :\n   if seq1 ==seq2:\n    return\n    \n   seq1_repr=safe_repr(seq1)\n   seq2_repr=safe_repr(seq2)\n   if len(seq1_repr)>30:\n    seq1_repr=seq1_repr[:30]+'...'\n   if len(seq2_repr)>30:\n    seq2_repr=seq2_repr[:30]+'...'\n   elements=(seq_type_name. capitalize(),seq1_repr,seq2_repr)\n   differing='%ss differ: %s != %s\\n'%elements\n   \n   for i in range(min(len1,len2)):\n    try :\n     item1=seq1[i]\n    except (TypeError,IndexError,NotImplementedError):\n     differing +=('\\nUnable to index element %d of first %s\\n'%\n     (i,seq_type_name))\n     break\n     \n    try :\n     item2=seq2[i]\n    except (TypeError,IndexError,NotImplementedError):\n     differing +=('\\nUnable to index element %d of second %s\\n'%\n     (i,seq_type_name))\n     break\n     \n    if item1 !=item2:\n     differing +=('\\nFirst differing element %d:\\n%s\\n%s\\n'%\n     (i,item1,item2))\n     break\n   else :\n    if (len1 ==len2 and seq_type is None and\n    type(seq1)!=type(seq2)):\n    \n     return\n     \n   if len1 >len2:\n    differing +=('\\nFirst %s contains %d additional '\n    'elements.\\n'%(seq_type_name,len1 -len2))\n    try :\n     differing +=('First extra element %d:\\n%s\\n'%\n     (len2,seq1[len2]))\n    except (TypeError,IndexError,NotImplementedError):\n     differing +=('Unable to index element %d '\n     'of first %s\\n'%(len2,seq_type_name))\n   elif len1 <len2:\n    differing +=('\\nSecond %s contains %d additional '\n    'elements.\\n'%(seq_type_name,len2 -len1))\n    try :\n     differing +=('First extra element %d:\\n%s\\n'%\n     (len1,seq2[len1]))\n    except (TypeError,IndexError,NotImplementedError):\n     differing +=('Unable to index element %d '\n     'of second %s\\n'%(len1,seq_type_name))\n  standardMsg=differing\n  diffMsg='\\n'+'\\n'. join(\n  difflib. ndiff(pprint. pformat(seq1). splitlines(),\n  pprint. pformat(seq2). splitlines()))\n  \n  standardMsg=self. _truncateMessage(standardMsg,diffMsg)\n  msg=self. _formatMessage(msg,standardMsg)\n  self. fail(msg)\n  \n def _truncateMessage(self,message,diff):\n  max_diff=self. maxDiff\n  if max_diff is None or len(diff)<=max_diff:\n   return message+diff\n  return message+(DIFF_OMITTED %len(diff))\n  \n def assertListEqual(self,list1,list2,msg=None ):\n  ''\n\n\n\n\n\n\n\n  \n  self. assertSequenceEqual(list1,list2,msg,seq_type=list)\n  \n def assertTupleEqual(self,tuple1,tuple2,msg=None ):\n  ''\n\n\n\n\n\n\n  \n  self. assertSequenceEqual(tuple1,tuple2,msg,seq_type=tuple)\n  \n def assertSetEqual(self,set1,set2,msg=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  try :\n   difference1=set1. difference(set2)\n  except TypeError as e:\n   self. fail('invalid type when attempting set difference: %s'%e)\n  except AttributeError as e:\n   self. fail('first argument does not support set difference: %s'%e)\n   \n  try :\n   difference2=set2. difference(set1)\n  except TypeError as e:\n   self. fail('invalid type when attempting set difference: %s'%e)\n  except AttributeError as e:\n   self. fail('second argument does not support set difference: %s'%e)\n   \n  if not (difference1 or difference2):\n   return\n   \n  lines=[]\n  if difference1:\n   lines. append('Items in the first set but not the second:')\n   for item in difference1:\n    lines. append(repr(item))\n  if difference2:\n   lines. append('Items in the second set but not the first:')\n   for item in difference2:\n    lines. append(repr(item))\n    \n  standardMsg='\\n'. join(lines)\n  self. fail(self. _formatMessage(msg,standardMsg))\n  \n def assertIn(self,member,container,msg=None ):\n  ''\n  if member not in container:\n   standardMsg='%s not found in %s'%(safe_repr(member),\n   safe_repr(container))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertNotIn(self,member,container,msg=None ):\n  ''\n  if member in container:\n   standardMsg='%s unexpectedly found in %s'%(safe_repr(member),\n   safe_repr(container))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertIs(self,expr1,expr2,msg=None ):\n  ''\n  if expr1 is not expr2:\n   standardMsg='%s is not %s'%(safe_repr(expr1),\n   safe_repr(expr2))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertIsNot(self,expr1,expr2,msg=None ):\n  ''\n  if expr1 is expr2:\n   standardMsg='unexpectedly identical: %s'%(safe_repr(expr1),)\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertDictEqual(self,d1,d2,msg=None ):\n  self. assertIsInstance(d1,dict,'First argument is not a dictionary')\n  self. assertIsInstance(d2,dict,'Second argument is not a dictionary')\n  \n  if d1 !=d2:\n   standardMsg='%s != %s'%(safe_repr(d1,True ),safe_repr(d2,True ))\n   diff=('\\n'+'\\n'. join(difflib. ndiff(\n   pprint. pformat(d1). splitlines(),\n   pprint. pformat(d2). splitlines())))\n   standardMsg=self. _truncateMessage(standardMsg,diff)\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertDictContainsSubset(self,subset,dictionary,msg=None ):\n  ''\n  warnings. warn('assertDictContainsSubset is deprecated',\n  DeprecationWarning)\n  missing=[]\n  mismatched=[]\n  for key,value in subset. items():\n   if key not in dictionary:\n    missing. append(key)\n   elif value !=dictionary[key]:\n    mismatched. append('%s, expected: %s, actual: %s'%\n    (safe_repr(key),safe_repr(value),\n    safe_repr(dictionary[key])))\n    \n  if not (missing or mismatched):\n   return\n   \n  standardMsg=''\n  if missing:\n   standardMsg='Missing: %s'%','. join(safe_repr(m)for m in\n   missing)\n  if mismatched:\n   if standardMsg:\n    standardMsg +='; '\n   standardMsg +='Mismatched values: %s'%','. join(mismatched)\n   \n  self. fail(self. _formatMessage(msg,standardMsg))\n  \n  \n def assertCountEqual(self,first,second,msg=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  first_seq,second_seq=list(first),list(second)\n  try :\n   first=collections. Counter(first_seq)\n   second=collections. Counter(second_seq)\n  except TypeError:\n  \n   differences=_count_diff_all_purpose(first_seq,second_seq)\n  else :\n   if first ==second:\n    return\n   differences=_count_diff_hashable(first_seq,second_seq)\n   \n  if differences:\n   standardMsg='Element counts were not equal:\\n'\n   lines=['First has %d, Second has %d:  %r'%diff for diff in differences]\n   diffMsg='\\n'. join(lines)\n   standardMsg=self. _truncateMessage(standardMsg,diffMsg)\n   msg=self. _formatMessage(msg,standardMsg)\n   self. fail(msg)\n   \n def assertMultiLineEqual(self,first,second,msg=None ):\n  ''\n  self. assertIsInstance(first,str,'First argument is not a string')\n  self. assertIsInstance(second,str,'Second argument is not a string')\n  \n  if first !=second:\n  \n   if (len(first)>self. _diffThreshold or\n   len(second)>self. _diffThreshold):\n    self. _baseAssertEqual(first,second,msg)\n   firstlines=first. splitlines(keepends=True )\n   secondlines=second. splitlines(keepends=True )\n   if len(firstlines)==1 and first. strip('\\r\\n')==first:\n    firstlines=[first+'\\n']\n    secondlines=[second+'\\n']\n   standardMsg='%s != %s'%(safe_repr(first,True ),\n   safe_repr(second,True ))\n   diff='\\n'+''. join(difflib. ndiff(firstlines,secondlines))\n   standardMsg=self. _truncateMessage(standardMsg,diff)\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertLess(self,a,b,msg=None ):\n  ''\n  if not a <b:\n   standardMsg='%s not less than %s'%(safe_repr(a),safe_repr(b))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertLessEqual(self,a,b,msg=None ):\n  ''\n  if not a <=b:\n   standardMsg='%s not less than or equal to %s'%(safe_repr(a),safe_repr(b))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertGreater(self,a,b,msg=None ):\n  ''\n  if not a >b:\n   standardMsg='%s not greater than %s'%(safe_repr(a),safe_repr(b))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertGreaterEqual(self,a,b,msg=None ):\n  ''\n  if not a >=b:\n   standardMsg='%s not greater than or equal to %s'%(safe_repr(a),safe_repr(b))\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertIsNone(self,obj,msg=None ):\n  ''\n  if obj is not None :\n   standardMsg='%s is not None'%(safe_repr(obj),)\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertIsNotNone(self,obj,msg=None ):\n  ''\n  if obj is None :\n   standardMsg='unexpectedly None'\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertIsInstance(self,obj,cls,msg=None ):\n  ''\n  \n  if not isinstance(obj,cls):\n   standardMsg='%s is not an instance of %r'%(safe_repr(obj),cls)\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertNotIsInstance(self,obj,cls,msg=None ):\n  ''\n  if isinstance(obj,cls):\n   standardMsg='%s is an instance of %r'%(safe_repr(obj),cls)\n   self. fail(self. _formatMessage(msg,standardMsg))\n   \n def assertRaisesRegex(self,expected_exception,expected_regex,\n callable_obj=None ,*args,**kwargs):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  context=_AssertRaisesContext(expected_exception,self,callable_obj,\n  expected_regex)\n  \n  return context. handle('assertRaisesRegex',callable_obj,args,kwargs)\n  \n def assertWarnsRegex(self,expected_warning,expected_regex,\n callable_obj=None ,*args,**kwargs):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  context=_AssertWarnsContext(expected_warning,self,callable_obj,\n  expected_regex)\n  return context. handle('assertWarnsRegex',callable_obj,args,kwargs)\n  \n def assertRegex(self,text,expected_regex,msg=None ):\n  ''\n  if isinstance(expected_regex,(str,bytes)):\n   assert expected_regex,\"expected_regex must not be empty.\"\n   expected_regex=re. compile(expected_regex)\n  if not expected_regex. search(text):\n   msg=msg or\"Regex didn't match\"\n   msg='%s: %r not found in %r'%(msg,expected_regex. pattern,text)\n   raise self. failureException(msg)\n   \n def assertNotRegex(self,text,unexpected_regex,msg=None ):\n  ''\n  if isinstance(unexpected_regex,(str,bytes)):\n   unexpected_regex=re. compile(unexpected_regex)\n  match=unexpected_regex. search(text)\n  if match:\n   msg=msg or\"Regex matched\"\n   msg='%s: %r matches %r in %r'%(msg,\n   text[match. start():match. end()],\n   unexpected_regex. pattern,\n   text)\n   raise self. failureException(msg)\n   \n   \n def _deprecate(original_func):\n  def deprecated_func(*args,**kwargs):\n   warnings. warn(\n   'Please use {0} instead.'. format(original_func. __name__),\n   DeprecationWarning,2)\n   return original_func(*args,**kwargs)\n  return deprecated_func\n  \n  \n failUnlessEqual=assertEquals=_deprecate(assertEqual)\n failIfEqual=assertNotEquals=_deprecate(assertNotEqual)\n failUnlessAlmostEqual=assertAlmostEquals=_deprecate(assertAlmostEqual)\n failIfAlmostEqual=assertNotAlmostEquals=_deprecate(assertNotAlmostEqual)\n failUnless=assert_=_deprecate(assertTrue)\n failUnlessRaises=_deprecate(assertRaises)\n failIf=_deprecate(assertFalse)\n assertRaisesRegexp=_deprecate(assertRaisesRegex)\n assertRegexpMatches=_deprecate(assertRegex)\n \n \n \nclass FunctionTestCase(TestCase):\n ''\n\n\n\n\n\n \n \n def __init__(self,testFunc,setUp=None ,tearDown=None ,description=None ):\n  super(FunctionTestCase,self). __init__()\n  self. _setUpFunc=setUp\n  self. _tearDownFunc=tearDown\n  self. _testFunc=testFunc\n  self. _description=description\n  \n def setUp(self):\n  if self. _setUpFunc is not None :\n   self. _setUpFunc()\n   \n def tearDown(self):\n  if self. _tearDownFunc is not None :\n   self. _tearDownFunc()\n   \n def runTest(self):\n  self. _testFunc()\n  \n def id(self):\n  return self. _testFunc. __name__\n  \n def __eq__(self,other):\n  if not isinstance(other,self. __class__):\n   return NotImplemented\n   \n  return self. _setUpFunc ==other. _setUpFunc and  self. _tearDownFunc ==other. _tearDownFunc and  self. _testFunc ==other. _testFunc and  self. _description ==other. _description\n  \n def __ne__(self,other):\n  return not self ==other\n  \n def __hash__(self):\n  return hash((type(self),self. _setUpFunc,self. _tearDownFunc,\n  self. _testFunc,self. _description))\n  \n def __str__(self):\n  return\"%s (%s)\"%(strclass(self. __class__),\n  self. _testFunc. __name__)\n  \n def __repr__(self):\n  return\"<%s tec=%s>\"%(strclass(self. __class__),\n  self. _testFunc)\n  \n def shortDescription(self):\n  if self. _description is not None :\n   return self. _description\n  doc=self. _testFunc. __doc__\n  return doc and doc. split(\"\\n\")[0]. strip()or None\n", ["collections", "difflib", "functools", "pprint", "re", "sys", "unittest", "unittest.result", "unittest.util", "warnings"]], "math": [".js", "var $module = (function($B){\n\nvar _b_ = $B.builtins\nvar $s = []\nfor(var $b in _b_){$s.push('var ' + $b +' = _b_[\"'+$b+'\"]')}\neval($s.join(';'))\n\n//for(var $py_builtin in _b_){eval(\"var \"+$py_builtin+\"=_b_[$py_builtin]\")}\n\nvar float_check = function(x) {\n    if(x.__class__ === $B.long_int){return parseInt(x.value)}\n    return _b_.float.$factory(x)\n}\n\nvar isWholeNumber = function(x){return (x * 10) % 10 == 0}\n\nvar isOdd = function(x) {return isWholeNumber(x) && 2 * Math.floor(x / 2) != x}\n\nvar isLargeNumber = function(x) {return x > Math.pow(2, 32)}\n\n// Big number Library from jsfromhell.com\n// This library helps with producing \"correct\" results from\n// mathematic operations\n\n//+ Jonas Raoni Soares Silva\n//@ http://jsfromhell.com/classes/bignumber [rev. #4]\n\n\nvar BigNumber = function(n, p, r){\n    var o = this, i\n    if(n instanceof BigNumber){\n        for(i in {precision: 0, roundType: 0, _s: 0, _f: 0}){o[i] = n[i]}\n        o._d = n._d.slice()\n        return\n    }\n    o.precision = isNaN(p = Math.abs(p)) ? BigNumber.defaultPrecision : p\n    o.roundType = isNaN(r = Math.abs(r)) ? BigNumber.defaultRoundType : r\n    o._s = (n += \"\").charAt(0) == \"-\"\n    o._f = ((n = n.replace(/[^\\d.]/g, \"\").split(\".\", 2))[0] =\n        n[0].replace(/^0+/, \"\") || \"0\").length\n    for(i = (n = o._d = (n.join(\"\") || \"0\").split(\"\")).length; i;\n        n[--i] = +n[i]){}\n    o.round()\n}\nwith({$: BigNumber, o: BigNumber.prototype}){\n    $.ROUND_HALF_EVEN = ($.ROUND_HALF_DOWN = ($.ROUND_HALF_UP =\n        ($.ROUND_FLOOR = ($.ROUND_CEIL = ($.ROUND_DOWN = ($.ROUND_UP = 0) + 1) +\n            1) + 1) + 1) + 1) + 1\n    $.defaultPrecision = 40\n    $.defaultRoundType = $.ROUND_HALF_UP\n    o.add = function(n){\n        if(this._s != (n = new BigNumber(n))._s){\n            return n._s ^= 1, this.subtract(n)\n        }\n        var o = new BigNumber(this),\n            a = o._d,\n            b = n._d,\n            la = o._f,\n            lb = n._f,\n            n = Math.max(la, lb),\n            i,\n            r\n        la != lb && ((lb = la - lb) > 0 ? o._zeroes(b, lb, 1) :\n            o._zeroes(a, -lb, 1))\n        i = (la = a.length) == (lb = b.length) ? a.length :\n            ((lb = la - lb) > 0 ? o._zeroes(b, lb) : o._zeroes(a, -lb)).length\n        for(r = 0; i; r = (a[--i] = a[i] + b[i] + r) / 10 >>> 0, a[i] %= 10){}\n        return r && ++n && a.unshift(r), o._f = n, o.round()\n    };\n    o.subtract = function(n){\n        if(this._s != (n = new BigNumber(n))._s)\n            return n._s ^= 1, this.add(n);\n        var o = new BigNumber(this),\n            c = o.abs().compare(n.abs()) + 1,\n            a = c ? o : n,\n            b = c ? n : o,\n            la = a._f,\n            lb = b._f,\n            d = la,\n            i,\n            j;\n        a = a._d, b = b._d, la != lb && ((lb = la - lb) > 0 ? o._zeroes(b, lb, 1) : o._zeroes(a, -lb, 1));\n        for(i = (la = a.length) == (lb = b.length) ? a.length : ((lb = la - lb) > 0 ? o._zeroes(b, lb) : o._zeroes(a, -lb)).length; i;){\n            if(a[--i] < b[i]){\n                for(j = i; j && !a[--j]; a[j] = 9);\n                --a[j], a[i] += 10;\n            }\n            b[i] = a[i] - b[i];\n        }\n        return c || (o._s ^= 1), o._f = d, o._d = b, o.round();\n    };\n    o.multiply = function(n){\n        var o = new BigNumber(this), r = o._d.length >= (n = new BigNumber(n))._d.length, a = (r ? o : n)._d,\n        b = (r ? n : o)._d, la = a.length, lb = b.length, x = new BigNumber, i, j, s;\n        for(i = lb; i; r && s.unshift(r), x.set(x.add(new BigNumber(s.join(\"\")))))\n            for(s = (new Array(lb - --i)).join(\"0\").split(\"\"), r = 0, j = la; j; r += a[--j] * b[i], s.unshift(r % 10), r = (r / 10) >>> 0);\n        return o._s = o._s != n._s, o._f = ((r = la + lb - o._f - n._f) >= (j = (o._d = x._d).length) ? this._zeroes(o._d, r - j + 1, 1).length : j) - r, o.round();\n    };\n    o.divide = function(n){\n        if((n = new BigNumber(n)) == \"0\")\n            throw new Error(\"Division by 0\");\n        else if(this == \"0\")\n            return new BigNumber;\n        var o = new BigNumber(this), a = o._d, b = n._d, la = a.length - o._f,\n        lb = b.length - n._f, r = new BigNumber, i = 0, j, s, l, f = 1, c = 0, e = 0;\n        r._s = o._s != n._s, r.precision = Math.max(o.precision, n.precision),\n        r._f = +r._d.pop(), la != lb && o._zeroes(la > lb ? b : a, Math.abs(la - lb));\n        n._f = b.length, b = n, b._s = false, b = b.round();\n        for(n = new BigNumber; a[0] == \"0\"; a.shift());\n        out:\n        do{\n            for(l = c = 0, n == \"0\" && (n._d = [], n._f = 0); i < a.length && n.compare(b) == -1; ++i){\n                (l = i + 1 == a.length, (!f && ++c > 1 || (e = l && n == \"0\" && a[i] == \"0\")))\n                && (r._f == r._d.length && ++r._f, r._d.push(0));\n                (a[i] == \"0\" && n == \"0\") || (n._d.push(a[i]), ++n._f);\n                if(e)\n                    break out;\n                if((l && n.compare(b) == -1 && (r._f == r._d.length && ++r._f, 1)) || (l = 0))\n                    while(r._d.push(0), n._d.push(0), ++n._f, n.compare(b) == -1);\n            }\n            if(f = 0, n.compare(b) == -1 && !(l = 0))\n                while(l ? r._d.push(0) : l = 1, n._d.push(0), ++n._f, n.compare(b) == -1);\n            for(s = new BigNumber, j = 0; n.compare(y = s.add(b)) + 1 && ++j; s.set(y));\n            n.set(n.subtract(s)), !l && r._f == r._d.length && ++r._f, r._d.push(j);\n        }\n        while((i < a.length || n != \"0\") && (r._d.length - r._f) <= r.precision);\n        return r.round();\n    };\n    o.mod = function(n){\n        return this.subtract(this.divide(n).intPart().multiply(n));\n    };\n    o.pow = function(n){\n        var o = new BigNumber(this), i;\n        if((n = (new BigNumber(n)).intPart()) == 0) return o.set(1);\n        for(i = Math.abs(n); --i; o.set(o.multiply(this)));\n        return n < 0 ? o.set((new BigNumber(1)).divide(o)) : o;\n    };\n    o.set = function(n){\n        return this.constructor(n), this;\n    };\n    o.compare = function(n){\n        var a = this, la = this._f, b = new BigNumber(n), lb = b._f, r = [-1, 1], i, l;\n        if(a._s != b._s)\n            return a._s ? -1 : 1;\n        if(la != lb)\n            return r[(la > lb) ^ a._s];\n        for(la = (a = a._d).length, lb = (b = b._d).length, i = -1, l = Math.min(la, lb); ++i < l;)\n            if(a[i] != b[i])\n                return r[(a[i] > b[i]) ^ a._s];\n        return la != lb ? r[(la > lb) ^ a._s] : 0;\n    };\n    o.negate = function(){\n        var n = new BigNumber(this); return n._s ^= 1, n;\n    };\n    o.abs = function(){\n        var n = new BigNumber(this); return n._s = 0, n;\n    };\n    o.intPart = function(){\n        return new BigNumber((this._s ? \"-\" : \"\") + (this._d.slice(0, this._f).join(\"\") || \"0\"));\n    };\n    o.valueOf = o.toString = function(){\n        var o = this;\n        return (o._s ? \"-\" : \"\") + (o._d.slice(0, o._f).join(\"\") || \"0\") + (o._f != o._d.length ? \".\" + o._d.slice(o._f).join(\"\") : \"\");\n    };\n    o._zeroes = function(n, l, t){\n        var s = [\"push\", \"unshift\"][t || 0];\n        for(++l; --l;  n[s](0));\n        return n;\n    };\n    o.round = function(){\n        if(\"_rounding\" in this) return this;\n        var $ = BigNumber, r = this.roundType, b = this._d, d, p, n, x;\n        for(this._rounding = true; this._f > 1 && !b[0]; --this._f, b.shift());\n        for(d = this._f, p = this.precision + d, n = b[p]; b.length > d && !b[b.length -1]; b.pop());\n        x = (this._s ? \"-\" : \"\") + (p - d ? \"0.\" + this._zeroes([], p - d - 1).join(\"\") : \"\") + 1;\n        if(b.length > p){\n            n && (r == $.DOWN ? false : r == $.UP ? true : r == $.CEIL ? !this._s\n            : r == $.FLOOR ? this._s : r == $.HALF_UP ? n >= 5 : r == $.HALF_DOWN ? n > 5\n            : r == $.HALF_EVEN ? n >= 5 && b[p - 1] & 1 : false) && this.add(x);\n            b.splice(p, b.length - p);\n        }\n        return delete this._rounding, this;\n    };\n}\n\nvar isNegZero = function(x) {return x === 0 && Math.atan2(x,x) < 0}\n\nvar _mod = {\n    __getattr__ : function(attr){\n        var res = this[attr]\n        if(res === undefined){$raise('AttributeError',\n            'module math has no attribute ' + attr)}\n        return res\n    },\n    acos: function(x) {return float.$factory(Math.acos(float_check(x)))},\n    acosh: function(x) {\n        if(_b_.$isinf(x)){return float.$factory('inf')}\n        var y = float_check(x)\n        return float.$factory(Math.log(y + Math.sqrt(y * y - 1)))\n    },\n    asin: function(x) {return float.$factory(Math.asin(float_check(x)))},\n    asinh: function(x) {\n        if(_b_.$isninf(x)){return float.$factory('-inf')}\n        if(_b_.$isinf(x)){return float.$factory('inf')}\n        var y = float_check(x)\n        return float.$factory(Math.log(y + Math.sqrt(y * y + 1)))\n    },\n    atan: function(x) {\n        if(_b_.$isninf(x)){return float.$factory(-Math.PI / 2)}\n        if(_b_.$isinf(x)){return float.$factory(Math.PI / 2)}\n        return float.$factory(Math.atan(float_check(x)))},\n    atan2: function(y, x) {\n        return float.$factory(Math.atan2(float_check(y), float_check(x)))\n    },\n    atanh: function(x) {\n       var y = float_check(x)\n       if(y == 0){return 0}\n       return float.$factory(0.5 * Math.log((1 / y + 1)/(1 / y - 1)));\n    },\n    ceil: function(x) {\n       try{return getattr(x, '__ceil__')()}catch(err){}\n\n       if(_b_.$isninf(x)){return float.$factory('-inf')}\n       if(_b_.$isinf(x)){return float.$factory('inf')}\n       if(isNaN(x)){return float.$factory('nan')}\n\n       var y = float_check(x)\n       if(! isNaN(parseFloat(y)) && isFinite(y)){\n           return int.$factory(Math.ceil(y))\n       }\n\n       $raise('ValueError',\n           'object is not a number and does not contain __ceil__')\n    },\n    copysign: function(x,y) {\n        var x1 = Math.abs(float_check(x))\n        var y1 = float_check(y)\n        var sign = y1 ? y1 < 0 ? -1 : 1 : 1\n        if(isNegZero(y1)){sign = -1}   // probably need to work on adding a check for -0\n        return float.$factory(x1 * sign)\n    },\n    cos : function(x){return float.$factory(Math.cos(float_check(x)))},\n    cosh: function(x){\n        if(_b_.$isinf(x)) {return float.$factory('inf')}\n        var y = float_check(x)\n        if(Math.cosh !== undefined){return float.$factory(Math.cosh(y))}\n        return float.$factory((Math.pow(Math.E, y) + Math.pow(Math.E, -y)) / 2)\n    },\n    degrees: function(x){return float.$factory(float_check(x) * 180 / Math.PI)},\n    e: float.$factory(Math.E),\n    erf: function(x) {\n        // inspired from\n        // http://stackoverflow.com/questions/457408/is-there-an-easily-available-implementation-of-erf-for-python\n        var y = float_check(x)\n        var t = 1.0 / (1.0 + 0.5 * Math.abs(y))\n        var ans = 1 - t * Math.exp( -y * y - 1.26551223 +\n                     t * ( 1.00002368 +\n                     t * ( 0.37409196 +\n                     t * ( 0.09678418 +\n                     t * (-0.18628806 +\n                     t * ( 0.27886807 +\n                     t * (-1.13520398 +\n                     t * ( 1.48851587 +\n                     t * (-0.82215223 +\n                     t * 0.17087277)))))))))\n        if(y >= 0.0){return ans}\n        return -ans\n    },\n\n    erfc: function(x) {\n        // inspired from\n        // http://stackoverflow.com/questions/457408/is-there-an-easily-available-implementation-of-erf-for-python\n        var y = float_check(x)\n        var t = 1.0 / (1.0 + 0.5 * Math.abs(y))\n        var ans = 1 - t * Math.exp( -y * y - 1.26551223 +\n                     t * ( 1.00002368 +\n                     t * ( 0.37409196 +\n                     t * ( 0.09678418 +\n                     t * (-0.18628806 +\n                     t * ( 0.27886807 +\n                     t * (-1.13520398 +\n                     t * ( 1.48851587 +\n                     t * (-0.82215223 +\n                     t * 0.17087277)))))))))\n        if(y >= 0.0){return 1 - ans}\n        return 1 + ans\n    },\n    exp: function(x){\n         if(_b_.$isninf(x)){return float.$factory(0)}\n         if(_b_.$isinf(x)){return float.$factory('inf')}\n         var _r = Math.exp(float_check(x))\n         if(_b_.$isinf(_r)){throw OverflowError(\"math range error\")}\n         return float.$factory(_r)\n    },\n    expm1: function(x){return float.$factory(Math.exp(float_check(x)) - 1)},\n    //fabs: function(x){ return x>0?float.$factory(x):float.$factory(-x)},\n    fabs: function(x){return _b_.$fabs(x)}, //located in py_float.js\n    factorial: function(x) {\n         //using code from http://stackoverflow.com/questions/3959211/fast-factorial-function-in-javascript\n         var y = float_check(x),\n             r = 1\n         for(var i = 2; i <= y; i++){r *= i}\n         return r\n    },\n    floor: function(x){return Math.floor(float_check(x))},\n    fmod: function(x,y){return float.$factory(float_check(x) % float_check(y))},\n    frexp: function(x){\n        var _l = _b_.$frexp(x)\n        return _b_.tuple.$factory([float.$factory(_l[0]), _l[1]])\n    },\n    fsum: function(x){\n        /* Translation into Javascript of the function msum in an Active\n           State Cookbook recipe : https://code.activestate.com/recipes/393090/\n           by Raymond Hettinger\n        */\n        var partials = [],\n            res = new Number(),\n            _it = _b_.iter(x)\n        while(true){\n            try{\n                var x = _b_.next(_it),\n                    i = 0\n                for(var j = 0, len = partials.length; j < len; j++){\n                    var y = partials[j]\n                    if(Math.abs(x) < Math.abs(y)){\n                        var z = x\n                        x = y\n                        y = z\n                    }\n                    var hi = x + y,\n                        lo = y - (hi - x)\n                    if(lo){\n                        partials[i] = lo\n                        i++\n                    }\n                    x = hi\n                }\n                partials = partials.slice(0, i).concat([x])\n            }catch(err){\n                if(_b_.isinstance(err, _b_.StopIteration)){break}\n                throw err\n            }\n        }\n        var res = new Number(0)\n        for(var i = 0; i < partials.length; i++){\n            res += new Number(partials[i])\n        }\n        return new Number(res)\n    },\n    gamma: function(x){\n         //using code from http://stackoverflow.com/questions/3959211/fast-factorial-function-in-javascript\n         // Lanczos Approximation of the Gamma Function\n         // As described in Numerical Recipes in C (2nd ed. Cambridge University Press, 1992)\n         var y = float_check(x)\n         var z = y + 1\n         var d1 = Math.sqrt(2 * Math.PI) / z\n\n         var d2 = 1.000000000190015;\n         d2 +=  76.18009172947146 / (z + 1)\n         d2 += -86.50532032941677 / (z + 2)\n         d2 +=  24.01409824083091 / (z + 3)\n         d2 += -1.231739572450155 / (z + 4)\n         d2 +=  1.208650973866179E-3 / (z + 5)\n         d2 += -5.395239384953E-6 / (z + 6)\n\n         return d1 * d2 * Math.pow(z + 5.5, z + 0.5) * Math.exp(-(z + 5.5))\n    },\n    hypot: function(x,y){\n       if(_b_.$isinf(x) || _b_.$isinf(y)){return float.$factory('inf')}\n       var x1 = float_check(x),\n           y1 = float_check(y)\n       return float.$factory(Math.sqrt(x1 * x1 + y1 * y1))},\n    inf: float.$factory('inf'),\n    isclose:function(){\n        var $ns = $B.args(\"isclose\",\n                          4,\n                          {a: null, b: null, rel_tol: null, abs_tol: null},\n                          ['a', 'b', 'rel_tol', 'abs_tol'],\n                          arguments,\n                          {rel_tol: 1e-09, abs_tol: 0.0},\n                          null,\n                          null)\n        var a = $ns['a'],\n            b = $ns['b'],\n            rel_tol = $ns['rel_tol'],\n            abs_tol = $ns['abs_tol']\n        if(rel_tol < 0.0 || abs_tol < 0.0){\n            throw ValueError('tolerances must be non-negative')\n        }\n        if(a == b){return True}\n        if(_b_.$isinf(a) || _b_.$isinf(b)){return false}\n        var diff = _b_.$fabs(b - a)\n        var result = (\n            (diff <= _b_.$fabs(rel_tol * b)) ||\n                (diff <= _b_.$fabs(rel_tol * a))\n            ) || (diff <= _b_.$fabs(abs_tol)\n        )\n        return result\n    },\n    isfinite: function(x){return isFinite(float_check(x))},\n    isinf: function(x){return _b_.$isinf(float_check(x))},\n    isnan: function(x){return isNaN(float_check(x))},\n    ldexp: function(x, i){return _b_.$ldexp(x, i)},   //located in py_float.js\n    lgamma: function(x){\n         // see gamma function for sources\n         var y = float_check(x),\n             z = y + 1,\n             d1 = Math.sqrt(2 * Math.PI) / z\n\n         var d2 = 1.000000000190015\n         d2 +=  76.18009172947146 / (z + 1)\n         d2 += -86.50532032941677 / (z + 2)\n         d2 +=  24.01409824083091 / (z + 3)\n         d2 += -1.231739572450155 / (z + 4)\n         d2 +=  1.208650973866179E-3 / (z + 5)\n         d2 += -5.395239384953E-6 / (z + 6)\n\n         return float.$factory(Math.log(Math.abs(d1 * d2 *\n             Math.pow(z + 5.5, z + 0.5) * Math.exp(-(z + 5.5)))))\n    },\n    log: function(x, base){\n         var x1 = float_check(x)\n         if(base === undefined){return float.$factory(Math.log(x1))}\n         return float.$factory(Math.log(x1) / Math.log(float_check(base)))\n    },\n    log1p: function(x){return float.$factory(Math.log(1.0 + float_check(x)))},\n    log2: function(x){\n        if(isNaN(x)){return float.$factory('nan')}\n        if(_b_.$isninf(x)) {throw ValueError('')}\n        var x1 = float_check(x)\n        if(x1 < 0.0){throw ValueError('')}\n        return float.$factory(Math.log(x1) / Math.LN2)\n    },\n    log10: function(x) {\n        return float.$factory(Math.log(float_check(x)) / Math.LN10)\n    },\n    modf: function(x) {\n       if(_b_.$isninf(x)){\n           return _b_.tuple.$factory([0.0, float.$factory('-inf')])\n       }\n       if(_b_.$isinf(x)){\n           return _b_.tuple.$factory([0.0, float.$factory('inf')])\n       }\n       if(isNaN(x)){\n           return _b_.tuple.$factory([float.$factory('nan'), \n               float.$factory('nan')])\n       }\n\n       var x1 = float_check(x)\n       if(x1 > 0){\n          var i = float.$factory(x1 - Math.floor(x1))\n          return _b_.tuple.$factory([i, float.$factory(x1 - i)])\n       }\n\n       var x2 = Math.ceil(x1)\n       var i = float.$factory(x1 - x2)\n       return _b_.tuple.$factory([i, float.$factory(x2)])\n    },\n    nan: float.$factory('nan'),\n    pi : float.$factory(Math.PI),\n    pow: function(x,y) {\n        var x1 = float_check(x)\n        var y1 = float_check(y)\n        if(y1 == 0){return float.$factory(1)}\n        if(x1 == 0 && y1 < 0){throw _b_.ValueError('')}\n\n        if(isNaN(y1)){\n            if(x1 == 1){return float.$factory(1)}\n            return float.$factory('nan')\n        }\n        if(x1 == 0){return float.$factory(0)}\n\n        if(_b_.$isninf(y)){\n            if(x1 == 1 || x1 == -1){return float.$factory(1)}\n            if(x1 < 1 && x1 > -1){return float.$factory('inf')}\n            return float.$factory(0)\n        }\n        if(_b_.$isinf(y)){\n            if(x1 == 1 || x1 == -1){return float.$factory(1)}\n            if(x1 < 1 && x1 > -1){return float.$factory(0)}\n            return float.$factory('inf')\n        }\n\n        if(isNaN(x1)){return float.$factory('nan')}\n        if(_b_.$isninf(x)){\n            if(y1 > 0 && isOdd(y1)){return float.$factory('-inf')}\n            if(y1 > 0){return float.$factory('inf')}  // this is even or a float\n            if(y1 < 0){return float.$factory(0)}\n            return float.$factory(1)\n        }\n\n        if(_b_.$isinf(x)){\n            if(y1 > 0){return float.$factory('inf')}\n            if(y1 < 0){return float.$factory(0)}\n            return float.$factory(1)\n        }\n\n        var r\n        if(isLargeNumber(x1) || isLargeNumber(y1)){\n           var x = new BigNumber(x1),\n               y = new BigNumber(y1)\n           r = x.pow(y)\n        }else{\n           r = Math.pow(x1,y1)\n        }\n\n        if(isNaN(r)){return float.$factory('nan')}\n        if(_b_.$isninf(r)){return float.$factory('-inf')}\n        if(_b_.$isinf(r)){return float.$factory('inf')}\n\n        return r\n    },\n    radians: function(x){\n        return float.$factory(float_check(x) * Math.PI / 180)\n    },\n    sin : function(x){return float.$factory(Math.sin(float_check(x)))},\n    sinh: function(x) {\n        //if (_b_.$isinf(x)) return float.$factory('inf');\n        var y = float_check(x)\n        if(Math.sinh !== undefined){return float.$factory(Math.sinh(y))}\n        return float.$factory(\n            (Math.pow(Math.E, y) - Math.pow(Math.E, -y)) / 2)\n    },\n    sqrt : function(x){\n      var y = float_check(x)\n      if(y < 0){throw ValueError(\"math range error\")}\n      if(_b_.$isinf(y)){return float.$factory('inf')}\n      var _r = Math.sqrt(y)\n      if(_b_.$isinf(_r)){throw OverflowError(\"math range error\")}\n      return float.$factory(_r)\n    },\n    tan: function(x) {\n        var y = float_check(x)\n        return float.$factory(Math.tan(y))\n    },\n    tanh: function(x) {\n        var y = float_check(x)\n        if(Math.tanh !== undefined){return float.$factory(Math.tanh(y))}\n        return float.$factory((Math.pow(Math.E, y) - Math.pow(Math.E, -y))/\n             (Math.pow(Math.E, y) + Math.pow(Math.E, -y)))\n    },\n    trunc: function(x) {\n       try{return getattr(x, '__trunc__')()}catch(err){}\n       var x1 = float_check(x)\n       if(!isNaN(parseFloat(x1)) && isFinite(x1)){\n          if(Math.trunc !== undefined){return int.$factory(Math.trunc(x1))}\n          if(x1 > 0){return int.$factory(Math.floor(x1))}\n          return int.$factory(Math.ceil(x1))  // x1 < 0\n       }\n       $raise('ValueError',\n           'object is not a number and does not contain __trunc__')\n    }\n}\n\nfor(var $attr in _mod){\n    if(typeof _mod[$attr] === 'function'){\n        _mod[$attr].__repr__ = (function(func){\n            return function(){return '<built-in function ' + func + '>'}\n        })($attr)\n        _mod[$attr].__str__ = (function(func){\n            return function(){return '<built-in function ' + func + '>'}\n        })($attr)\n    }\n}\n\nreturn _mod\n\n})(__BRYTHON__)\n"], "inspect": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__author__=('Ka-Ping Yee <ping@lfw.org>',\n'Yury Selivanov <yselivanov@sprymix.com>')\n\nimport imp\nimport importlib. machinery\nimport itertools\nimport linecache\nimport os\nimport re\nimport sys\nimport tokenize\nimport types\nimport warnings\nimport functools\nimport builtins\nfrom operator import attrgetter\nfrom collections import namedtuple,OrderedDict\n\n\n\n\ntry :\n from dis import COMPILER_FLAG_NAMES as _flag_names\nexcept ImportError:\n CO_OPTIMIZED,CO_NEWLOCALS=0x1,0x2\n CO_VARARGS,CO_VARKEYWORDS=0x4,0x8\n CO_NESTED,CO_GENERATOR,CO_NOFREE=0x10,0x20,0x40\nelse :\n mod_dict=globals()\n for k,v in _flag_names. items():\n  mod_dict[\"CO_\"+v]=k\n  \n  \nTPFLAGS_IS_ABSTRACT=1 <<20\n\n\ndef ismodule(object):\n ''\n\n\n\n\n \n return isinstance(object,types. ModuleType)\n \ndef isclass(object):\n ''\n\n\n\n \n return isinstance(object,type)\n \ndef ismethod(object):\n ''\n\n\n\n\n\n \n return isinstance(object,types. MethodType)\n \ndef ismethoddescriptor(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n \n if isclass(object)or ismethod(object)or isfunction(object):\n \n  return False\n tp=type(object)\n return hasattr(tp,\"__get__\")and not hasattr(tp,\"__set__\")\n \ndef isdatadescriptor(object):\n ''\n\n\n\n\n\n \n if isclass(object)or ismethod(object)or isfunction(object):\n \n  return False\n tp=type(object)\n return hasattr(tp,\"__set__\")and hasattr(tp,\"__get__\")\n \nif hasattr(types,'MemberDescriptorType'):\n\n def ismemberdescriptor(object):\n  ''\n\n\n  \n  return isinstance(object,types. MemberDescriptorType)\nelse :\n\n def ismemberdescriptor(object):\n  ''\n\n\n  \n  return False\n  \nif hasattr(types,'GetSetDescriptorType'):\n\n def isgetsetdescriptor(object):\n  ''\n\n\n  \n  return isinstance(object,types. GetSetDescriptorType)\nelse :\n\n def isgetsetdescriptor(object):\n  ''\n\n\n  \n  return False\n  \ndef isfunction(object):\n ''\n\n\n\n\n\n\n\n\n \n return isinstance(object,types. FunctionType)\n \ndef isgeneratorfunction(object):\n ''\n\n\n\n \n return bool((isfunction(object)or ismethod(object))and\n object. __code__. co_flags&CO_GENERATOR)\n \ndef isgenerator(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n return isinstance(object,types. GeneratorType)\n \ndef istraceback(object):\n ''\n\n\n\n\n\n \n return isinstance(object,types. TracebackType)\n \ndef isframe(object):\n ''\n\n\n\n\n\n\n\n\n\n \n return isinstance(object,types. FrameType)\n \ndef iscode(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n return isinstance(object,types. CodeType)\n \ndef isbuiltin(object):\n ''\n\n\n\n\n \n return isinstance(object,types. BuiltinFunctionType)\n \ndef isroutine(object):\n ''\n return (isbuiltin(object)\n or isfunction(object)\n or ismethod(object)\n or ismethoddescriptor(object))\n \ndef isabstract(object):\n ''\n return bool(isinstance(object,type)and object. __flags__&TPFLAGS_IS_ABSTRACT)\n \ndef getmembers(object,predicate=None ):\n ''\n \n if isclass(object):\n  mro=(object,)+getmro(object)\n else :\n  mro=()\n results=[]\n for key in dir(object):\n \n \n  for base in mro:\n   if key in base. __dict__:\n    value=base. __dict__[key]\n    break\n  else :\n   try :\n    value=getattr(object,key)\n   except AttributeError:\n    continue\n  if not predicate or predicate(value):\n   results. append((key,value))\n results. sort()\n return results\n \nAttribute=namedtuple('Attribute','name kind defining_class object')\n\ndef classify_class_attrs(cls):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n mro=getmro(cls)\n names=dir(cls)\n result=[]\n for name in names:\n \n \n \n \n \n \n  homecls=None\n  for base in (cls,)+mro:\n   if name in base. __dict__:\n    obj=base. __dict__[name]\n    homecls=base\n    break\n  else :\n   obj=getattr(cls,name)\n   homecls=getattr(obj,\"__objclass__\",homecls)\n   \n   \n  if isinstance(obj,staticmethod):\n   kind=\"static method\"\n  elif isinstance(obj,classmethod):\n   kind=\"class method\"\n  elif isinstance(obj,property):\n   kind=\"property\"\n  elif ismethoddescriptor(obj):\n   kind=\"method\"\n  elif isdatadescriptor(obj):\n   kind=\"data\"\n  else :\n   obj_via_getattr=getattr(cls,name)\n   if (isfunction(obj_via_getattr)or\n   ismethoddescriptor(obj_via_getattr)):\n    kind=\"method\"\n   else :\n    kind=\"data\"\n   obj=obj_via_getattr\n   \n  result. append(Attribute(name,kind,homecls,obj))\n  \n return result\n \n \n \ndef getmro(cls):\n ''\n return cls. __mro__\n \n \ndef indentsize(line):\n ''\n expline=line. expandtabs()\n return len(expline)-len(expline. lstrip())\n \ndef getdoc(object):\n ''\n\n\n\n \n try :\n  doc=object. __doc__\n except AttributeError:\n  return None\n if not isinstance(doc,str):\n  return None\n return cleandoc(doc)\n \ndef cleandoc(doc):\n ''\n\n\n \n try :\n  lines=doc. expandtabs(). split('\\n')\n except UnicodeError:\n  return None\n else :\n \n  margin=sys. maxsize\n  for line in lines[1:]:\n   content=len(line. lstrip())\n   if content:\n    indent=len(line)-content\n    margin=min(margin,indent)\n    \n  if lines:\n   lines[0]=lines[0]. lstrip()\n  if margin <sys. maxsize:\n   for i in range(1,len(lines)):lines[i]=lines[i][margin:]\n   \n  while lines and not lines[-1]:\n   lines. pop()\n  while lines and not lines[0]:\n   lines. pop(0)\n  return'\\n'. join(lines)\n  \ndef getfile(object):\n ''\n if ismodule(object):\n  if hasattr(object,'__file__'):\n   return object. __file__\n  raise TypeError('{!r} is a built-in module'. format(object))\n if isclass(object):\n  object=sys. modules. get(object. __module__)\n  if hasattr(object,'__file__'):\n   return object. __file__\n  raise TypeError('{!r} is a built-in class'. format(object))\n if ismethod(object):\n  object=object. __func__\n if isfunction(object):\n  object=object. __code__\n if istraceback(object):\n  object=object. tb_frame\n if isframe(object):\n  object=object. f_code\n if iscode(object):\n  return object. co_filename\n raise TypeError('{!r} is not a module, class, method, '\n 'function, traceback, frame, or code object'. format(object))\n \nModuleInfo=namedtuple('ModuleInfo','name suffix mode module_type')\n\ndef getmoduleinfo(path):\n ''\n warnings. warn('inspect.getmoduleinfo() is deprecated',DeprecationWarning,\n 2)\n filename=os. path. basename(path)\n suffixes=[(-len(suffix),suffix,mode,mtype)\n for suffix,mode,mtype in imp. get_suffixes()]\n suffixes. sort()\n for neglen,suffix,mode,mtype in suffixes:\n  if filename[neglen:]==suffix:\n   return ModuleInfo(filename[:neglen],suffix,mode,mtype)\n   \ndef getmodulename(path):\n ''\n fname=os. path. basename(path)\n \n suffixes=[(-len(suffix),suffix)\n for suffix in importlib. machinery. all_suffixes()]\n suffixes. sort()\n for neglen,suffix in suffixes:\n  if fname. endswith(suffix):\n   return fname[:neglen]\n return None\n \ndef getsourcefile(object):\n ''\n\n \n filename=getfile(object)\n all_bytecode_suffixes=importlib. machinery. DEBUG_BYTECODE_SUFFIXES[:]\n all_bytecode_suffixes +=importlib. machinery. OPTIMIZED_BYTECODE_SUFFIXES[:]\n if any(filename. endswith(s)for s in all_bytecode_suffixes):\n  filename=(os. path. splitext(filename)[0]+\n  importlib. machinery. SOURCE_SUFFIXES[0])\n elif any(filename. endswith(s)for s in\n importlib. machinery. EXTENSION_SUFFIXES):\n  return None\n if os. path. exists(filename):\n  return filename\n  \n if hasattr(getmodule(object,filename),'__loader__'):\n  return filename\n  \n if filename in linecache. cache:\n  return filename\n  \ndef getabsfile(object,_filename=None ):\n ''\n\n\n \n if _filename is None :\n  _filename=getsourcefile(object)or getfile(object)\n return os. path. normcase(os. path. abspath(_filename))\n \nmodulesbyfile={}\n_filesbymodname={}\n\ndef getmodule(object,_filename=None ):\n ''\n if ismodule(object):\n  return object\n if hasattr(object,'__module__'):\n  return sys. modules. get(object. __module__)\n  \n if _filename is not None and _filename in modulesbyfile:\n  return sys. modules. get(modulesbyfile[_filename])\n  \n try :\n  file=getabsfile(object,_filename)\n except TypeError:\n  return None\n if file in modulesbyfile:\n  return sys. modules. get(modulesbyfile[file])\n  \n  \n for modname,module in list(sys. modules. items()):\n  if ismodule(module)and hasattr(module,'__file__'):\n   f=module. __file__\n   if f ==_filesbymodname. get(modname,None ):\n   \n    continue\n   _filesbymodname[modname]=f\n   f=getabsfile(module)\n   \n   modulesbyfile[f]=modulesbyfile[\n   os. path. realpath(f)]=module. __name__\n if file in modulesbyfile:\n  return sys. modules. get(modulesbyfile[file])\n  \n main=sys. modules['__main__']\n if not hasattr(object,'__name__'):\n  return None\n if hasattr(main,object. __name__):\n  mainobject=getattr(main,object. __name__)\n  if mainobject is object:\n   return main\n   \n builtin=sys. modules['builtins']\n if hasattr(builtin,object. __name__):\n  builtinobject=getattr(builtin,object. __name__)\n  if builtinobject is object:\n   return builtin\n   \ndef findsource(object):\n ''\n\n\n\n\n \n \n file=getfile(object)\n sourcefile=getsourcefile(object)\n if not sourcefile and file[:1]+file[-1:]!='<>':\n  raise IOError('source code not available')\n file=sourcefile if sourcefile else file\n \n module=getmodule(object,file)\n if module:\n  lines=linecache. getlines(file,module. __dict__)\n else :\n  lines=linecache. getlines(file)\n if not lines:\n  raise IOError('could not get source code')\n  \n if ismodule(object):\n  return lines,0\n  \n if isclass(object):\n  name=object. __name__\n  pat=re. compile(r'^(\\s*)class\\s*'+name+r'\\b')\n  \n  \n  \n  candidates=[]\n  for i in range(len(lines)):\n   match=pat. match(lines[i])\n   if match:\n   \n    if lines[i][0]=='c':\n     return lines,i\n     \n    candidates. append((match. group(1),i))\n  if candidates:\n  \n  \n   candidates. sort()\n   return lines,candidates[0][1]\n  else :\n   raise IOError('could not find class definition')\n   \n if ismethod(object):\n  object=object. __func__\n if isfunction(object):\n  object=object. __code__\n if istraceback(object):\n  object=object. tb_frame\n if isframe(object):\n  object=object. f_code\n if iscode(object):\n  if not hasattr(object,'co_firstlineno'):\n   raise IOError('could not find function definition')\n  lnum=object. co_firstlineno -1\n  pat=re. compile(r'^(\\s*def\\s)|(.*(?<!\\w)lambda(:|\\s))|^(\\s*@)')\n  while lnum >0:\n   if pat. match(lines[lnum]):break\n   lnum=lnum -1\n  return lines,lnum\n raise IOError('could not find code object')\n \ndef getcomments(object):\n ''\n\n\n \n try :\n  lines,lnum=findsource(object)\n except (IOError,TypeError):\n  return None\n  \n if ismodule(object):\n \n  start=0\n  if lines and lines[0][:2]=='#!':start=1\n  while start <len(lines)and lines[start]. strip()in ('','#'):\n   start=start+1\n  if start <len(lines)and lines[start][:1]=='#':\n   comments=[]\n   end=start\n   while end <len(lines)and lines[end][:1]=='#':\n    comments. append(lines[end]. expandtabs())\n    end=end+1\n   return''. join(comments)\n   \n   \n elif lnum >0:\n  indent=indentsize(lines[lnum])\n  end=lnum -1\n  if end >=0 and lines[end]. lstrip()[:1]=='#'and  indentsize(lines[end])==indent:\n   comments=[lines[end]. expandtabs(). lstrip()]\n   if end >0:\n    end=end -1\n    comment=lines[end]. expandtabs(). lstrip()\n    while comment[:1]=='#'and indentsize(lines[end])==indent:\n     comments[:0]=[comment]\n     end=end -1\n     if end <0:break\n     comment=lines[end]. expandtabs(). lstrip()\n   while comments and comments[0]. strip()=='#':\n    comments[:1]=[]\n   while comments and comments[-1]. strip()=='#':\n    comments[-1:]=[]\n   return''. join(comments)\n   \nclass EndOfBlock(Exception):pass\n\nclass BlockFinder:\n ''\n def __init__(self):\n  self. indent=0\n  self. islambda=False\n  self. started=False\n  self. passline=False\n  self. last=1\n  \n def tokeneater(self,type,token,srowcol,erowcol,line):\n  if not self. started:\n  \n   if token in (\"def\",\"class\",\"lambda\"):\n    if token ==\"lambda\":\n     self. islambda=True\n    self. started=True\n   self. passline=True\n  elif type ==tokenize. NEWLINE:\n   self. passline=False\n   self. last=srowcol[0]\n   if self. islambda:\n    raise EndOfBlock\n  elif self. passline:\n   pass\n  elif type ==tokenize. INDENT:\n   self. indent=self. indent+1\n   self. passline=True\n  elif type ==tokenize. DEDENT:\n   self. indent=self. indent -1\n   \n   \n   \n   if self. indent <=0:\n    raise EndOfBlock\n  elif self. indent ==0 and type not in (tokenize. COMMENT,tokenize. NL):\n  \n  \n   raise EndOfBlock\n   \ndef getblock(lines):\n ''\n blockfinder=BlockFinder()\n try :\n  tokens=tokenize. generate_tokens(iter(lines). __next__)\n  for _token in tokens:\n   blockfinder. tokeneater(*_token)\n except (EndOfBlock,IndentationError):\n  pass\n return lines[:blockfinder. last]\n \ndef getsourcelines(object):\n ''\n\n\n\n\n\n \n lines,lnum=findsource(object)\n \n if ismodule(object):return lines,0\n else :return getblock(lines[lnum:]),lnum+1\n \ndef getsource(object):\n ''\n\n\n\n \n lines,lnum=getsourcelines(object)\n return''. join(lines)\n \n \ndef walktree(classes,children,parent):\n ''\n results=[]\n classes. sort(key=attrgetter('__module__','__name__'))\n for c in classes:\n  results. append((c,c. __bases__))\n  if c in children:\n   results. append(walktree(children[c],children,c))\n return results\n \ndef getclasstree(classes,unique=False ):\n ''\n\n\n\n\n\n\n \n children={}\n roots=[]\n for c in classes:\n  if c. __bases__:\n   for parent in c. __bases__:\n    if not parent in children:\n     children[parent]=[]\n    if c not in children[parent]:\n     children[parent]. append(c)\n    if unique and parent in classes:break\n  elif c not in roots:\n   roots. append(c)\n for parent in children:\n  if parent not in classes:\n   roots. append(parent)\n return walktree(roots,children,None )\n \n \nArguments=namedtuple('Arguments','args, varargs, varkw')\n\ndef getargs(co):\n ''\n\n\n\n\n \n args,varargs,kwonlyargs,varkw=_getfullargs(co)\n return Arguments(args+kwonlyargs,varargs,varkw)\n \ndef _getfullargs(co):\n ''\n\n\n\n \n \n if not iscode(co):\n  raise TypeError('{!r} is not a code object'. format(co))\n  \n nargs=co. co_argcount\n names=co. co_varnames\n nkwargs=co. co_kwonlyargcount\n args=list(names[:nargs])\n kwonlyargs=list(names[nargs:nargs+nkwargs])\n step=0\n \n nargs +=nkwargs\n varargs=None\n if co. co_flags&CO_VARARGS:\n  varargs=co. co_varnames[nargs]\n  nargs=nargs+1\n varkw=None\n if co. co_flags&CO_VARKEYWORDS:\n  varkw=co. co_varnames[nargs]\n return args,varargs,kwonlyargs,varkw\n \n \nArgSpec=namedtuple('ArgSpec','args varargs keywords defaults')\n\ndef getargspec(func):\n ''\n\n\n\n\n\n\n\n\n\n\n \n \n args,varargs,varkw,defaults,kwonlyargs,kwonlydefaults,ann= getfullargspec(func)\n if kwonlyargs or ann:\n  raise ValueError(\"Function has keyword-only arguments or annotations\"\n  \", use getfullargspec() API which can support them\")\n return ArgSpec(args,varargs,varkw,defaults)\n \nFullArgSpec=namedtuple('FullArgSpec',\n'args, varargs, varkw, defaults, kwonlyargs, kwonlydefaults, annotations')\n\ndef getfullargspec(func):\n ''\n\n\n\n\n\n\n\n\n\n\n\n \n \n if ismethod(func):\n  func=func. __func__\n if not isfunction(func):\n  raise TypeError('{!r} is not a Python function'. format(func))\n args,varargs,kwonlyargs,varkw=_getfullargs(func. __code__)\n return FullArgSpec(args,varargs,varkw,func. __defaults__,\n kwonlyargs,func. __kwdefaults__,func. __annotations__)\n \nArgInfo=namedtuple('ArgInfo','args varargs keywords locals')\n\ndef getargvalues(frame):\n ''\n\n\n\n\n \n args,varargs,varkw=getargs(frame. f_code)\n return ArgInfo(args,varargs,varkw,frame. f_locals)\n \ndef formatannotation(annotation,base_module=None ):\n if isinstance(annotation,type):\n  if annotation. __module__ in ('builtins',base_module):\n   return annotation. __name__\n  return annotation. __module__+'.'+annotation. __name__\n return repr(annotation)\n \ndef formatannotationrelativeto(object):\n module=getattr(object,'__module__',None )\n def _formatannotation(annotation):\n  return formatannotation(annotation,module)\n return _formatannotation\n \n \ndef formatargspec(args,varargs=None ,varkw=None ,defaults=None ,\nkwonlyargs=(),kwonlydefaults={},annotations={},\nformatarg=str,\nformatvarargs=lambda name:'*'+name,\nformatvarkw=lambda name:'**'+name,\nformatvalue=lambda value:'='+repr(value),\nformatreturns=lambda text:' -> '+text,\nformatannotation=formatannotation):\n ''\n\n\n\n\n\n\n \n def formatargandannotation(arg):\n  result=formatarg(arg)\n  if arg in annotations:\n   result +=': '+formatannotation(annotations[arg])\n  return result\n specs=[]\n if defaults:\n  firstdefault=len(args)-len(defaults)\n for i,arg in enumerate(args):\n  spec=formatargandannotation(arg)\n  if defaults and i >=firstdefault:\n   spec=spec+formatvalue(defaults[i -firstdefault])\n  specs. append(spec)\n if varargs is not None :\n  specs. append(formatvarargs(formatargandannotation(varargs)))\n else :\n  if kwonlyargs:\n   specs. append('*')\n if kwonlyargs:\n  for kwonlyarg in kwonlyargs:\n   spec=formatargandannotation(kwonlyarg)\n   if kwonlydefaults and kwonlyarg in kwonlydefaults:\n    spec +=formatvalue(kwonlydefaults[kwonlyarg])\n   specs. append(spec)\n if varkw is not None :\n  specs. append(formatvarkw(formatargandannotation(varkw)))\n result='('+', '. join(specs)+')'\n if'return'in annotations:\n  result +=formatreturns(formatannotation(annotations['return']))\n return result\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \ndef _missing_arguments(f_name,argnames,pos,values):\n names=[repr(name)for name in argnames if name not in values]\n missing=len(names)\n if missing ==1:\n  s=names[0]\n elif missing ==2:\n  s=\"{} and {}\". format(*names)\n else :\n  tail=\", {} and {}\". format(names[-2:])\n  del names[-2:]\n  s=\", \". join(names)+tail\n raise TypeError(\"%s() missing %i required %s argument%s: %s\"%\n (f_name,missing,\n \"positional\"if pos else\"keyword-only\",\n \"\"if missing ==1 else\"s\",s))\n \ndef _too_many(f_name,args,kwonly,varargs,defcount,given,values):\n atleast=len(args)-defcount\n kwonly_given=len([arg for arg in kwonly if arg in values])\n if varargs:\n  plural=atleast !=1\n  sig=\"at least %d\"%(atleast,)\n elif defcount:\n  plural=True\n  sig=\"from %d to %d\"%(atleast,len(args))\n else :\n  plural=len(args)!=1\n  sig=str(len(args))\n kwonly_sig=\"\"\n if kwonly_given:\n  msg=\" positional argument%s (and %d keyword-only argument%s)\"\n  kwonly_sig=(msg %(\"s\"if given !=1 else\"\",kwonly_given,\n  \"s\"if kwonly_given !=1 else\"\"))\n raise TypeError(\"%s() takes %s positional argument%s but %d%s %s given\"%\n (f_name,sig,\"s\"if plural else\"\",given,kwonly_sig,\n \"was\"if given ==1 and not kwonly_given else\"were\"))\n \ndef getcallargs(func,*positional,**named):\n ''\n\n\n\n \n spec=getfullargspec(func)\n args,varargs,varkw,defaults,kwonlyargs,kwonlydefaults,ann=spec\n f_name=func. __name__\n arg2value={}\n \n \n if ismethod(func)and func. __self__ is not None :\n \n  positional=(func. __self__,)+positional\n num_pos=len(positional)\n num_args=len(args)\n num_defaults=len(defaults)if defaults else 0\n \n n=min(num_pos,num_args)\n for i in range(n):\n  arg2value[args[i]]=positional[i]\n if varargs:\n  arg2value[varargs]=tuple(positional[n:])\n possible_kwargs=set(args+kwonlyargs)\n if varkw:\n  arg2value[varkw]={}\n for kw,value in named. items():\n  if kw not in possible_kwargs:\n   if not varkw:\n    raise TypeError(\"%s() got an unexpected keyword argument %r\"%\n    (f_name,kw))\n   arg2value[varkw][kw]=value\n   continue\n  if kw in arg2value:\n   raise TypeError(\"%s() got multiple values for argument %r\"%\n   (f_name,kw))\n  arg2value[kw]=value\n if num_pos >num_args and not varargs:\n  _too_many(f_name,args,kwonlyargs,varargs,num_defaults,\n  num_pos,arg2value)\n if num_pos <num_args:\n  req=args[:num_args -num_defaults]\n  for arg in req:\n   if arg not in arg2value:\n    _missing_arguments(f_name,req,True ,arg2value)\n  for i,arg in enumerate(args[num_args -num_defaults:]):\n   if arg not in arg2value:\n    arg2value[arg]=defaults[i]\n missing=0\n for kwarg in kwonlyargs:\n  if kwarg not in arg2value:\n   if kwarg in kwonlydefaults:\n    arg2value[kwarg]=kwonlydefaults[kwarg]\n   else :\n    missing +=1\n if missing:\n  _missing_arguments(f_name,kwonlyargs,False ,arg2value)\n return arg2value\n \nClosureVars=namedtuple('ClosureVars','nonlocals globals builtins unbound')\n\ndef getclosurevars(func):\n ''\n\n\n\n\n\n \n \n if ismethod(func):\n  func=func. __func__\n  \n if not isfunction(func):\n  raise TypeError(\"'{!r}' is not a Python function\". format(func))\n  \n code=func. __code__\n \n \n if func. __closure__ is None :\n  nonlocal_vars={}\n else :\n  nonlocal_vars={\n  var:cell. cell_contents\n  for var,cell in zip(code. co_freevars,func. __closure__)\n  }\n  \n  \n  \n global_ns=func. __globals__\n builtin_ns=global_ns. get(\"__builtins__\",builtins. __dict__)\n if ismodule(builtin_ns):\n  builtin_ns=builtin_ns. __dict__\n global_vars={}\n builtin_vars={}\n unbound_names=set()\n for name in code. co_names:\n  if name in (\"None\",\"True\",\"False\"):\n  \n  \n   continue\n  try :\n   global_vars[name]=global_ns[name]\n  except KeyError:\n   try :\n    builtin_vars[name]=builtin_ns[name]\n   except KeyError:\n    unbound_names. add(name)\n    \n return ClosureVars(nonlocal_vars,global_vars,\n builtin_vars,unbound_names)\n \n \n \nTraceback=namedtuple('Traceback','filename lineno function code_context index')\n\ndef getframeinfo(frame,context=1):\n ''\n\n\n\n\n\n \n if istraceback(frame):\n  lineno=frame. tb_lineno\n  frame=frame. tb_frame\n else :\n  lineno=frame. f_lineno\n if not isframe(frame):\n  raise TypeError('{!r} is not a frame or traceback object'. format(frame))\n  \n filename=getsourcefile(frame)or getfile(frame)\n if context >0:\n  start=lineno -1 -context //2\n  try :\n   lines,lnum=findsource(frame)\n  except IOError:\n   lines=index=None\n  else :\n   start=max(start,1)\n   start=max(0,min(start,len(lines)-context))\n   lines=lines[start:start+context]\n   index=lineno -1 -start\n else :\n  lines=index=None\n  \n return Traceback(filename,lineno,frame. f_code. co_name,lines,index)\n \ndef getlineno(frame):\n ''\n \n return frame. f_lineno\n \ndef getouterframes(frame,context=1):\n ''\n\n\n \n framelist=[]\n while frame:\n  framelist. append((frame,)+getframeinfo(frame,context))\n  frame=frame. f_back\n return framelist\n \ndef getinnerframes(tb,context=1):\n ''\n\n\n \n framelist=[]\n while tb:\n  framelist. append((tb. tb_frame,)+getframeinfo(tb,context))\n  tb=tb. tb_next\n return framelist\n \ndef currentframe():\n ''\n return sys. _getframe(1)if hasattr(sys,\"_getframe\")else None\n \ndef stack(context=1):\n ''\n return getouterframes(sys. _getframe(1),context)\n \ndef trace(context=1):\n ''\n return getinnerframes(sys. exc_info()[2],context)\n \n \n \n \n_sentinel=object()\n\ndef _static_getmro(klass):\n return type. __dict__['__mro__']. __get__(klass)\n \ndef _check_instance(obj,attr):\n instance_dict={}\n try :\n  instance_dict=object. __getattribute__(obj,\"__dict__\")\n except AttributeError:\n  pass\n return dict. get(instance_dict,attr,_sentinel)\n \n \ndef _check_class(klass,attr):\n for entry in _static_getmro(klass):\n  if _shadowed_dict(type(entry))is _sentinel:\n   try :\n    return entry. __dict__[attr]\n   except KeyError:\n    pass\n return _sentinel\n \ndef _is_type(obj):\n try :\n  _static_getmro(obj)\n except TypeError:\n  return False\n return True\n \ndef _shadowed_dict(klass):\n dict_attr=type. __dict__[\"__dict__\"]\n for entry in _static_getmro(klass):\n  try :\n   class_dict=dict_attr. __get__(entry)[\"__dict__\"]\n  except KeyError:\n   pass\n  else :\n   if not (type(class_dict)is types. GetSetDescriptorType and\n   class_dict. __name__ ==\"__dict__\"and\n   class_dict. __objclass__ is entry):\n    return class_dict\n return _sentinel\n \ndef getattr_static(obj,attr,default=_sentinel):\n ''\n\n\n\n\n\n\n\n\n \n instance_result=_sentinel\n if not _is_type(obj):\n  klass=type(obj)\n  dict_attr=_shadowed_dict(klass)\n  if (dict_attr is _sentinel or\n  type(dict_attr)is types. MemberDescriptorType):\n   instance_result=_check_instance(obj,attr)\n else :\n  klass=obj\n  \n klass_result=_check_class(klass,attr)\n \n if instance_result is not _sentinel and klass_result is not _sentinel:\n  if (_check_class(type(klass_result),'__get__')is not _sentinel and\n  _check_class(type(klass_result),'__set__')is not _sentinel):\n   return klass_result\n   \n if instance_result is not _sentinel:\n  return instance_result\n if klass_result is not _sentinel:\n  return klass_result\n  \n if obj is klass:\n \n  for entry in _static_getmro(type(klass)):\n   if _shadowed_dict(type(entry))is _sentinel:\n    try :\n     return entry. __dict__[attr]\n    except KeyError:\n     pass\n if default is not _sentinel:\n  return default\n raise AttributeError(attr)\n \n \n \n \nGEN_CREATED='GEN_CREATED'\nGEN_RUNNING='GEN_RUNNING'\nGEN_SUSPENDED='GEN_SUSPENDED'\nGEN_CLOSED='GEN_CLOSED'\n\ndef getgeneratorstate(generator):\n ''\n\n\n\n\n\n\n \n if generator. gi_running:\n  return GEN_RUNNING\n if generator. gi_frame is None :\n  return GEN_CLOSED\n if generator. gi_frame. f_lasti ==-1:\n  return GEN_CREATED\n return GEN_SUSPENDED\n \n \ndef getgeneratorlocals(generator):\n ''\n\n\n\n \n \n if not isgenerator(generator):\n  raise TypeError(\"'{!r}' is not a Python generator\". format(generator))\n  \n frame=getattr(generator,\"gi_frame\",None )\n if frame is not None :\n  return generator. gi_frame. f_locals\n else :\n  return {}\n  \n  \n  \n  \n  \n  \n_WrapperDescriptor=type(type. __call__)\n_MethodWrapper=type(all. __call__)\n\n_NonUserDefinedCallables=(_WrapperDescriptor,\n_MethodWrapper,\ntypes. BuiltinFunctionType)\n\n\ndef _get_user_defined_method(cls,method_name):\n try :\n  meth=getattr(cls,method_name)\n except AttributeError:\n  return\n else :\n  if not isinstance(meth,_NonUserDefinedCallables):\n  \n  \n   return meth\n   \n   \ndef signature(obj):\n ''\n \n if not callable(obj):\n  raise TypeError('{!r} is not a callable object'. format(obj))\n  \n if isinstance(obj,types. MethodType):\n \n \n  sig=signature(obj. __func__)\n  return sig. replace(parameters=tuple(sig. parameters. values())[1:])\n  \n try :\n  sig=obj. __signature__\n except AttributeError:\n  pass\n else :\n  if sig is not None :\n   return sig\n   \n try :\n \n  wrapped=obj. __wrapped__\n except AttributeError:\n  pass\n else :\n  return signature(wrapped)\n  \n if isinstance(obj,types. FunctionType):\n  return Signature. from_function(obj)\n  \n if isinstance(obj,functools. partial):\n  sig=signature(obj. func)\n  \n  new_params=OrderedDict(sig. parameters. items())\n  \n  partial_args=obj. args or ()\n  partial_keywords=obj. keywords or {}\n  try :\n   ba=sig. bind_partial(*partial_args,**partial_keywords)\n  except TypeError as ex:\n   msg='partial object {!r} has incorrect arguments'. format(obj)\n   raise ValueError(msg)from ex\n   \n  for arg_name,arg_value in ba. arguments. items():\n   param=new_params[arg_name]\n   if arg_name in partial_keywords:\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n    new_params[arg_name]=param. replace(default=arg_value,\n    _partial_kwarg=True )\n    \n   elif (param. kind not in (_VAR_KEYWORD,_VAR_POSITIONAL)and\n   not param. _partial_kwarg):\n    new_params. pop(arg_name)\n    \n  return sig. replace(parameters=new_params. values())\n  \n sig=None\n if isinstance(obj,type):\n \n \n \n \n  call=_get_user_defined_method(type(obj),'__call__')\n  if call is not None :\n   sig=signature(call)\n  else :\n  \n   new=_get_user_defined_method(obj,'__new__')\n   if new is not None :\n    sig=signature(new)\n   else :\n   \n    init=_get_user_defined_method(obj,'__init__')\n    if init is not None :\n     sig=signature(init)\n elif not isinstance(obj,_NonUserDefinedCallables):\n \n \n \n \n  call=_get_user_defined_method(type(obj),'__call__')\n  if call is not None :\n   sig=signature(call)\n   \n if sig is not None :\n \n \n  return sig. replace(parameters=tuple(sig. parameters. values())[1:])\n  \n if isinstance(obj,types. BuiltinFunctionType):\n \n  msg='no signature found for builtin function {!r}'. format(obj)\n  raise ValueError(msg)\n  \n raise ValueError('callable {!r} is not supported by signature'. format(obj))\n \n \nclass _void:\n ''\n \n \nclass _empty:\n pass\n \n \nclass _ParameterKind(int):\n def __new__(self,*args,name):\n  obj=int. __new__(self,*args)\n  obj. _name=name\n  return obj\n  \n def __str__(self):\n  return self. _name\n  \n def __repr__(self):\n  return'<_ParameterKind: {!r}>'. format(self. _name)\n  \n  \n_POSITIONAL_ONLY=_ParameterKind(0,name='POSITIONAL_ONLY')\n_POSITIONAL_OR_KEYWORD=_ParameterKind(1,name='POSITIONAL_OR_KEYWORD')\n_VAR_POSITIONAL=_ParameterKind(2,name='VAR_POSITIONAL')\n_KEYWORD_ONLY=_ParameterKind(3,name='KEYWORD_ONLY')\n_VAR_KEYWORD=_ParameterKind(4,name='VAR_KEYWORD')\n\n\nclass Parameter:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n __slots__=('_name','_kind','_default','_annotation','_partial_kwarg')\n \n POSITIONAL_ONLY=_POSITIONAL_ONLY\n POSITIONAL_OR_KEYWORD=_POSITIONAL_OR_KEYWORD\n VAR_POSITIONAL=_VAR_POSITIONAL\n KEYWORD_ONLY=_KEYWORD_ONLY\n VAR_KEYWORD=_VAR_KEYWORD\n \n empty=_empty\n \n def __init__(self,name,kind,*,default=_empty,annotation=_empty,\n _partial_kwarg=False ):\n \n  if kind not in (_POSITIONAL_ONLY,_POSITIONAL_OR_KEYWORD,\n  _VAR_POSITIONAL,_KEYWORD_ONLY,_VAR_KEYWORD):\n   raise ValueError(\"invalid value for 'Parameter.kind' attribute\")\n  self. _kind=kind\n  \n  if default is not _empty:\n   if kind in (_VAR_POSITIONAL,_VAR_KEYWORD):\n    msg='{} parameters cannot have default values'. format(kind)\n    raise ValueError(msg)\n  self. _default=default\n  self. _annotation=annotation\n  \n  if name is None :\n   if kind !=_POSITIONAL_ONLY:\n    raise ValueError(\"None is not a valid name for a \"\n    \"non-positional-only parameter\")\n   self. _name=name\n  else :\n   name=str(name)\n   if kind !=_POSITIONAL_ONLY and not name. isidentifier():\n    msg='{!r} is not a valid parameter name'. format(name)\n    raise ValueError(msg)\n   self. _name=name\n   \n  self. _partial_kwarg=_partial_kwarg\n  \n @property\n def name(self):\n  return self. _name\n  \n @property\n def default(self):\n  return self. _default\n  \n @property\n def annotation(self):\n  return self. _annotation\n  \n @property\n def kind(self):\n  return self. _kind\n  \n def replace(self,*,name=_void,kind=_void,annotation=_void,\n default=_void,_partial_kwarg=_void):\n  ''\n  \n  if name is _void:\n   name=self. _name\n   \n  if kind is _void:\n   kind=self. _kind\n   \n  if annotation is _void:\n   annotation=self. _annotation\n   \n  if default is _void:\n   default=self. _default\n   \n  if _partial_kwarg is _void:\n   _partial_kwarg=self. _partial_kwarg\n   \n  return type(self)(name,kind,default=default,annotation=annotation,\n  _partial_kwarg=_partial_kwarg)\n  \n def __str__(self):\n  kind=self. kind\n  \n  formatted=self. _name\n  if kind ==_POSITIONAL_ONLY:\n   if formatted is None :\n    formatted=''\n   formatted='<{}>'. format(formatted)\n   \n   \n  if self. _annotation is not _empty:\n   formatted='{}:{}'. format(formatted,\n   formatannotation(self. _annotation))\n   \n  if self. _default is not _empty:\n   formatted='{}={}'. format(formatted,repr(self. _default))\n   \n  if kind ==_VAR_POSITIONAL:\n   formatted='*'+formatted\n  elif kind ==_VAR_KEYWORD:\n   formatted='**'+formatted\n   \n  return formatted\n  \n def __repr__(self):\n  return'<{} at {:#x} {!r}>'. format(self. __class__. __name__,\n  id(self),self. name)\n  \n def __eq__(self,other):\n  return (issubclass(other. __class__,Parameter)and\n  self. _name ==other. _name and\n  self. _kind ==other. _kind and\n  self. _default ==other. _default and\n  self. _annotation ==other. _annotation)\n  \n def __ne__(self,other):\n  return not self. __eq__(other)\n  \n  \nclass BoundArguments:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,signature,arguments):\n  self. arguments=arguments\n  self. _signature=signature\n  \n @property\n def signature(self):\n  return self. _signature\n  \n @property\n def args(self):\n  args=[]\n  for param_name,param in self. _signature. parameters. items():\n   if (param. kind in (_VAR_KEYWORD,_KEYWORD_ONLY)or\n   param. _partial_kwarg):\n   \n   \n   \n   \n    break\n    \n   try :\n    arg=self. arguments[param_name]\n   except KeyError:\n   \n   \n    break\n   else :\n    if param. kind ==_VAR_POSITIONAL:\n    \n     args. extend(arg)\n    else :\n    \n     args. append(arg)\n     \n  return tuple(args)\n  \n @property\n def kwargs(self):\n  kwargs={}\n  kwargs_started=False\n  for param_name,param in self. _signature. parameters. items():\n   if not kwargs_started:\n    if (param. kind in (_VAR_KEYWORD,_KEYWORD_ONLY)or\n    param. _partial_kwarg):\n     kwargs_started=True\n    else :\n     if param_name not in self. arguments:\n      kwargs_started=True\n      continue\n      \n   if not kwargs_started:\n    continue\n    \n   try :\n    arg=self. arguments[param_name]\n   except KeyError:\n    pass\n   else :\n    if param. kind ==_VAR_KEYWORD:\n    \n     kwargs. update(arg)\n    else :\n    \n     kwargs[param_name]=arg\n     \n  return kwargs\n  \n def __eq__(self,other):\n  return (issubclass(other. __class__,BoundArguments)and\n  self. signature ==other. signature and\n  self. arguments ==other. arguments)\n  \n def __ne__(self,other):\n  return not self. __eq__(other)\n  \n  \nclass Signature:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n __slots__=('_return_annotation','_parameters')\n \n _parameter_cls=Parameter\n _bound_arguments_cls=BoundArguments\n \n empty=_empty\n \n def __init__(self,parameters=None ,*,return_annotation=_empty,\n __validate_parameters__=True ):\n  ''\n\n  \n  \n  if parameters is None :\n   params=OrderedDict()\n  else :\n   if __validate_parameters__:\n    params=OrderedDict()\n    top_kind=_POSITIONAL_ONLY\n    \n    for idx,param in enumerate(parameters):\n     kind=param. kind\n     if kind <top_kind:\n      msg='wrong parameter order: {} before {}'\n      msg=msg. format(top_kind,param. kind)\n      raise ValueError(msg)\n     else :\n      top_kind=kind\n      \n     name=param. name\n     if name is None :\n      name=str(idx)\n      param=param. replace(name=name)\n      \n     if name in params:\n      msg='duplicate parameter name: {!r}'. format(name)\n      raise ValueError(msg)\n     params[name]=param\n   else :\n    params=OrderedDict(((param. name,param)\n    for param in parameters))\n    \n  self. _parameters=types. MappingProxyType(params)\n  self. _return_annotation=return_annotation\n  \n @classmethod\n def from_function(cls,func):\n  ''\n  \n  if not isinstance(func,types. FunctionType):\n   raise TypeError('{!r} is not a Python function'. format(func))\n   \n  Parameter=cls. _parameter_cls\n  \n  \n  func_code=func. __code__\n  pos_count=func_code. co_argcount\n  arg_names=func_code. co_varnames\n  positional=tuple(arg_names[:pos_count])\n  keyword_only_count=func_code. co_kwonlyargcount\n  keyword_only=arg_names[pos_count:(pos_count+keyword_only_count)]\n  annotations=func. __annotations__\n  defaults=func. __defaults__\n  kwdefaults=func. __kwdefaults__\n  \n  if defaults:\n   pos_default_count=len(defaults)\n  else :\n   pos_default_count=0\n   \n  parameters=[]\n  \n  \n  non_default_count=pos_count -pos_default_count\n  for name in positional[:non_default_count]:\n   annotation=annotations. get(name,_empty)\n   parameters. append(Parameter(name,annotation=annotation,\n   kind=_POSITIONAL_OR_KEYWORD))\n   \n   \n  for offset,name in enumerate(positional[non_default_count:]):\n   annotation=annotations. get(name,_empty)\n   parameters. append(Parameter(name,annotation=annotation,\n   kind=_POSITIONAL_OR_KEYWORD,\n   default=defaults[offset]))\n   \n   \n  if func_code. co_flags&0x04:\n   name=arg_names[pos_count+keyword_only_count]\n   annotation=annotations. get(name,_empty)\n   parameters. append(Parameter(name,annotation=annotation,\n   kind=_VAR_POSITIONAL))\n   \n   \n  for name in keyword_only:\n   default=_empty\n   if kwdefaults is not None :\n    default=kwdefaults. get(name,_empty)\n    \n   annotation=annotations. get(name,_empty)\n   parameters. append(Parameter(name,annotation=annotation,\n   kind=_KEYWORD_ONLY,\n   default=default))\n   \n  if func_code. co_flags&0x08:\n   index=pos_count+keyword_only_count\n   if func_code. co_flags&0x04:\n    index +=1\n    \n   name=arg_names[index]\n   annotation=annotations. get(name,_empty)\n   parameters. append(Parameter(name,annotation=annotation,\n   kind=_VAR_KEYWORD))\n   \n  return cls(parameters,\n  return_annotation=annotations. get('return',_empty),\n  __validate_parameters__=False )\n  \n @property\n def parameters(self):\n  return self. _parameters\n  \n @property\n def return_annotation(self):\n  return self. _return_annotation\n  \n def replace(self,*,parameters=_void,return_annotation=_void):\n  ''\n\n\n  \n  \n  if parameters is _void:\n   parameters=self. parameters. values()\n   \n  if return_annotation is _void:\n   return_annotation=self. _return_annotation\n   \n  return type(self)(parameters,\n  return_annotation=return_annotation)\n  \n def __eq__(self,other):\n  if (not issubclass(type(other),Signature)or\n  self. return_annotation !=other. return_annotation or\n  len(self. parameters)!=len(other. parameters)):\n   return False\n   \n  other_positions={param:idx\n  for idx,param in enumerate(other. parameters. keys())}\n  \n  for idx,(param_name,param)in enumerate(self. parameters. items()):\n   if param. kind ==_KEYWORD_ONLY:\n    try :\n     other_param=other. parameters[param_name]\n    except KeyError:\n     return False\n    else :\n     if param !=other_param:\n      return False\n   else :\n    try :\n     other_idx=other_positions[param_name]\n    except KeyError:\n     return False\n    else :\n     if (idx !=other_idx or\n     param !=other. parameters[param_name]):\n      return False\n      \n  return True\n  \n def __ne__(self,other):\n  return not self. __eq__(other)\n  \n def _bind(self,args,kwargs,*,partial=False ):\n  ''\n  \n  arguments=OrderedDict()\n  \n  parameters=iter(self. parameters. values())\n  parameters_ex=()\n  arg_vals=iter(args)\n  \n  if partial:\n  \n  \n  \n   for param_name,param in self. parameters. items():\n    if (param. _partial_kwarg and param_name not in kwargs):\n    \n     kwargs[param_name]=param. default\n     \n  while True :\n  \n  \n   try :\n    arg_val=next(arg_vals)\n   except StopIteration:\n   \n    try :\n     param=next(parameters)\n    except StopIteration:\n    \n    \n     break\n    else :\n     if param. kind ==_VAR_POSITIONAL:\n     \n     \n      break\n     elif param. name in kwargs:\n      if param. kind ==_POSITIONAL_ONLY:\n       msg='{arg!r} parameter is positional only, '       'but was passed as a keyword'\n       msg=msg. format(arg=param. name)\n       raise TypeError(msg)from None\n      parameters_ex=(param,)\n      break\n     elif (param. kind ==_VAR_KEYWORD or\n     param. default is not _empty):\n     \n     \n     \n      parameters_ex=(param,)\n      break\n     else :\n      if partial:\n       parameters_ex=(param,)\n       break\n      else :\n       msg='{arg!r} parameter lacking default value'\n       msg=msg. format(arg=param. name)\n       raise TypeError(msg)from None\n   else :\n   \n    try :\n     param=next(parameters)\n    except StopIteration:\n     raise TypeError('too many positional arguments')from None\n    else :\n     if param. kind in (_VAR_KEYWORD,_KEYWORD_ONLY):\n     \n     \n      raise TypeError('too many positional arguments')\n      \n     if param. kind ==_VAR_POSITIONAL:\n     \n     \n     \n      values=[arg_val]\n      values. extend(arg_vals)\n      arguments[param. name]=tuple(values)\n      break\n      \n     if param. name in kwargs:\n      raise TypeError('multiple values for argument '\n      '{arg!r}'. format(arg=param. name))\n      \n     arguments[param. name]=arg_val\n     \n     \n     \n  kwargs_param=None\n  for param in itertools. chain(parameters_ex,parameters):\n   if param. kind ==_POSITIONAL_ONLY:\n   \n   \n   \n    raise TypeError('{arg!r} parameter is positional only, '\n    'but was passed as a keyword'.    format(arg=param. name))\n    \n   if param. kind ==_VAR_KEYWORD:\n   \n    kwargs_param=param\n    continue\n    \n   param_name=param. name\n   try :\n    arg_val=kwargs. pop(param_name)\n   except KeyError:\n   \n   \n   \n   \n    if (not partial and param. kind !=_VAR_POSITIONAL and\n    param. default is _empty):\n     raise TypeError('{arg!r} parameter lacking default value'.     format(arg=param_name))from None\n     \n   else :\n    arguments[param_name]=arg_val\n    \n  if kwargs:\n   if kwargs_param is not None :\n   \n    arguments[kwargs_param. name]=kwargs\n   else :\n    raise TypeError('too many keyword arguments')\n    \n  return self. _bound_arguments_cls(self,arguments)\n  \n def bind(__bind_self,*args,**kwargs):\n  ''\n\n\n  \n  return __bind_self. _bind(args,kwargs)\n  \n def bind_partial(__bind_self,*args,**kwargs):\n  ''\n\n\n  \n  return __bind_self. _bind(args,kwargs,partial=True )\n  \n def __str__(self):\n  result=[]\n  render_kw_only_separator=True\n  for idx,param in enumerate(self. parameters. values()):\n   formatted=str(param)\n   \n   kind=param. kind\n   if kind ==_VAR_POSITIONAL:\n   \n   \n    render_kw_only_separator=False\n   elif kind ==_KEYWORD_ONLY and render_kw_only_separator:\n   \n   \n   \n    result. append('*')\n    \n    \n    render_kw_only_separator=False\n    \n   result. append(formatted)\n   \n  rendered='({})'. format(', '. join(result))\n  \n  if self. return_annotation is not _empty:\n   anno=formatannotation(self. return_annotation)\n   rendered +=' -> {}'. format(anno)\n   \n  return rendered\n", ["builtins", "collections", "dis", "functools", "imp", "importlib.machinery", "itertools", "linecache", "operator", "os", "re", "sys", "tokenize", "types", "warnings"]], "atexit": [".py", "''\n\n\n\n\n\nclass __loader__(object):\n pass\n \ndef _clear(*args,**kw):\n ''\n \n pass\n \ndef _run_exitfuncs(*args,**kw):\n ''\n \n pass\n \ndef register(*args,**kw):\n ''\n\n\n\n\n\n\n \n pass\n \ndef unregister(*args,**kw):\n ''\n\n\n\n \n pass\n", []], "_socket": [".py", "''\n\n\n\n\nAF_APPLETALK=16\n\nAF_DECnet=12\n\nAF_INET=2\n\nAF_INET6=23\n\nAF_IPX=6\n\nAF_IRDA=26\n\nAF_SNA=11\n\nAF_UNSPEC=0\n\nAI_ADDRCONFIG=1024\n\nAI_ALL=256\n\nAI_CANONNAME=2\n\nAI_NUMERICHOST=4\n\nAI_NUMERICSERV=8\n\nAI_PASSIVE=1\n\nAI_V4MAPPED=2048\n\nCAPI='<capsule object \"_socket.CAPI\" at 0x00BC4F38>'\n\nEAI_AGAIN=11002\n\nEAI_BADFLAGS=10022\n\nEAI_FAIL=11003\n\nEAI_FAMILY=10047\n\nEAI_MEMORY=8\n\nEAI_NODATA=11001\n\nEAI_NONAME=11001\n\nEAI_SERVICE=10109\n\nEAI_SOCKTYPE=10044\n\nINADDR_ALLHOSTS_GROUP=-536870911\n\nINADDR_ANY=0\n\nINADDR_BROADCAST=-1\n\nINADDR_LOOPBACK=2130706433\n\nINADDR_MAX_LOCAL_GROUP=-536870657\n\nINADDR_NONE=-1\n\nINADDR_UNSPEC_GROUP=-536870912\n\nIPPORT_RESERVED=1024\n\nIPPORT_USERRESERVED=5000\n\nIPPROTO_ICMP=1\n\nIPPROTO_IP=0\n\nIPPROTO_RAW=255\n\nIPPROTO_TCP=6\n\nIPPROTO_UDP=17\n\nIPV6_CHECKSUM=26\n\nIPV6_DONTFRAG=14\n\nIPV6_HOPLIMIT=21\n\nIPV6_HOPOPTS=1\n\nIPV6_JOIN_GROUP=12\n\nIPV6_LEAVE_GROUP=13\n\nIPV6_MULTICAST_HOPS=10\n\nIPV6_MULTICAST_IF=9\n\nIPV6_MULTICAST_LOOP=11\n\nIPV6_PKTINFO=19\n\nIPV6_RECVRTHDR=38\n\nIPV6_RECVTCLASS=40\n\nIPV6_RTHDR=32\n\nIPV6_TCLASS=39\n\nIPV6_UNICAST_HOPS=4\n\nIPV6_V6ONLY=27\n\nIP_ADD_MEMBERSHIP=12\n\nIP_DROP_MEMBERSHIP=13\n\nIP_HDRINCL=2\n\nIP_MULTICAST_IF=9\n\nIP_MULTICAST_LOOP=11\n\nIP_MULTICAST_TTL=10\n\nIP_OPTIONS=1\n\nIP_RECVDSTADDR=25\n\nIP_TOS=3\n\nIP_TTL=4\n\nMSG_BCAST=1024\n\nMSG_CTRUNC=512\n\nMSG_DONTROUTE=4\n\nMSG_MCAST=2048\n\nMSG_OOB=1\n\nMSG_PEEK=2\n\nMSG_TRUNC=256\n\nNI_DGRAM=16\n\nNI_MAXHOST=1025\n\nNI_MAXSERV=32\n\nNI_NAMEREQD=4\n\nNI_NOFQDN=1\n\nNI_NUMERICHOST=2\n\nNI_NUMERICSERV=8\n\nRCVALL_MAX=3\n\nRCVALL_OFF=0\n\nRCVALL_ON=1\n\nRCVALL_SOCKETLEVELONLY=2\n\nSHUT_RD=0\n\nSHUT_RDWR=2\n\nSHUT_WR=1\n\nSIO_KEEPALIVE_VALS=2550136836\n\nSIO_RCVALL=2550136833\n\nSOCK_DGRAM=2\n\nSOCK_RAW=3\n\nSOCK_RDM=4\n\nSOCK_SEQPACKET=5\n\nSOCK_STREAM=1\n\nSOL_IP=0\n\nSOL_SOCKET=65535\n\nSOL_TCP=6\n\nSOL_UDP=17\n\nSOMAXCONN=2147483647\n\nSO_ACCEPTCONN=2\n\nSO_BROADCAST=32\n\nSO_DEBUG=1\n\nSO_DONTROUTE=16\n\nSO_ERROR=4103\n\nSO_EXCLUSIVEADDRUSE=-5\n\nSO_KEEPALIVE=8\n\nSO_LINGER=128\n\nSO_OOBINLINE=256\n\nSO_RCVBUF=4098\n\nSO_RCVLOWAT=4100\n\nSO_RCVTIMEO=4102\n\nSO_REUSEADDR=4\n\nSO_SNDBUF=4097\n\nSO_SNDLOWAT=4099\n\nSO_SNDTIMEO=4101\n\nSO_TYPE=4104\n\nSO_USELOOPBACK=64\n\nclass SocketType:\n pass\n \nTCP_MAXSEG=4\n\nTCP_NODELAY=1\n\n__loader__='<_frozen_importlib.ExtensionFileLoader object at 0x00CA2D90>'\n\ndef dup(*args,**kw):\n ''\n\n \n pass\n \nclass error:\n pass\n \nclass gaierror:\n pass\n \ndef getaddrinfo(*args,**kw):\n ''\n\n \n pass\n \ndef getdefaulttimeout(*args,**kw):\n ''\n\n\n \n pass\n \ndef gethostbyaddr(*args,**kw):\n ''\n\n \n pass\n \ndef gethostbyname(*args,**kw):\n ''\n \n pass\n \ndef gethostbyname_ex(*args,**kw):\n ''\n\n \n pass\n \ndef gethostname(*args,**kw):\n ''\n \n pass\n \ndef getnameinfo(*args,**kw):\n ''\n \n pass\n \ndef getprotobyname(*args,**kw):\n ''\n \n pass\n \ndef getservbyname(*args,**kw):\n ''\n\n\n \n pass\n \ndef getservbyport(*args,**kw):\n ''\n\n\n \n pass\n \nhas_ipv6=True\n\nclass herror:\n pass\n \ndef htonl(*args,**kw):\n ''\n \n pass\n \ndef htons(*args,**kw):\n ''\n \n pass\n \ndef inet_aton(*args,**kw):\n ''\n\n \n pass\n \ndef inet_ntoa(*args,**kw):\n ''\n \n pass\n \ndef ntohl(*args,**kw):\n ''\n \n pass\n \ndef ntohs(*args,**kw):\n ''\n \n pass\n \ndef setdefaulttimeout(*args,**kw):\n ''\n\n\n \n pass\n \nclass socket:\n def __init__(self,*args,**kw):\n  pass\n def bind(self,*args,**kw):\n  pass\n def close(self):\n  pass\n  \nclass timeout:\n pass\n", []], "urllib.request": [".py", "from browser import ajax\nfrom . import error\n\nclass FileIO:\n def __init__(self,data):\n  self. _data=data\n  \n def read(self):\n  return self. _data\n  \ndef urlopen(url,data=None ,timeout=None ):\n global result\n result=None\n \n def on_complete(req):\n  global result\n  if req. status ==200:\n   result=req\n   \n _ajax=ajax. ajax()\n _ajax. bind('complete',on_complete)\n if timeout is not None :\n  _ajax. set_timeout(timeout)\n  \n if data is None :\n  _ajax. open('GET',url,False )\n  _ajax. send()\n else :\n  _ajax. open('POST',url,False )\n  _ajax. send(data)\n  \n if result is not None :\n  if isinstance(result. text,str):\n   return FileIO(result. text)\n   \n  return FileIO(result. text())\n raise error. HTTPError('file not found')", ["browser", "browser.ajax", "urllib", "urllib.error"]], "unittest.loader": [".py", "''\n\nimport os\nimport re\nimport sys\nimport traceback\nimport types\nimport functools\n\nfrom fnmatch import fnmatch\n\nfrom . import case,suite,util\n\n__unittest=True\n\n\n\n\nVALID_MODULE_NAME=re. compile(r'[_a-z]\\w*\\.py$',re. IGNORECASE)\n\n\ndef _make_failed_import_test(name,suiteClass):\n message='Failed to import test module: %s\\n%s'%(name,traceback. format_exc())\n return _make_failed_test('ModuleImportFailure',name,ImportError(message),\n suiteClass)\n \ndef _make_failed_load_tests(name,exception,suiteClass):\n return _make_failed_test('LoadTestsFailure',name,exception,suiteClass)\n \ndef _make_failed_test(classname,methodname,exception,suiteClass):\n def testFailure(self):\n  raise exception\n attrs={methodname:testFailure}\n TestClass=type(classname,(case. TestCase,),attrs)\n return suiteClass((TestClass(methodname),))\n \ndef _jython_aware_splitext(path):\n if path. lower(). endswith('$py.class'):\n  return path[:-9]\n return os. path. splitext(path)[0]\n \n \nclass TestLoader(object):\n ''\n\n\n \n testMethodPrefix='test'\n sortTestMethodsUsing=staticmethod(util. three_way_cmp)\n suiteClass=suite. TestSuite\n _top_level_dir=None\n \n def loadTestsFromTestCase(self,testCaseClass):\n  ''\n  if issubclass(testCaseClass,suite. TestSuite):\n   raise TypeError(\"Test cases should not be derived from TestSuite.\"   \" Maybe you meant to derive from TestCase?\")\n  testCaseNames=self. getTestCaseNames(testCaseClass)\n  if not testCaseNames and hasattr(testCaseClass,'runTest'):\n   testCaseNames=['runTest']\n  loaded_suite=self. suiteClass(map(testCaseClass,testCaseNames))\n  return loaded_suite\n  \n def loadTestsFromModule(self,module,use_load_tests=True ):\n  ''\n  tests=[]\n  for name in dir(module):\n   obj=getattr(module,name)\n   if isinstance(obj,type)and issubclass(obj,case. TestCase):\n    tests. append(self. loadTestsFromTestCase(obj))\n    \n  load_tests=getattr(module,'load_tests',None )\n  tests=self. suiteClass(tests)\n  if use_load_tests and load_tests is not None :\n   try :\n    return load_tests(self,tests,None )\n   except Exception as e:\n    return _make_failed_load_tests(module. __name__,e,\n    self. suiteClass)\n  return tests\n  \n def loadTestsFromName(self,name,module=None ):\n  ''\n\n\n\n\n\n\n  \n  parts=name. split('.')\n  if module is None :\n   parts_copy=parts[:]\n   while parts_copy:\n    try :\n     module=__import__('.'. join(parts_copy))\n     break\n    except ImportError:\n     del parts_copy[-1]\n     if not parts_copy:\n      raise\n   parts=parts[1:]\n  obj=module\n  for part in parts:\n   parent,obj=obj,getattr(obj,part)\n   \n  if isinstance(obj,types. ModuleType):\n   return self. loadTestsFromModule(obj)\n  elif isinstance(obj,type)and issubclass(obj,case. TestCase):\n   return self. loadTestsFromTestCase(obj)\n  elif (isinstance(obj,types. FunctionType)and\n  isinstance(parent,type)and\n  issubclass(parent,case. TestCase)):\n   name=parts[-1]\n   inst=parent(name)\n   \n   if not isinstance(getattr(inst,name),types. FunctionType):\n    return self. suiteClass([inst])\n  elif isinstance(obj,suite. TestSuite):\n   return obj\n  if callable(obj):\n   test=obj()\n   if isinstance(test,suite. TestSuite):\n    return test\n   elif isinstance(test,case. TestCase):\n    return self. suiteClass([test])\n   else :\n    raise TypeError(\"calling %s returned %s, not a test\"%\n    (obj,test))\n  else :\n   raise TypeError(\"don't know how to make test from: %s\"%obj)\n   \n def loadTestsFromNames(self,names,module=None ):\n  ''\n\n  \n  suites=[self. loadTestsFromName(name,module)for name in names]\n  return self. suiteClass(suites)\n  \n def getTestCaseNames(self,testCaseClass):\n  ''\n  \n  def isTestMethod(attrname,testCaseClass=testCaseClass,\n  prefix=self. testMethodPrefix):\n   return attrname. startswith(prefix)and   callable(getattr(testCaseClass,attrname))\n  testFnNames=list(filter(isTestMethod,dir(testCaseClass)))\n  if self. sortTestMethodsUsing:\n   testFnNames. sort(key=functools. cmp_to_key(self. sortTestMethodsUsing))\n  return testFnNames\n  \n def discover(self,start_dir,pattern='test*.py',top_level_dir=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  set_implicit_top=False\n  if top_level_dir is None and self. _top_level_dir is not None :\n  \n   top_level_dir=self. _top_level_dir\n  elif top_level_dir is None :\n   set_implicit_top=True\n   top_level_dir=start_dir\n   \n  top_level_dir=os. path. abspath(top_level_dir)\n  \n  if not top_level_dir in sys. path:\n  \n  \n  \n  \n   sys. path. insert(0,top_level_dir)\n  self. _top_level_dir=top_level_dir\n  \n  is_not_importable=False\n  if os. path. isdir(os. path. abspath(start_dir)):\n   start_dir=os. path. abspath(start_dir)\n   if start_dir !=top_level_dir:\n    is_not_importable=not os. path. isfile(os. path. join(start_dir,'__init__.py'))\n  else :\n  \n   try :\n    __import__(start_dir)\n   except ImportError:\n    is_not_importable=True\n   else :\n    the_module=sys. modules[start_dir]\n    top_part=start_dir. split('.')[0]\n    start_dir=os. path. abspath(os. path. dirname((the_module. __file__)))\n    if set_implicit_top:\n     self. _top_level_dir=self. _get_directory_containing_module(top_part)\n     sys. path. remove(top_level_dir)\n     \n  if is_not_importable:\n   raise ImportError('Start directory is not importable: %r'%start_dir)\n   \n  tests=list(self. _find_tests(start_dir,pattern))\n  return self. suiteClass(tests)\n  \n def _get_directory_containing_module(self,module_name):\n  module=sys. modules[module_name]\n  full_path=os. path. abspath(module. __file__)\n  \n  if os. path. basename(full_path). lower(). startswith('__init__.py'):\n   return os. path. dirname(os. path. dirname(full_path))\n  else :\n  \n  \n  \n   return os. path. dirname(full_path)\n   \n def _get_name_from_path(self,path):\n  path=_jython_aware_splitext(os. path. normpath(path))\n  \n  _relpath=os. path. relpath(path,self. _top_level_dir)\n  assert not os. path. isabs(_relpath),\"Path must be within the project\"\n  assert not _relpath. startswith('..'),\"Path must be within the project\"\n  \n  name=_relpath. replace(os. path. sep,'.')\n  return name\n  \n def _get_module_from_name(self,name):\n  __import__(name)\n  return sys. modules[name]\n  \n def _match_path(self,path,full_path,pattern):\n \n  return fnmatch(path,pattern)\n  \n def _find_tests(self,start_dir,pattern):\n  ''\n  paths=os. listdir(start_dir)\n  \n  for path in paths:\n   full_path=os. path. join(start_dir,path)\n   if os. path. isfile(full_path):\n    if not VALID_MODULE_NAME. match(path):\n    \n     continue\n    if not self. _match_path(path,full_path,pattern):\n     continue\n     \n    name=self. _get_name_from_path(full_path)\n    try :\n     module=self. _get_module_from_name(name)\n    except :\n     yield _make_failed_import_test(name,self. suiteClass)\n    else :\n     mod_file=os. path. abspath(getattr(module,'__file__',full_path))\n     realpath=_jython_aware_splitext(os. path. realpath(mod_file))\n     fullpath_noext=_jython_aware_splitext(os. path. realpath(full_path))\n     if realpath. lower()!=fullpath_noext. lower():\n      module_dir=os. path. dirname(realpath)\n      mod_name=_jython_aware_splitext(os. path. basename(full_path))\n      expected_dir=os. path. dirname(full_path)\n      msg=(\"%r module incorrectly imported from %r. Expected %r. \"\n      \"Is this module globally installed?\")\n      raise ImportError(msg %(mod_name,module_dir,expected_dir))\n     yield self. loadTestsFromModule(module)\n   elif os. path. isdir(full_path):\n    if not os. path. isfile(os. path. join(full_path,'__init__.py')):\n     continue\n     \n    load_tests=None\n    tests=None\n    if fnmatch(path,pattern):\n    \n     name=self. _get_name_from_path(full_path)\n     package=self. _get_module_from_name(name)\n     load_tests=getattr(package,'load_tests',None )\n     tests=self. loadTestsFromModule(package,use_load_tests=False )\n     \n    if load_tests is None :\n     if tests is not None :\n     \n      yield tests\n      \n     for test in self. _find_tests(full_path,pattern):\n      yield test\n    else :\n     try :\n      yield load_tests(self,tests,pattern)\n     except Exception as e:\n      yield _make_failed_load_tests(package. __name__,e,\n      self. suiteClass)\n      \ndefaultTestLoader=TestLoader()\n\n\ndef _makeLoader(prefix,sortUsing,suiteClass=None ):\n loader=TestLoader()\n loader. sortTestMethodsUsing=sortUsing\n loader. testMethodPrefix=prefix\n if suiteClass:\n  loader. suiteClass=suiteClass\n return loader\n \ndef getTestCaseNames(testCaseClass,prefix,sortUsing=util. three_way_cmp):\n return _makeLoader(prefix,sortUsing). getTestCaseNames(testCaseClass)\n \ndef makeSuite(testCaseClass,prefix='test',sortUsing=util. three_way_cmp,\nsuiteClass=suite. TestSuite):\n return _makeLoader(prefix,sortUsing,suiteClass). loadTestsFromTestCase(\n testCaseClass)\n \ndef findTestCases(module,prefix='test',sortUsing=util. three_way_cmp,\nsuiteClass=suite. TestSuite):\n return _makeLoader(prefix,sortUsing,suiteClass). loadTestsFromModule( module)\n", ["fnmatch", "functools", "os", "re", "sys", "traceback", "types", "unittest", "unittest.case", "unittest.suite", "unittest.util"]], "dis": [".js", "var $module=(function($B){\n\nvar mod = {\n    dis:function(src){\n        $B.$py_module_path['__main__'] = $B.brython_path\n        return __BRYTHON__.py2js(src,'__main__','__main__',\n            $B.builtins_scope).to_js()\n    }\n}\nreturn mod\n\n})(__BRYTHON__)"], "_string": [".py", "''\n\nimport re\n\nclass __loader__(object):\n pass\n \ndef formatter_field_name_split(fieldname):\n ''\n _list=[]\n for _name in fieldname:\n  _parts=_name. split('.')\n  for _item in _parts:\n   is_attr=False\n   if re. match('\\d+',_item):\n    _list. append((int(_item),is_attr))\n   else :\n    _list. append((_item,is_attr))\n    \n return _list[0][0],iter(_list[1:])\n \ndef formatter_parser(*args,**kw):\n ''\n \n assert len(args)==1\n assert isinstance(args[0],str)\n \n _result=[]\n for _match in re. finditer(\"([^{]*)?(\\{[^}]*\\})?\",args[0]):\n  _pre,_fmt=_match. groups()\n  if _fmt is None :\n   _result. append((_pre,None ,None ,None ))\n  elif _fmt =='{}':\n   _result. append((_pre,'','',None ))\n  else :\n   _m=re. match(\"\\{([^!]*)!?(.*)?\\}\",_fmt)\n   _name=_m. groups(0)\n   _flags=_m. groups(1)\n   \n   _result. append((_pre,_name,_flags,None ))\n   \n return _result\n", ["re"]], "random": [".js", "// Javascript implementation of the random module\n// Based on Ian Bicking's implementation of the Mersenne twister\n\nvar $module = (function($B){\n\n_b_ = $B.builtins\n\nvar VERSION = 3\n\n// Code copied from https://github.com/ianb/whrandom/blob/master/mersenne.js\n// by Ian Bicking\n\n// this program is a JavaScript version of Mersenne Twister,\n// a straight conversion from the original program, mt19937ar.c,\n// translated by y. okada on july 17, 2006.\n// and modified a little at july 20, 2006, but there are not any substantial differences.\n// modularized by Ian Bicking, March 25, 2013 (found original version at http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/VERSIONS/JAVASCRIPT/java-script.html)\n// in this program, procedure descriptions and comments of original source code were not removed.\n// lines commented with //c// were originally descriptions of c procedure. and a few following lines are appropriate JavaScript descriptions.\n// lines commented with /* and */ are original comments.\n// lines commented with // are additional comments in this JavaScript version.\n/*\n   A C-program for MT19937, with initialization improved 2002/1/26.\n   Coded by Takuji Nishimura and Makoto Matsumoto.\n\n   Before using, initialize the state by using init_genrand(seed)\n   or init_by_array(init_key, key_length).\n\n   Copyright (C) 1997 - 2002, Makoto Matsumoto and Takuji Nishimura,\n   All rights reserved.\n\n   Redistribution and use in source and binary forms, with or without\n   modification, are permitted provided that the following conditions\n   are met:\n\n     1. Redistributions of source code must retain the above copyright\n        notice, this list of conditions and the following disclaimer.\n\n     2. Redistributions in binary form must reproduce the above copyright\n        notice, this list of conditions and the following disclaimer in the\n        documentation and/or other materials provided with the distribution.\n\n     3. The names of its contributors may not be used to endorse or promote\n        products derived from this software without specific prior written\n        permission.\n\n   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n   \"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR\n   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\n   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\n   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\n   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\n   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\n   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n\n   Any feedback is very welcome.\n   http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/emt.html\n   email: m-mat @ math.sci.hiroshima-u.ac.jp (remove space)\n*/\n\nfunction RandomStream(seed) {\n\n    /*jshint bitwise:false */\n    /* Period parameters */\n    //c//#define N 624\n    //c//#define M 397\n    //c//#define MATRIX_A 0x9908b0dfUL   /* constant vector a */\n    //c//#define UPPER_MASK 0x80000000UL /* most significant w-r bits */\n    //c//#define LOWER_MASK 0x7fffffffUL /* least significant r bits */\n    var N = 624\n    var M = 397\n    var MATRIX_A = 0x9908b0df   /* constant vector a */\n    var UPPER_MASK = 0x80000000 /* most significant w-r bits */\n    var LOWER_MASK = 0x7fffffff /* least significant r bits */\n    //c//static unsigned long mt[N]; /* the array for the state vector  */\n    //c//static int mti=N+1; /* mti==N+1 means mt[N] is not initialized */\n    var mt = new Array(N)   /* the array for the state vector  */\n    var mti = N + 1           /* mti==N+1 means mt[N] is not initialized */\n\n    function unsigned32(n1){\n        // returns a 32-bits unsiged integer from an operand to which applied a\n        // bit operator.\n        return n1 < 0 ? (n1 ^ UPPER_MASK) + UPPER_MASK : n1\n    }\n\n    function subtraction32(n1, n2){\n    // emulates lowerflow of a c 32-bits unsiged integer variable, instead of\n    // the operator -. these both arguments must be non-negative integers\n    // expressible using unsigned 32 bits.\n        return n1 < n2 ? unsigned32((0x100000000 - (n2 - n1)) & 0xffffffff) :\n          n1 - n2\n    }\n\n    function addition32(n1, n2){\n        // emulates overflow of a c 32-bits unsiged integer variable, instead of\n        // the operator +. these both arguments must be non-negative integers\n        // expressible using unsigned 32 bits.\n        return unsigned32((n1 + n2) & 0xffffffff)\n    }\n\n    function multiplication32(n1, n2){\n        // emulates overflow of a c 32-bits unsiged integer variable, instead of the\n        // operator *. these both arguments must be non-negative integers\n        // expressible using unsigned 32 bits.\n        var sum = 0\n        for (var i = 0; i < 32; ++i){\n            if((n1 >>> i) & 0x1){\n                sum = addition32(sum, unsigned32(n2 << i))\n            }\n        }\n        return sum\n    }\n\n    /* initializes mt[N] with a seed */\n    //c//void init_genrand(unsigned long s)\n    function init_genrand(s) {\n        //c//mt[0]= s & 0xffffffff;\n        mt[0] = unsigned32(s & 0xffffffff)\n        for(mti = 1; mti < N; mti++){\n            mt[mti] =\n                //c//(1812433253 * (mt[mti-1] ^ (mt[mti-1] >> 30)) + mti);\n                addition32(multiplication32(1812433253,\n                    unsigned32(mt[mti - 1] ^ (mt[mti - 1] >>> 30))), mti)\n            /* See Knuth TAOCP Vol2. 3rd Ed. P.106 for multiplier. */\n            /* In the previous versions, MSBs of the seed affect   */\n            /* only MSBs of the array mt[].                        */\n            /* 2002/01/09 modified by Makoto Matsumoto             */\n            //c//mt[mti] &= 0xffffffff;\n            mt[mti] = unsigned32(mt[mti] & 0xffffffff);\n            /* for >32 bit machines */\n        }\n    }\n\n    /* initialize by an array with array-length */\n    /* init_key is the array for initializing keys */\n    /* key_length is its length */\n    /* slight change for C++, 2004/2/26 */\n    //c//void init_by_array(unsigned long init_key[], int key_length)\n    function init_by_array(init_key, key_length) {\n        //c//int i, j, k;\n        var i, j, k\n        init_genrand(19650218)\n        i = 1\n        j = 0\n        k = (N > key_length ? N : key_length)\n        for(; k; k--){\n          //c//mt[i] = (mt[i] ^ ((mt[i-1] ^ (mt[i-1] >> 30)) * 1664525))\n          //c// + init_key[j] + j; /* non linear */\n          mt[i] = addition32(\n              addition32(unsigned32(mt[i] ^\n                  multiplication32(unsigned32(mt[i - 1] ^ (mt[i - 1] >>> 30)),\n                  1664525)),\n              init_key[j]), j)\n          mt[i] =\n              //c//mt[i] &= 0xffffffff; /* for WORDSIZE > 32 machines */\n              unsigned32(mt[i] & 0xffffffff)\n          i++\n          j++\n          if(i >= N){mt[0] = mt[N - 1]; i = 1}\n          if(j >= key_length){j = 0}\n        }\n        for(k = N - 1; k; k--){\n            //c//mt[i] = (mt[i] ^ ((mt[i-1] ^ (mt[i-1] >> 30)) * 1566083941))\n            //c//- i; /* non linear */\n            mt[i] = subtraction32(\n                unsigned32(\n                    (mt[i]) ^\n                        multiplication32(\n                            unsigned32(mt[i - 1] ^ (mt[i - 1] >>> 30)),\n                    1566083941)),\n                i\n            )\n            //c//mt[i] &= 0xffffffff; /* for WORDSIZE > 32 machines */\n            mt[i] = unsigned32(mt[i] & 0xffffffff)\n            i++\n            if(i >= N){mt[0] = mt[N - 1]; i = 1}\n        }\n        mt[0] = 0x80000000; /* MSB is 1; assuring non-zero initial array */\n    }\n\n    /* generates a random number on [0,0xffffffff]-interval */\n    //c//unsigned long genrand_int32(void)\n    function genrand_int32() {\n        //c//unsigned long y;\n        //c//static unsigned long mag01[2]={0x0UL, MATRIX_A};\n        var y;\n        var mag01 = [0x0, MATRIX_A];\n        /* mag01[x] = x * MATRIX_A  for x=0,1 */\n\n        if(mti >= N){ /* generate N words at one time */\n            //c//int kk;\n            var kk\n\n            if(mti == N + 1){   /* if init_genrand() has not been called, */\n              init_genrand(Date.now()) /* a default initial seed is used */\n            }\n\n            for(kk = 0; kk < N - M; kk++){\n              //c//y = (mt[kk]&UPPER_MASK)|(mt[kk+1]&LOWER_MASK);\n              //c//mt[kk] = mt[kk+M] ^ (y >> 1) ^ mag01[y & 0x1];\n              y = unsigned32((mt[kk]&UPPER_MASK) | (mt[kk + 1]&LOWER_MASK))\n              mt[kk] = unsigned32(mt[kk + M] ^ (y >>> 1) ^ mag01[y & 0x1])\n            }\n            for(;kk < N - 1; kk++){\n              //c//y = (mt[kk]&UPPER_MASK)|(mt[kk+1]&LOWER_MASK);\n              //c//mt[kk] = mt[kk+(M-N)] ^ (y >> 1) ^ mag01[y & 0x1];\n              y = unsigned32((mt[kk]&UPPER_MASK) | (mt[kk + 1]&LOWER_MASK))\n              mt[kk] = unsigned32(mt[kk + (M - N)] ^ (y >>> 1) ^ mag01[y & 0x1])\n            }\n            //c//y = (mt[N-1]&UPPER_MASK)|(mt[0]&LOWER_MASK);\n            //c//mt[N-1] = mt[M-1] ^ (y >> 1) ^ mag01[y & 0x1];\n            y = unsigned32((mt[N - 1] & UPPER_MASK) | (mt[0] & LOWER_MASK))\n            mt[N - 1] = unsigned32(mt[M - 1] ^ (y >>> 1) ^ mag01[y & 0x1])\n            mti = 0\n        }\n\n        y = mt[mti++]\n\n        /* Tempering */\n        //c//y ^= (y >> 11);\n        //c//y ^= (y << 7) & 0x9d2c5680;\n        //c//y ^= (y << 15) & 0xefc60000;\n        //c//y ^= (y >> 18);\n        y = unsigned32(y ^ (y >>> 11))\n        y = unsigned32(y ^ ((y << 7) & 0x9d2c5680))\n        y = unsigned32(y ^ ((y << 15) & 0xefc60000))\n        y = unsigned32(y ^ (y >>> 18))\n\n        return y\n    }\n\n    /* generates a random number on [0,0x7fffffff]-interval */\n    //c//long genrand_int31(void)\n    function genrand_int31(){\n        //c//return (genrand_int32()>>1);\n        return (genrand_int32()>>>1)\n    }\n\n    /* generates a random number on [0,1]-real-interval */\n    //c//double genrand_real1(void)\n    function genrand_real1(){\n        return genrand_int32()*(1.0/4294967295.0)\n        /* divided by 2^32-1 */\n    }\n\n    /* generates a random number on [0,1)-real-interval */\n    //c//double genrand_real2(void)\n    function genrand_real2(){\n        return genrand_int32() * (1.0 / 4294967296.0)\n        /* divided by 2^32 */\n    }\n\n    /* generates a random number on (0,1)-real-interval */\n    //c//double genrand_real3(void)\n    function genrand_real3() {\n        return ((genrand_int32()) + 0.5) * (1.0 / 4294967296.0)\n        /* divided by 2^32 */\n    }\n\n    /* generates a random number on [0,1) with 53-bit resolution*/\n    //c//double genrand_res53(void)\n    function genrand_res53() {\n        //c//unsigned long a=genrand_int32()>>5, b=genrand_int32()>>6;\n        var a = genrand_int32() >>> 5,\n            b = genrand_int32() >>> 6\n        return (a * 67108864.0 + b) * (1.0 / 9007199254740992.0)\n    }\n    /* These real versions are due to Isaku Wada, 2002/01/09 added */\n\n    var random = genrand_res53\n\n    random.seed = function(seed){\n        if(! seed){seed = Date.now()}\n        if(typeof seed != \"number\"){seed = parseInt(seed, 10)}\n        if((seed !== 0 && ! seed) || isNaN(seed)){throw \"Bad seed\"}\n        init_genrand(seed)\n    }\n\n    random.seed(seed)\n\n    random.int31 = genrand_int31\n    random.real1 = genrand_real1\n    random.real2 = genrand_real2\n    random.real3 = genrand_real3\n    random.res53 = genrand_res53\n\n    // Added for compatibility with Python\n    random.getstate = function(){return [VERSION, mt, mti]}\n\n    random.setstate = function(state){\n        mt = state[1]\n        mti = state[2]\n    }\n\n    return random\n\n}\n\n// magic constants\n\nvar NV_MAGICCONST = 4 * Math.exp(-0.5)/Math.sqrt(2),\n    gauss_next = null,\n    NV_MAGICCONST = 1.71552776992141,\n    TWOPI = 6.28318530718,\n    LOG4 = 1.38629436111989,\n    SG_MAGICCONST = 2.50407739677627,\n    VERSION = VERSION\n\nvar Random = $B.make_class(\"Random\",\n    function(){\n        return {\n            __class__: Random,\n            _random: RandomStream()\n        }\n    }\n)\n\nRandom._randbelow = function(self, x){\n    return Math.floor(x * self._random())\n}\n\nRandom._urandom = function(self, n){\n    /*\n    urandom(n) -> str\n    Return n random bytes suitable for cryptographic use.\n    */\n\n    var randbytes = []\n    for(i = 0; i < n; i++){randbytes.push(parseInt(self._random() * 256))}\n    return _b_.bytes.$factory(randbytes)\n}\n\nRandom.betavariate = function(){\n    /* Beta distribution.\n\n    Conditions on the parameters are alpha > 0 and beta > 0.\n    Returned values range between 0 and 1.\n\n\n    # This version due to Janne Sinkkonen, and matches all the std\n    # texts (e.g., Knuth Vol 2 Ed 3 pg 134 \"the beta distribution\").\n    */\n\n    var $ = $B.args('betavariate', 3, {self: null, alpha:null, beta:null},\n            ['self', 'alpha', 'beta'], arguments, {}, null, null),\n        self = $.self,\n        alpha = $.alpha,\n        beta = $.beta\n\n    var y = Random.gammavariate(self, alpha, 1)\n    if(y == 0){return _b_.float.$factory(0)}\n    else{return y / (y + Random.gammavariate(self, beta, 1))}\n}\n\nRandom.choice = function(){\n    var $ = $B.args(\"choice\", 2,\n        {self: null, seq:null},[\"self\", \"seq\"],arguments, {}, null, null),\n        self = $.self,\n        seq = $.seq\n    var len, rank\n    if(Array.isArray(seq)){len = seq.length}\n    else{len = _b_.getattr(seq,\"__len__\")()}\n    if(len == 0){\n        throw _b_.IndexError.$factory(\"Cannot choose from an empty sequence\")\n    }\n    rank = parseInt(self._random() * len)\n    if(Array.isArray(seq)){return seq[rank]}\n    else{return _b_.getattr(seq, \"__getitem__\")(rank)}\n}\n\nRandom.expovariate = function(self, lambd){\n    /*\n    Exponential distribution.\n\n    lambd is 1.0 divided by the desired mean.  It should be\n    nonzero.  (The parameter would be called \"lambda\", but that is\n    a reserved word in Python.)  Returned values range from 0 to\n    positive infinity if lambd is positive, and from negative\n    infinity to 0 if lambd is negative.\n\n    */\n    // lambd: rate lambd = 1/mean\n    // ('lambda' is a Python reserved word)\n\n    // we use 1-random() instead of random() to preclude the\n    // possibility of taking the log of zero.\n    return -Math.log(1.0 - self._random()) / lambd\n}\n\nRandom.gammavariate = function(self, alpha, beta){\n    /* Gamma distribution.  Not the gamma function!\n\n    Conditions on the parameters are alpha > 0 and beta > 0.\n\n    The probability distribution function is:\n\n                x ** (alpha - 1) * math.exp(-x / beta)\n      pdf(x) =  --------------------------------------\n                  math.gamma(alpha) * beta ** alpha\n\n    */\n\n    // alpha > 0, beta > 0, mean is alpha*beta, variance is alpha*beta**2\n\n    // Warning: a few older sources define the gamma distribution in terms\n    // of alpha > -1.0\n\n    var $ = $B.args('gammavariate', 3,\n            {self: null, alpha:null, beta:null},\n            ['self', 'alpha', 'beta'],\n            arguments, {}, null, null),\n        self = $.self,\n        alpha = $.alpha,\n        beta = $.beta,\n        LOG4 = Math.log(4),\n        SG_MAGICCONST = 1.0 + Math.log(4.5)\n\n    if(alpha <= 0.0 || beta <= 0.0){\n        throw _b_.ValueError.$factory('gammavariate: alpha and beta must be > 0.0')\n    }\n\n    if(alpha > 1.0){\n\n        // Uses R.C.H. Cheng, \"The generation of Gamma\n        // variables with non-integral shape parameters\",\n        // Applied Statistics, (1977), 26, No. 1, p71-74\n\n        var ainv = Math.sqrt(2.0 * alpha - 1.0),\n            bbb = alpha - LOG4,\n            ccc = alpha + ainv\n\n        while(true){\n            var u1 = self._random()\n            if(!((1e-7 < u1) && (u1 < .9999999))){\n                continue\n            }\n            var u2 = 1.0 - self._random(),\n                v = Math.log(u1 / (1.0 - u1)) / ainv,\n                x = alpha * Math.exp(v),\n                z = u1 * u1 * u2,\n                r = bbb + ccc * v - x\n            if((r + SG_MAGICCONST - 4.5 * z >= 0.0) || r >= Math.log(z)){\n                return x * beta\n            }\n        }\n    }else if(alpha == 1.0){\n        // expovariate(1)\n        var u = _random()\n        while(u <= 1e-7){u = self._random()}\n        return -Math.log(u) * beta\n    }else{\n        // alpha is between 0 and 1 (exclusive)\n\n        // Uses ALGORITHM GS of Statistical Computing - Kennedy & Gentle\n\n        while(true){\n            var u = self._random(),\n                b = (Math.E + alpha)/Math.E,\n                p = b*u,\n                x\n            if(p <= 1.0){x = Math.pow(p, (1.0/alpha))}\n            else{x = -Math.log((b-p)/alpha)}\n            var u1 = self._random()\n            if(p > 1.0){\n                if(u1 <= Math.pow(x, alpha - 1.0)){\n                    break\n                }\n            }else if(u1 <= Math.exp(-x)){\n                break\n            }\n        }\n        return x * beta\n    }\n}\n\nRandom.gauss = function(){\n\n    /* Gaussian distribution.\n\n    mu is the mean, and sigma is the standard deviation.  This is\n    slightly faster than the normalvariate() function.\n\n    Not thread-safe without a lock around calls.\n\n    # When x and y are two variables from [0, 1), uniformly\n    # distributed, then\n    #\n    #    cos(2*pi*x)*sqrt(-2*log(1-y))\n    #    sin(2*pi*x)*sqrt(-2*log(1-y))\n    #\n    # are two *independent* variables with normal distribution\n    # (mu = 0, sigma = 1).\n    # (Lambert Meertens)\n    # (corrected version; bug discovered by Mike Miller, fixed by LM)\n\n    # Multithreading note: When two threads call this function\n    # simultaneously, it is possible that they will receive the\n    # same return value.  The window is very small though.  To\n    # avoid this, you have to use a lock around all calls.  (I\n    # didn't want to slow this down in the serial case by using a\n    # lock here.)\n    */\n\n    var $ = $B.args('gauss', 3, {self: null, mu:null, sigma:null},\n            ['self', 'mu', 'sigma'], arguments, {}, null, null),\n        self = $.self,\n        mu = $.mu,\n        sigma = $.sigma\n\n    var z = gauss_next\n    gauss_next = null\n    if(z === null){\n        var x2pi = self._random() * Math.PI * 2,\n            g2rad = Math.sqrt(-2.0 * Math.log(1.0 - self._random())),\n            z = Math.cos(x2pi) * g2rad\n        gauss_next = Math.sin(x2pi) * g2rad\n    }\n    return mu + z*sigma\n}\n\nRandom.getrandbits = function(){\n    var $ = $B.args(\"getrandbits\", 2,\n        {self: null, k:null},[\"self\", \"k\"],arguments, {}, null, null),\n        self = $.self,\n        k = $B.$GetInt($.k)\n    // getrandbits(k) -> x.  Generates a long int with k random bits.\n    if(k <= 0){\n        throw _b_.ValueError.$factory('number of bits must be greater than zero')\n    }\n    if(k != _b_.int.$factory(k)){\n        throw _b_.TypeError('number of bits should be an integer')\n    }\n    var numbytes = (k + 7), // bits / 8 and rounded up\n        x = _b_.int.from_bytes(Random._urandom(self, numbytes), 'big')\n    return _b_.getattr(x, '__rshift__')(\n        _b_.getattr(numbytes*8,'__sub__')(k))\n}\n\nRandom.getstate = function(){\n    // Return internal state; can be passed to setstate() later.\n    var $ = $B.args('getstate', 1, {self: null},\n        [\"self\"], arguments, {}, null, null)\n    return $.self._random.getstate()\n}\n\nRandom.lognormvariate = function(){\n    /*\n    Log normal distribution.\n\n    If you take the natural logarithm of this distribution, you'll get a\n    normal distribution with mean mu and standard deviation sigma.\n    mu can have any value, and sigma must be greater than zero.\n\n    */\n    return Math.exp(Random.normalvariate.apply(null, arguments))\n}\n\nRandom.normalvariate = function(){\n    /*\n    Normal distribution.\n\n    mu is the mean, and sigma is the standard deviation.\n\n    */\n\n    // mu = mean, sigma = standard deviation\n\n    // Uses Kinderman and Monahan method. Reference: Kinderman,\n    // A.J. and Monahan, J.F., \"Computer generation of random\n    // variables using the ratio of uniform deviates\", ACM Trans\n    // Math Software, 3, (1977), pp257-260.\n\n    var $ = $B.args(\"normalvariate\", 3,\n        {self: null, mu:null, sigma:null}, [\"self\", \"mu\", \"sigma\"],\n        arguments, {}, null, null),\n        self = $.self,\n        mu = $.mu,\n        sigma = $.sigma\n\n    while(true){\n        var u1 = self._random(),\n            u2 = 1.0 - self._random(),\n            z = NV_MAGICCONST * (u1 - 0.5) / u2,\n            zz = z * z / 4.0\n        if(zz <= -Math.log(u2)){break}\n    }\n    return mu + z * sigma\n}\n\nRandom.paretovariate = function(){\n    /* Pareto distribution.  alpha is the shape parameter.*/\n    // Jain, pg. 495\n\n    var $ = $B.args(\"paretovariate\", 2, {self: null, alpha:null},\n        [\"self\", \"alpha\"], arguments, {}, null, null)\n\n    var u = 1 - $.self._random()\n    return 1 / Math.pow(u, 1 / $.alpha)\n}\n\nRandom.randint = function(self, a, b){\n    var $ = $B.args('randint', 3,\n        {self: null, a:null, b:null},\n        ['self', 'a', 'b'],\n        arguments, {}, null, null)\n    return Random.randrange($.self, $.a, $.b + 1)\n}\n\nRandom.random = function(self){\n    return self._random()\n}\n\nRandom.randrange = function(){\n    var $ = $B.args('randrange', 4,\n        {self: null, x:null, stop:null, step:null},\n        ['self', 'x', 'stop', 'step'],\n        arguments, {stop:null, step:null}, null, null),\n        self = $.self,\n        _random = self._random\n        //console.log(\"randrange\", $)\n\n    if($.stop === null){\n        var start = 0, stop = $.x, step = 1\n    }else{\n        var start = $.x, stop = $.stop,\n            step = $.step === null ? 1 : $.step\n        if(step == 0){throw _b_.ValueError.$factory('step cannot be 0')}\n    }\n    if((step > 0 && start > stop) || (step < 0 && start < stop)){\n        throw _b_.ValueError.$factory(\"empty range for randrange() (\" +\n            start + \", \" + stop + \", \" + step + \")\")\n    }\n    if(typeof start == 'number' && typeof stop == 'number' &&\n        typeof step == 'number'){\n        return start + step * Math.floor(_random() *\n            Math.ceil((stop - start) / step))\n    }else{\n        var d = _b_.getattr(stop, '__sub__')(start)\n        d = _b_.getattr(d, '__floordiv__')(step)\n        // Force d to be a LongInt\n        d = $B.long_int.$factory(d)\n        // d is a long integer with n digits ; to choose a random number\n        // between 0 and d the most simple is to take a random digit\n        // at each position, except the first one\n        var s = d.value,\n            _len = s.length,\n            res = Math.floor(_random() * (parseInt(s.charAt(0)) +\n                (_len == 1 ? 0 : 1))) + ''\n        var same_start = res.charAt(0) == s.charAt(0)\n        for(var i = 1; i < _len; i++){\n            if(same_start){\n                // If it's the last digit, don't allow stop as valid\n                if(i == _len - 1){\n                    res += Math.floor(_random() * parseInt(s.charAt(i))) + ''\n                }else{\n                    res += Math.floor(_random() *\n                        (parseInt(s.charAt(i)) + 1)) + ''\n                    same_start = res.charAt(i) == s.charAt(i)\n                }\n            }else{\n                res += Math.floor(_random() * 10) + ''\n            }\n        }\n        var offset = {__class__: $B.long_int, value: res,\n            pos: true}\n        d = _b_.getattr(step, '__mul__')(offset)\n        d = _b_.getattr(start, '__add__')(d)\n        return _b_.int.$factory(d)\n    }\n}\n\nRandom.sample = function(){\n    /*\n    Chooses k unique random elements from a population sequence or set.\n\n    Returns a new list containing elements from the population while\n    leaving the original population unchanged.  The resulting list is\n    in selection order so that all sub-slices will also be valid random\n    samples.  This allows raffle winners (the sample) to be partitioned\n    into grand prize and second place winners (the subslices).\n\n    Members of the population need not be hashable or unique.  If the\n    population contains repeats, then each occurrence is a possible\n    selection in the sample.\n\n    To choose a sample in a range of integers, use range as an argument.\n    This is especially fast and space efficient for sampling from a\n    large population:   sample(range(10000000), 60)\n\n    # Sampling without replacement entails tracking either potential\n    # selections (the pool) in a list or previous selections in a set.\n\n    # When the number of selections is small compared to the\n    # population, then tracking selections is efficient, requiring\n    # only a small set and an occasional reselection.  For\n    # a larger number of selections, the pool tracking method is\n    # preferred since the list takes less space than the\n    # set and it doesn't suffer from frequent reselections.'\n\n    */\n    var $ = $B.args('sample', 3, {self: null, population: null,k: null},\n        ['self', 'population','k'], arguments, {}, null, null),\n        self = $.self,\n        population = $.population,\n        k = $.k\n\n    if(!_b_.hasattr(population, '__len__')){\n        throw _b_.TypeError(\"Population must be a sequence or set. \" +\n            \"For dicts, use list(d).\")\n    }\n    var n = _b_.getattr(population, '__len__')()\n\n    if(k < 0 || k > n){\n        throw _b_.ValueError.$factory(\"Sample larger than population\")\n    }\n    var result = [],\n        setsize = 21        // size of a small set minus size of an empty list\n    if(k > 5){\n        setsize += Math.pow(4, Math.ceil(Math.log(k * 3, 4))) // table size for big sets\n    }\n    if(n <= setsize){\n        // An n-length list is smaller than a k-length set\n        if(Array.isArray(population)){\n            var pool = population.slice()\n        }else{var pool = _b_.list.$factory(population)}\n        for(var i = 0; i < k; i++){ //invariant:  non-selected at [0,n-i)\n            var j = Random._randbelow(self, n - i)\n            result[i] = pool[j]\n            pool[j] = pool[n - i - 1]   // move non-selected item into vacancy\n        }\n    }else{\n        selected = {}\n        for(var i = 0; i < k; i++){\n            var j = Random._randbelow(self, n)\n            while(selected[j] !== undefined){\n                j = Random._randbelow(self, n)\n            }\n            selected[j] = true\n            result[i] = Array.isArray(population) ? population[j] :\n                            _b_.getattr(population, '__getitem__')(j)\n        }\n    }\n    return result\n}\n\nRandom.seed = function(){\n    /*\n    Initialize internal state from hashable object.\n\n    None or no argument seeds from current time or from an operating\n    system specific randomness source if available.\n\n    If *a* is an int, all bits are used.\n    */\n    var $ = $B.args('seed', 3, {self: null, a: null, version: null},\n        ['self', 'a', 'version'],\n        arguments, {a: new Date(), version: 2}, null, null),\n        self = $.self,\n        a = $.a,\n        version = $.version\n\n    if(version == 1){a = _b_.hash(a)}\n    else if(version == 2){\n        if(_b_.isinstance(a, _b_.str)){\n            a = _b_.int.from_bytes(_b_.bytes.$factory(a, 'utf-8'), 'big')\n        }else if(_b_.isinstance(a, [_b_.bytes, _b_.bytearray])){\n            a = _b_.int.from_bytes(a, 'big')\n        }else if(!_b_.isinstance(a, _b_.int)){\n            throw _b_.TypeError('wrong argument')\n        }\n        if(a.__class__ === $B.long_int){\n            // In this implementation, seed() only accepts safe integers\n            // Generate a random one from the underlying string value,\n            // using an arbitrary seed (99) to always return the same\n            // integer\n            var numbers = a.value,\n                res = '',\n                pos\n            self._random.seed(99)\n            for(var i = 0; i < 17; i++){\n                pos = parseInt(self._random() * numbers.length)\n                res += numbers.charAt(pos)\n            }\n            a = parseInt(res)\n        }\n    }else{\n        throw ValueError.$factory('version can only be 1 or 2')\n    }\n\n    self._random.seed(a)\n    gauss_next = null\n}\n\nRandom.setstate = function(state){\n    // Restore internal state from object returned by getstate().\n    var $ = $B.args('setstate', 2, {self: null, state:null}, ['self', 'state'],\n        arguments, {}, null, null),\n        self = $.self\n    var state = self._random.getstate()\n    if(! Array.isArray($.state)){\n        throw _b_.TypeError('state must be a list, not '+\n            $B.get_class($.state).__name__)\n    }\n    if($.state.length < state.length){\n        throw _b_.ValueError.$factory(\"need more than \" + $.state.length +\n            \" values to unpack\")\n    }else if($.state.length > state.length){\n        throw _b_.ValueError.$factory(\"too many values to unpack (expected \" +\n            state.length + \")\")\n    }\n    if($.state[0] != 3){\n        throw _b_.ValueError.$factory(\"ValueError: state with version \" +\n            $.state[0] + \" passed to Random.setstate() of version 3\")\n    }\n    var second = _b_.list.$factory($.state[1])\n    if(second.length !== state[1].length){\n        throw _b_.ValueError.$factory('state vector is the wrong size')\n    }\n    for(var i = 0; i < second.length; i++){\n        if(typeof second[i] != 'number'){\n            throw _b_.ValueError.$factory('state vector items must be integers')\n        }\n    }\n    self._random.setstate($.state)\n}\n\nRandom.shuffle = function(x, random){\n    /*\n    x, random = random.random -> shuffle list x in place; return None.\n\n    Optional arg random is a 0-argument function returning a random\n    float in [0.0, 1.0); by default, the standard random.random.\n    */\n\n    var $ = $B.args('shuffle', 3, {self: null, x: null, random: null},\n        ['self', 'x','random'],\n        arguments, {random: null}, null, null),\n        self = $.self,\n        x = $.x,\n        random = $.random\n\n    if(random === null){random = self._random}\n\n    if(Array.isArray(x)){\n        for(var i = x.length - 1; i >= 0;i--){\n            var j = Math.floor(random() * (i + 1)),\n                temp = x[j]\n            x[j] = x[i]\n            x[i] = temp\n        }\n    }else{\n        var len = _b_.getattr(x, '__len__')(), temp,\n            x_get = _b_.getattr(x, '__getitem__'),\n            x_set = _b_.getattr(x, '__setitem__')\n\n        for(i = len - 1; i >= 0; i--){\n            var j = Math.floor(random() * (i + 1)),\n                temp = x_get(j)\n            x_set(j, x_get(i))\n            x_set(i, temp)\n        }\n    }\n}\n\nRandom.triangular = function(){\n    /*\n    Triangular distribution.\n\n    Continuous distribution bounded by given lower and upper limits,\n    and having a given mode value in-between.\n\n    http://en.wikipedia.org/wiki/Triangular_distribution\n    */\n    var $ = $B.args('triangular', 4,\n        {self: null, low: null, high: null, mode: null},\n        ['self', 'low', 'high', 'mode'],\n        arguments, {low: 0, high: 1, mode: null}, null, null),\n        low = $.low,\n        high = $.high,\n        mode = $.mode\n\n    var u = $.self._random(),\n        c = mode === null ? 0.5 : (mode - low) / (high - low)\n    if(u > c){\n        u = 1 - u\n        c = 1 - c\n        var temp = low\n        low = high\n        high = temp\n    }\n    return low + (high - low) * Math.pow(u * c, 0.5)\n}\n\nRandom.uniform = function(){\n    var $ = $B.args('uniform', 3, {self: null, a: null, b: null},\n        ['self', 'a', 'b'], arguments, {}, null, null),\n        a = $B.$GetInt($.a),\n        b = $B.$GetInt($.b)\n\n    return a + (b - a) * $.self._random()\n}\n\nRandom.vonmisesvariate = function(){\n    /* Circular data distribution.\n\n    mu is the mean angle, expressed in radians between 0 and 2*pi, and\n    kappa is the concentration parameter, which must be greater than or\n    equal to zero.  If kappa is equal to zero, this distribution reduces\n    to a uniform random angle over the range 0 to 2*pi.\n\n    */\n    // mu:    mean angle (in radians between 0 and 2*pi)\n    // kappa: concentration parameter kappa (>= 0)\n    // if kappa = 0 generate uniform random angle\n\n    // Based upon an algorithm published in: Fisher, N.I.,\n    // \"Statistical Analysis of Circular Data\", Cambridge\n    // University Press, 1993.\n\n    // Thanks to Magnus Kessler for a correction to the\n    // implementation of step 4.\n\n    var $ = $B.args('vonmisesvariate', 3,\n            {self: null, mu: null, kappa:null}, ['self', 'mu', 'kappa'],\n            arguments, {}, null, null),\n        self = $.self,\n        mu = $.mu,\n        kappa = $.kappa,\n        TWOPI = 2*Math.PI\n\n    if(kappa <= 1e-6){return TWOPI * self._random()}\n\n    var s = 0.5 / kappa,\n        r = s + Math.sqrt(1.0 + s * s)\n\n    while(true){\n        var u1 = self._random(),\n            z = Math.cos(Math.PI * u1),\n            d = z / (r + z),\n            u2 = self._random()\n        if((u2 < 1.0 - d * d) ||\n            (u2 <= (1.0 - d) * Math.exp(d))){\n                break\n        }\n    }\n    var q = 1.0 / r,\n        f = (q + z) / (1.0 + q * z),\n        u3 = self._random()\n    if(u3 > 0.5){var theta = (mu + Math.acos(f)) % TWOPI}\n    else{var theta = (mu - Math.acos(f)) % TWOPI}\n    return theta\n}\n\nRandom.weibullvariate = function(){\n    /*Weibull distribution.\n\n    alpha is the scale parameter and beta is the shape parameter.\n\n    */\n    // Jain, pg. 499; bug fix courtesy Bill Arms\n    var $ = $B.args(\"weibullvariate\", 3, \n        {self: null, alpha: null, beta: null},\n        [\"self\", \"alpha\", \"beta\"], arguments, {}, null, null)\n\n    var u = 1 - $.self._random()\n    return $.alpha * Math.pow(-Math.log(u), 1 / $.beta)\n}\n\n$B.set_func_names(Random, \"random\")\n\nvar $module = Random.$factory()\nfor(var attr in Random){\n    $module[attr] = (function(x){\n        return function(){return Random[x]($module, ...arguments)}\n    })(attr)\n    $module[attr].$infos = Random[attr].$infos\n}\n\n$module.Random = Random\n\nvar SystemRandom = $B.make_class(\"SystemRandom\",\n    function(){\n        return {__class__: SystemRandom}\n    }\n)\nSystemRandom.__getattribute__ = function(){\n    throw $B.builtins.NotImplementedError()\n}\n\n$module.SystemRandom = SystemRandom\n\nreturn $module\n\n})(__BRYTHON__)\n\n"], "os": [".py", "''\n\n\n\nimport sys\n\nerror=OSError\nname='posix'\nlinesep='\\n'\n\nfrom posix import *\nimport posixpath as path\n\nsys. modules['os.path']=path\nfrom os. path import (curdir,pardir,sep,pathsep,defpath,extsep,altsep,\ndevnull)\n\nenviron={'HOME':__BRYTHON__. curdir,\n'PYTHONPATH':__BRYTHON__. brython_path\n}\n\ndef _get_exports_list(module):\n try :\n  return list(module. __all__)\n except AttributeError:\n  return [n for n in dir(module)if n[0]!='_']\n  \ndef getenv(key,default=None ):\n ''\n\n \n return environ. get(key,default)\n \nsupports_bytes_environ=True\n\ndef chdir(path):\n __BRYTHON__. curdir=path\n \ndef fsencode(filename):\n ''\n\n\n\n \n encoding=sys. getfilesystemencoding()\n errors='surrogateescape'\n if isinstance(filename,bytes):\n  return filename\n elif isinstance(filename,str):\n  return filename. encode(encoding,errors)\n else :\n  raise TypeError(\"expect bytes or str, not %s\"%type(filename). __name__)\n  \ndef fsdecode(filename):\n ''\n\n\n\n \n encoding=sys. getfilesystemencoding()\n errors='surrogateescape'\n if isinstance(filename,str):\n  return filename\n elif isinstance(filename,bytes):\n  return filename. decode(encoding,errors)\n else :\n  raise TypeError(\"expect bytes or str, not %s\"%type(filename). __name__)\ndef getcwd():\n return __BRYTHON__. curdir\n \n_set=set()\n\nsupports_dir_fd=_set\n\nsupports_effective_ids=_set\n\nsupports_fd=_set\n\nsupports_follow_symlinks=_set\n\n", ["os.path", "posix", "posixpath", "sys"]], "http": [".py", "", [], 1], "traceback": [".py", "import sys\nfrom browser import console\n\ndef _restore_current(exc):\n ''\n\n \n __BRYTHON__. current_exception=exc\n \ndef print_exc(file=sys. stderr):\n file. write(format_exc())\n \ndef format_exc(limit=None ,chain=True ):\n exc=__BRYTHON__. current_exception\n return format_exception(exc. __class__,exc,exc. traceback)\n \ndef format_exception(_type,exc,tb,limit=None ,chain=True ):\n res='';\n if isinstance(exc,SyntaxError):\n  res +='\\n module %s line %s'%(exc. args[1],exc. args[2])\n  offset=exc. args[3]\n  res +='\\n  '+exc. args[4]\n  res +='\\n  '+offset *' '+'^'\n else :\n  res +=exc. info\n msg=exc. __class__. __name__+': '\n try :\n  msg +=str(exc)\n except :\n  msg +='<unprintable {} object>'. format(exc. __class__. __name__)\n res='\\n'+msg+'\\n'+res\n if not res. endswith('\\n'):\n  res +='\\n'\n _restore_current(exc)\n return res\n \ndef extract_tb(tb,limit=None ):\n return tb\n", ["browser", "sys"]], "_warnings": [".py", "''\n\n\n\ndefault_action=\"\"\"default\"\"\"\n\nfilters=[('ignore',None ,DeprecationWarning,None ,0),\n('ignore',None ,PendingDeprecationWarning,None ,0),\n('ignore',None ,ImportWarning,None ,0),\n('ignore',None ,BytesWarning,None ,0)]\n\nonce_registry={}\n\ndef warn(*args,**kw):\n ''\n pass\n \ndef warn_explicit(*args,**kw):\n ''\n pass\n", []], "formatter": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nimport sys\n\n\nAS_IS=None\n\n\nclass NullFormatter:\n ''\n\n\n\n\n\n\n\n \n \n def __init__(self,writer=None ):\n  if writer is None :\n   writer=NullWriter()\n  self. writer=writer\n def end_paragraph(self,blankline):pass\n def add_line_break(self):pass\n def add_hor_rule(self,*args,**kw):pass\n def add_label_data(self,format,counter,blankline=None ):pass\n def add_flowing_data(self,data):pass\n def add_literal_data(self,data):pass\n def flush_softspace(self):pass\n def push_alignment(self,align):pass\n def pop_alignment(self):pass\n def push_font(self,x):pass\n def pop_font(self):pass\n def push_margin(self,margin):pass\n def pop_margin(self):pass\n def set_spacing(self,spacing):pass\n def push_style(self,*styles):pass\n def pop_style(self,n=1):pass\n def assert_line_data(self,flag=1):pass\n \n \nclass AbstractFormatter:\n ''\n\n\n\n\n\n \n \n \n \n \n \n \n def __init__(self,writer):\n  self. writer=writer\n  self. align=None\n  self. align_stack=[]\n  self. font_stack=[]\n  self. margin_stack=[]\n  self. spacing=None\n  self. style_stack=[]\n  self. nospace=1\n  self. softspace=0\n  self. para_end=1\n  self. parskip=0\n  self. hard_break=1\n  self. have_label=0\n  \n def end_paragraph(self,blankline):\n  if not self. hard_break:\n   self. writer. send_line_break()\n   self. have_label=0\n  if self. parskip <blankline and not self. have_label:\n   self. writer. send_paragraph(blankline -self. parskip)\n   self. parskip=blankline\n   self. have_label=0\n  self. hard_break=self. nospace=self. para_end=1\n  self. softspace=0\n  \n def add_line_break(self):\n  if not (self. hard_break or self. para_end):\n   self. writer. send_line_break()\n   self. have_label=self. parskip=0\n  self. hard_break=self. nospace=1\n  self. softspace=0\n  \n def add_hor_rule(self,*args,**kw):\n  if not self. hard_break:\n   self. writer. send_line_break()\n  self. writer. send_hor_rule(*args,**kw)\n  self. hard_break=self. nospace=1\n  self. have_label=self. para_end=self. softspace=self. parskip=0\n  \n def add_label_data(self,format,counter,blankline=None ):\n  if self. have_label or not self. hard_break:\n   self. writer. send_line_break()\n  if not self. para_end:\n   self. writer. send_paragraph((blankline and 1)or 0)\n  if isinstance(format,str):\n   self. writer. send_label_data(self. format_counter(format,counter))\n  else :\n   self. writer. send_label_data(format)\n  self. nospace=self. have_label=self. hard_break=self. para_end=1\n  self. softspace=self. parskip=0\n  \n def format_counter(self,format,counter):\n  label=''\n  for c in format:\n   if c =='1':\n    label=label+('%d'%counter)\n   elif c in'aA':\n    if counter >0:\n     label=label+self. format_letter(c,counter)\n   elif c in'iI':\n    if counter >0:\n     label=label+self. format_roman(c,counter)\n   else :\n    label=label+c\n  return label\n  \n def format_letter(self,case,counter):\n  label=''\n  while counter >0:\n   counter,x=divmod(counter -1,26)\n   \n   \n   \n   s=chr(ord(case)+x)\n   label=s+label\n  return label\n  \n def format_roman(self,case,counter):\n  ones=['i','x','c','m']\n  fives=['v','l','d']\n  label,index='',0\n  \n  while counter >0:\n   counter,x=divmod(counter,10)\n   if x ==9:\n    label=ones[index]+ones[index+1]+label\n   elif x ==4:\n    label=ones[index]+fives[index]+label\n   else :\n    if x >=5:\n     s=fives[index]\n     x=x -5\n    else :\n     s=''\n    s=s+ones[index]*x\n    label=s+label\n   index=index+1\n  if case =='I':\n   return label. upper()\n  return label\n  \n def add_flowing_data(self,data):\n  if not data:return\n  prespace=data[:1]. isspace()\n  postspace=data[-1:]. isspace()\n  data=\" \". join(data. split())\n  if self. nospace and not data:\n   return\n  elif prespace or self. softspace:\n   if not data:\n    if not self. nospace:\n     self. softspace=1\n     self. parskip=0\n    return\n   if not self. nospace:\n    data=' '+data\n  self. hard_break=self. nospace=self. para_end=  self. parskip=self. have_label=0\n  self. softspace=postspace\n  self. writer. send_flowing_data(data)\n  \n def add_literal_data(self,data):\n  if not data:return\n  if self. softspace:\n   self. writer. send_flowing_data(\" \")\n  self. hard_break=data[-1:]=='\\n'\n  self. nospace=self. para_end=self. softspace=  self. parskip=self. have_label=0\n  self. writer. send_literal_data(data)\n  \n def flush_softspace(self):\n  if self. softspace:\n   self. hard_break=self. para_end=self. parskip=   self. have_label=self. softspace=0\n   self. nospace=1\n   self. writer. send_flowing_data(' ')\n   \n def push_alignment(self,align):\n  if align and align !=self. align:\n   self. writer. new_alignment(align)\n   self. align=align\n   self. align_stack. append(align)\n  else :\n   self. align_stack. append(self. align)\n   \n def pop_alignment(self):\n  if self. align_stack:\n   del self. align_stack[-1]\n  if self. align_stack:\n   self. align=align=self. align_stack[-1]\n   self. writer. new_alignment(align)\n  else :\n   self. align=None\n   self. writer. new_alignment(None )\n   \n def push_font(self,font):\n  size,i,b,tt=font\n  if self. softspace:\n   self. hard_break=self. para_end=self. softspace=0\n   self. nospace=1\n   self. writer. send_flowing_data(' ')\n  if self. font_stack:\n   csize,ci,cb,ctt=self. font_stack[-1]\n   if size is AS_IS:size=csize\n   if i is AS_IS:i=ci\n   if b is AS_IS:b=cb\n   if tt is AS_IS:tt=ctt\n  font=(size,i,b,tt)\n  self. font_stack. append(font)\n  self. writer. new_font(font)\n  \n def pop_font(self):\n  if self. font_stack:\n   del self. font_stack[-1]\n  if self. font_stack:\n   font=self. font_stack[-1]\n  else :\n   font=None\n  self. writer. new_font(font)\n  \n def push_margin(self,margin):\n  self. margin_stack. append(margin)\n  fstack=[m for m in self. margin_stack if m]\n  if not margin and fstack:\n   margin=fstack[-1]\n  self. writer. new_margin(margin,len(fstack))\n  \n def pop_margin(self):\n  if self. margin_stack:\n   del self. margin_stack[-1]\n  fstack=[m for m in self. margin_stack if m]\n  if fstack:\n   margin=fstack[-1]\n  else :\n   margin=None\n  self. writer. new_margin(margin,len(fstack))\n  \n def set_spacing(self,spacing):\n  self. spacing=spacing\n  self. writer. new_spacing(spacing)\n  \n def push_style(self,*styles):\n  if self. softspace:\n   self. hard_break=self. para_end=self. softspace=0\n   self. nospace=1\n   self. writer. send_flowing_data(' ')\n  for style in styles:\n   self. style_stack. append(style)\n  self. writer. new_styles(tuple(self. style_stack))\n  \n def pop_style(self,n=1):\n  del self. style_stack[-n:]\n  self. writer. new_styles(tuple(self. style_stack))\n  \n def assert_line_data(self,flag=1):\n  self. nospace=self. hard_break=not flag\n  self. para_end=self. parskip=self. have_label=0\n  \n  \nclass NullWriter:\n ''\n\n\n\n\n\n \n def __init__(self):pass\n def flush(self):pass\n def new_alignment(self,align):pass\n def new_font(self,font):pass\n def new_margin(self,margin,level):pass\n def new_spacing(self,spacing):pass\n def new_styles(self,styles):pass\n def send_paragraph(self,blankline):pass\n def send_line_break(self):pass\n def send_hor_rule(self,*args,**kw):pass\n def send_label_data(self,data):pass\n def send_flowing_data(self,data):pass\n def send_literal_data(self,data):pass\n \n \nclass AbstractWriter(NullWriter):\n ''\n\n\n\n\n \n \n def new_alignment(self,align):\n  print(\"new_alignment(%r)\"%(align,))\n  \n def new_font(self,font):\n  print(\"new_font(%r)\"%(font,))\n  \n def new_margin(self,margin,level):\n  print(\"new_margin(%r, %d)\"%(margin,level))\n  \n def new_spacing(self,spacing):\n  print(\"new_spacing(%r)\"%(spacing,))\n  \n def new_styles(self,styles):\n  print(\"new_styles(%r)\"%(styles,))\n  \n def send_paragraph(self,blankline):\n  print(\"send_paragraph(%r)\"%(blankline,))\n  \n def send_line_break(self):\n  print(\"send_line_break()\")\n  \n def send_hor_rule(self,*args,**kw):\n  print(\"send_hor_rule()\")\n  \n def send_label_data(self,data):\n  print(\"send_label_data(%r)\"%(data,))\n  \n def send_flowing_data(self,data):\n  print(\"send_flowing_data(%r)\"%(data,))\n  \n def send_literal_data(self,data):\n  print(\"send_literal_data(%r)\"%(data,))\n  \n  \nclass DumbWriter(NullWriter):\n ''\n\n\n\n\n\n \n \n def __init__(self,file=None ,maxcol=72):\n  self. file=file or sys. stdout\n  self. maxcol=maxcol\n  NullWriter. __init__(self)\n  self. reset()\n  \n def reset(self):\n  self. col=0\n  self. atbreak=0\n  \n def send_paragraph(self,blankline):\n  self. file. write('\\n'*blankline)\n  self. col=0\n  self. atbreak=0\n  \n def send_line_break(self):\n  self. file. write('\\n')\n  self. col=0\n  self. atbreak=0\n  \n def send_hor_rule(self,*args,**kw):\n  self. file. write('\\n')\n  self. file. write('-'*self. maxcol)\n  self. file. write('\\n')\n  self. col=0\n  self. atbreak=0\n  \n def send_literal_data(self,data):\n  self. file. write(data)\n  i=data. rfind('\\n')\n  if i >=0:\n   self. col=0\n   data=data[i+1:]\n  data=data. expandtabs()\n  self. col=self. col+len(data)\n  self. atbreak=0\n  \n def send_flowing_data(self,data):\n  if not data:return\n  atbreak=self. atbreak or data[0]. isspace()\n  col=self. col\n  maxcol=self. maxcol\n  write=self. file. write\n  for word in data. split():\n   if atbreak:\n    if col+len(word)>=maxcol:\n     write('\\n')\n     col=0\n    else :\n     write(' ')\n     col=col+1\n   write(word)\n   col=col+len(word)\n   atbreak=1\n  self. col=col\n  self. atbreak=data[-1]. isspace()\n  \n  \ndef test(file=None ):\n w=DumbWriter()\n f=AbstractFormatter(w)\n if file is not None :\n  fp=open(file)\n elif sys. argv[1:]:\n  fp=open(sys. argv[1])\n else :\n  fp=sys. stdin\n for line in fp:\n  if line =='\\n':\n   f. end_paragraph(1)\n  else :\n   f. add_flowing_data(line)\n f. end_paragraph(0)\n \n \nif __name__ =='__main__':\n test()\n", ["sys"]], "_thread": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__all__=['error','start_new_thread','exit','get_ident','allocate_lock',\n'interrupt_main','LockType']\n\n\nTIMEOUT_MAX=2 **31\n\n\n\n\n\n\nerror=RuntimeError\n\ndef start_new_thread(function,args,kwargs={}):\n ''\n\n\n\n\n\n\n\n\n\n\n \n if type(args)!=type(tuple()):\n  raise TypeError(\"2nd arg must be a tuple\")\n if type(kwargs)!=type(dict()):\n  raise TypeError(\"3rd arg must be a dict\")\n global _main\n _main=False\n try :\n  function(*args,**kwargs)\n except SystemExit:\n  pass\n except :\n  import traceback\n  traceback. print_exc()\n _main=True\n global _interrupt\n if _interrupt:\n  _interrupt=False\n  raise KeyboardInterrupt\n  \ndef exit():\n ''\n raise SystemExit\n \ndef get_ident():\n ''\n\n\n\n\n \n return -1\n \ndef allocate_lock():\n ''\n return LockType()\n \ndef stack_size(size=None ):\n ''\n if size is not None :\n  raise error(\"setting thread stack size not supported\")\n return 0\n \nclass LockType(object):\n ''\n\n\n\n\n\n\n\n \n \n def __init__(self):\n  self. locked_status=False\n  \n def acquire(self,waitflag=None ,timeout=-1):\n  ''\n\n\n\n\n\n\n\n\n  \n  if waitflag is None or waitflag:\n   self. locked_status=True\n   return True\n  else :\n   if not self. locked_status:\n    self. locked_status=True\n    return True\n   else :\n    if timeout >0:\n     import time\n     time. sleep(timeout)\n    return False\n    \n __enter__=acquire\n \n def __exit__(self,typ,val,tb):\n  self. release()\n  \n def release(self):\n  ''\n  \n  \n  if not self. locked_status:\n   raise error\n  self. locked_status=False\n  return True\n  \n def locked(self):\n  return self. locked_status\n  \n  \n_interrupt=False\n\n_main=True\n\ndef interrupt_main():\n ''\n \n if _main:\n  raise KeyboardInterrupt\n else :\n  global _interrupt\n  _interrupt=True\n  \n  \nclass _local:\n pass", ["time", "traceback"]], "linecache": [".py", "''\n\n\n\n\n\n\nimport sys\nimport os\nimport tokenize\n\n__all__=[\"getline\",\"clearcache\",\"checkcache\"]\n\ndef getline(filename,lineno,module_globals=None ):\n lines=getlines(filename,module_globals)\n if 1 <=lineno <=len(lines):\n  return lines[lineno -1]\n else :\n  return''\n  \n  \n  \n  \ncache={}\n\n\ndef clearcache():\n ''\n \n global cache\n cache={}\n \n \ndef getlines(filename,module_globals=None ):\n ''\n \n \n if filename in cache:\n  return cache[filename][2]\n else :\n  return updatecache(filename,module_globals)\n  \n  \ndef checkcache(filename=None ):\n ''\n \n \n if filename is None :\n  filenames=list(cache. keys())\n else :\n  if filename in cache:\n   filenames=[filename]\n  else :\n   return\n   \n for filename in filenames:\n  size,mtime,lines,fullname=cache[filename]\n  if mtime is None :\n   continue\n  try :\n   stat=os. stat(fullname)\n  except os. error:\n   del cache[filename]\n   continue\n  if size !=stat. st_size or mtime !=stat. st_mtime:\n   del cache[filename]\n   \n   \ndef updatecache(filename,module_globals=None ):\n ''\n\n \n \n if filename in cache:\n  del cache[filename]\n if not filename or (filename. startswith('<')and filename. endswith('>')):\n  return []\n  \n fullname=filename\n try :\n  stat=os. stat(fullname)\n except OSError:\n  basename=filename\n  \n  \n  if module_globals and'__loader__'in module_globals:\n   name=module_globals. get('__name__')\n   loader=module_globals['__loader__']\n   get_source=getattr(loader,'get_source',None )\n   \n   if name and get_source:\n    try :\n     data=get_source(name)\n    except (ImportError,IOError):\n     pass\n    else :\n     if data is None :\n     \n     \n      return []\n     cache[filename]=(\n     len(data),None ,\n     [line+'\\n'for line in data. splitlines()],fullname\n     )\n     return cache[filename][2]\n     \n     \n     \n  if os. path. isabs(filename):\n   return []\n   \n  for dirname in sys. path:\n   try :\n    fullname=os. path. join(dirname,basename)\n   except (TypeError,AttributeError):\n   \n    continue\n   try :\n    stat=os. stat(fullname)\n    break\n   except os. error:\n    pass\n  else :\n   return []\n try :\n  with tokenize. open(fullname)as fp:\n   lines=fp. readlines()\n except IOError:\n  return []\n if lines and not lines[-1]. endswith('\\n'):\n  lines[-1]+='\\n'\n size,mtime=stat. st_size,stat. st_mtime\n cache[filename]=size,mtime,lines,fullname\n return lines\n", ["os", "sys", "tokenize"]], "_dummy_thread": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__all__=['error','start_new_thread','exit','get_ident','allocate_lock',\n'interrupt_main','LockType']\n\n\nTIMEOUT_MAX=2 **31\n\n\n\n\n\n\nerror=RuntimeError\n\ndef start_new_thread(function,args,kwargs={}):\n ''\n\n\n\n\n\n\n\n\n\n\n \n if type(args)!=type(tuple()):\n  raise TypeError(\"2nd arg must be a tuple\")\n if type(kwargs)!=type(dict()):\n  raise TypeError(\"3rd arg must be a dict\")\n global _main\n _main=False\n try :\n  function(*args,**kwargs)\n except SystemExit:\n  pass\n except :\n  import traceback\n  traceback. print_exc()\n _main=True\n global _interrupt\n if _interrupt:\n  _interrupt=False\n  raise KeyboardInterrupt\n  \ndef exit():\n ''\n raise SystemExit\n \ndef get_ident():\n ''\n\n\n\n\n \n return -1\n \ndef allocate_lock():\n ''\n return LockType()\n \ndef stack_size(size=None ):\n ''\n if size is not None :\n  raise error(\"setting thread stack size not supported\")\n return 0\n \nclass LockType(object):\n ''\n\n\n\n\n\n\n\n \n \n def __init__(self):\n  self. locked_status=False\n  \n def acquire(self,waitflag=None ,timeout=-1):\n  ''\n\n\n\n\n\n\n\n\n  \n  if waitflag is None or waitflag:\n   self. locked_status=True\n   return True\n  else :\n   if not self. locked_status:\n    self. locked_status=True\n    return True\n   else :\n    if timeout >0:\n     import time\n     time. sleep(timeout)\n    return False\n    \n __enter__=acquire\n \n def __exit__(self,typ,val,tb):\n  self. release()\n  \n def release(self):\n  ''\n  \n  \n  if not self. locked_status:\n   raise error\n  self. locked_status=False\n  return True\n  \n def locked(self):\n  return self. locked_status\n  \n  \n_interrupt=False\n\n_main=True\n\ndef interrupt_main():\n ''\n \n if _main:\n  raise KeyboardInterrupt\n else :\n  global _interrupt\n  _interrupt=True\n", ["time", "traceback"]], "select": [".py", "''\n\n\n\n\n\n\n\n\n\nimport errno\nimport os\nimport queue\nimport socket\n\nclass error(Exception):pass\n\nALL=None\n\n_exception_map={\n\n\n\n\n\n\n}\n\ndef _map_exception(exc,circumstance=ALL):\n try :\n  mapped_exception=_exception_map[(exc. __class__,circumstance)]\n  mapped_exception. java_exception=exc\n  return mapped_exception\n except KeyError:\n  return error(-1,'Unmapped java exception: <%s:%s>'%(exc. toString(),circumstance))\n  \nPOLLIN=1\nPOLLOUT=2\n\n\n\n\n\nPOLLPRI=4\nPOLLERR=8\nPOLLHUP=16\nPOLLNVAL=32\n\ndef _getselectable(selectable_object):\n try :\n  channel=selectable_object. getchannel()\n except :\n  try :\n   channel=selectable_object. fileno(). getChannel()\n  except :\n   raise TypeError(\"Object '%s' is not watchable\"%selectable_object,\n   errno. ENOTSOCK)\n   \n if channel and not isinstance(channel,java. nio. channels. SelectableChannel):\n  raise TypeError(\"Object '%s' is not watchable\"%selectable_object,\n  errno. ENOTSOCK)\n return channel\n \nclass poll:\n\n def __init__(self):\n  self. selector=java. nio. channels. Selector. open()\n  self. chanmap={}\n  self. unconnected_sockets=[]\n  \n def _register_channel(self,socket_object,channel,mask):\n  jmask=0\n  if mask&POLLIN:\n  \n   if channel. validOps()&OP_ACCEPT:\n    jmask=OP_ACCEPT\n   else :\n    jmask=OP_READ\n  if mask&POLLOUT:\n   if channel. validOps()&OP_WRITE:\n    jmask |=OP_WRITE\n   if channel. validOps()&OP_CONNECT:\n    jmask |=OP_CONNECT\n  selectionkey=channel. register(self. selector,jmask)\n  self. chanmap[channel]=(socket_object,selectionkey)\n  \n def _check_unconnected_sockets(self):\n  temp_list=[]\n  for socket_object,mask in self. unconnected_sockets:\n   channel=_getselectable(socket_object)\n   if channel is not None :\n    self. _register_channel(socket_object,channel,mask)\n   else :\n    temp_list. append((socket_object,mask))\n  self. unconnected_sockets=temp_list\n  \n def register(self,socket_object,mask=POLLIN |POLLOUT |POLLPRI):\n  try :\n   channel=_getselectable(socket_object)\n   if channel is None :\n   \n   \n    self. unconnected_sockets. append((socket_object,mask))\n    return\n   self. _register_channel(socket_object,channel,mask)\n  except BaseException:\n  \n   raise _map_exception(jlx)\n   \n def unregister(self,socket_object):\n  try :\n   channel=_getselectable(socket_object)\n   self. chanmap[channel][1]. cancel()\n   del self. chanmap[channel]\n  except BaseException:\n  \n   raise _map_exception(jlx)\n   \n def _dopoll(self,timeout):\n  if timeout is None or timeout <0:\n   self. selector. select()\n  else :\n   try :\n    timeout=int(timeout)\n    if not timeout:\n     self. selector. selectNow()\n    else :\n    \n     self. selector. select(timeout)\n   except ValueError as vx:\n    raise error(\"poll timeout must be a number of milliseconds or None\",errno. EINVAL)\n    \n  return self. selector. selectedKeys()\n  \n def poll(self,timeout=None ):\n  try :\n   self. _check_unconnected_sockets()\n   selectedkeys=self. _dopoll(timeout)\n   results=[]\n   for k in selectedkeys. iterator():\n    jmask=k. readyOps()\n    pymask=0\n    if jmask&OP_READ:pymask |=POLLIN\n    if jmask&OP_WRITE:pymask |=POLLOUT\n    if jmask&OP_ACCEPT:pymask |=POLLIN\n    if jmask&OP_CONNECT:pymask |=POLLOUT\n    \n    results. append((self. chanmap[k. channel()][0],pymask))\n   return results\n  except BaseException:\n  \n   raise _map_exception(jlx)\n   \n def _deregister_all(self):\n  try :\n   for k in self. selector. keys():\n    k. cancel()\n    \n   self. selector. selectNow()\n  except BaseException:\n  \n   raise _map_exception(jlx)\n   \n def close(self):\n  try :\n   self. _deregister_all()\n   self. selector. close()\n  except BaseException:\n  \n   raise _map_exception(jlx)\n   \ndef _calcselecttimeoutvalue(value):\n if value is None :\n  return None\n try :\n  floatvalue=float(value)\n except Exception as x:\n  raise TypeError(\"Select timeout value must be a number or None\")\n if value <0:\n  raise error(\"Select timeout value cannot be negative\",errno. EINVAL)\n if floatvalue <0.000001:\n  return 0\n return int(floatvalue *1000)\n \n \n \n \nclass poll_object_cache:\n\n def __init__(self):\n  self. is_windows=os. name =='nt'\n  if self. is_windows:\n   self. poll_object_queue=Queue. Queue()\n  import atexit\n  atexit. register(self. finalize)\n  \n def get_poll_object(self):\n  if not self. is_windows:\n   return poll()\n  try :\n   return self. poll_object_queue. get(False )\n  except Queue. Empty:\n   return poll()\n   \n def release_poll_object(self,pobj):\n  if self. is_windows:\n   pobj. _deregister_all()\n   self. poll_object_queue. put(pobj)\n  else :\n   pobj. close()\n   \n def finalize(self):\n  if self. is_windows:\n   while True :\n    try :\n     p=self. poll_object_queue. get(False )\n     p. close()\n    except Queue. Empty:\n     return\n     \n_poll_object_cache=poll_object_cache()\n\ndef native_select(read_fd_list,write_fd_list,outofband_fd_list,timeout=None ):\n timeout=_calcselecttimeoutvalue(timeout)\n \n pobj=_poll_object_cache. get_poll_object()\n try :\n  registered_for_read={}\n  \n  for fd in read_fd_list:\n   pobj. register(fd,POLLIN)\n   registered_for_read[fd]=1\n   \n  for fd in write_fd_list:\n   if fd in registered_for_read:\n   \n    pobj. register(fd,POLLIN |POLLOUT)\n   else :\n    pobj. register(fd,POLLOUT)\n  results=pobj. poll(timeout)\n  \n  read_ready_list,write_ready_list,oob_ready_list=[],[],[]\n  for fd,mask in results:\n   if mask&POLLIN:\n    read_ready_list. append(fd)\n   if mask&POLLOUT:\n    write_ready_list. append(fd)\n  return read_ready_list,write_ready_list,oob_ready_list\n finally :\n  _poll_object_cache. release_poll_object(pobj)\n  \nselect=native_select\n\ndef cpython_compatible_select(read_fd_list,write_fd_list,outofband_fd_list,timeout=None ):\n\n\n modified_channels=[]\n try :\n  for socket_list in [read_fd_list,write_fd_list,outofband_fd_list]:\n   for s in socket_list:\n    channel=_getselectable(s)\n    if channel. isBlocking():\n     modified_channels. append(channel)\n     channel. configureBlocking(0)\n  return native_select(read_fd_list,write_fd_list,outofband_fd_list,timeout)\n finally :\n  for channel in modified_channels:\n   channel. configureBlocking(1)\n", ["atexit", "errno", "os", "queue", "socket"]], "re": [".py", "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nr\"\"\"Support for regular expressions (RE).\n\nThis module provides regular expression matching operations similar to\nthose found in Perl.  It supports both 8-bit and Unicode strings; both\nthe pattern and the strings being processed can contain null bytes and\ncharacters outside the US ASCII range.\n\nRegular expressions can contain both special and ordinary characters.\nMost ordinary characters, like \"A\", \"a\", or \"0\", are the simplest\nregular expressions; they simply match themselves.  You can\nconcatenate ordinary characters, so last matches the string 'last'.\n\nThe special characters are:\n    \".\"      Matches any character except a newline.\n    \"^\"      Matches the start of the string.\n    \"$\"      Matches the end of the string or just before the newline at\n             the end of the string.\n    \"*\"      Matches 0 or more (greedy) repetitions of the preceding RE.\n             Greedy means that it will match as many repetitions as possible.\n    \"+\"      Matches 1 or more (greedy) repetitions of the preceding RE.\n    \"?\"      Matches 0 or 1 (greedy) of the preceding RE.\n    *?,+?,?? Non-greedy versions of the previous three special characters.\n    {m,n}    Matches from m to n repetitions of the preceding RE.\n    {m,n}?   Non-greedy version of the above.\n    \"\\\\\"     Either escapes special characters or signals a special sequence.\n    []       Indicates a set of characters.\n             A \"^\" as the first character indicates a complementing set.\n    \"|\"      A|B, creates an RE that will match either A or B.\n    (...)    Matches the RE inside the parentheses.\n             The contents can be retrieved or matched later in the string.\n    (?aiLmsux) Set the A, I, L, M, S, U, or X flag for the RE (see below).\n    (?:...)  Non-grouping version of regular parentheses.\n    (?P<name>...) The substring matched by the group is accessible by name.\n    (?P=name)     Matches the text matched earlier by the group named name.\n    (?#...)  A comment; ignored.\n    (?=...)  Matches if ... matches next, but doesn't consume the string.\n    (?!...)  Matches if ... doesn't match next.\n    (?<=...) Matches if preceded by ... (must be fixed length).\n    (?<!...) Matches if not preceded by ... (must be fixed length).\n    (?(id/name)yes|no) Matches yes pattern if the group with id/name matched,\n                       the (optional) no pattern otherwise.\n\nThe special sequences consist of \"\\\\\" and a character from the list\nbelow.  If the ordinary character is not on the list, then the\nresulting RE will match the second character.\n    \\number  Matches the contents of the group of the same number.\n    \\A       Matches only at the start of the string.\n    \\Z       Matches only at the end of the string.\n    \\b       Matches the empty string, but only at the start or end of a word.\n    \\B       Matches the empty string, but not at the start or end of a word.\n    \\d       Matches any decimal digit; equivalent to the set [0-9] in\n             bytes patterns or string patterns with the ASCII flag.\n             In string patterns without the ASCII flag, it will match the whole\n             range of Unicode digits.\n    \\D       Matches any non-digit character; equivalent to [^\\d].\n    \\s       Matches any whitespace character; equivalent to [ \\t\\n\\r\\f\\v] in\n             bytes patterns or string patterns with the ASCII flag.\n             In string patterns without the ASCII flag, it will match the whole\n             range of Unicode whitespace characters.\n    \\S       Matches any non-whitespace character; equivalent to [^\\s].\n    \\w       Matches any alphanumeric character; equivalent to [a-zA-Z0-9_]\n             in bytes patterns or string patterns with the ASCII flag.\n             In string patterns without the ASCII flag, it will match the\n             range of Unicode alphanumeric characters (letters plus digits\n             plus underscore).\n             With LOCALE, it will match the set [0-9_] plus characters defined\n             as letters for the current locale.\n    \\W       Matches the complement of \\w.\n    \\\\       Matches a literal backslash.\n\nThis module exports the following functions:\n    match    Match a regular expression pattern to the beginning of a string.\n    search   Search a string for the presence of a pattern.\n    sub      Substitute occurrences of a pattern found in a string.\n    subn     Same as sub, but also return the number of substitutions made.\n    split    Split a string by the occurrences of a pattern.\n    findall  Find all occurrences of a pattern in a string.\n    finditer Return an iterator yielding a match object for each match.\n    compile  Compile a pattern into a RegexObject.\n    purge    Clear the regular expression cache.\n    escape   Backslash all non-alphanumerics in a string.\n\nSome of the functions in this module takes flags as optional parameters:\n    A  ASCII       For string patterns, make \\w, \\W, \\b, \\B, \\d, \\D\n                   match the corresponding ASCII character categories\n                   (rather than the whole Unicode categories, which is the\n                   default).\n                   For bytes patterns, this flag is the only available\n                   behaviour and needn't be specified.\n    I  IGNORECASE  Perform case-insensitive matching.\n    L  LOCALE      Make \\w, \\W, \\b, \\B, dependent on the current locale.\n    M  MULTILINE   \"^\" matches the beginning of lines (after a newline)\n                   as well as the string.\n                   \"$\" matches the end of lines (before a newline) as well\n                   as the end of the string.\n    S  DOTALL      \".\" matches any character at all, including the newline.\n    X  VERBOSE     Ignore whitespace and comments for nicer looking RE's.\n    U  UNICODE     For compatibility only. Ignored for string patterns (it\n                   is the default), and forbidden for bytes patterns.\n\nThis module also defines an exception 'error'.\n\n\"\"\"\n\nimport sre_compile\nimport sre_parse\n\n\n__all__=[\"match\",\"search\",\"sub\",\"subn\",\"split\",\"findall\",\n\"compile\",\"purge\",\"template\",\"escape\",\"A\",\"I\",\"L\",\"M\",\"S\",\"X\",\n\"U\",\"ASCII\",\"IGNORECASE\",\"LOCALE\",\"MULTILINE\",\"DOTALL\",\"VERBOSE\",\n\"UNICODE\",\"error\"]\n\n__version__=\"2.2.1\"\n\n\nA=ASCII=sre_compile. SRE_FLAG_ASCII\nI=IGNORECASE=sre_compile. SRE_FLAG_IGNORECASE\nL=LOCALE=sre_compile. SRE_FLAG_LOCALE\nU=UNICODE=sre_compile. SRE_FLAG_UNICODE\nM=MULTILINE=sre_compile. SRE_FLAG_MULTILINE\nS=DOTALL=sre_compile. SRE_FLAG_DOTALL\nX=VERBOSE=sre_compile. SRE_FLAG_VERBOSE\n\n\nT=TEMPLATE=sre_compile. SRE_FLAG_TEMPLATE\nDEBUG=sre_compile. SRE_FLAG_DEBUG\n\n\nerror=sre_compile. error\n\n\n\n\ndef match(pattern,string,flags=0):\n ''\n \n return _compile(pattern,flags). match(string)\n \ndef search(pattern,string,flags=0):\n ''\n \n return _compile(pattern,flags). search(string)\n \ndef sub(pattern,repl,string,count=0,flags=0):\n ''\n\n\n\n\n \n return _compile(pattern,flags). sub(repl,string,count)\n \ndef subn(pattern,repl,string,count=0,flags=0):\n ''\n\n\n\n\n\n\n \n return _compile(pattern,flags). subn(repl,string,count)\n \ndef split(pattern,string,maxsplit=0,flags=0):\n ''\n\n\n\n\n\n \n return _compile(pattern,flags). split(string,maxsplit)\n \ndef findall(pattern,string,flags=0):\n ''\n\n\n\n\n\n \n return _compile(pattern,flags). findall(string)\n \ndef finditer(pattern,string,flags=0):\n ''\n\n\n \n return _compile(pattern,flags). finditer(string)\n \ndef compile(pattern,flags=0):\n ''\n \n return _compile(pattern,flags)\n \ndef purge():\n ''\n _cache. clear()\n _cache_repl. clear()\n \ndef template(pattern,flags=0):\n ''\n return _compile(pattern,flags |T)\n \n_alphanum_str=frozenset(\n\"_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ01234567890\")\n_alphanum_bytes=frozenset(\nb\"_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ01234567890\")\n\ndef escape(pattern):\n ''\n\n \n if isinstance(pattern,str):\n  alphanum=_alphanum_str\n  s=list(pattern)\n  for i,c in enumerate(pattern):\n   if c not in alphanum:\n    if c ==\"\\000\":\n     s[i]=\"\\\\000\"\n    else :\n     s[i]=\"\\\\\"+c\n  return\"\". join(s)\n else :\n  alphanum=_alphanum_bytes\n  s=[]\n  esc=ord(b\"\\\\\")\n  for c in pattern:\n   if c in alphanum:\n    s. append(c)\n   else :\n    if c ==0:\n     s. extend(b\"\\\\000\")\n    else :\n     s. append(esc)\n     s. append(c)\n  return bytes(s)\n  \n  \n  \n  \n_cache={}\n_cache_repl={}\n\n_pattern_type=type(sre_compile. compile(\"\",0))\n\n_MAXCACHE=512\ndef _compile(pattern,flags):\n\n try :\n \n \n  return _cache[\"%s:%s:%s\"%(type(pattern),pattern,flags)]\n except KeyError:\n  pass\n  \n if isinstance(pattern,_pattern_type):\n  if flags:\n   raise ValueError(\n   \"Cannot process flags argument with a compiled pattern\")\n  return pattern\n if not sre_compile. isstring(pattern):\n  raise TypeError(\"first argument must be string or compiled pattern\")\n p=sre_compile. compile(pattern,flags)\n \n if len(_cache)>=_MAXCACHE:\n  _cache. clear()\n  \n  \n _cache[\"%s:%s:%s\"%(type(pattern),pattern,flags)]=p\n return p\n \ndef _compile_repl(repl,pattern):\n\n try :\n \n \n  return _cache_repl[\"%s:%s\"%(repl,pattern)]\n except KeyError:\n  pass\n p=sre_parse. parse_template(repl,pattern)\n if len(_cache_repl)>=_MAXCACHE:\n  _cache_repl. clear()\n _cache_repl[\"%s:%s\"%(repl,pattern)]=p\n \n \n return p\n \ndef _expand(pattern,match,template):\n\n template=sre_parse. parse_template(template,pattern)\n return sre_parse. expand_template(template,match)\n \ndef _subx(pattern,template):\n\n template=_compile_repl(template,pattern)\n if not template[0]and len(template[1])==1:\n \n  return template[1][0]\n def filter(match,template=template):\n  return sre_parse. expand_template(template,match)\n return filter\n \n \n \nimport copyreg\n\ndef _pickle(p):\n return _compile,(p. pattern,p. flags)\n \ncopyreg. pickle(_pattern_type,_pickle,_compile)\n\n\n\n\nclass Scanner:\n def __init__(self,lexicon,flags=0):\n  from sre_constants import BRANCH,SUBPATTERN\n  self. lexicon=lexicon\n  \n  p=[]\n  s=sre_parse. Pattern()\n  s. flags=flags\n  for phrase,action in lexicon:\n   p. append(sre_parse. SubPattern(s,[\n   (SUBPATTERN,(len(p)+1,sre_parse. parse(phrase,flags))),\n   ]))\n  s. groups=len(p)+1\n  p=sre_parse. SubPattern(s,[(BRANCH,(None ,p))])\n  self. scanner=sre_compile. compile(p)\n def scan(self,string):\n  result=[]\n  append=result. append\n  match=self. scanner. scanner(string). match\n  i=0\n  while 1:\n   m=match()\n   if not m:\n    break\n   j=m. end()\n   if i ==j:\n    break\n   action=self. lexicon[m. lastindex -1][1]\n   if callable(action):\n    self. match=m\n    action=action(self,m. group())\n   if action is not None :\n    append(action)\n   i=j\n  return result,string[i:]\n", ["copyreg", "sre_compile", "sre_constants", "sre_parse"]], "getopt": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__all__=[\"GetoptError\",\"error\",\"getopt\",\"gnu_getopt\"]\n\nimport os\ntry :\n from gettext import gettext as _\nexcept ImportError:\n\n def _(s):return s\n \nclass GetoptError(Exception):\n opt=''\n msg=''\n def __init__(self,msg,opt=''):\n  self. msg=msg\n  self. opt=opt\n  Exception. __init__(self,msg,opt)\n  \n def __str__(self):\n  return self. msg\n  \nerror=GetoptError\n\ndef getopt(args,shortopts,longopts=[]):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n opts=[]\n if type(longopts)==type(\"\"):\n  longopts=[longopts]\n else :\n  longopts=list(longopts)\n while args and args[0]. startswith('-')and args[0]!='-':\n  if args[0]=='--':\n   args=args[1:]\n   break\n  if args[0]. startswith('--'):\n   opts,args=do_longs(opts,args[0][2:],longopts,args[1:])\n  else :\n   opts,args=do_shorts(opts,args[0][1:],shortopts,args[1:])\n   \n return opts,args\n \ndef gnu_getopt(args,shortopts,longopts=[]):\n ''\n\n\n\n\n\n\n\n\n\n\n\n \n \n opts=[]\n prog_args=[]\n if isinstance(longopts,str):\n  longopts=[longopts]\n else :\n  longopts=list(longopts)\n  \n  \n if shortopts. startswith('+'):\n  shortopts=shortopts[1:]\n  all_options_first=True\n elif os. environ. get(\"POSIXLY_CORRECT\"):\n  all_options_first=True\n else :\n  all_options_first=False\n  \n while args:\n  if args[0]=='--':\n   prog_args +=args[1:]\n   break\n   \n  if args[0][:2]=='--':\n   opts,args=do_longs(opts,args[0][2:],longopts,args[1:])\n  elif args[0][:1]=='-'and args[0]!='-':\n   opts,args=do_shorts(opts,args[0][1:],shortopts,args[1:])\n  else :\n   if all_options_first:\n    prog_args +=args\n    break\n   else :\n    prog_args. append(args[0])\n    args=args[1:]\n    \n return opts,prog_args\n \ndef do_longs(opts,opt,longopts,args):\n try :\n  i=opt. index('=')\n except ValueError:\n  optarg=None\n else :\n  opt,optarg=opt[:i],opt[i+1:]\n  \n has_arg,opt=long_has_args(opt,longopts)\n if has_arg:\n  if optarg is None :\n   if not args:\n    raise GetoptError(_('option --%s requires argument')%opt,opt)\n   optarg,args=args[0],args[1:]\n elif optarg is not None :\n  raise GetoptError(_('option --%s must not have an argument')%opt,opt)\n opts. append(('--'+opt,optarg or''))\n return opts,args\n \n \n \n \ndef long_has_args(opt,longopts):\n possibilities=[o for o in longopts if o. startswith(opt)]\n if not possibilities:\n  raise GetoptError(_('option --%s not recognized')%opt,opt)\n  \n if opt in possibilities:\n  return False ,opt\n elif opt+'='in possibilities:\n  return True ,opt\n  \n if len(possibilities)>1:\n \n \n  raise GetoptError(_('option --%s not a unique prefix')%opt,opt)\n assert len(possibilities)==1\n unique_match=possibilities[0]\n has_arg=unique_match. endswith('=')\n if has_arg:\n  unique_match=unique_match[:-1]\n return has_arg,unique_match\n \ndef do_shorts(opts,optstring,shortopts,args):\n while optstring !='':\n  opt,optstring=optstring[0],optstring[1:]\n  if short_has_arg(opt,shortopts):\n   if optstring =='':\n    if not args:\n     raise GetoptError(_('option -%s requires argument')%opt,\n     opt)\n    optstring,args=args[0],args[1:]\n   optarg,optstring=optstring,''\n  else :\n   optarg=''\n  opts. append(('-'+opt,optarg))\n return opts,args\n \ndef short_has_arg(opt,shortopts):\n for i in range(len(shortopts)):\n  if opt ==shortopts[i]!=':':\n   return shortopts. startswith(':',i+1)\n raise GetoptError(_('option -%s not recognized')%opt,opt)\n \nif __name__ =='__main__':\n import sys\n print(getopt(sys. argv[1:],\"a:b\",[\"alpha=\",\"beta\"]))\n", ["gettext", "os", "sys"]], "bdb": [".py", "''\n\nimport fnmatch\nimport sys\nimport os\nfrom inspect import CO_GENERATOR\n\n__all__=[\"BdbQuit\",\"Bdb\",\"Breakpoint\"]\n\nclass BdbQuit(Exception):\n ''\n \n \nclass Bdb:\n ''\n\n\n\n\n \n \n def __init__(self,skip=None ):\n  self. skip=set(skip)if skip else None\n  self. breaks={}\n  self. fncache={}\n  self. frame_returning=None\n  \n def canonic(self,filename):\n  if filename ==\"<\"+filename[1:-1]+\">\":\n   return filename\n  canonic=self. fncache. get(filename)\n  if not canonic:\n   canonic=os. path. abspath(filename)\n   canonic=os. path. normcase(canonic)\n   self. fncache[filename]=canonic\n  return canonic\n  \n def reset(self):\n  import linecache\n  linecache. checkcache()\n  self. botframe=None\n  self. _set_stopinfo(None ,None )\n  \n def trace_dispatch(self,frame,event,arg):\n  if self. quitting:\n   return\n  if event =='line':\n   return self. dispatch_line(frame)\n  if event =='call':\n   return self. dispatch_call(frame,arg)\n  if event =='return':\n   return self. dispatch_return(frame,arg)\n  if event =='exception':\n   return self. dispatch_exception(frame,arg)\n  if event =='c_call':\n   return self. trace_dispatch\n  if event =='c_exception':\n   return self. trace_dispatch\n  if event =='c_return':\n   return self. trace_dispatch\n  print('bdb.Bdb.dispatch: unknown debugging event:',repr(event))\n  return self. trace_dispatch\n  \n def dispatch_line(self,frame):\n  if self. stop_here(frame)or self. break_here(frame):\n   self. user_line(frame)\n   if self. quitting:raise BdbQuit\n  return self. trace_dispatch\n  \n def dispatch_call(self,frame,arg):\n \n  if self. botframe is None :\n  \n   self. botframe=frame. f_back\n   return self. trace_dispatch\n  if not (self. stop_here(frame)or self. break_anywhere(frame)):\n  \n   return\n   \n  if self. stopframe and frame. f_code. co_flags&CO_GENERATOR:\n   return self. trace_dispatch\n  self. user_call(frame,arg)\n  if self. quitting:raise BdbQuit\n  return self. trace_dispatch\n  \n def dispatch_return(self,frame,arg):\n  if self. stop_here(frame)or frame ==self. returnframe:\n  \n   if self. stopframe and frame. f_code. co_flags&CO_GENERATOR:\n    return self. trace_dispatch\n   try :\n    self. frame_returning=frame\n    self. user_return(frame,arg)\n   finally :\n    self. frame_returning=None\n   if self. quitting:raise BdbQuit\n   \n   if self. stopframe is frame and self. stoplineno !=-1:\n    self. _set_stopinfo(None ,None )\n  return self. trace_dispatch\n  \n def dispatch_exception(self,frame,arg):\n  if self. stop_here(frame):\n  \n  \n  \n   if not (frame. f_code. co_flags&CO_GENERATOR\n   and arg[0]is StopIteration and arg[2]is None ):\n    self. user_exception(frame,arg)\n    if self. quitting:raise BdbQuit\n    \n    \n    \n    \n  elif (self. stopframe and frame is not self. stopframe\n  and self. stopframe. f_code. co_flags&CO_GENERATOR\n  and arg[0]in (StopIteration,GeneratorExit)):\n   self. user_exception(frame,arg)\n   if self. quitting:raise BdbQuit\n   \n  return self. trace_dispatch\n  \n  \n  \n  \n  \n def is_skipped_module(self,module_name):\n  for pattern in self. skip:\n   if fnmatch. fnmatch(module_name,pattern):\n    return True\n  return False\n  \n def stop_here(self,frame):\n \n \n  if self. skip and  self. is_skipped_module(frame. f_globals. get('__name__')):\n   return False\n  if frame is self. stopframe:\n   if self. stoplineno ==-1:\n    return False\n   return frame. f_lineno >=self. stoplineno\n  if not self. stopframe:\n   return True\n  return False\n  \n def break_here(self,frame):\n  filename=self. canonic(frame. f_code. co_filename)\n  if filename not in self. breaks:\n   return False\n  lineno=frame. f_lineno\n  if lineno not in self. breaks[filename]:\n  \n  \n   lineno=frame. f_code. co_firstlineno\n   if lineno not in self. breaks[filename]:\n    return False\n    \n    \n  (bp,flag)=effective(filename,lineno,frame)\n  if bp:\n   self. currentbp=bp. number\n   if (flag and bp. temporary):\n    self. do_clear(str(bp. number))\n   return True\n  else :\n   return False\n   \n def do_clear(self,arg):\n  raise NotImplementedError(\"subclass of bdb must implement do_clear()\")\n  \n def break_anywhere(self,frame):\n  return self. canonic(frame. f_code. co_filename)in self. breaks\n  \n  \n  \n  \n def user_call(self,frame,argument_list):\n  ''\n  \n  pass\n  \n def user_line(self,frame):\n  ''\n  pass\n  \n def user_return(self,frame,return_value):\n  ''\n  pass\n  \n def user_exception(self,frame,exc_info):\n  ''\n  \n  pass\n  \n def _set_stopinfo(self,stopframe,returnframe,stoplineno=0):\n  self. stopframe=stopframe\n  self. returnframe=returnframe\n  self. quitting=False\n  \n  \n  self. stoplineno=stoplineno\n  \n  \n  \n  \n def set_until(self,frame,lineno=None ):\n  ''\n  \n  \n  if lineno is None :\n   lineno=frame. f_lineno+1\n  self. _set_stopinfo(frame,frame,lineno)\n  \n def set_step(self):\n  ''\n  \n  \n  \n  \n  if self. frame_returning:\n   caller_frame=self. frame_returning. f_back\n   if caller_frame and not caller_frame. f_trace:\n    caller_frame. f_trace=self. trace_dispatch\n  self. _set_stopinfo(None ,None )\n  \n def set_next(self,frame):\n  ''\n  self. _set_stopinfo(frame,None )\n  \n def set_return(self,frame):\n  ''\n  if frame. f_code. co_flags&CO_GENERATOR:\n   self. _set_stopinfo(frame,None ,-1)\n  else :\n   self. _set_stopinfo(frame. f_back,frame)\n   \n def set_trace(self,frame=None ):\n  ''\n\n\n  \n  if frame is None :\n   frame=sys. _getframe(). f_back\n  self. reset()\n  while frame:\n   frame. f_trace=self. trace_dispatch\n   self. botframe=frame\n   frame=frame. f_back\n  self. set_step()\n  sys. settrace(self. trace_dispatch)\n  \n def set_continue(self):\n \n  self. _set_stopinfo(self. botframe,None ,-1)\n  if not self. breaks:\n  \n   sys. settrace(None )\n   frame=sys. _getframe(). f_back\n   while frame and frame is not self. botframe:\n    del frame. f_trace\n    frame=frame. f_back\n    \n def set_quit(self):\n  self. stopframe=self. botframe\n  self. returnframe=None\n  self. quitting=True\n  sys. settrace(None )\n  \n  \n  \n  \n  \n  \n  \n  \n def set_break(self,filename,lineno,temporary=False ,cond=None ,\n funcname=None ):\n  filename=self. canonic(filename)\n  import linecache\n  line=linecache. getline(filename,lineno)\n  if not line:\n   return'Line %s:%d does not exist'%(filename,lineno)\n  list=self. breaks. setdefault(filename,[])\n  if lineno not in list:\n   list. append(lineno)\n  bp=Breakpoint(filename,lineno,temporary,cond,funcname)\n  \n def _prune_breaks(self,filename,lineno):\n  if (filename,lineno)not in Breakpoint. bplist:\n   self. breaks[filename]. remove(lineno)\n  if not self. breaks[filename]:\n   del self. breaks[filename]\n   \n def clear_break(self,filename,lineno):\n  filename=self. canonic(filename)\n  if filename not in self. breaks:\n   return'There are no breakpoints in %s'%filename\n  if lineno not in self. breaks[filename]:\n   return'There is no breakpoint at %s:%d'%(filename,lineno)\n   \n   \n  for bp in Breakpoint. bplist[filename,lineno][:]:\n   bp. deleteMe()\n  self. _prune_breaks(filename,lineno)\n  \n def clear_bpbynumber(self,arg):\n  try :\n   bp=self. get_bpbynumber(arg)\n  except ValueError as err:\n   return str(err)\n  bp. deleteMe()\n  self. _prune_breaks(bp. file,bp. line)\n  \n def clear_all_file_breaks(self,filename):\n  filename=self. canonic(filename)\n  if filename not in self. breaks:\n   return'There are no breakpoints in %s'%filename\n  for line in self. breaks[filename]:\n   blist=Breakpoint. bplist[filename,line]\n   for bp in blist:\n    bp. deleteMe()\n  del self. breaks[filename]\n  \n def clear_all_breaks(self):\n  if not self. breaks:\n   return'There are no breakpoints'\n  for bp in Breakpoint. bpbynumber:\n   if bp:\n    bp. deleteMe()\n  self. breaks={}\n  \n def get_bpbynumber(self,arg):\n  if not arg:\n   raise ValueError('Breakpoint number expected')\n  try :\n   number=int(arg)\n  except ValueError:\n   raise ValueError('Non-numeric breakpoint number %s'%arg)\n  try :\n   bp=Breakpoint. bpbynumber[number]\n  except IndexError:\n   raise ValueError('Breakpoint number %d out of range'%number)\n  if bp is None :\n   raise ValueError('Breakpoint %d already deleted'%number)\n  return bp\n  \n def get_break(self,filename,lineno):\n  filename=self. canonic(filename)\n  return filename in self. breaks and  lineno in self. breaks[filename]\n  \n def get_breaks(self,filename,lineno):\n  filename=self. canonic(filename)\n  return filename in self. breaks and  lineno in self. breaks[filename]and  Breakpoint. bplist[filename,lineno]or []\n  \n def get_file_breaks(self,filename):\n  filename=self. canonic(filename)\n  if filename in self. breaks:\n   return self. breaks[filename]\n  else :\n   return []\n   \n def get_all_breaks(self):\n  return self. breaks\n  \n  \n  \n  \n def get_stack(self,f,t):\n  stack=[]\n  if t and t. tb_frame is f:\n   t=t. tb_next\n  while f is not None :\n   stack. append((f,f. f_lineno))\n   if f is self. botframe:\n    break\n   f=f. f_back\n  stack. reverse()\n  i=max(0,len(stack)-1)\n  while t is not None :\n   stack. append((t. tb_frame,t. tb_lineno))\n   t=t. tb_next\n  if f is None :\n   i=max(0,len(stack)-1)\n  return stack,i\n  \n def format_stack_entry(self,frame_lineno,lprefix=': '):\n  import linecache,reprlib\n  frame,lineno=frame_lineno\n  filename=self. canonic(frame. f_code. co_filename)\n  s='%s(%r)'%(filename,lineno)\n  if frame. f_code. co_name:\n   s +=frame. f_code. co_name\n  else :\n   s +=\"<lambda>\"\n  if'__args__'in frame. f_locals:\n   args=frame. f_locals['__args__']\n  else :\n   args=None\n  if args:\n   s +=reprlib. repr(args)\n  else :\n   s +='()'\n  if'__return__'in frame. f_locals:\n   rv=frame. f_locals['__return__']\n   s +='->'\n   s +=reprlib. repr(rv)\n  line=linecache. getline(filename,lineno,frame. f_globals)\n  if line:\n   s +=lprefix+line. strip()\n  return s\n  \n  \n  \n  \n  \n def run(self,cmd,globals=None ,locals=None ):\n  if globals is None :\n   import __main__\n   globals=__main__. __dict__\n  if locals is None :\n   locals=globals\n  self. reset()\n  if isinstance(cmd,str):\n   cmd=compile(cmd,\"<string>\",\"exec\")\n  sys. settrace(self. trace_dispatch)\n  try :\n   exec(cmd,globals,locals)\n  except BdbQuit:\n   pass\n  finally :\n   self. quitting=True\n   sys. settrace(None )\n   \n def runeval(self,expr,globals=None ,locals=None ):\n  if globals is None :\n   import __main__\n   globals=__main__. __dict__\n  if locals is None :\n   locals=globals\n  self. reset()\n  sys. settrace(self. trace_dispatch)\n  try :\n   return eval(expr,globals,locals)\n  except BdbQuit:\n   pass\n  finally :\n   self. quitting=True\n   sys. settrace(None )\n   \n def runctx(self,cmd,globals,locals):\n \n  self. run(cmd,globals,locals)\n  \n  \n  \n def runcall(self,func,*args,**kwds):\n  self. reset()\n  sys. settrace(self. trace_dispatch)\n  res=None\n  try :\n   res=func(*args,**kwds)\n  except BdbQuit:\n   pass\n  finally :\n   self. quitting=True\n   sys. settrace(None )\n  return res\n  \n  \ndef set_trace():\n Bdb(). set_trace()\n \n \nclass Breakpoint:\n ''\n\n\n\n\n\n\n\n\n\n\n \n \n \n \n \n next=1\n bplist={}\n bpbynumber=[None ]\n \n \n \n def __init__(self,file,line,temporary=False ,cond=None ,funcname=None ):\n  self. funcname=funcname\n  \n  self. func_first_executable_line=None\n  self. file=file\n  self. line=line\n  self. temporary=temporary\n  self. cond=cond\n  self. enabled=True\n  self. ignore=0\n  self. hits=0\n  self. number=Breakpoint. next\n  Breakpoint. next +=1\n  \n  self. bpbynumber. append(self)\n  if (file,line)in self. bplist:\n   self. bplist[file,line]. append(self)\n  else :\n   self. bplist[file,line]=[self]\n   \n def deleteMe(self):\n  index=(self. file,self. line)\n  self. bpbynumber[self. number]=None\n  self. bplist[index]. remove(self)\n  if not self. bplist[index]:\n  \n   del self. bplist[index]\n   \n def enable(self):\n  self. enabled=True\n  \n def disable(self):\n  self. enabled=False\n  \n def bpprint(self,out=None ):\n  if out is None :\n   out=sys. stdout\n  print(self. bpformat(),file=out)\n  \n def bpformat(self):\n  if self. temporary:\n   disp='del  '\n  else :\n   disp='keep '\n  if self. enabled:\n   disp=disp+'yes  '\n  else :\n   disp=disp+'no   '\n  ret='%-4dbreakpoint   %s at %s:%d'%(self. number,disp,\n  self. file,self. line)\n  if self. cond:\n   ret +='\\n\\tstop only if %s'%(self. cond,)\n  if self. ignore:\n   ret +='\\n\\tignore next %d hits'%(self. ignore,)\n  if self. hits:\n   if self. hits >1:\n    ss='s'\n   else :\n    ss=''\n   ret +='\\n\\tbreakpoint already hit %d time%s'%(self. hits,ss)\n  return ret\n  \n def __str__(self):\n  return'breakpoint %s at %s:%s'%(self. number,self. file,self. line)\n  \n  \n  \ndef checkfuncname(b,frame):\n ''\n if not b. funcname:\n \n  if b. line !=frame. f_lineno:\n  \n  \n   return False\n  return True\n  \n  \n  \n if frame. f_code. co_name !=b. funcname:\n \n  return False\n  \n  \n if not b. func_first_executable_line:\n \n  b. func_first_executable_line=frame. f_lineno\n  \n if b. func_first_executable_line !=frame. f_lineno:\n \n  return False\n return True\n \n \n \ndef effective(file,line,frame):\n ''\n\n\n\n\n\n \n possibles=Breakpoint. bplist[file,line]\n for b in possibles:\n  if not b. enabled:\n   continue\n  if not checkfuncname(b,frame):\n   continue\n   \n  b. hits +=1\n  if not b. cond:\n  \n   if b. ignore >0:\n    b. ignore -=1\n    continue\n   else :\n   \n    return (b,True )\n  else :\n  \n  \n  \n   try :\n    val=eval(b. cond,frame. f_globals,frame. f_locals)\n    if val:\n     if b. ignore >0:\n      b. ignore -=1\n      \n     else :\n      return (b,True )\n      \n      \n   except :\n   \n   \n   \n    return (b,False )\n return (None ,None )\n \n \n \n \nclass Tdb(Bdb):\n def user_call(self,frame,args):\n  name=frame. f_code. co_name\n  if not name:name='???'\n  print('+++ call',name,args)\n def user_line(self,frame):\n  import linecache\n  name=frame. f_code. co_name\n  if not name:name='???'\n  fn=self. canonic(frame. f_code. co_filename)\n  line=linecache. getline(fn,frame. f_lineno,frame. f_globals)\n  print('+++',fn,frame. f_lineno,name,':',line. strip())\n def user_return(self,frame,retval):\n  print('+++ return',retval)\n def user_exception(self,frame,exc_stuff):\n  print('+++ exception',exc_stuff)\n  self. set_continue()\n  \ndef foo(n):\n print('foo(',n,')')\n x=bar(n *10)\n print('bar returned',x)\n \ndef bar(a):\n print('bar(',a,')')\n return a /2\n \ndef test():\n t=Tdb()\n t. run('import bdb; bdb.foo(10)')\n", ["__main__", "fnmatch", "inspect", "linecache", "os", "reprlib", "sys"]], "threading": [".py", "''\n\nimport sys as _sys\nimport _thread\n\nfrom time import sleep as _sleep\ntry :\n from time import monotonic as _time\nexcept ImportError:\n from time import time as _time\nfrom traceback import format_exc as _format_exc\nfrom _weakrefset import WeakSet\n\n\n\n\n\n\n\n\n\n\n\n__all__=['active_count','Condition','current_thread','enumerate','Event',\n'Lock','RLock','Semaphore','BoundedSemaphore','Thread','Barrier',\n'Timer','ThreadError','setprofile','settrace','local','stack_size']\n\n\n_start_new_thread=_thread. start_new_thread\n_allocate_lock=_thread. allocate_lock\nget_ident=_thread. get_ident\nThreadError=_thread. error\ntry :\n _CRLock=_thread. RLock\nexcept AttributeError:\n _CRLock=None\nTIMEOUT_MAX=_thread. TIMEOUT_MAX\ndel _thread\n\n\n\n\n_profile_hook=None\n_trace_hook=None\n\ndef setprofile(func):\n ''\n\n\n\n\n \n global _profile_hook\n _profile_hook=func\n \ndef settrace(func):\n ''\n\n\n\n\n \n global _trace_hook\n _trace_hook=func\n \n \n \nLock=_allocate_lock\n\ndef RLock(*args,**kwargs):\n ''\n\n\n\n\n\n\n \n if _CRLock is None :\n  return _PyRLock(*args,**kwargs)\n return _CRLock(*args,**kwargs)\n \nclass _RLock:\n ''\n\n\n\n\n\n\n \n \n def __init__(self):\n  self. _block=_allocate_lock()\n  self. _owner=None\n  self. _count=0\n  \n def __repr__(self):\n  owner=self. _owner\n  try :\n   owner=_active[owner]. name\n  except KeyError:\n   pass\n  return\"<%s owner=%r count=%d>\"%(\n  self. __class__. __name__,owner,self. _count)\n  \n def acquire(self,blocking=True ,timeout=-1):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  me=get_ident()\n  if self. _owner ==me:\n   self. _count=self. _count+1\n   return 1\n  rc=self. _block. acquire(blocking,timeout)\n  if rc:\n   self. _owner=me\n   self. _count=1\n  return rc\n  \n __enter__=acquire\n \n def release(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if self. _owner !=get_ident():\n   raise RuntimeError(\"cannot release un-acquired lock\")\n  self. _count=count=self. _count -1\n  if not count:\n   self. _owner=None\n   self. _block. release()\n   \n def __exit__(self,t,v,tb):\n  self. release()\n  \n  \n  \n def _acquire_restore(self,state):\n  self. _block. acquire()\n  self. _count,self. _owner=state\n  \n def _release_save(self):\n  if self. _count ==0:\n   raise RuntimeError(\"cannot release un-acquired lock\")\n  count=self. _count\n  self. _count=0\n  owner=self. _owner\n  self. _owner=None\n  self. _block. release()\n  return (count,owner)\n  \n def _is_owned(self):\n  return self. _owner ==get_ident()\n  \n_PyRLock=_RLock\n\n\nclass Condition:\n ''\n\n\n\n\n\n\n\n\n \n \n def __init__(self,lock=None ):\n  if lock is None :\n   lock=RLock()\n  self. _lock=lock\n  \n  self. acquire=lock. acquire\n  self. release=lock. release\n  \n  \n  \n  try :\n   self. _release_save=lock. _release_save\n  except AttributeError:\n   pass\n  try :\n   self. _acquire_restore=lock. _acquire_restore\n  except AttributeError:\n   pass\n  try :\n   self. _is_owned=lock. _is_owned\n  except AttributeError:\n   pass\n  self. _waiters=[]\n  \n def __enter__(self):\n  return self. _lock. __enter__()\n  \n def __exit__(self,*args):\n  return self. _lock. __exit__(*args)\n  \n def __repr__(self):\n  return\"<Condition(%s, %d)>\"%(self. _lock,len(self. _waiters))\n  \n def _release_save(self):\n  self. _lock. release()\n  \n def _acquire_restore(self,x):\n  self. _lock. acquire()\n  \n def _is_owned(self):\n \n \n  if self. _lock. acquire(0):\n   self. _lock. release()\n   return False\n  else :\n   return True\n   \n def wait(self,timeout=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if not self. _is_owned():\n   raise RuntimeError(\"cannot wait on un-acquired lock\")\n  waiter=_allocate_lock()\n  waiter. acquire()\n  self. _waiters. append(waiter)\n  saved_state=self. _release_save()\n  try :\n   if timeout is None :\n    waiter. acquire()\n    gotit=True\n   else :\n    if timeout >0:\n     gotit=waiter. acquire(True ,timeout)\n    else :\n     gotit=waiter. acquire(False )\n    if not gotit:\n     try :\n      self. _waiters. remove(waiter)\n     except ValueError:\n      pass\n   return gotit\n  finally :\n   self. _acquire_restore(saved_state)\n   \n def wait_for(self,predicate,timeout=None ):\n  ''\n\n\n\n\n\n  \n  endtime=None\n  waittime=timeout\n  result=predicate()\n  while not result:\n   if waittime is not None :\n    if endtime is None :\n     endtime=_time()+waittime\n    else :\n     waittime=endtime -_time()\n     if waittime <=0:\n      break\n   self. wait(waittime)\n   result=predicate()\n  return result\n  \n def notify(self,n=1):\n  ''\n\n\n\n\n\n\n\n  \n  if not self. _is_owned():\n   raise RuntimeError(\"cannot notify on un-acquired lock\")\n  __waiters=self. _waiters\n  waiters=__waiters[:n]\n  if not waiters:\n   return\n  for waiter in waiters:\n   waiter. release()\n   try :\n    __waiters. remove(waiter)\n   except ValueError:\n    pass\n    \n def notify_all(self):\n  ''\n\n\n\n\n  \n  self. notify(len(self. _waiters))\n  \n notifyAll=notify_all\n \n \nclass Semaphore:\n ''\n\n\n\n\n\n\n \n \n \n \n def __init__(self,value=1):\n  if value <0:\n   raise ValueError(\"semaphore initial value must be >= 0\")\n  self. _cond=Condition(Lock())\n  self. _value=value\n  \n def acquire(self,blocking=True ,timeout=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if not blocking and timeout is not None :\n   raise ValueError(\"can't specify timeout for non-blocking acquire\")\n  rc=False\n  endtime=None\n  with self. _cond:\n   while self. _value ==0:\n    if not blocking:\n     break\n    if timeout is not None :\n     if endtime is None :\n      endtime=_time()+timeout\n     else :\n      timeout=endtime -_time()\n      if timeout <=0:\n       break\n    self. _cond. wait(timeout)\n   else :\n    self. _value=self. _value -1\n    rc=True\n  return rc\n  \n __enter__=acquire\n \n def release(self):\n  ''\n\n\n\n\n  \n  with self. _cond:\n   self. _value=self. _value+1\n   self. _cond. notify()\n   \n def __exit__(self,t,v,tb):\n  self. release()\n  \n  \nclass BoundedSemaphore(Semaphore):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __init__(self,value=1):\n  Semaphore. __init__(self,value)\n  self. _initial_value=value\n  \n def release(self):\n  ''\n\n\n\n\n\n\n\n  \n  with self. _cond:\n   if self. _value >=self. _initial_value:\n    raise ValueError(\"Semaphore released too many times\")\n   self. _value +=1\n   self. _cond. notify()\n   \n   \nclass Event:\n ''\n\n\n\n\n\n \n \n \n \n def __init__(self):\n  self. _cond=Condition(Lock())\n  self. _flag=False\n  \n def _reset_internal_locks(self):\n \n  self. _cond. __init__()\n  \n def is_set(self):\n  ''\n  return self. _flag\n  \n isSet=is_set\n \n def set(self):\n  ''\n\n\n\n\n  \n  self. _cond. acquire()\n  try :\n   self. _flag=True\n   self. _cond. notify_all()\n  finally :\n   self. _cond. release()\n   \n def clear(self):\n  ''\n\n\n\n\n  \n  self. _cond. acquire()\n  try :\n   self. _flag=False\n  finally :\n   self. _cond. release()\n   \n def wait(self,timeout=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. _cond. acquire()\n  try :\n   signaled=self. _flag\n   if not signaled:\n    signaled=self. _cond. wait(timeout)\n   return signaled\n  finally :\n   self. _cond. release()\n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \n   \nclass Barrier:\n ''\n\n\n\n\n\n \n \n def __init__(self,parties,action=None ,timeout=None ):\n  ''\n\n\n\n\n\n\n  \n  self. _cond=Condition(Lock())\n  self. _action=action\n  self. _timeout=timeout\n  self. _parties=parties\n  self. _state=0\n  self. _count=0\n  \n def wait(self,timeout=None ):\n  ''\n\n\n\n\n\n\n  \n  if timeout is None :\n   timeout=self. _timeout\n  with self. _cond:\n   self. _enter()\n   index=self. _count\n   self. _count +=1\n   try :\n    if index+1 ==self. _parties:\n    \n     self. _release()\n    else :\n    \n     self. _wait(timeout)\n    return index\n   finally :\n    self. _count -=1\n    \n    self. _exit()\n    \n    \n    \n def _enter(self):\n  while self. _state in (-1,1):\n  \n   self. _cond. wait()\n   \n  if self. _state <0:\n   raise BrokenBarrierError\n  assert self. _state ==0\n  \n  \n  \n def _release(self):\n  try :\n   if self. _action:\n    self. _action()\n    \n   self. _state=1\n   self. _cond. notify_all()\n  except :\n  \n   self. _break()\n   raise\n   \n   \n   \n def _wait(self,timeout):\n  if not self. _cond. wait_for(lambda :self. _state !=0,timeout):\n  \n   self. _break()\n   raise BrokenBarrierError\n  if self. _state <0:\n   raise BrokenBarrierError\n  assert self. _state ==1\n  \n  \n  \n def _exit(self):\n  if self. _count ==0:\n   if self. _state in (-1,1):\n   \n    self. _state=0\n    self. _cond. notify_all()\n    \n def reset(self):\n  ''\n\n\n\n\n  \n  with self. _cond:\n   if self. _count >0:\n    if self. _state ==0:\n    \n     self. _state=-1\n    elif self. _state ==-2:\n    \n    \n     self. _state=-1\n   else :\n    self. _state=0\n   self. _cond. notify_all()\n   \n def abort(self):\n  ''\n\n\n\n\n  \n  with self. _cond:\n   self. _break()\n   \n def _break(self):\n \n \n  self. _state=-2\n  self. _cond. notify_all()\n  \n @property\n def parties(self):\n  ''\n  return self. _parties\n  \n @property\n def n_waiting(self):\n  ''\n  \n  \n  if self. _state ==0:\n   return self. _count\n  return 0\n  \n @property\n def broken(self):\n  ''\n  return self. _state ==-2\n  \n  \nclass BrokenBarrierError(RuntimeError):\n pass\n \n \n \n_counter=0\ndef _newname(template=\"Thread-%d\"):\n global _counter\n _counter=_counter+1\n return template %_counter\n \n \n_active_limbo_lock=_allocate_lock()\n_active={}\n_limbo={}\n\n\n_dangling=WeakSet()\n\n\n\nclass Thread:\n ''\n\n\n\n\n\n \n \n __initialized=False\n \n \n \n \n __exc_info=_sys. exc_info\n \n \n \n \n def __init__(self,group=None ,target=None ,name=None ,\n args=(),kwargs=None ,*,daemon=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  assert group is None ,\"group argument must be None for now\"\n  if kwargs is None :\n   kwargs={}\n  self. _target=target\n  self. _name=str(name or _newname())\n  self. _args=args\n  self. _kwargs=kwargs\n  if daemon is not None :\n   self. _daemonic=daemon\n  else :\n   self. _daemonic=current_thread(). daemon\n  self. _ident=None\n  self. _started=Event()\n  self. _stopped=False\n  self. _block=Condition(Lock())\n  self. _initialized=True\n  \n  \n  self. _stderr=_sys. stderr\n  _dangling. add(self)\n  \n def _reset_internal_locks(self):\n \n \n  if hasattr(self,'_block'):\n   self. _block. __init__()\n  self. _started. _reset_internal_locks()\n  \n def __repr__(self):\n  assert self. _initialized,\"Thread.__init__() was not called\"\n  status=\"initial\"\n  if self. _started. is_set():\n   status=\"started\"\n  if self. _stopped:\n   status=\"stopped\"\n  if self. _daemonic:\n   status +=\" daemon\"\n  if self. _ident is not None :\n   status +=\" %s\"%self. _ident\n  return\"<%s(%s, %s)>\"%(self. __class__. __name__,self. _name,status)\n  \n def start(self):\n  ''\n\n\n\n\n\n\n\n  \n  if not self. _initialized:\n   raise RuntimeError(\"thread.__init__() not called\")\n   \n  if self. _started. is_set():\n   raise RuntimeError(\"threads can only be started once\")\n  with _active_limbo_lock:\n   _limbo[self]=self\n  try :\n   _start_new_thread(self. _bootstrap,())\n  except Exception:\n   with _active_limbo_lock:\n    del _limbo[self]\n   raise\n  self. _started. wait()\n  \n def run(self):\n  ''\n\n\n\n\n\n\n  \n  try :\n   if self. _target:\n    self. _target(*self. _args,**self. _kwargs)\n  finally :\n  \n  \n   del self. _target,self. _args,self. _kwargs\n   \n def _bootstrap(self):\n \n \n \n \n \n \n \n \n \n \n \n \n  try :\n   self. _bootstrap_inner()\n  except :\n   if self. _daemonic and _sys is None :\n    return\n   raise\n   \n def _set_ident(self):\n  self. _ident=get_ident()\n  \n def _bootstrap_inner(self):\n  try :\n   self. _set_ident()\n   self. _started. set()\n   with _active_limbo_lock:\n    _active[self. _ident]=self\n    del _limbo[self]\n    \n   if _trace_hook:\n    _sys. settrace(_trace_hook)\n   if _profile_hook:\n    _sys. setprofile(_profile_hook)\n    \n   try :\n    self. run()\n   except SystemExit:\n    pass\n   except :\n   \n   \n   \n   \n    if _sys:\n     _sys. stderr. write(\"Exception in thread %s:\\n%s\\n\"%\n     (self. name,_format_exc()))\n    else :\n    \n    \n    \n     exc_type,exc_value,exc_tb=self. _exc_info()\n     try :\n      print((\n      \"Exception in thread \"+self. name+\n      \" (most likely raised during interpreter shutdown):\"),file=self. _stderr)\n      print((\n      \"Traceback (most recent call last):\"),file=self. _stderr)\n      while exc_tb:\n       print((\n       '  File \"%s\", line %s, in %s'%\n       (exc_tb. tb_frame. f_code. co_filename,\n       exc_tb. tb_lineno,\n       exc_tb. tb_frame. f_code. co_name)),file=self. _stderr)\n       exc_tb=exc_tb. tb_next\n      print((\"%s: %s\"%(exc_type,exc_value)),file=self. _stderr)\n      \n      \n     finally :\n      del exc_type,exc_value,exc_tb\n   finally :\n   \n   \n   \n   \n   \n    pass\n  finally :\n   with _active_limbo_lock:\n    self. _stop()\n    try :\n    \n    \n     del _active[get_ident()]\n    except :\n     pass\n     \n def _stop(self):\n  self. _block. acquire()\n  self. _stopped=True\n  self. _block. notify_all()\n  self. _block. release()\n  \n def _delete(self):\n  ''\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  try :\n   with _active_limbo_lock:\n    del _active[get_ident()]\n    \n    \n    \n    \n  except KeyError:\n   if'dummy_threading'not in _sys. modules:\n    raise\n    \n def join(self,timeout=None ):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if not self. _initialized:\n   raise RuntimeError(\"Thread.__init__() not called\")\n  if not self. _started. is_set():\n   raise RuntimeError(\"cannot join thread before it is started\")\n  if self is current_thread():\n   raise RuntimeError(\"cannot join current thread\")\n   \n  self. _block. acquire()\n  try :\n   if timeout is None :\n    while not self. _stopped:\n     self. _block. wait()\n   else :\n    deadline=_time()+timeout\n    while not self. _stopped:\n     delay=deadline -_time()\n     if delay <=0:\n      break\n     self. _block. wait(delay)\n  finally :\n   self. _block. release()\n   \n @property\n def name(self):\n  ''\n\n\n\n\n  \n  assert self. _initialized,\"Thread.__init__() not called\"\n  return self. _name\n  \n @name. setter\n def name(self,name):\n  assert self. _initialized,\"Thread.__init__() not called\"\n  self. _name=str(name)\n  \n @property\n def ident(self):\n  ''\n\n\n\n\n\n  \n  assert self. _initialized,\"Thread.__init__() not called\"\n  return self. _ident\n  \n def is_alive(self):\n  ''\n\n\n\n\n\n  \n  assert self. _initialized,\"Thread.__init__() not called\"\n  return self. _started. is_set()and not self. _stopped\n  \n isAlive=is_alive\n \n @property\n def daemon(self):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  assert self. _initialized,\"Thread.__init__() not called\"\n  return self. _daemonic\n  \n @daemon. setter\n def daemon(self,daemonic):\n  if not self. _initialized:\n   raise RuntimeError(\"Thread.__init__() not called\")\n  if self. _started. is_set():\n   raise RuntimeError(\"cannot set daemon status of active thread\");\n  self. _daemonic=daemonic\n  \n def isDaemon(self):\n  return self. daemon\n  \n def setDaemon(self,daemonic):\n  self. daemon=daemonic\n  \n def getName(self):\n  return self. name\n  \n def setName(self,name):\n  self. name=name\n  \n  \n  \nclass Timer(Thread):\n ''\n\n\n\n\n\n \n \n def __init__(self,interval,function,args=None ,kwargs=None ):\n  Thread. __init__(self)\n  self. interval=interval\n  self. function=function\n  self. args=args if args is not None else []\n  self. kwargs=kwargs if kwargs is not None else {}\n  self. finished=Event()\n  \n def cancel(self):\n  ''\n  self. finished. set()\n  \n def run(self):\n  self. finished. wait(self. interval)\n  if not self. finished. is_set():\n   self. function(*self. args,**self. kwargs)\n  self. finished. set()\n  \n  \n  \n  \nclass _MainThread(Thread):\n\n def __init__(self):\n  Thread. __init__(self,name=\"MainThread\",daemon=False )\n  self. _started. set()\n  self. _set_ident()\n  with _active_limbo_lock:\n   _active[self. _ident]=self\n   \n def _exitfunc(self):\n  self. _stop()\n  t=_pickSomeNonDaemonThread()\n  while t:\n   t. join()\n   t=_pickSomeNonDaemonThread()\n  self. _delete()\n  \ndef _pickSomeNonDaemonThread():\n for t in enumerate():\n  if not t. daemon and t. is_alive():\n   return t\n return None\n \n \n \n \n \n \n \n \n \n \nclass _DummyThread(Thread):\n\n def __init__(self):\n  Thread. __init__(self,name=_newname(\"Dummy-%d\"),daemon=True )\n  \n  \n  \n  \n  del self. _block\n  \n  self. _started. set()\n  self. _set_ident()\n  with _active_limbo_lock:\n   _active[self. _ident]=self\n   \n def _stop(self):\n  pass\n  \n def join(self,timeout=None ):\n  assert False ,\"cannot join a dummy thread\"\n  \n  \n  \n  \ndef current_thread():\n ''\n\n\n\n\n \n try :\n  return _active[get_ident()]\n except KeyError:\n  return _DummyThread()\n  \ncurrentThread=current_thread\n\ndef active_count():\n ''\n\n\n\n\n \n with _active_limbo_lock:\n  return len(_active)+len(_limbo)\n  \nactiveCount=active_count\n\ndef _enumerate():\n\n return list(_active. values())+list(_limbo. values())\n \ndef enumerate():\n ''\n\n\n\n\n\n \n with _active_limbo_lock:\n  return list(_active. values())+list(_limbo. values())\n  \nfrom _thread import stack_size\n\n\n\n\n\n_shutdown=_MainThread(). _exitfunc\n\n\n\n\ntry :\n from _thread import _local as local\nexcept ImportError:\n from _threading_local import local\n \n \ndef _after_fork():\n\n\n\n\n\n\n global _active_limbo_lock\n _active_limbo_lock=_allocate_lock()\n \n \n new_active={}\n current=current_thread()\n with _active_limbo_lock:\n  for thread in _enumerate():\n  \n  \n   thread. _reset_internal_locks()\n   if thread is current:\n   \n   \n    ident=get_ident()\n    thread. _ident=ident\n    new_active[ident]=thread\n   else :\n   \n    thread. _stop()\n    \n  _limbo. clear()\n  _active. clear()\n  _active. update(new_active)\n  assert len(_active)==1\n", ["_thread", "_threading_local", "_weakrefset", "sys", "time", "traceback"]], "textwrap": [".py", "''\n\n\n\n\n\n\nimport re\n\n__all__=['TextWrapper','wrap','fill','dedent','indent']\n\n\n\n\n\n\n\n\n\n_whitespace='\\t\\n\\x0b\\x0c\\r '\n\nclass TextWrapper:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n unicode_whitespace_trans={}\n uspace=ord(' ')\n for x in _whitespace:\n  unicode_whitespace_trans[ord(x)]=uspace\n  \n  \n  \n  \n  \n  \n  \n wordsep_re=re. compile(\n r'(\\s+|'\n r'[^\\s\\w]*\\w+[^0-9\\W]-(?=\\w+[^0-9\\W])|'\n r'(?<=[\\w\\!\\\"\\'\\&\\.\\,\\?])-{2,}(?=\\w))')\n \n \n \n \n \n wordsep_simple_re=re. compile(r'(\\s+)')\n \n \n \n sentence_end_re=re. compile(r'[a-z]'\n r'[\\.\\!\\?]'\n r'[\\\"\\']?'\n r'\\Z')\n \n \n def __init__(self,\n width=70,\n initial_indent=\"\",\n subsequent_indent=\"\",\n expand_tabs=True ,\n replace_whitespace=True ,\n fix_sentence_endings=False ,\n break_long_words=True ,\n drop_whitespace=True ,\n break_on_hyphens=True ,\n tabsize=8):\n  self. width=width\n  self. initial_indent=initial_indent\n  self. subsequent_indent=subsequent_indent\n  self. expand_tabs=expand_tabs\n  self. replace_whitespace=replace_whitespace\n  self. fix_sentence_endings=fix_sentence_endings\n  self. break_long_words=break_long_words\n  self. drop_whitespace=drop_whitespace\n  self. break_on_hyphens=break_on_hyphens\n  self. tabsize=tabsize\n  \n  \n  \n  \n  \n def _munge_whitespace(self,text):\n  ''\n\n\n\n\n  \n  if self. expand_tabs:\n   text=text. expandtabs(self. tabsize)\n  if self. replace_whitespace:\n   text=text. translate(self. unicode_whitespace_trans)\n  return text\n  \n  \n def _split(self,text):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if self. break_on_hyphens is True :\n   chunks=self. wordsep_re. split(text)\n  else :\n   chunks=self. wordsep_simple_re. split(text)\n  chunks=[c for c in chunks if c]\n  return chunks\n  \n def _fix_sentence_endings(self,chunks):\n  ''\n\n\n\n\n\n\n  \n  i=0\n  patsearch=self. sentence_end_re. search\n  while i <len(chunks)-1:\n   if chunks[i+1]==\" \"and patsearch(chunks[i]):\n    chunks[i+1]=\"  \"\n    i +=2\n   else :\n    i +=1\n    \n def _handle_long_word(self,reversed_chunks,cur_line,cur_len,width):\n  ''\n\n\n\n\n\n  \n  \n  \n  if width <1:\n   space_left=1\n  else :\n   space_left=width -cur_len\n   \n   \n   \n  if self. break_long_words:\n   cur_line. append(reversed_chunks[-1][:space_left])\n   reversed_chunks[-1]=reversed_chunks[-1][space_left:]\n   \n   \n   \n   \n  elif not cur_line:\n   cur_line. append(reversed_chunks. pop())\n   \n   \n   \n   \n   \n   \n   \n def _wrap_chunks(self,chunks):\n  ''\n\n\n\n\n\n\n\n\n\n\n  \n  lines=[]\n  if self. width <=0:\n   raise ValueError(\"invalid width %r (must be > 0)\"%self. width)\n   \n   \n   \n  chunks. reverse()\n  \n  while chunks:\n  \n  \n  \n   cur_line=[]\n   cur_len=0\n   \n   \n   if lines:\n    indent=self. subsequent_indent\n   else :\n    indent=self. initial_indent\n    \n    \n   width=self. width -len(indent)\n   \n   \n   \n   if self. drop_whitespace and chunks[-1]. strip()==''and lines:\n    del chunks[-1]\n    \n   while chunks:\n    l=len(chunks[-1])\n    \n    \n    if cur_len+l <=width:\n     cur_line. append(chunks. pop())\n     cur_len +=l\n     \n     \n    else :\n     break\n     \n     \n     \n   if chunks and len(chunks[-1])>width:\n    self. _handle_long_word(chunks,cur_line,cur_len,width)\n    \n    \n   if self. drop_whitespace and cur_line and cur_line[-1]. strip()=='':\n    del cur_line[-1]\n    \n    \n    \n   if cur_line:\n    lines. append(indent+''. join(cur_line))\n    \n  return lines\n  \n  \n  \n  \n def wrap(self,text):\n  ''\n\n\n\n\n\n\n  \n  text=self. _munge_whitespace(text)\n  chunks=self. _split(text)\n  if self. fix_sentence_endings:\n   self. _fix_sentence_endings(chunks)\n  return self. _wrap_chunks(chunks)\n  \n def fill(self,text):\n  ''\n\n\n\n\n  \n  return\"\\n\". join(self. wrap(text))\n  \n  \n  \n  \ndef wrap(text,width=70,**kwargs):\n ''\n\n\n\n\n\n\n\n \n w=TextWrapper(width=width,**kwargs)\n return w. wrap(text)\n \ndef fill(text,width=70,**kwargs):\n ''\n\n\n\n\n\n\n \n w=TextWrapper(width=width,**kwargs)\n return w. fill(text)\n \n \n \n \n_whitespace_only_re=re. compile('^[ \\t]+$',re. MULTILINE)\n_leading_whitespace_re=re. compile('(^[ \\t]*)(?:[^ \\t\\n])',re. MULTILINE)\n\ndef dedent(text):\n ''\n\n\n\n\n\n\n\n\n\n\n \n \n \n margin=None\n text=_whitespace_only_re. sub('',text)\n indents=_leading_whitespace_re. findall(text)\n for indent in indents:\n  if margin is None :\n   margin=indent\n   \n   \n   \n  elif indent. startswith(margin):\n   pass\n   \n   \n   \n  elif margin. startswith(indent):\n   margin=indent\n   \n   \n   \n  else :\n   margin=\"\"\n   break\n   \n   \n if 0 and margin:\n  for line in text. split(\"\\n\"):\n   assert not line or line. startswith(margin),   \"line = %r, margin = %r\"%(line,margin)\n   \n if margin:\n  text=re. sub(r'(?m)^'+margin,'',text)\n return text\n \n \ndef indent(text,prefix,predicate=None ):\n ''\n\n\n\n\n\n \n if predicate is None :\n  def predicate(line):\n   return line. strip()\n   \n def prefixed_lines():\n  for line in text. splitlines(True ):\n   yield (prefix+line if predicate(line)else line)\n return''. join(prefixed_lines())\n \n \nif __name__ ==\"__main__\":\n\n\n print(dedent(\"Hello there.\\n  This is indented.\"))\n", ["re"]], "_weakref": [".py", "class ProxyType:\n\n def __init__(self,obj):\n  self. obj=obj\n  \nCallableProxyType=ProxyType\nProxyTypes=[ProxyType,CallableProxyType]\n\nclass ReferenceType:\n\n def __init__(self,obj,callback):\n  self. obj=obj\n  self. callback=callback\n  \nclass ref:\n\n def __init__(self,obj,callback=None ):\n  self. obj=ReferenceType(obj,callback)\n  self. callback=callback\n  \n def __call__(self):\n  return self. obj. obj\n  \n def __hash__(self):\n  return hash(self. obj. obj)\n  \n def __eq__(self,other):\n  return self. obj. obj ==other. obj. obj\n  \ndef getweakrefcount(obj):\n return 1\n \ndef getweakrefs(obj):\n return obj\n \n \ndef proxy(obj,callback=None ):\n return ProxyType(obj)\n \n", []], "platform": [".py", "''\n\n\n\nfrom browser import window\n\ndef architecture(*args,**kw):\n return\"<unknown>\",window. navigator. platform\n \ndef machine(*args,**kw):\n return''\n \ndef node(*args,**kw):\n return''\n \ndef platform(*args,**kw):\n return window. navigator. platform\n \ndef processor(*args,**kw):\n return''\n \ndef python_build():\n return ('.'. join(map(str,__BRYTHON__. implementation[:-1])),\n __BRYTHON__. compiled_date)\n \ndef python_compiler():\n return''\n \ndef python_branch():\n return''\n \ndef python_implementation():\n return'Brython'\n \ndef python_revision():\n return''\n \ndef python_version():\n return'.'. join(map(str,__BRYTHON__. version_info[:3]))\n \ndef python_version_tuple():\n return __BRYTHON__. version_info[:3]\n \ndef release():\n return''\n \ndef system():\n return window. navigator. platform\n \ndef system_alias(*args,**kw):\n return window. navigator. platform\n \ndef uname():\n from collections import namedtuple\n klass=namedtuple('uname_result',\n 'system node release version machine processor')\n return klass(window. navigator. platform,'','','','','')", ["browser", "collections"]], "json": [".js", "var $module = (function($B){\n\nreturn  {\n    loads : function(){\n        var $ = $B.args('loads', 1, {obj:null}, ['obj'], arguments, {},\n            null, null)\n        return $B.jsobject2pyobject(JSON.parse($.obj))\n    },\n    load : function(){\n        var $ = $B.args('load', 1, {obj:null}, ['obj'], arguments, {},\n            null, null)\n        return $module.loads(obj.$content);\n    },\n    dumps : function(){\n        var $ = $B.args('dumps', 1, {obj:null}, ['obj'], arguments, {},\n            null, null)\n        return JSON.stringify($B.pyobject2jsobject($.obj))\n    },\n}\n\n})(__BRYTHON__)\n"], "_sre": [".py", "\n''\n\n\n\n\n\n\n\nMAXREPEAT=2147483648\n\n\nimport operator,sys\nfrom sre_constants import ATCODES,OPCODES,CHCODES\nfrom sre_constants import SRE_INFO_PREFIX,SRE_INFO_LITERAL\nfrom sre_constants import SRE_FLAG_UNICODE,SRE_FLAG_LOCALE\n\n\nimport sys\n\n\n\nMAGIC=20031017\n\n\n\n\n\n\n\n\n\n\n\n\n\nCODESIZE=4\n\ncopyright=\"_sre.py 2.4c Copyright 2005 by Nik Haldimann\"\n\n\ndef getcodesize():\n return CODESIZE\n \ndef compile(pattern,flags,code,groups=0,groupindex={},indexgroup=[None ]):\n ''\n \n return SRE_Pattern(pattern,flags,code,groups,groupindex,indexgroup)\n \ndef getlower(char_ord,flags):\n if (char_ord <128)or (flags&SRE_FLAG_UNICODE) or (flags&SRE_FLAG_LOCALE and char_ord <256):\n \n  return ord(chr(char_ord). lower())\n else :\n  return char_ord\n  \n  \nclass SRE_Pattern:\n\n def __init__(self,pattern,flags,code,groups=0,groupindex={},indexgroup=[None ]):\n  self. pattern=pattern\n  self. flags=flags\n  self. groups=groups\n  self. groupindex=groupindex\n  self. _indexgroup=indexgroup\n  self. _code=code\n  \n def match(self,string,pos=0,endpos=sys. maxsize):\n  ''\n\n  \n  state=_State(string,pos,endpos,self. flags)\n  if state. match(self. _code):\n   return SRE_Match(self,state)\n  return None\n  \n def search(self,string,pos=0,endpos=sys. maxsize):\n  ''\n\n\n  \n  state=_State(string,pos,endpos,self. flags)\n  if state. search(self. _code):\n   return SRE_Match(self,state)\n  else :\n   return None\n   \n def findall(self,string,pos=0,endpos=sys. maxsize):\n  ''\n  matchlist=[]\n  state=_State(string,pos,endpos,self. flags)\n  while state. start <=state. end:\n   state. reset()\n   state. string_position=state. start\n   if not state. search(self. _code):\n    break\n   match=SRE_Match(self,state)\n   if self. groups ==0 or self. groups ==1:\n    item=match. group(self. groups)\n   else :\n    item=match. groups(\"\")\n   matchlist. append(item)\n   if state. string_position ==state. start:\n    state. start +=1\n   else :\n    state. start=state. string_position\n  return matchlist\n  \n def _subx(self,template,string,count=0,subn=False ):\n  filter=template\n  if not callable(template)and\"\\\\\"in template:\n  \n  \n  \n  \n   import re as sre\n   filter=sre. _subx(self,template)\n  state=_State(string,0,sys. maxsize,self. flags)\n  sublist=[]\n  \n  n=last_pos=0\n  while not count or n <count:\n   state. reset()\n   state. string_position=state. start\n   if not state. search(self. _code):\n    break\n   if last_pos <state. start:\n    sublist. append(string[last_pos:state. start])\n   if not (last_pos ==state. start and\n   last_pos ==state. string_position and n >0):\n   \n    if callable(filter):\n     sublist. append(filter(SRE_Match(self,state)))\n    else :\n     sublist. append(filter)\n    last_pos=state. string_position\n    n +=1\n   if state. string_position ==state. start:\n    state. start +=1\n   else :\n    state. start=state. string_position\n    \n  if last_pos <state. end:\n   sublist. append(string[last_pos:state. end])\n  item=\"\". join(sublist)\n  if subn:\n   return item,n\n  else :\n   return item\n   \n def sub(self,repl,string,count=0):\n  ''\n  \n  return self. _subx(repl,string,count,False )\n  \n def subn(self,repl,string,count=0):\n  ''\n\n  \n  return self. _subx(repl,string,count,True )\n  \n def split(self,string,maxsplit=0):\n  ''\n  splitlist=[]\n  state=_State(string,0,sys. maxsize,self. flags)\n  n=0\n  last=state. start\n  while not maxsplit or n <maxsplit:\n   state. reset()\n   state. string_position=state. start\n   if not state. search(self. _code):\n    break\n   if state. start ==state. string_position:\n    if last ==state. end:\n     break\n    state. start +=1\n    continue\n   splitlist. append(string[last:state. start])\n   \n   if self. groups:\n    match=SRE_Match(self,state)\n    splitlist. extend(list(match. groups(None )))\n   n +=1\n   last=state. start=state. string_position\n  splitlist. append(string[last:state. end])\n  return splitlist\n  \n def finditer(self,string,pos=0,endpos=sys. maxsize):\n  ''\n  \n  _list=[]\n  _m=self. scanner(string,pos,endpos)\n  _re=SRE_Scanner(self,string,pos,endpos)\n  _m=_re. search()\n  while _m:\n   _list. append(_m)\n   _m=_re. search()\n  return _list\n  \n  \n def scanner(self,string,start=0,end=sys. maxsize):\n  return SRE_Scanner(self,string,start,end)\n  \n def __copy__(self):\n  raise TypeError(\"cannot copy this pattern object\")\n  \n def __deepcopy__(self):\n  raise TypeError(\"cannot copy this pattern object\")\n  \nclass SRE_Scanner:\n ''\n \n def __init__(self,pattern,string,start,end):\n  self. pattern=pattern\n  self. _state=_State(string,start,end,self. pattern. flags)\n  \n def _match_search(self,matcher):\n  state=self. _state\n  state. reset()\n  state. string_position=state. start\n  match=None\n  if matcher(self. pattern. _code):\n   match=SRE_Match(self. pattern,state)\n  if match is None or state. string_position ==state. start:\n   state. start +=1\n  else :\n   state. start=state. string_position\n  return match\n  \n def match(self):\n  return self. _match_search(self. _state. match)\n  \n def search(self):\n  return self. _match_search(self. _state. search)\n  \nclass SRE_Match:\n\n def __init__(self,pattern,state):\n  self. re=pattern\n  self. string=state. string\n  self. pos=state. pos\n  self. endpos=state. end\n  self. lastindex=state. lastindex\n  if self. lastindex <0:\n   self. lastindex=None\n  self. regs=self. _create_regs(state)\n  \n  \n  \n  if self. lastindex is not None and pattern. _indexgroup and 0 <=self. lastindex <len(pattern. _indexgroup):\n  \n  \n  \n  \n  \n   self. lastgroup=pattern. _indexgroup[self. lastindex]\n  else :\n   self. lastgroup=None\n   \n def _create_regs(self,state):\n  ''\n  regs=[(state. start,state. string_position)]\n  for group in range(self. re. groups):\n   mark_index=2 *group\n   if mark_index+1 <len(state. marks)   and state. marks[mark_index]is not None   and state. marks[mark_index+1]is not None :\n    regs. append((state. marks[mark_index],state. marks[mark_index+1]))\n   else :\n    regs. append((-1,-1))\n  return tuple(regs)\n  \n def _get_index(self,group):\n  if isinstance(group,int):\n   if group >=0 and group <=self. re. groups:\n    return group\n  else :\n   if group in self. re. groupindex:\n    return self. re. groupindex[group]\n  raise IndexError(\"no such group\")\n  \n def _get_slice(self,group,default):\n  group_indices=self. regs[group]\n  if group_indices[0]>=0:\n   return self. string[group_indices[0]:group_indices[1]]\n  else :\n   return default\n   \n def start(self,group=0):\n  ''\n\n  \n  return self. regs[self. _get_index(group)][0]\n  \n def end(self,group=0):\n  ''\n\n  \n  return self. regs[self. _get_index(group)][1]\n  \n def span(self,group=0):\n  ''\n  return self. start(group),self. end(group)\n  \n def expand(self,template):\n  ''\n  \n  import sre\n  return sre. _expand(self. re,self,template)\n  \n def groups(self,default=None ):\n  ''\n\n  \n  groups=[]\n  for indices in self. regs[1:]:\n   if indices[0]>=0:\n    groups. append(self. string[indices[0]:indices[1]])\n   else :\n    groups. append(default)\n  return tuple(groups)\n  \n def groupdict(self,default=None ):\n  ''\n\n  \n  groupdict={}\n  for key,value in self. re. groupindex. items():\n   groupdict[key]=self. _get_slice(value,default)\n  return groupdict\n  \n def group(self,*args):\n  ''\n  \n  if len(args)==0:\n   args=(0,)\n  grouplist=[]\n  for group in args:\n   grouplist. append(self. _get_slice(self. _get_index(group),None ))\n  if len(grouplist)==1:\n   return grouplist[0]\n  else :\n   return tuple(grouplist)\n   \n def __copy__():\n  raise TypeError(\"cannot copy this pattern object\")\n  \n def __deepcopy__():\n  raise TypeError(\"cannot copy this pattern object\")\n  \n  \nclass _State:\n\n def __init__(self,string,start,end,flags):\n  self. string=string\n  if start <0:\n   start=0\n  if end >len(string):\n   end=len(string)\n  self. start=start\n  self. string_position=self. start\n  self. end=end\n  self. pos=start\n  self. flags=flags\n  self. reset()\n  \n def reset(self):\n  self. marks=[]\n  self. lastindex=-1\n  self. marks_stack=[]\n  self. context_stack=[]\n  self. repeat=None\n  \n def match(self,pattern_codes):\n \n \n \n \n \n \n \n \n \n  dispatcher=_OpcodeDispatcher()\n  self. context_stack. append(_MatchContext(self,pattern_codes))\n  has_matched=None\n  while len(self. context_stack)>0:\n   context=self. context_stack[-1]\n   has_matched=dispatcher. match(context)\n   if has_matched is not None :\n    self. context_stack. pop()\n  return has_matched\n  \n def search(self,pattern_codes):\n  flags=0\n  if pattern_codes[0]==OPCODES[\"info\"]:\n  \n  \n   if pattern_codes[2]&SRE_INFO_PREFIX and pattern_codes[5]>1:\n    return self. fast_search(pattern_codes)\n   flags=pattern_codes[2]\n   pattern_codes=pattern_codes[pattern_codes[1]+1:]\n   \n  string_position=self. start\n  if pattern_codes[0]==OPCODES[\"literal\"]:\n  \n  \n   character=pattern_codes[1]\n   while True :\n    while string_position <self. end    and ord(self. string[string_position])!=character:\n     string_position +=1\n    if string_position >=self. end:\n     return False\n    self. start=string_position\n    string_position +=1\n    self. string_position=string_position\n    if flags&SRE_INFO_LITERAL:\n     return True\n    if self. match(pattern_codes[2:]):\n     return True\n   return False\n   \n   \n  while string_position <=self. end:\n   self. reset()\n   self. start=self. string_position=string_position\n   if self. match(pattern_codes):\n    return True\n   string_position +=1\n  return False\n  \n def fast_search(self,pattern_codes):\n  ''\n  \n  \n  \n  flags=pattern_codes[2]\n  prefix_len=pattern_codes[5]\n  prefix_skip=pattern_codes[6]\n  prefix=pattern_codes[7:7+prefix_len]\n  overlap=pattern_codes[7+prefix_len -1:pattern_codes[1]+1]\n  pattern_codes=pattern_codes[pattern_codes[1]+1:]\n  i=0\n  string_position=self. string_position\n  while string_position <self. end:\n   while True :\n    if ord(self. string[string_position])!=prefix[i]:\n     if i ==0:\n      break\n     else :\n      i=overlap[i]\n    else :\n     i +=1\n     if i ==prefix_len:\n     \n      self. start=string_position+1 -prefix_len\n      self. string_position=string_position+1      -prefix_len+prefix_skip\n      if flags&SRE_INFO_LITERAL:\n       return True\n      if self. match(pattern_codes[2 *prefix_skip:]):\n       return True\n      i=overlap[i]\n     break\n   string_position +=1\n  return False\n  \n def set_mark(self,mark_nr,position):\n  if mark_nr&1:\n  \n  \n  \n   self. lastindex=mark_nr //2+1\n  if mark_nr >=len(self. marks):\n   self. marks. extend([None ]*(mark_nr -len(self. marks)+1))\n  self. marks[mark_nr]=position\n  \n def get_marks(self,group_index):\n  marks_index=2 *group_index\n  if len(self. marks)>marks_index+1:\n   return self. marks[marks_index],self. marks[marks_index+1]\n  else :\n   return None ,None\n   \n def marks_push(self):\n  self. marks_stack. append((self. marks[:],self. lastindex))\n  \n def marks_pop(self):\n  self. marks,self. lastindex=self. marks_stack. pop()\n  \n def marks_pop_keep(self):\n  self. marks,self. lastindex=self. marks_stack[-1]\n  \n def marks_pop_discard(self):\n  self. marks_stack. pop()\n  \n def lower(self,char_ord):\n  return getlower(char_ord,self. flags)\n  \n  \nclass _MatchContext:\n\n def __init__(self,state,pattern_codes):\n  self. state=state\n  self. pattern_codes=pattern_codes\n  self. string_position=state. string_position\n  self. code_position=0\n  self. has_matched=None\n  \n def push_new_context(self,pattern_offset):\n  ''\n\n  \n  child_context=_MatchContext(self. state,\n  self. pattern_codes[self. code_position+pattern_offset:])\n  \n  \n  \n  \n  self. state. context_stack. append(child_context)\n  return child_context\n  \n def peek_char(self,peek=0):\n  return self. state. string[self. string_position+peek]\n  \n def skip_char(self,skip_count):\n  self. string_position +=skip_count\n  \n def remaining_chars(self):\n  return self. state. end -self. string_position\n  \n def peek_code(self,peek=0):\n  return self. pattern_codes[self. code_position+peek]\n  \n def skip_code(self,skip_count):\n  self. code_position +=skip_count\n  \n def remaining_codes(self):\n  return len(self. pattern_codes)-self. code_position\n  \n def at_beginning(self):\n  return self. string_position ==0\n  \n def at_end(self):\n  return self. string_position ==self. state. end\n  \n def at_linebreak(self):\n  return not self. at_end()and _is_linebreak(self. peek_char())\n  \n def at_boundary(self,word_checker):\n  if self. at_beginning()and self. at_end():\n   return False\n  that=not self. at_beginning()and word_checker(self. peek_char(-1))\n  this=not self. at_end()and word_checker(self. peek_char())\n  return this !=that\n  \n  \nclass _RepeatContext(_MatchContext):\n\n def __init__(self,context):\n  _MatchContext. __init__(self,context. state,\n  context. pattern_codes[context. code_position:])\n  self. count=-1\n  \n  self. previous=context. state. repeat\n  self. last_position=None\n  \n  \nclass _Dispatcher:\n\n DISPATCH_TABLE=None\n \n def dispatch(self,code,context):\n  method=self. DISPATCH_TABLE. get(code,self. __class__. unknown)\n  return method(self,context)\n  \n def unknown(self,code,ctx):\n  raise NotImplementedError()\n  \n def build_dispatch_table(cls,code_dict,method_prefix):\n  if cls. DISPATCH_TABLE is not None :\n   return\n  table={}\n  for key,value in code_dict. items():\n   if hasattr(cls,\"%s%s\"%(method_prefix,key)):\n    table[value]=getattr(cls,\"%s%s\"%(method_prefix,key))\n  cls. DISPATCH_TABLE=table\n  \n build_dispatch_table=classmethod(build_dispatch_table)\n \n \nclass _OpcodeDispatcher(_Dispatcher):\n\n def __init__(self):\n  self. executing_contexts={}\n  self. at_dispatcher=_AtcodeDispatcher()\n  self. ch_dispatcher=_ChcodeDispatcher()\n  self. set_dispatcher=_CharsetDispatcher()\n  \n def match(self,context):\n  ''\n\n  \n  while context. remaining_codes()>0 and context. has_matched is None :\n   opcode=context. peek_code()\n   if not self. dispatch(opcode,context):\n    return None\n  if context. has_matched is None :\n   context. has_matched=False\n  return context. has_matched\n  \n def dispatch(self,opcode,context):\n  ''\n  \n  \n  if id(context)in self. executing_contexts:\n   generator=self. executing_contexts[id(context)]\n   del self. executing_contexts[id(context)]\n   has_finished=next(generator)\n  else :\n   method=self. DISPATCH_TABLE. get(opcode,_OpcodeDispatcher. unknown)\n   has_finished=method(self,context)\n   if hasattr(has_finished,\"__next__\"):\n    generator=has_finished\n    has_finished=next(generator)\n  if not has_finished:\n   self. executing_contexts[id(context)]=generator\n  return has_finished\n  \n def op_success(self,ctx):\n \n \n  ctx. state. string_position=ctx. string_position\n  ctx. has_matched=True\n  return True\n  \n def op_failure(self,ctx):\n \n \n  ctx. has_matched=False\n  return True\n  \n def general_op_literal(self,ctx,compare,decorate=lambda x:x):\n \n  if ctx. at_end()or not compare(decorate(ord(ctx. peek_char())),\n  decorate(ctx. peek_code(1))):\n   ctx. has_matched=False\n  ctx. skip_code(2)\n  ctx. skip_char(1)\n  \n def op_literal(self,ctx):\n \n \n \n  self. general_op_literal(ctx,operator. eq)\n  return True\n  \n def op_not_literal(self,ctx):\n \n \n \n  self. general_op_literal(ctx,operator. ne)\n  return True\n  \n def op_literal_ignore(self,ctx):\n \n \n \n  self. general_op_literal(ctx,operator. eq,ctx. state. lower)\n  return True\n  \n def op_not_literal_ignore(self,ctx):\n \n \n \n  self. general_op_literal(ctx,operator. ne,ctx. state. lower)\n  return True\n  \n def op_at(self,ctx):\n \n \n \n  if not self. at_dispatcher. dispatch(ctx. peek_code(1),ctx):\n   ctx. has_matched=False\n   \n   return True\n  ctx. skip_code(2)\n  return True\n  \n def op_category(self,ctx):\n \n \n \n  if ctx. at_end()or not self. ch_dispatcher. dispatch(ctx. peek_code(1),ctx):\n   ctx. has_matched=False\n   \n   return True\n  ctx. skip_code(2)\n  ctx. skip_char(1)\n  return True\n  \n def op_any(self,ctx):\n \n \n \n  if ctx. at_end()or ctx. at_linebreak():\n   ctx. has_matched=False\n   \n   return True\n  ctx. skip_code(1)\n  ctx. skip_char(1)\n  return True\n  \n def op_any_all(self,ctx):\n \n \n \n  if ctx. at_end():\n   ctx. has_matched=False\n   \n   return True\n  ctx. skip_code(1)\n  ctx. skip_char(1)\n  return True\n  \n def general_op_in(self,ctx,decorate=lambda x:x):\n \n \n  if ctx. at_end():\n   ctx. has_matched=False\n   \n   return\n  skip=ctx. peek_code(1)\n  ctx. skip_code(2)\n  \n  \n  if not self. check_charset(ctx,decorate(ord(ctx. peek_char()))):\n  \n   ctx. has_matched=False\n   return\n  ctx. skip_code(skip -1)\n  ctx. skip_char(1)\n  \n  \n def op_in(self,ctx):\n \n \n \n  self. general_op_in(ctx)\n  return True\n  \n def op_in_ignore(self,ctx):\n \n \n \n  self. general_op_in(ctx,ctx. state. lower)\n  return True\n  \n def op_jump(self,ctx):\n \n \n \n  ctx. skip_code(ctx. peek_code(1)+1)\n  return True\n  \n  \n  \n op_info=op_jump\n \n def op_mark(self,ctx):\n \n \n \n  ctx. state. set_mark(ctx. peek_code(1),ctx. string_position)\n  ctx. skip_code(2)\n  return True\n  \n def op_branch(self,ctx):\n \n \n \n  ctx. state. marks_push()\n  ctx. skip_code(1)\n  current_branch_length=ctx. peek_code(0)\n  while current_branch_length:\n  \n  \n   if not (ctx. peek_code(1)==OPCODES[\"literal\"]and   (ctx. at_end()or ctx. peek_code(2)!=ord(ctx. peek_char()))):\n    ctx. state. string_position=ctx. string_position\n    child_context=ctx. push_new_context(1)\n    \n    yield False\n    if child_context. has_matched:\n     ctx. has_matched=True\n     yield True\n    ctx. state. marks_pop_keep()\n   ctx. skip_code(current_branch_length)\n   current_branch_length=ctx. peek_code(0)\n  ctx. state. marks_pop_discard()\n  ctx. has_matched=False\n  \n  yield True\n  \n def op_repeat_one(self,ctx):\n \n \n \n \n  mincount=ctx. peek_code(2)\n  maxcount=ctx. peek_code(3)\n  \n  \n  \n  if ctx. remaining_chars()<mincount:\n   ctx. has_matched=False\n   yield True\n  ctx. state. string_position=ctx. string_position\n  count=self. count_repetitions(ctx,maxcount)\n  ctx. skip_char(count)\n  if count <mincount:\n   ctx. has_matched=False\n   yield True\n  if ctx. peek_code(ctx. peek_code(1)+1)==OPCODES[\"success\"]:\n  \n   ctx. state. string_position=ctx. string_position\n   ctx. has_matched=True\n   yield True\n   \n  ctx. state. marks_push()\n  if ctx. peek_code(ctx. peek_code(1)+1)==OPCODES[\"literal\"]:\n  \n  \n   char=ctx. peek_code(ctx. peek_code(1)+2)\n   while True :\n    while count >=mincount and    (ctx. at_end()or ord(ctx. peek_char())!=char):\n     ctx. skip_char(-1)\n     count -=1\n    if count <mincount:\n     break\n    ctx. state. string_position=ctx. string_position\n    child_context=ctx. push_new_context(ctx. peek_code(1)+1)\n    \n    yield False\n    if child_context. has_matched:\n     ctx. has_matched=True\n     yield True\n    ctx. skip_char(-1)\n    count -=1\n    ctx. state. marks_pop_keep()\n    \n  else :\n  \n   while count >=mincount:\n    ctx. state. string_position=ctx. string_position\n    child_context=ctx. push_new_context(ctx. peek_code(1)+1)\n    yield False\n    if child_context. has_matched:\n     ctx. has_matched=True\n     yield True\n    ctx. skip_char(-1)\n    count -=1\n    ctx. state. marks_pop_keep()\n    \n  ctx. state. marks_pop_discard()\n  ctx. has_matched=False\n  \n  yield True\n  \n def op_min_repeat_one(self,ctx):\n \n \n  mincount=ctx. peek_code(2)\n  maxcount=ctx. peek_code(3)\n  \n  \n  if ctx. remaining_chars()<mincount:\n   ctx. has_matched=False\n   yield True\n  ctx. state. string_position=ctx. string_position\n  if mincount ==0:\n   count=0\n  else :\n   count=self. count_repetitions(ctx,mincount)\n   if count <mincount:\n    ctx. has_matched=False\n    \n    yield True\n   ctx. skip_char(count)\n  if ctx. peek_code(ctx. peek_code(1)+1)==OPCODES[\"success\"]:\n  \n   ctx. state. string_position=ctx. string_position\n   ctx. has_matched=True\n   yield True\n   \n  ctx. state. marks_push()\n  while maxcount ==MAXREPEAT or count <=maxcount:\n   ctx. state. string_position=ctx. string_position\n   child_context=ctx. push_new_context(ctx. peek_code(1)+1)\n   \n   yield False\n   if child_context. has_matched:\n    ctx. has_matched=True\n    yield True\n   ctx. state. string_position=ctx. string_position\n   if self. count_repetitions(ctx,1)==0:\n    break\n   ctx. skip_char(1)\n   count +=1\n   ctx. state. marks_pop_keep()\n   \n  ctx. state. marks_pop_discard()\n  ctx. has_matched=False\n  yield True\n  \n def op_repeat(self,ctx):\n \n \n \n \n \n \n \n \n \n  repeat=_RepeatContext(ctx)\n  ctx. state. repeat=repeat\n  ctx. state. string_position=ctx. string_position\n  child_context=ctx. push_new_context(ctx. peek_code(1)+1)\n  \n  \n  \n  \n  yield False\n  ctx. state. repeat=repeat. previous\n  ctx. has_matched=child_context. has_matched\n  yield True\n  \n def op_max_until(self,ctx):\n \n \n  repeat=ctx. state. repeat\n  \n  if repeat is None :\n  \n   raise RuntimeError(\"Internal re error: MAX_UNTIL without REPEAT.\")\n  mincount=repeat. peek_code(2)\n  maxcount=repeat. peek_code(3)\n  ctx. state. string_position=ctx. string_position\n  count=repeat. count+1\n  \n  \n  if count <mincount:\n  \n   repeat. count=count\n   child_context=repeat. push_new_context(4)\n   yield False\n   ctx. has_matched=child_context. has_matched\n   if not ctx. has_matched:\n    repeat. count=count -1\n    ctx. state. string_position=ctx. string_position\n   yield True\n   \n  if (count <maxcount or maxcount ==MAXREPEAT)  and ctx. state. string_position !=repeat. last_position:\n  \n   repeat. count=count\n   ctx. state. marks_push()\n   save_last_position=repeat. last_position\n   repeat. last_position=ctx. state. string_position\n   child_context=repeat. push_new_context(4)\n   yield False\n   repeat. last_position=save_last_position\n   if child_context. has_matched:\n    ctx. state. marks_pop_discard()\n    ctx. has_matched=True\n    yield True\n   ctx. state. marks_pop()\n   repeat. count=count -1\n   ctx. state. string_position=ctx. string_position\n   \n   \n  ctx. state. repeat=repeat. previous\n  child_context=ctx. push_new_context(1)\n  \n  yield False\n  ctx. has_matched=child_context. has_matched\n  if not ctx. has_matched:\n   ctx. state. repeat=repeat\n   ctx. state. string_position=ctx. string_position\n  yield True\n  \n def op_min_until(self,ctx):\n \n \n  repeat=ctx. state. repeat\n  if repeat is None :\n   raise RuntimeError(\"Internal re error: MIN_UNTIL without REPEAT.\")\n  mincount=repeat. peek_code(2)\n  maxcount=repeat. peek_code(3)\n  ctx. state. string_position=ctx. string_position\n  count=repeat. count+1\n  \n  \n  if count <mincount:\n  \n   repeat. count=count\n   child_context=repeat. push_new_context(4)\n   yield False\n   ctx. has_matched=child_context. has_matched\n   if not ctx. has_matched:\n    repeat. count=count -1\n    ctx. state. string_position=ctx. string_position\n   yield True\n   \n   \n  ctx. state. marks_push()\n  ctx. state. repeat=repeat. previous\n  child_context=ctx. push_new_context(1)\n  \n  yield False\n  if child_context. has_matched:\n   ctx. has_matched=True\n   yield True\n  ctx. state. repeat=repeat\n  ctx. state. string_position=ctx. string_position\n  ctx. state. marks_pop()\n  \n  \n  if count >=maxcount and maxcount !=MAXREPEAT:\n   ctx. has_matched=False\n   \n   yield True\n  repeat. count=count\n  child_context=repeat. push_new_context(4)\n  yield False\n  ctx. has_matched=child_context. has_matched\n  if not ctx. has_matched:\n   repeat. count=count -1\n   ctx. state. string_position=ctx. string_position\n  yield True\n  \n def general_op_groupref(self,ctx,decorate=lambda x:x):\n  group_start,group_end=ctx. state. get_marks(ctx. peek_code(1))\n  if group_start is None or group_end is None or group_end <group_start:\n   ctx. has_matched=False\n   return True\n  while group_start <group_end:\n   if ctx. at_end()or decorate(ord(ctx. peek_char()))   !=decorate(ord(ctx. state. string[group_start])):\n    ctx. has_matched=False\n    \n    return True\n   group_start +=1\n   ctx. skip_char(1)\n  ctx. skip_code(2)\n  return True\n  \n def op_groupref(self,ctx):\n \n \n \n  return self. general_op_groupref(ctx)\n  \n def op_groupref_ignore(self,ctx):\n \n \n \n  return self. general_op_groupref(ctx,ctx. state. lower)\n  \n def op_groupref_exists(self,ctx):\n \n \n  group_start,group_end=ctx. state. get_marks(ctx. peek_code(1))\n  if group_start is None or group_end is None or group_end <group_start:\n   ctx. skip_code(ctx. peek_code(2)+1)\n  else :\n   ctx. skip_code(3)\n  return True\n  \n def op_assert(self,ctx):\n \n \n \n  ctx. state. string_position=ctx. string_position -ctx. peek_code(2)\n  if ctx. state. string_position <0:\n   ctx. has_matched=False\n   yield True\n  child_context=ctx. push_new_context(3)\n  yield False\n  if child_context. has_matched:\n   ctx. skip_code(ctx. peek_code(1)+1)\n  else :\n   ctx. has_matched=False\n  yield True\n  \n def op_assert_not(self,ctx):\n \n \n \n  ctx. state. string_position=ctx. string_position -ctx. peek_code(2)\n  if ctx. state. string_position >=0:\n   child_context=ctx. push_new_context(3)\n   yield False\n   if child_context. has_matched:\n    ctx. has_matched=False\n    yield True\n  ctx. skip_code(ctx. peek_code(1)+1)\n  yield True\n  \n def unknown(self,ctx):\n \n  raise RuntimeError(\"Internal re error. Unknown opcode: %s\"%ctx. peek_code())\n  \n def check_charset(self,ctx,char):\n  ''\n  \n  self. set_dispatcher. reset(char)\n  save_position=ctx. code_position\n  result=None\n  while result is None :\n   result=self. set_dispatcher. dispatch(ctx. peek_code(),ctx)\n  ctx. code_position=save_position\n  \n  return result\n  \n def count_repetitions(self,ctx,maxcount):\n  ''\n\n  \n  count=0\n  real_maxcount=ctx. state. end -ctx. string_position\n  if maxcount <real_maxcount and maxcount !=MAXREPEAT:\n   real_maxcount=maxcount\n   \n   \n   \n  code_position=ctx. code_position\n  string_position=ctx. string_position\n  ctx. skip_code(4)\n  reset_position=ctx. code_position\n  while count <real_maxcount:\n  \n  \n   ctx. code_position=reset_position\n   self. dispatch(ctx. peek_code(),ctx)\n   \n   if ctx. has_matched is False :\n    break\n   count +=1\n  ctx. has_matched=None\n  ctx. code_position=code_position\n  ctx. string_position=string_position\n  return count\n  \n def _log(self,context,opname,*args):\n  arg_string=(\"%s \"*len(args))%args\n  _log(\"|%s|%s|%s %s\"%(context. pattern_codes,\n  context. string_position,opname,arg_string))\n  \n_OpcodeDispatcher. build_dispatch_table(OPCODES,\"op_\")\n\n\nclass _CharsetDispatcher(_Dispatcher):\n\n def __init__(self):\n  self. ch_dispatcher=_ChcodeDispatcher()\n  \n def reset(self,char):\n  self. char=char\n  self. ok=True\n  \n def set_failure(self,ctx):\n  return not self. ok\n def set_literal(self,ctx):\n \n  if ctx. peek_code(1)==self. char:\n   return self. ok\n  else :\n   ctx. skip_code(2)\n def set_category(self,ctx):\n \n  if self. ch_dispatcher. dispatch(ctx. peek_code(1),ctx):\n   return self. ok\n  else :\n   ctx. skip_code(2)\n def set_charset(self,ctx):\n \n  char_code=self. char\n  ctx. skip_code(1)\n  if CODESIZE ==2:\n   if char_code <256 and ctx. peek_code(char_code >>4)   &(1 <<(char_code&15)):\n    return self. ok\n   ctx. skip_code(16)\n  else :\n   if char_code <256 and ctx. peek_code(char_code >>5)   &(1 <<(char_code&31)):\n    return self. ok\n   ctx. skip_code(8)\n def set_range(self,ctx):\n \n  if ctx. peek_code(1)<=self. char <=ctx. peek_code(2):\n   return self. ok\n  ctx. skip_code(3)\n def set_negate(self,ctx):\n  self. ok=not self. ok\n  ctx. skip_code(1)\n  \n  \n def set_bigcharset(self,ctx):\n  raise NotImplementedError(\"_sre.py: set_bigcharset, array not implemented\")\n  \n  char_code=self. char\n  count=ctx. peek_code(1)\n  ctx. skip_code(2)\n  if char_code <65536:\n   block_index=char_code >>8\n   \n   a=array. array(\"B\")\n   a. fromstring(array. array(CODESIZE ==2 and\"H\"or\"I\",\n   [ctx. peek_code(block_index //CODESIZE)]). tostring())\n   block=a[block_index %CODESIZE]\n   ctx. skip_code(256 //CODESIZE)\n   block_value=ctx. peek_code(block *(32 //CODESIZE)\n   +((char_code&255)>>(CODESIZE ==2 and 4 or 5)))\n   if block_value&(1 <<(char_code&((8 *CODESIZE)-1))):\n    return self. ok\n  else :\n   ctx. skip_code(256 //CODESIZE)\n  ctx. skip_code(count *(32 //CODESIZE))\n  \n def unknown(self,ctx):\n  return False\n  \n_CharsetDispatcher. build_dispatch_table(OPCODES,\"set_\")\n\n\nclass _AtcodeDispatcher(_Dispatcher):\n\n def at_beginning(self,ctx):\n  return ctx. at_beginning()\n at_beginning_string=at_beginning\n def at_beginning_line(self,ctx):\n  return ctx. at_beginning()or _is_linebreak(ctx. peek_char(-1))\n def at_end(self,ctx):\n  return (ctx. remaining_chars()==1 and ctx. at_linebreak())or ctx. at_end()\n def at_end_line(self,ctx):\n  return ctx. at_linebreak()or ctx. at_end()\n def at_end_string(self,ctx):\n  return ctx. at_end()\n def at_boundary(self,ctx):\n  return ctx. at_boundary(_is_word)\n def at_non_boundary(self,ctx):\n  return not ctx. at_boundary(_is_word)\n def at_loc_boundary(self,ctx):\n  return ctx. at_boundary(_is_loc_word)\n def at_loc_non_boundary(self,ctx):\n  return not ctx. at_boundary(_is_loc_word)\n def at_uni_boundary(self,ctx):\n  return ctx. at_boundary(_is_uni_word)\n def at_uni_non_boundary(self,ctx):\n  return not ctx. at_boundary(_is_uni_word)\n def unknown(self,ctx):\n  return False\n  \n_AtcodeDispatcher. build_dispatch_table(ATCODES,\"\")\n\n\nclass _ChcodeDispatcher(_Dispatcher):\n\n def category_digit(self,ctx):\n  return _is_digit(ctx. peek_char())\n def category_not_digit(self,ctx):\n  return not _is_digit(ctx. peek_char())\n def category_space(self,ctx):\n  return _is_space(ctx. peek_char())\n def category_not_space(self,ctx):\n  return not _is_space(ctx. peek_char())\n def category_word(self,ctx):\n  return _is_word(ctx. peek_char())\n def category_not_word(self,ctx):\n  return not _is_word(ctx. peek_char())\n def category_linebreak(self,ctx):\n  return _is_linebreak(ctx. peek_char())\n def category_not_linebreak(self,ctx):\n  return not _is_linebreak(ctx. peek_char())\n def category_loc_word(self,ctx):\n  return _is_loc_word(ctx. peek_char())\n def category_loc_not_word(self,ctx):\n  return not _is_loc_word(ctx. peek_char())\n def category_uni_digit(self,ctx):\n  return ctx. peek_char(). isdigit()\n def category_uni_not_digit(self,ctx):\n  return not ctx. peek_char(). isdigit()\n def category_uni_space(self,ctx):\n  return ctx. peek_char(). isspace()\n def category_uni_not_space(self,ctx):\n  return not ctx. peek_char(). isspace()\n def category_uni_word(self,ctx):\n  return _is_uni_word(ctx. peek_char())\n def category_uni_not_word(self,ctx):\n  return not _is_uni_word(ctx. peek_char())\n def category_uni_linebreak(self,ctx):\n  return ord(ctx. peek_char())in _uni_linebreaks\n def category_uni_not_linebreak(self,ctx):\n  return ord(ctx. peek_char())not in _uni_linebreaks\n def unknown(self,ctx):\n  return False\n  \n_ChcodeDispatcher. build_dispatch_table(CHCODES,\"\")\n\n\n_ascii_char_info=[0,0,0,0,0,0,0,0,0,2,6,2,\n2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,\n0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,25,25,25,25,25,\n25,25,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,\n24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,0,0,\n0,0,16,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,\n24,24,24,24,24,24,24,24,24,24,24,24,0,0,0,0,0]\n\ndef _is_digit(char):\n code=ord(char)\n return code <128 and _ascii_char_info[code]&1\n \ndef _is_space(char):\n code=ord(char)\n return code <128 and _ascii_char_info[code]&2\n \ndef _is_word(char):\n\n code=ord(char)\n return code <128 and _ascii_char_info[code]&16\n \ndef _is_loc_word(char):\n return (not (ord(char)&~255)and char. isalnum())or char =='_'\n \ndef _is_uni_word(char):\n\n\n return chr(ord(char)). isalnum()or char =='_'\n \ndef _is_linebreak(char):\n return char ==\"\\n\"\n \n \n_uni_linebreaks=[10,13,28,29,30,133,8232,8233]\n\ndef _log(message):\n if 0:\n  print(message)\n", ["operator", "re", "sre", "sre_constants", "sys"]], "_abcoll": [".py", "\n\n\n\"\"\"Abstract Base Classes (ABCs) for collections, according to PEP 3119.\n\nDON'T USE THIS MODULE DIRECTLY!  The classes here should be imported\nvia collections; they are defined here only to alleviate certain\nbootstrapping issues.  Unit tests are in test_collections.\n\"\"\"\n\n\n\n\nimport sys\n\n__all__=[\"Hashable\",\"Iterable\",\"Iterator\",\n\"Sized\",\"Container\",\"Callable\",\n\"Set\",\"MutableSet\",\n\"Mapping\",\"MutableMapping\",\n\"MappingView\",\"KeysView\",\"ItemsView\",\"ValuesView\",\n\"Sequence\",\"MutableSequence\",\n\"ByteString\",\n]\n\n\"\"\"\n### collection related types which are not exposed through builtin ###\n## iterators ##\n#fixme brython\n#bytes_iterator = type(iter(b''))\nbytes_iterator = type(iter(''))\n#fixme brython\n#bytearray_iterator = type(iter(bytearray()))\n#callable_iterator = ???\ndict_keyiterator = type(iter({}.keys()))\ndict_valueiterator = type(iter({}.values()))\ndict_itemiterator = type(iter({}.items()))\nlist_iterator = type(iter([]))\nlist_reverseiterator = type(iter(reversed([])))\nrange_iterator = type(iter(range(0)))\nset_iterator = type(iter(set()))\nstr_iterator = type(iter(\"\"))\ntuple_iterator = type(iter(()))\nzip_iterator = type(iter(zip()))\n## views ##\ndict_keys = type({}.keys())\ndict_values = type({}.values())\ndict_items = type({}.items())\n## misc ##\ndict_proxy = type(type.__dict__)\n\"\"\"\n\ndef abstractmethod(self):\n return self\n \n \n \n \n \nclass Iterable:\n\n @abstractmethod\n def __iter__(self):\n  while False :\n   yield None\n   \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Iterable:\n   if any(\"__iter__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \n  \nclass Sized:\n\n @abstractmethod\n def __len__(self):\n  return 0\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Sized:\n   if any(\"__len__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \n  \nclass Container:\n\n @abstractmethod\n def __contains__(self,x):\n  return False\n  \n @classmethod\n def __subclasshook__(cls,C):\n  if cls is Container:\n   if any(\"__contains__\"in B. __dict__ for B in C. __mro__):\n    return True\n  return NotImplemented\n  \n  \n  \n  \nclass Mapping(Sized,Iterable,Container):\n\n @abstractmethod\n def __getitem__(self,key):\n  raise KeyError\n  \n def get(self,key,default=None ):\n  try :\n   return self[key]\n  except KeyError:\n   return default\n   \n def __contains__(self,key):\n  try :\n   self[key]\n  except KeyError:\n   return False\n  else :\n   return True\n   \n def keys(self):\n  return KeysView(self)\n  \n def items(self):\n  return ItemsView(self)\n  \n def values(self):\n  return ValuesView(self)\n  \n def __eq__(self,other):\n  if not isinstance(other,Mapping):\n   return NotImplemented\n  return dict(self. items())==dict(other. items())\n  \n def __ne__(self,other):\n  return not (self ==other)\n  \n  \nclass MutableMapping(Mapping):\n\n @abstractmethod\n def __setitem__(self,key,value):\n  raise KeyError\n  \n @abstractmethod\n def __delitem__(self,key):\n  raise KeyError\n  \n __marker=object()\n \n def pop(self,key,default=__marker):\n  try :\n   value=self[key]\n  except KeyError:\n   if default is self. __marker:\n    raise\n   return default\n  else :\n   del self[key]\n   return value\n   \n def popitem(self):\n  try :\n   key=next(iter(self))\n  except StopIteration:\n   raise KeyError\n  value=self[key]\n  del self[key]\n  return key,value\n  \n def clear(self):\n  try :\n   while True :\n    self. popitem()\n  except KeyError:\n   pass\n   \n def update(*args,**kwds):\n  if len(args)>2:\n   raise TypeError(\"update() takes at most 2 positional \"\n   \"arguments ({} given)\". format(len(args)))\n  elif not args:\n   raise TypeError(\"update() takes at least 1 argument (0 given)\")\n  self=args[0]\n  other=args[1]if len(args)>=2 else ()\n  \n  if isinstance(other,Mapping):\n   for key in other:\n    self[key]=other[key]\n  elif hasattr(other,\"keys\"):\n   for key in other. keys():\n    self[key]=other[key]\n  else :\n   for key,value in other:\n    self[key]=value\n  for key,value in kwds. items():\n   self[key]=value\n   \n def setdefault(self,key,default=None ):\n  try :\n   return self[key]\n  except KeyError:\n   self[key]=default\n  return default\n  \n  \n", ["sys"]], "datetime": [".py", "''\n\n\n\n\n\nimport time as _time\nimport math as _math\n\ndef _cmp(x,y):\n return 0 if x ==y else 1 if x >y else -1\n \nMINYEAR=1\nMAXYEAR=9999\n_MAXORDINAL=3652059\n\n\n\n\n\n\n\n\n\n\n_DAYS_IN_MONTH=[None ,31,28,31,30,31,30,31,31,30,31,30,31]\n\n_DAYS_BEFORE_MONTH=[None ]\ndbm=0\nfor dim in _DAYS_IN_MONTH[1:]:\n _DAYS_BEFORE_MONTH. append(dbm)\n dbm +=dim\ndel dbm,dim\n\ndef _is_leap(year):\n ''\n return year %4 ==0 and (year %100 !=0 or year %400 ==0)\n \ndef _days_before_year(year):\n ''\n y=year -1\n return y *365+y //4 -y //100+y //400\n \ndef _days_in_month(year,month):\n ''\n assert 1 <=month <=12,month\n if month ==2 and _is_leap(year):\n  return 29\n return _DAYS_IN_MONTH[month]\n \ndef _days_before_month(year,month):\n ''\n assert 1 <=month <=12,'month must be in 1..12'\n return _DAYS_BEFORE_MONTH[month]+(month >2 and _is_leap(year))\n \ndef _ymd2ord(year,month,day):\n ''\n assert 1 <=month <=12,'month must be in 1..12'\n dim=_days_in_month(year,month)\n assert 1 <=day <=dim,('day must be in 1..%d'%dim)\n return (_days_before_year(year)+\n _days_before_month(year,month)+\n day)\n \n_DI400Y=_days_before_year(401)\n_DI100Y=_days_before_year(101)\n_DI4Y=_days_before_year(5)\n\n\n\nassert _DI4Y ==4 *365+1\n\n\n\nassert _DI400Y ==4 *_DI100Y+1\n\n\n\nassert _DI100Y ==25 *_DI4Y -1\n\ndef _ord2ymd(n):\n ''\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \n n -=1\n n400,n=divmod(n,_DI400Y)\n year=n400 *400+1\n \n \n \n \n \n \n n100,n=divmod(n,_DI100Y)\n \n \n n4,n=divmod(n,_DI4Y)\n \n \n \n n1,n=divmod(n,365)\n \n year +=n100 *100+n4 *4+n1\n if n1 ==4 or n100 ==4:\n  assert n ==0\n  return year -1,12,31\n  \n  \n  \n leapyear=n1 ==3 and (n4 !=24 or n100 ==3)\n assert leapyear ==_is_leap(year)\n month=(n+50)>>5\n preceding=_DAYS_BEFORE_MONTH[month]+(month >2 and leapyear)\n if preceding >n:\n  month -=1\n  preceding -=_DAYS_IN_MONTH[month]+(month ==2 and leapyear)\n n -=preceding\n assert 0 <=n <_days_in_month(year,month)\n \n \n \n return year,month,n+1\n \n \n_MONTHNAMES=[None ,\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\n\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]\n_DAYNAMES=[None ,\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\",\"Sun\"]\n\n\ndef _build_struct_time(y,m,d,hh,mm,ss,dstflag):\n wday=(_ymd2ord(y,m,d)+6)%7\n dnum=_days_before_month(y,m)+d\n return _time. struct_time((y,m,d,hh,mm,ss,wday,dnum,dstflag))\n \ndef _format_time(hh,mm,ss,us):\n\n result=\"%02d:%02d:%02d\"%(hh,mm,ss)\n if us:\n  result +=\".%06d\"%us\n return result\n \n \ndef _wrap_strftime(object,format,timetuple):\n\n freplace=None\n zreplace=None\n Zreplace=None\n \n \n newformat=[]\n push=newformat. append\n i,n=0,len(format)\n while i <n:\n  ch=format[i]\n  i +=1\n  if ch =='%':\n   if i <n:\n    ch=format[i]\n    i +=1\n    if ch =='f':\n     if freplace is None :\n      freplace='%06d'%getattr(object,\n      'microsecond',0)\n     newformat. append(freplace)\n    elif ch =='z':\n     if zreplace is None :\n      zreplace=\"\"\n      if hasattr(object,\"utcoffset\"):\n       offset=object. utcoffset()\n       if offset is not None :\n        sign='+'\n        if offset. days <0:\n         offset=-offset\n         sign='-'\n        h,m=divmod(offset,timedelta(hours=1))\n        assert not m %timedelta(minutes=1),\"whole minute\"\n        m //=timedelta(minutes=1)\n        zreplace='%c%02d%02d'%(sign,h,m)\n     assert'%'not in zreplace\n     newformat. append(zreplace)\n    elif ch =='Z':\n     if Zreplace is None :\n      Zreplace=\"\"\n      if hasattr(object,\"tzname\"):\n       s=object. tzname()\n       if s is not None :\n       \n        Zreplace=s. replace('%','%%')\n     newformat. append(Zreplace)\n    else :\n     push('%')\n     push(ch)\n   else :\n    push('%')\n  else :\n   push(ch)\n newformat=\"\". join(newformat)\n return _time. strftime(newformat,timetuple)\n \ndef _call_tzinfo_method(tzinfo,methname,tzinfoarg):\n if tzinfo is None :\n  return None\n return getattr(tzinfo,methname)(tzinfoarg)\n \n \ndef _check_tzname(name):\n if name is not None and not isinstance(name,str):\n  raise TypeError(\"tzinfo.tzname() must return None or string, \"\n  \"not '%s'\"%type(name))\n  \n  \n  \n  \n  \n  \n  \ndef _check_utc_offset(name,offset):\n assert name in (\"utcoffset\",\"dst\")\n if offset is None :\n  return\n if not isinstance(offset,timedelta):\n  raise TypeError(\"tzinfo.%s() must return None \"\n  \"or timedelta, not '%s'\"%(name,type(offset)))\n if offset %timedelta(minutes=1)or offset. microseconds:\n  raise ValueError(\"tzinfo.%s() must return a whole number \"\n  \"of minutes, got %s\"%(name,offset))\n if not -timedelta(1)<offset <timedelta(1):\n  raise ValueError(\"%s()=%s, must be must be strictly between\"\n  \" -timedelta(hours=24) and timedelta(hours=24)\"\n  %(name,offset))\n  \ndef _check_date_fields(year,month,day):\n if not isinstance(year,int):\n  raise TypeError('int expected')\n if not MINYEAR <=year <=MAXYEAR:\n  raise ValueError('year must be in %d..%d'%(MINYEAR,MAXYEAR),year)\n if not 1 <=month <=12:\n  raise ValueError('month must be in 1..12',month)\n dim=_days_in_month(year,month)\n if not 1 <=day <=dim:\n  raise ValueError('day must be in 1..%d'%dim,day)\n  \ndef _check_time_fields(hour,minute,second,microsecond):\n if not isinstance(hour,int):\n  raise TypeError('int expected')\n if not 0 <=hour <=23:\n  raise ValueError('hour must be in 0..23',hour)\n if not 0 <=minute <=59:\n  raise ValueError('minute must be in 0..59',minute)\n if not 0 <=second <=59:\n  raise ValueError('second must be in 0..59',second)\n if not 0 <=microsecond <=999999:\n  raise ValueError('microsecond must be in 0..999999',microsecond)\n  \ndef _check_tzinfo_arg(tz):\n if tz is not None and not isinstance(tz,tzinfo):\n  raise TypeError(\"tzinfo argument must be None or of a tzinfo subclass\")\n  \ndef _cmperror(x,y):\n raise TypeError(\"can't compare '%s' to '%s'\"%(\n type(x). __name__,type(y). __name__))\n \nclass timedelta:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n __slots__='_days','_seconds','_microseconds'\n \n def __new__(cls,days=0,seconds=0,microseconds=0,\n milliseconds=0,minutes=0,hours=0,weeks=0):\n \n \n \n \n \n \n \n \n \n \n \n \n  d=s=us=0\n  \n  \n  days +=weeks *7\n  seconds +=minutes *60+hours *3600\n  microseconds +=milliseconds *1000\n  \n  \n  \n  if isinstance(days,float):\n   dayfrac,days=_math. modf(days)\n   daysecondsfrac,daysecondswhole=_math. modf(dayfrac *(24. *3600.))\n   assert daysecondswhole ==int(daysecondswhole)\n   s=int(daysecondswhole)\n   assert days ==int(days)\n   d=int(days)\n  else :\n   daysecondsfrac=0.0\n   d=days\n  assert isinstance(daysecondsfrac,float)\n  assert abs(daysecondsfrac)<=1.0\n  assert isinstance(d,int)\n  assert abs(s)<=24 *3600\n  \n  \n  if isinstance(seconds,float):\n   secondsfrac,seconds=_math. modf(seconds)\n   assert seconds ==int(seconds)\n   seconds=int(seconds)\n   secondsfrac +=daysecondsfrac\n   assert abs(secondsfrac)<=2.0\n  else :\n   secondsfrac=daysecondsfrac\n   \n  assert isinstance(secondsfrac,float)\n  assert abs(secondsfrac)<=2.0\n  \n  assert isinstance(seconds,int)\n  days,seconds=divmod(seconds,24 *3600)\n  d +=days\n  s +=int(seconds)\n  assert isinstance(s,int)\n  assert abs(s)<=2 *24 *3600\n  \n  \n  usdouble=secondsfrac *1e6\n  assert abs(usdouble)<2.1e6\n  \n  \n  if isinstance(microseconds,float):\n   microseconds +=usdouble\n   microseconds=round(microseconds,0)\n   seconds,microseconds=divmod(microseconds,1e6)\n   assert microseconds ==int(microseconds)\n   assert seconds ==int(seconds)\n   days,seconds=divmod(seconds,24. *3600.)\n   assert days ==int(days)\n   assert seconds ==int(seconds)\n   d +=int(days)\n   s +=int(seconds)\n   assert isinstance(s,int)\n   assert abs(s)<=3 *24 *3600\n  else :\n   seconds,microseconds=divmod(microseconds,1000000)\n   days,seconds=divmod(seconds,24 *3600)\n   d +=days\n   s +=int(seconds)\n   assert isinstance(s,int)\n   assert abs(s)<=3 *24 *3600\n   microseconds=float(microseconds)\n   microseconds +=usdouble\n   microseconds=round(microseconds,0)\n  assert abs(s)<=3 *24 *3600\n  assert abs(microseconds)<3.1e6\n  \n  \n  assert isinstance(microseconds,float)\n  assert int(microseconds)==microseconds\n  us=int(microseconds)\n  seconds,us=divmod(us,1000000)\n  s +=seconds\n  assert isinstance(s,int)\n  days,s=divmod(s,24 *3600)\n  d +=days\n  \n  assert isinstance(d,int)\n  assert isinstance(s,int)and 0 <=s <24 *3600\n  assert isinstance(us,int)and 0 <=us <1000000\n  \n  self=object. __new__(cls)\n  \n  self. _days=d\n  self. _seconds=s\n  self. _microseconds=us\n  if abs(d)>999999999:\n   raise OverflowError(\"timedelta # of days is too large: %d\"%d)\n   \n  return self\n  \n def __repr__(self):\n  if self. _microseconds:\n   return\"%s(%d, %d, %d)\"%('datetime.'+self. __class__. __name__,\n   self. _days,\n   self. _seconds,\n   self. _microseconds)\n  if self. _seconds:\n   return\"%s(%d, %d)\"%('datetime.'+self. __class__. __name__,\n   self. _days,\n   self. _seconds)\n  return\"%s(%d)\"%('datetime.'+self. __class__. __name__,self. _days)\n  \n def __str__(self):\n  mm,ss=divmod(self. _seconds,60)\n  hh,mm=divmod(mm,60)\n  s=\"%d:%02d:%02d\"%(hh,mm,ss)\n  if self. _days:\n   def plural(n):\n    return n,abs(n)!=1 and\"s\"or\"\"\n   s=(\"%d day%s, \"%plural(self. _days))+s\n  if self. _microseconds:\n   s=s+\".%06d\"%self. _microseconds\n  return s\n  \n def total_seconds(self):\n  ''\n  return ((self. days *86400+self. seconds)*10 **6+\n  self. microseconds)/10 **6\n  \n  \n @property\n def days(self):\n  ''\n  return self. _days\n  \n @property\n def seconds(self):\n  ''\n  return self. _seconds\n  \n @property\n def microseconds(self):\n  ''\n  return self. _microseconds\n  \n def __add__(self,other):\n  if isinstance(other,timedelta):\n  \n  \n   return timedelta(self. _days+other. _days,\n   self. _seconds+other. _seconds,\n   self. _microseconds+other. _microseconds)\n  return NotImplemented\n  \n __radd__=__add__\n \n def __sub__(self,other):\n  if isinstance(other,timedelta):\n  \n  \n   return timedelta(self. _days -other. _days,\n   self. _seconds -other. _seconds,\n   self. _microseconds -other. _microseconds)\n  return NotImplemented\n  \n def __rsub__(self,other):\n  if isinstance(other,timedelta):\n   return -self+other\n  return NotImplemented\n  \n def __neg__(self):\n \n \n  return timedelta(-self. _days,\n  -self. _seconds,\n  -self. _microseconds)\n  \n def __pos__(self):\n  return self\n  \n def __abs__(self):\n  if self. _days <0:\n   return -self\n  else :\n   return self\n   \n def __mul__(self,other):\n  if isinstance(other,int):\n  \n  \n   return timedelta(self. _days *other,\n   self. _seconds *other,\n   self. _microseconds *other)\n  if isinstance(other,float):\n   a,b=other. as_integer_ratio()\n   return self *a /b\n  return NotImplemented\n  \n __rmul__=__mul__\n \n def _to_microseconds(self):\n  return ((self. _days *(24 *3600)+self. _seconds)*1000000+\n  self. _microseconds)\n  \n def __floordiv__(self,other):\n  if not isinstance(other,(int,timedelta)):\n   return NotImplemented\n  usec=self. _to_microseconds()\n  if isinstance(other,timedelta):\n   return usec //other. _to_microseconds()\n  if isinstance(other,int):\n   return timedelta(0,0,usec //other)\n   \n def __truediv__(self,other):\n  if not isinstance(other,(int,float,timedelta)):\n   return NotImplemented\n  usec=self. _to_microseconds()\n  if isinstance(other,timedelta):\n   return usec /other. _to_microseconds()\n  if isinstance(other,int):\n   return timedelta(0,0,usec /other)\n  if isinstance(other,float):\n   a,b=other. as_integer_ratio()\n   return timedelta(0,0,b *usec /a)\n   \n def __mod__(self,other):\n  if isinstance(other,timedelta):\n   r=self. _to_microseconds()%other. _to_microseconds()\n   return timedelta(0,0,r)\n  return NotImplemented\n  \n def __divmod__(self,other):\n  if isinstance(other,timedelta):\n   q,r=divmod(self. _to_microseconds(),\n   other. _to_microseconds())\n   return q,timedelta(0,0,r)\n  return NotImplemented\n  \n  \n  \n def __eq__(self,other):\n  if isinstance(other,timedelta):\n   return self. _cmp(other)==0\n  else :\n   return False\n   \n def __ne__(self,other):\n  if isinstance(other,timedelta):\n   return self. _cmp(other)!=0\n  else :\n   return True\n   \n def __le__(self,other):\n  if isinstance(other,timedelta):\n   return self. _cmp(other)<=0\n  else :\n   _cmperror(self,other)\n   \n def __lt__(self,other):\n  if isinstance(other,timedelta):\n   return self. _cmp(other)<0\n  else :\n   _cmperror(self,other)\n   \n def __ge__(self,other):\n  if isinstance(other,timedelta):\n   return self. _cmp(other)>=0\n  else :\n   _cmperror(self,other)\n   \n def __gt__(self,other):\n  if isinstance(other,timedelta):\n   return self. _cmp(other)>0\n  else :\n   _cmperror(self,other)\n   \n def _cmp(self,other):\n  assert isinstance(other,timedelta)\n  return _cmp(self. _getstate(),other. _getstate())\n  \n def __hash__(self):\n  return hash(self. _getstate())\n  \n def __bool__(self):\n  return (self. _days !=0 or\n  self. _seconds !=0 or\n  self. _microseconds !=0)\n  \n  \n  \n def _getstate(self):\n  return (self. _days,self. _seconds,self. _microseconds)\n  \n def __reduce__(self):\n  return (self. __class__,self. _getstate())\n  \ntimedelta. min=timedelta(-999999999)\ntimedelta. max=timedelta(days=999999999,hours=23,minutes=59,seconds=59,\nmicroseconds=999999)\ntimedelta. resolution=timedelta(microseconds=1)\n\nclass date:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n __slots__='_year','_month','_day'\n \n def __new__(cls,year,month=None ,day=None ):\n  ''\n\n\n\n\n  \n  if (isinstance(year,bytes)and len(year)==4 and\n  1 <=year[2]<=12 and month is None ):\n  \n   self=object. __new__(cls)\n   self. __setstate(year)\n   return self\n  _check_date_fields(year,month,day)\n  self=object. __new__(cls)\n  self. _year=year\n  self. _month=month\n  self. _day=day\n  return self\n  \n  \n  \n @classmethod\n def fromtimestamp(cls,t):\n  ''\n  y,m,d,hh,mm,ss,weekday,jday,dst=_time. localtime(t)\n  return cls(y,m,d)\n  \n @classmethod\n def today(cls):\n  ''\n  t=_time. time()\n  return cls. fromtimestamp(t)\n  \n @classmethod\n def fromordinal(cls,n):\n  ''\n\n\n\n  \n  y,m,d=_ord2ymd(n)\n  return cls(y,m,d)\n  \n  \n  \n def __repr__(self):\n  ''\n\n\n\n\n\n\n\n\n  \n  return\"%s(%d, %d, %d)\"%('datetime.'+self. __class__. __name__,\n  self. _year,\n  self. _month,\n  self. _day)\n  \n  \n  \n  \n  \n  \n def ctime(self):\n  ''\n  weekday=self. toordinal()%7 or 7\n  return\"%s %s %2d 00:00:00 %04d\"%(\n  _DAYNAMES[weekday],\n  _MONTHNAMES[self. _month],\n  self. _day,self. _year)\n  \n def strftime(self,fmt):\n  ''\n  return _wrap_strftime(self,fmt,self. timetuple())\n  \n def __format__(self,fmt):\n  if len(fmt)!=0:\n   return self. strftime(fmt)\n  return str(self)\n  \n def isoformat(self):\n  ''\n\n\n\n\n\n\n  \n  return\"%04d-%02d-%02d\"%(self. _year,self. _month,self. _day)\n  \n __str__=isoformat\n \n \n @property\n def year(self):\n  ''\n  return self. _year\n  \n @property\n def month(self):\n  ''\n  return self. _month\n  \n @property\n def day(self):\n  ''\n  return self. _day\n  \n  \n  \n def timetuple(self):\n  ''\n  return _build_struct_time(self. _year,self. _month,self. _day,\n  0,0,0,-1)\n  \n def toordinal(self):\n  ''\n\n\n\n  \n  return _ymd2ord(self. _year,self. _month,self. _day)\n  \n def replace(self,year=None ,month=None ,day=None ):\n  ''\n  if year is None :\n   year=self. _year\n  if month is None :\n   month=self. _month\n  if day is None :\n   day=self. _day\n  _check_date_fields(year,month,day)\n  return date(year,month,day)\n  \n  \n  \n def __eq__(self,other):\n  if isinstance(other,date):\n   return self. _cmp(other)==0\n  return NotImplemented\n  \n def __ne__(self,other):\n  if isinstance(other,date):\n   return self. _cmp(other)!=0\n  return NotImplemented\n  \n def __le__(self,other):\n  if isinstance(other,date):\n   return self. _cmp(other)<=0\n  return NotImplemented\n  \n def __lt__(self,other):\n  if isinstance(other,date):\n   return self. _cmp(other)<0\n  return NotImplemented\n  \n def __ge__(self,other):\n  if isinstance(other,date):\n   return self. _cmp(other)>=0\n  return NotImplemented\n  \n def __gt__(self,other):\n  if isinstance(other,date):\n   return self. _cmp(other)>0\n  return NotImplemented\n  \n def _cmp(self,other):\n  assert isinstance(other,date)\n  y,m,d=self. _year,self. _month,self. _day\n  y2,m2,d2=other. _year,other. _month,other. _day\n  return _cmp((y,m,d),(y2,m2,d2))\n  \n def __hash__(self):\n  ''\n  return hash(self. _getstate())\n  \n  \n  \n def __add__(self,other):\n  ''\n  if isinstance(other,timedelta):\n   o=self. toordinal()+other. days\n   if 0 <o <=_MAXORDINAL:\n    return date. fromordinal(o)\n   raise OverflowError(\"result out of range\")\n  return NotImplemented\n  \n __radd__=__add__\n \n def __sub__(self,other):\n  ''\n  if isinstance(other,timedelta):\n   return self+timedelta(-other. days)\n  if isinstance(other,date):\n   days1=self. toordinal()\n   days2=other. toordinal()\n   return timedelta(days1 -days2)\n  return NotImplemented\n  \n def weekday(self):\n  ''\n  return (self. toordinal()+6)%7\n  \n  \n  \n def isoweekday(self):\n  ''\n  \n  return self. toordinal()%7 or 7\n  \n def isocalendar(self):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  year=self. _year\n  week1monday=_isoweek1monday(year)\n  today=_ymd2ord(self. _year,self. _month,self. _day)\n  \n  week,day=divmod(today -week1monday,7)\n  if week <0:\n   year -=1\n   week1monday=_isoweek1monday(year)\n   week,day=divmod(today -week1monday,7)\n  elif week >=52:\n   if today >=_isoweek1monday(year+1):\n    year +=1\n    week=0\n  return year,week+1,day+1\n  \n  \n  \n def _getstate(self):\n  yhi,ylo=divmod(self. _year,256)\n  return bytes([yhi,ylo,self. _month,self. _day]),\n  \n def __setstate(self,string):\n  if len(string)!=4 or not (1 <=string[2]<=12):\n   raise TypeError(\"not enough arguments\")\n  yhi,ylo,self. _month,self. _day=string\n  self. _year=yhi *256+ylo\n  \n def __reduce__(self):\n  return (self. __class__,self. _getstate())\n  \n_date_class=date\n\ndate. min=date(1,1,1)\ndate. max=date(9999,12,31)\ndate. resolution=timedelta(days=1)\n\nclass tzinfo:\n ''\n\n\n \n __slots__=()\n def tzname(self,dt):\n  ''\n  raise NotImplementedError(\"tzinfo subclass must override tzname()\")\n  \n def utcoffset(self,dt):\n  ''\n  raise NotImplementedError(\"tzinfo subclass must override utcoffset()\")\n  \n def dst(self,dt):\n  ''\n\n\n\n  \n  raise NotImplementedError(\"tzinfo subclass must override dst()\")\n  \n def fromutc(self,dt):\n  ''\n  \n  if not isinstance(dt,datetime):\n   raise TypeError(\"fromutc() requires a datetime argument\")\n  if dt. tzinfo is not self:\n   raise ValueError(\"dt.tzinfo is not self\")\n   \n  dtoff=dt. utcoffset()\n  if dtoff is None :\n   raise ValueError(\"fromutc() requires a non-None utcoffset() \"\n   \"result\")\n   \n   \n   \n  dtdst=dt. dst()\n  if dtdst is None :\n   raise ValueError(\"fromutc() requires a non-None dst() result\")\n  delta=dtoff -dtdst\n  if delta:\n   dt +=delta\n   dtdst=dt. dst()\n   if dtdst is None :\n    raise ValueError(\"fromutc(): dt.dst gave inconsistent \"\n    \"results; cannot convert\")\n  return dt+dtdst\n  \n  \n  \n def __reduce__(self):\n  getinitargs=getattr(self,\"__getinitargs__\",None )\n  if getinitargs:\n   args=getinitargs()\n  else :\n   args=()\n  getstate=getattr(self,\"__getstate__\",None )\n  if getstate:\n   state=getstate()\n  else :\n   state=getattr(self,\"__dict__\",None )or None\n  if state is None :\n   return (self. __class__,args)\n  else :\n   return (self. __class__,args,state)\n   \n_tzinfo_class=tzinfo\n\nclass time:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n def __new__(cls,hour=0,minute=0,second=0,microsecond=0,tzinfo=None ):\n  ''\n\n\n\n\n\n\n  \n  self=object. __new__(cls)\n  if isinstance(hour,bytes)and len(hour)==6:\n  \n   self. __setstate(hour,minute or None )\n   return self\n  _check_tzinfo_arg(tzinfo)\n  _check_time_fields(hour,minute,second,microsecond)\n  self. _hour=hour\n  self. _minute=minute\n  self. _second=second\n  self. _microsecond=microsecond\n  self. _tzinfo=tzinfo\n  return self\n  \n  \n @property\n def hour(self):\n  ''\n  return self. _hour\n  \n @property\n def minute(self):\n  ''\n  return self. _minute\n  \n @property\n def second(self):\n  ''\n  return self. _second\n  \n @property\n def microsecond(self):\n  ''\n  return self. _microsecond\n  \n @property\n def tzinfo(self):\n  ''\n  return self. _tzinfo\n  \n  \n  \n  \n  \n def __eq__(self,other):\n  if isinstance(other,time):\n   return self. _cmp(other,allow_mixed=True )==0\n  else :\n   return False\n   \n def __ne__(self,other):\n  if isinstance(other,time):\n   return self. _cmp(other,allow_mixed=True )!=0\n  else :\n   return True\n   \n def __le__(self,other):\n  if isinstance(other,time):\n   return self. _cmp(other)<=0\n  else :\n   _cmperror(self,other)\n   \n def __lt__(self,other):\n  if isinstance(other,time):\n   return self. _cmp(other)<0\n  else :\n   _cmperror(self,other)\n   \n def __ge__(self,other):\n  if isinstance(other,time):\n   return self. _cmp(other)>=0\n  else :\n   _cmperror(self,other)\n   \n def __gt__(self,other):\n  if isinstance(other,time):\n   return self. _cmp(other)>0\n  else :\n   _cmperror(self,other)\n   \n def _cmp(self,other,allow_mixed=False ):\n  assert isinstance(other,time)\n  mytz=self. _tzinfo\n  ottz=other. _tzinfo\n  myoff=otoff=None\n  \n  if mytz is ottz:\n   base_compare=True\n  else :\n   myoff=self. utcoffset()\n   otoff=other. utcoffset()\n   base_compare=myoff ==otoff\n   \n  if base_compare:\n   return _cmp((self. _hour,self. _minute,self. _second,\n   self. _microsecond),\n   (other. _hour,other. _minute,other. _second,\n   other. _microsecond))\n  if myoff is None or otoff is None :\n   if allow_mixed:\n    return 2\n   else :\n    raise TypeError(\"cannot compare naive and aware times\")\n  myhhmm=self. _hour *60+self. _minute -myoff //timedelta(minutes=1)\n  othhmm=other. _hour *60+other. _minute -otoff //timedelta(minutes=1)\n  return _cmp((myhhmm,self. _second,self. _microsecond),\n  (othhmm,other. _second,other. _microsecond))\n  \n def __hash__(self):\n  ''\n  tzoff=self. utcoffset()\n  if not tzoff:\n   return hash(self. _getstate()[0])\n  h,m=divmod(timedelta(hours=self. hour,minutes=self. minute)-tzoff,\n  timedelta(hours=1))\n  assert not m %timedelta(minutes=1),\"whole minute\"\n  m //=timedelta(minutes=1)\n  if 0 <=h <24:\n   return hash(time(h,m,self. second,self. microsecond))\n  return hash((h,m,self. second,self. microsecond))\n  \n  \n  \n def _tzstr(self,sep=\":\"):\n  ''\n  off=self. utcoffset()\n  if off is not None :\n   if off. days <0:\n    sign=\"-\"\n    off=-off\n   else :\n    sign=\"+\"\n   hh,mm=divmod(off,timedelta(hours=1))\n   assert not mm %timedelta(minutes=1),\"whole minute\"\n   mm //=timedelta(minutes=1)\n   assert 0 <=hh <24\n   off=\"%s%02d%s%02d\"%(sign,hh,sep,mm)\n  return off\n  \n def __repr__(self):\n  ''\n  if self. _microsecond !=0:\n   s=\", %d, %d\"%(self. _second,self. _microsecond)\n  elif self. _second !=0:\n   s=\", %d\"%self. _second\n  else :\n   s=\"\"\n  s=\"%s(%d, %d%s)\"%('datetime.'+self. __class__. __name__,\n  self. _hour,self. _minute,s)\n  if self. _tzinfo is not None :\n   assert s[-1:]==\")\"\n   s=s[:-1]+\", tzinfo=%r\"%self. _tzinfo+\")\"\n  return s\n  \n def isoformat(self):\n  ''\n\n\n\n  \n  s=_format_time(self. _hour,self. _minute,self. _second,\n  self. _microsecond)\n  tz=self. _tzstr()\n  if tz:\n   s +=tz\n  return s\n  \n __str__=isoformat\n \n def strftime(self,fmt):\n  ''\n\n  \n  \n  \n  timetuple=(1900,1,1,\n  self. _hour,self. _minute,self. _second,\n  0,1,-1)\n  return _wrap_strftime(self,fmt,timetuple)\n  \n def __format__(self,fmt):\n  if len(fmt)!=0:\n   return self. strftime(fmt)\n  return str(self)\n  \n  \n  \n def utcoffset(self):\n  ''\n  \n  if self. _tzinfo is None :\n   return None\n  offset=self. _tzinfo. utcoffset(None )\n  _check_utc_offset(\"utcoffset\",offset)\n  return offset\n  \n def tzname(self):\n  ''\n\n\n\n\n  \n  if self. _tzinfo is None :\n   return None\n  name=self. _tzinfo. tzname(None )\n  _check_tzname(name)\n  return name\n  \n def dst(self):\n  ''\n\n\n\n\n\n\n  \n  if self. _tzinfo is None :\n   return None\n  offset=self. _tzinfo. dst(None )\n  _check_utc_offset(\"dst\",offset)\n  return offset\n  \n def replace(self,hour=None ,minute=None ,second=None ,microsecond=None ,\n tzinfo=True ):\n  ''\n  if hour is None :\n   hour=self. hour\n  if minute is None :\n   minute=self. minute\n  if second is None :\n   second=self. second\n  if microsecond is None :\n   microsecond=self. microsecond\n  if tzinfo is True :\n   tzinfo=self. tzinfo\n  _check_time_fields(hour,minute,second,microsecond)\n  _check_tzinfo_arg(tzinfo)\n  return time(hour,minute,second,microsecond,tzinfo)\n  \n def __bool__(self):\n  if self. second or self. microsecond:\n   return True\n  offset=self. utcoffset()or timedelta(0)\n  return timedelta(hours=self. hour,minutes=self. minute)!=offset\n  \n  \n  \n def _getstate(self):\n  us2,us3=divmod(self. _microsecond,256)\n  us1,us2=divmod(us2,256)\n  basestate=bytes([self. _hour,self. _minute,self. _second,\n  us1,us2,us3])\n  if self. _tzinfo is None :\n   return (basestate,)\n  else :\n   return (basestate,self. _tzinfo)\n   \n def __setstate(self,string,tzinfo):\n  if len(string)!=6 or string[0]>=24:\n   raise TypeError(\"an integer is required\")\n  (self. _hour,self. _minute,self. _second,\n  us1,us2,us3)=string\n  self. _microsecond=(((us1 <<8)|us2)<<8)|us3\n  if tzinfo is None or isinstance(tzinfo,_tzinfo_class):\n   self. _tzinfo=tzinfo\n  else :\n   raise TypeError(\"bad tzinfo state arg %r\"%tzinfo)\n   \n def __reduce__(self):\n  return (time,self. _getstate())\n  \n_time_class=time\n\ntime. min=time(0,0,0)\ntime. max=time(23,59,59,999999)\ntime. resolution=timedelta(microseconds=1)\n\nclass datetime(date):\n ''\n\n\n\n \n \n __slots__=date. __slots__+(\n '_hour','_minute','_second',\n '_microsecond','_tzinfo')\n def __new__(cls,year,month=None ,day=None ,hour=0,minute=0,second=0,\n microsecond=0,tzinfo=None ):\n  if isinstance(year,bytes)and len(year)==10:\n  \n   self=date. __new__(cls,year[:4])\n   self. __setstate(year,month)\n   return self\n  _check_tzinfo_arg(tzinfo)\n  _check_time_fields(hour,minute,second,microsecond)\n  self=date. __new__(cls,year,month,day)\n  self. _hour=hour\n  self. _minute=minute\n  self. _second=second\n  self. _microsecond=microsecond\n  self. _tzinfo=tzinfo\n  return self\n  \n  \n @property\n def hour(self):\n  ''\n  return self. _hour\n  \n @property\n def minute(self):\n  ''\n  return self. _minute\n  \n @property\n def second(self):\n  ''\n  return self. _second\n  \n @property\n def microsecond(self):\n  ''\n  return self. _microsecond\n  \n @property\n def tzinfo(self):\n  ''\n  return self. _tzinfo\n  \n @classmethod\n def fromtimestamp(cls,t,tz=None ):\n  ''\n\n\n  \n  \n  _check_tzinfo_arg(tz)\n  \n  converter=_time. localtime if tz is None else _time. gmtime\n  \n  t,frac=divmod(t,1.0)\n  us=int(frac *1e6)\n  \n  \n  \n  \n  \n  if us ==1000000:\n   t +=1\n   us=0\n  y,m,d,hh,mm,ss,weekday,jday,dst=converter(t)\n  ss=min(ss,59)\n  result=cls(y,m,d,hh,mm,ss,us,tz)\n  if tz is not None :\n   result=tz. fromutc(result)\n  return result\n  \n @classmethod\n def utcfromtimestamp(cls,t):\n  ''\n  t,frac=divmod(t,1.0)\n  us=int(frac *1e6)\n  \n  \n  \n  \n  \n  if us ==1000000:\n   t +=1\n   us=0\n  y,m,d,hh,mm,ss,weekday,jday,dst=_time. gmtime(t)\n  ss=min(ss,59)\n  return cls(y,m,d,hh,mm,ss,us)\n  \n  \n  \n  \n  \n  \n @classmethod\n def now(cls,tz=None ):\n  ''\n  t=_time. time()\n  return cls. fromtimestamp(t,tz)\n  \n @classmethod\n def utcnow(cls):\n  ''\n  t=_time. time()\n  return cls. utcfromtimestamp(t)\n  \n @classmethod\n def combine(cls,date,time):\n  ''\n  if not isinstance(date,_date_class):\n   raise TypeError(\"date argument must be a date instance\")\n  if not isinstance(time,_time_class):\n   raise TypeError(\"time argument must be a time instance\")\n  return cls(date. year,date. month,date. day,\n  time. hour,time. minute,time. second,time. microsecond,\n  time. tzinfo)\n  \n def timetuple(self):\n  ''\n  dst=self. dst()\n  if dst is None :\n   dst=-1\n  elif dst:\n   dst=1\n  else :\n   dst=0\n  return _build_struct_time(self. year,self. month,self. day,\n  self. hour,self. minute,self. second,\n  dst)\n  \n def timestamp(self):\n  ''\n  if self. _tzinfo is None :\n   return _time. mktime((self. year,self. month,self. day,\n   self. hour,self. minute,self. second,\n   -1,-1,-1))+self. microsecond /1e6\n  else :\n   return (self -_EPOCH). total_seconds()\n   \n def utctimetuple(self):\n  ''\n  offset=self. utcoffset()\n  if offset:\n   self -=offset\n  y,m,d=self. year,self. month,self. day\n  hh,mm,ss=self. hour,self. minute,self. second\n  return _build_struct_time(y,m,d,hh,mm,ss,0)\n  \n def date(self):\n  ''\n  return date(self. _year,self. _month,self. _day)\n  \n def time(self):\n  ''\n  return time(self. hour,self. minute,self. second,self. microsecond)\n  \n def timetz(self):\n  ''\n  return time(self. hour,self. minute,self. second,self. microsecond,\n  self. _tzinfo)\n  \n def replace(self,year=None ,month=None ,day=None ,hour=None ,\n minute=None ,second=None ,microsecond=None ,tzinfo=True ):\n  ''\n  if year is None :\n   year=self. year\n  if month is None :\n   month=self. month\n  if day is None :\n   day=self. day\n  if hour is None :\n   hour=self. hour\n  if minute is None :\n   minute=self. minute\n  if second is None :\n   second=self. second\n  if microsecond is None :\n   microsecond=self. microsecond\n  if tzinfo is True :\n   tzinfo=self. tzinfo\n  _check_date_fields(year,month,day)\n  _check_time_fields(hour,minute,second,microsecond)\n  _check_tzinfo_arg(tzinfo)\n  return datetime(year,month,day,hour,minute,second,\n  microsecond,tzinfo)\n  \n def astimezone(self,tz=None ):\n  if tz is None :\n   if self. tzinfo is None :\n    raise ValueError(\"astimezone() requires an aware datetime\")\n   ts=(self -_EPOCH)//timedelta(seconds=1)\n   localtm=_time. localtime(ts)\n   local=datetime(*localtm[:6])\n   try :\n   \n    gmtoff=localtm. tm_gmtoff\n    zone=localtm. tm_zone\n   except AttributeError:\n   \n   \n   \n    delta=local -datetime(*_time. gmtime(ts)[:6])\n    dst=_time. daylight and localtm. tm_isdst >0\n    gmtoff=-(_time. altzone if dst else _time. timezone)\n    if delta ==timedelta(seconds=gmtoff):\n     tz=timezone(delta,_time. tzname[dst])\n    else :\n     tz=timezone(delta)\n   else :\n    tz=timezone(timedelta(seconds=gmtoff),zone)\n    \n  elif not isinstance(tz,tzinfo):\n   raise TypeError(\"tz argument must be an instance of tzinfo\")\n   \n  mytz=self. tzinfo\n  if mytz is None :\n   raise ValueError(\"astimezone() requires an aware datetime\")\n   \n  if tz is mytz:\n   return self\n   \n   \n  myoffset=self. utcoffset()\n  if myoffset is None :\n   raise ValueError(\"astimezone() requires an aware datetime\")\n  utc=(self -myoffset). replace(tzinfo=tz)\n  \n  \n  return tz. fromutc(utc)\n  \n  \n  \n def ctime(self):\n  ''\n  weekday=self. toordinal()%7 or 7\n  return\"%s %s %2d %02d:%02d:%02d %04d\"%(\n  _DAYNAMES[weekday],\n  _MONTHNAMES[self. _month],\n  self. _day,\n  self. _hour,self. _minute,self. _second,\n  self. _year)\n  \n def isoformat(self,sep='T'):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  s=(\"%04d-%02d-%02d%c\"%(self. _year,self. _month,self. _day,\n  sep)+\n  _format_time(self. _hour,self. _minute,self. _second,\n  self. _microsecond))\n  off=self. utcoffset()\n  if off is not None :\n   if off. days <0:\n    sign=\"-\"\n    off=-off\n   else :\n    sign=\"+\"\n   hh,mm=divmod(off,timedelta(hours=1))\n   assert not mm %timedelta(minutes=1),\"whole minute\"\n   mm //=timedelta(minutes=1)\n   s +=\"%s%02d:%02d\"%(sign,hh,mm)\n  return s\n  \n def __repr__(self):\n  ''\n  L=[self. _year,self. _month,self. _day,\n  self. _hour,self. _minute,self. _second,self. _microsecond]\n  if L[-1]==0:\n   del L[-1]\n  if L[-1]==0:\n   del L[-1]\n  s=\", \". join(map(str,L))\n  s=\"%s(%s)\"%('datetime.'+self. __class__. __name__,s)\n  if self. _tzinfo is not None :\n   assert s[-1:]==\")\"\n   s=s[:-1]+\", tzinfo=%r\"%self. _tzinfo+\")\"\n  return s\n  \n def __str__(self):\n  ''\n  return self. isoformat(sep=' ')\n  \n @classmethod\n def strptime(cls,date_string,format):\n  ''\n  import _strptime\n  return _strptime. _strptime_datetime(cls,date_string,format)\n  \n def utcoffset(self):\n  ''\n  \n  if self. _tzinfo is None :\n   return None\n  offset=self. _tzinfo. utcoffset(self)\n  _check_utc_offset(\"utcoffset\",offset)\n  return offset\n  \n def tzname(self):\n  ''\n\n\n\n\n  \n  name=_call_tzinfo_method(self. _tzinfo,\"tzname\",self)\n  _check_tzname(name)\n  return name\n  \n def dst(self):\n  ''\n\n\n\n\n\n\n  \n  if self. _tzinfo is None :\n   return None\n  offset=self. _tzinfo. dst(self)\n  _check_utc_offset(\"dst\",offset)\n  return offset\n  \n  \n  \n def __eq__(self,other):\n  if isinstance(other,datetime):\n   return self. _cmp(other,allow_mixed=True )==0\n  elif not isinstance(other,date):\n   return NotImplemented\n  else :\n   return False\n   \n def __ne__(self,other):\n  if isinstance(other,datetime):\n   return self. _cmp(other,allow_mixed=True )!=0\n  elif not isinstance(other,date):\n   return NotImplemented\n  else :\n   return True\n   \n def __le__(self,other):\n  if isinstance(other,datetime):\n   return self. _cmp(other)<=0\n  elif not isinstance(other,date):\n   return NotImplemented\n  else :\n   _cmperror(self,other)\n   \n def __lt__(self,other):\n  if isinstance(other,datetime):\n   return self. _cmp(other)<0\n  elif not isinstance(other,date):\n   return NotImplemented\n  else :\n   _cmperror(self,other)\n   \n def __ge__(self,other):\n  if isinstance(other,datetime):\n   return self. _cmp(other)>=0\n  elif not isinstance(other,date):\n   return NotImplemented\n  else :\n   _cmperror(self,other)\n   \n def __gt__(self,other):\n  if isinstance(other,datetime):\n   return self. _cmp(other)>0\n  elif not isinstance(other,date):\n   return NotImplemented\n  else :\n   _cmperror(self,other)\n   \n def _cmp(self,other,allow_mixed=False ):\n  assert isinstance(other,datetime)\n  mytz=self. _tzinfo\n  ottz=other. _tzinfo\n  myoff=otoff=None\n  \n  if mytz is ottz:\n   base_compare=True\n  else :\n   myoff=self. utcoffset()\n   otoff=other. utcoffset()\n   base_compare=myoff ==otoff\n   \n  if base_compare:\n   return _cmp((self. _year,self. _month,self. _day,\n   self. _hour,self. _minute,self. _second,\n   self. _microsecond),\n   (other. _year,other. _month,other. _day,\n   other. _hour,other. _minute,other. _second,\n   other. _microsecond))\n  if myoff is None or otoff is None :\n   if allow_mixed:\n    return 2\n   else :\n    raise TypeError(\"cannot compare naive and aware datetimes\")\n    \n  diff=self -other\n  if diff. days <0:\n   return -1\n  return diff and 1 or 0\n  \n def __add__(self,other):\n  ''\n  if not isinstance(other,timedelta):\n   return NotImplemented\n  delta=timedelta(self. toordinal(),\n  hours=self. _hour,\n  minutes=self. _minute,\n  seconds=self. _second,\n  microseconds=self. _microsecond)\n  delta +=other\n  hour,rem=divmod(delta. seconds,3600)\n  minute,second=divmod(rem,60)\n  if 0 <delta. days <=_MAXORDINAL:\n   return datetime. combine(date. fromordinal(delta. days),\n   time(hour,minute,second,\n   delta. microseconds,\n   tzinfo=self. _tzinfo))\n  raise OverflowError(\"result out of range\")\n  \n __radd__=__add__\n \n def __sub__(self,other):\n  ''\n  if not isinstance(other,datetime):\n   if isinstance(other,timedelta):\n    return self+-other\n   return NotImplemented\n   \n  days1=self. toordinal()\n  days2=other. toordinal()\n  secs1=self. _second+self. _minute *60+self. _hour *3600\n  secs2=other. _second+other. _minute *60+other. _hour *3600\n  base=timedelta(days1 -days2,\n  secs1 -secs2,\n  self. _microsecond -other. _microsecond)\n  if self. _tzinfo is other. _tzinfo:\n   return base\n  myoff=self. utcoffset()\n  otoff=other. utcoffset()\n  if myoff ==otoff:\n   return base\n  if myoff is None or otoff is None :\n   raise TypeError(\"cannot mix naive and timezone-aware time\")\n  return base+otoff -myoff\n  \n def __hash__(self):\n  tzoff=self. utcoffset()\n  if tzoff is None :\n   return hash(self. _getstate()[0])\n  days=_ymd2ord(self. year,self. month,self. day)\n  seconds=self. hour *3600+self. minute *60+self. second\n  return hash(timedelta(days,seconds,self. microsecond)-tzoff)\n  \n  \n  \n def _getstate(self):\n  yhi,ylo=divmod(self. _year,256)\n  us2,us3=divmod(self. _microsecond,256)\n  us1,us2=divmod(us2,256)\n  basestate=bytes([yhi,ylo,self. _month,self. _day,\n  self. _hour,self. _minute,self. _second,\n  us1,us2,us3])\n  if self. _tzinfo is None :\n   return (basestate,)\n  else :\n   return (basestate,self. _tzinfo)\n   \n def __setstate(self,string,tzinfo):\n  (yhi,ylo,self. _month,self. _day,self. _hour,\n  self. _minute,self. _second,us1,us2,us3)=string\n  self. _year=yhi *256+ylo\n  self. _microsecond=(((us1 <<8)|us2)<<8)|us3\n  if tzinfo is None or isinstance(tzinfo,_tzinfo_class):\n   self. _tzinfo=tzinfo\n  else :\n   raise TypeError(\"bad tzinfo state arg %r\"%tzinfo)\n   \n def __reduce__(self):\n  return (self. __class__,self. _getstate())\n  \n  \ndatetime. min=datetime(1,1,1)\ndatetime. max=datetime(9999,12,31,23,59,59,999999)\ndatetime. resolution=timedelta(microseconds=1)\n\n\ndef _isoweek1monday(year):\n\n\n THURSDAY=3\n firstday=_ymd2ord(year,1,1)\n firstweekday=(firstday+6)%7\n week1monday=firstday -firstweekday\n if firstweekday >THURSDAY:\n  week1monday +=7\n return week1monday\n \nclass timezone(tzinfo):\n __slots__='_offset','_name'\n \n \n _Omitted=object()\n def __new__(cls,offset,name=_Omitted):\n  if not isinstance(offset,timedelta):\n   raise TypeError(\"offset must be a timedelta\")\n  if name is cls. _Omitted:\n   if not offset:\n    return cls. utc\n   name=None\n  elif not isinstance(name,str):\n   raise TypeError(\"name must be a string\")\n  if not cls. _minoffset <=offset <=cls. _maxoffset:\n   raise ValueError(\"offset must be a timedelta\"\n   \" strictly between -timedelta(hours=24) and\"\n   \" timedelta(hours=24).\")\n  if (offset. microseconds !=0 or\n  offset. seconds %60 !=0):\n   raise ValueError(\"offset must be a timedelta\"\n   \" representing a whole number of minutes\")\n  return cls. _create(offset,name)\n  \n @classmethod\n def _create(cls,offset,name=None ):\n  self=tzinfo. __new__(cls)\n  self. _offset=offset\n  self. _name=name\n  return self\n  \n def __getinitargs__(self):\n  ''\n  if self. _name is None :\n   return (self. _offset,)\n  return (self. _offset,self. _name)\n  \n def __eq__(self,other):\n  if type(other)!=timezone:\n   return False\n  return self. _offset ==other. _offset\n  \n def __hash__(self):\n  return hash(self. _offset)\n  \n def __repr__(self):\n  ''\n\n\n\n\n\n\n\n  \n  if self is self. utc:\n   return'datetime.timezone.utc'\n  if self. _name is None :\n   return\"%s(%r)\"%('datetime.'+self. __class__. __name__,\n   self. _offset)\n  return\"%s(%r, %r)\"%('datetime.'+self. __class__. __name__,\n  self. _offset,self. _name)\n  \n def __str__(self):\n  return self. tzname(None )\n  \n def utcoffset(self,dt):\n  if isinstance(dt,datetime)or dt is None :\n   return self. _offset\n  raise TypeError(\"utcoffset() argument must be a datetime instance\"\n  \" or None\")\n  \n def tzname(self,dt):\n  if isinstance(dt,datetime)or dt is None :\n   if self. _name is None :\n    return self. _name_from_offset(self. _offset)\n   return self. _name\n  raise TypeError(\"tzname() argument must be a datetime instance\"\n  \" or None\")\n  \n def dst(self,dt):\n  if isinstance(dt,datetime)or dt is None :\n   return None\n  raise TypeError(\"dst() argument must be a datetime instance\"\n  \" or None\")\n  \n def fromutc(self,dt):\n  if isinstance(dt,datetime):\n   if dt. tzinfo is not self:\n    raise ValueError(\"fromutc: dt.tzinfo \"\n    \"is not self\")\n   return dt+self. _offset\n  raise TypeError(\"fromutc() argument must be a datetime instance\"\n  \" or None\")\n  \n _maxoffset=timedelta(hours=23,minutes=59)\n _minoffset=-_maxoffset\n \n @staticmethod\n def _name_from_offset(delta):\n  if delta <timedelta(0):\n   sign='-'\n   delta=-delta\n  else :\n   sign='+'\n  hours,rest=divmod(delta,timedelta(hours=1))\n  minutes=rest //timedelta(minutes=1)\n  return'UTC{}{:02d}:{:02d}'. format(sign,hours,minutes)\n  \ntimezone. utc=timezone. _create(timedelta(0))\ntimezone. min=timezone. _create(timezone. _minoffset)\ntimezone. max=timezone. _create(timezone. _maxoffset)\n_EPOCH=datetime(1970,1,1,tzinfo=timezone. utc)\n''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", ["_strptime", "math", "time"]], "code": [".py", "''\n\n\n\n\n\n\nimport sys\nimport traceback\nfrom codeop import CommandCompiler,compile_command\n\n__all__=[\"InteractiveInterpreter\",\"InteractiveConsole\",\"interact\",\n\"compile_command\"]\n\nclass InteractiveInterpreter:\n ''\n\n\n\n\n\n \n \n def __init__(self,locals=None ):\n  ''\n\n\n\n\n\n\n  \n  if locals is None :\n   locals={\"__name__\":\"__console__\",\"__doc__\":None }\n  self. locals=locals\n  self. compile=CommandCompiler()\n  \n def runsource(self,source,filename=\"<input>\",symbol=\"single\"):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  try :\n   code=self. compile(source,filename,symbol)\n  except (OverflowError,SyntaxError,ValueError):\n  \n   self. showsyntaxerror(filename)\n   return False\n   \n  if code is None :\n  \n   return True\n   \n   \n  self. runcode(code)\n  return False\n  \n def runcode(self,code):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  try :\n   exec(code,self. locals)\n  except SystemExit:\n   raise\n  except :\n   self. showtraceback()\n   \n def showsyntaxerror(self,filename=None ):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  type,value,tb=sys. exc_info()\n  sys. last_type=type\n  sys. last_value=value\n  sys. last_traceback=tb\n  if filename and type is SyntaxError:\n  \n   try :\n    msg,(dummy_filename,lineno,offset,line)=value. args\n   except ValueError:\n   \n    pass\n   else :\n   \n    value=SyntaxError(msg,(filename,lineno,offset,line))\n    sys. last_value=value\n  if sys. excepthook is sys. __excepthook__:\n   lines=traceback. format_exception_only(type,value)\n   self. write(''. join(lines))\n  else :\n  \n  \n   sys. excepthook(type,value,tb)\n   \n def showtraceback(self):\n  ''\n\n\n\n\n\n  \n  try :\n   type,value,tb=sys. exc_info()\n   sys. last_type=type\n   sys. last_value=value\n   sys. last_traceback=tb\n   tblist=traceback. extract_tb(tb)\n   del tblist[:1]\n   lines=traceback. format_list(tblist)\n   if lines:\n    lines. insert(0,\"Traceback (most recent call last):\\n\")\n   lines. extend(traceback. format_exception_only(type,value))\n  finally :\n   tblist=tb=None\n  if sys. excepthook is sys. __excepthook__:\n   self. write(''. join(lines))\n  else :\n  \n  \n   sys. excepthook(type,value,tb)\n   \n def write(self,data):\n  ''\n\n\n\n\n  \n  sys. stderr. write(data)\n  \n  \nclass InteractiveConsole(InteractiveInterpreter):\n ''\n\n\n\n\n \n \n def __init__(self,locals=None ,filename=\"<console>\"):\n  ''\n\n\n\n\n\n\n\n  \n  InteractiveInterpreter. __init__(self,locals)\n  self. filename=filename\n  self. resetbuffer()\n  \n def resetbuffer(self):\n  ''\n  self. buffer=[]\n  \n def interact(self,banner=None ):\n  ''\n\n\n\n\n\n\n\n\n  \n  try :\n   sys. ps1\n  except AttributeError:\n   sys. ps1=\">>> \"\n  try :\n   sys. ps2\n  except AttributeError:\n   sys. ps2=\"... \"\n  cprt='Type \"help\", \"copyright\", \"credits\" or \"license\" for more information.'\n  if banner is None :\n   self. write(\"Python %s on %s\\n%s\\n(%s)\\n\"%\n   (sys. version,sys. platform,cprt,\n   self. __class__. __name__))\n  elif banner:\n   self. write(\"%s\\n\"%str(banner))\n  more=0\n  while 1:\n   try :\n    if more:\n     prompt=sys. ps2\n    else :\n     prompt=sys. ps1\n    try :\n     line=self. raw_input(prompt)\n    except EOFError:\n     self. write(\"\\n\")\n     break\n    else :\n     more=self. push(line)\n   except KeyboardInterrupt:\n    self. write(\"\\nKeyboardInterrupt\\n\")\n    self. resetbuffer()\n    more=0\n    \n def push(self,line):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. buffer. append(line)\n  source=\"\\n\". join(self. buffer)\n  more=self. runsource(source,self. filename)\n  if not more:\n   self. resetbuffer()\n  return more\n  \n def raw_input(self,prompt=\"\"):\n  ''\n\n\n\n\n\n\n\n\n  \n  return input(prompt)\n  \n  \n  \ndef interact(banner=None ,readfunc=None ,local=None ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n \n console=InteractiveConsole(local)\n if readfunc is not None :\n  console. raw_input=readfunc\n else :\n  try :\n   import readline\n  except ImportError:\n   pass\n console. interact(banner)\n \n \nif __name__ ==\"__main__\":\n interact()\n", ["codeop", "readline", "sys", "traceback"]], "sys": [".py", "\nfrom _sys import *\n\n_getframe=Getframe\nfrom javascript import JSObject\nfrom browser import window\n\nbrython_debug_mode=__BRYTHON__. debug\n\nbase_exec_prefix=__BRYTHON__. brython_path\n\nbase_prefix=__BRYTHON__. brython_path\n\nbuiltin_module_names=__BRYTHON__. builtin_module_names\n\nbyteorder='little'\n\ndef exc_info():\n exc=__BRYTHON__. current_exception\n if exc is None :\n  return (None ,None ,None )\n return (exc. __class__,exc,exc. traceback)\n \nexec_prefix=__BRYTHON__. brython_path\n\nexecutable=__BRYTHON__. brython_path+'/brython.js'\n\nargv=__BRYTHON__. __ARGV\n\ndef exit(i=None ):\n raise SystemExit('')\n \nclass flag_class:\n def __init__(self):\n  self. debug=0\n  self. inspect=0\n  self. interactive=0\n  self. optimize=0\n  self. dont_write_bytecode=0\n  self. no_user_site=0\n  self. no_site=0\n  self. ignore_environment=0\n  self. verbose=0\n  self. bytes_warning=0\n  self. quiet=0\n  self. hash_randomization=1\n  \nflags=flag_class()\n\nclass float_info:\n mant_dig=53\n max=window. Number. MAX_VALUE\n min=window. Number. MIN_VALUE\n radix=2\n \ndef getfilesystemencoding(*args,**kw):\n ''\n\n \n return'utf-8'\n \ndef getrecursionlimit():\n return 200\n \nmaxsize=2 **63 -1\n\nmaxunicode=1114111\n\n\n\n\n\n\nplatform=\"brython\"\n\nprefix=__BRYTHON__. brython_path\n\nversion='.'. join(str(x)for x in __BRYTHON__. version_info[:3])\nversion +=\" (default, %s) \\n[Javascript 1.5] on Brython\"%__BRYTHON__. compiled_date\nhexversion=0x03000000\n\nclass _version_info(object):\n def __init__(self,version_info):\n  self. version_info=version_info\n  self. major=version_info[0]\n  self. minor=version_info[1]\n  self. micro=version_info[2]\n  self. releaselevel=version_info[3]\n  self. serial=version_info[4]\n  \n def __getitem__(self,index):\n  if isinstance(self. version_info[index],list):\n   return tuple(self. version_info[index])\n  return self. version_info[index]\n  \n def hexversion(self):\n  try :\n   return'0%d0%d0%d'%(self. major,self. minor,self. micro)\n  finally :\n   return'0%d0000'%(self. major)\n   \n def __str__(self):\n  _s=\"sys.version(major=%d, minor=%d, micro=%d, releaselevel='%s', serial=%d)\"\n  return _s %(self. major,self. minor,self. micro,\n  self. releaselevel,self. serial)\n  \n  \n def __eq__(self,other):\n  if isinstance(other,tuple):\n   return (self. major,self. minor,self. micro)==other\n   \n  raise Error(\"Error! I don't know how to compare!\")\n  \n def __ge__(self,other):\n  if isinstance(other,tuple):\n   return (self. major,self. minor,self. micro)>=other\n   \n  raise Error(\"Error! I don't know how to compare!\")\n  \n def __gt__(self,other):\n  if isinstance(other,tuple):\n   return (self. major,self. minor,self. micro)>other\n   \n  raise Error(\"Error! I don't know how to compare!\")\n  \n def __le__(self,other):\n  if isinstance(other,tuple):\n   return (self. major,self. minor,self. micro)<=other\n   \n  raise Error(\"Error! I don't know how to compare!\")\n  \n def __lt__(self,other):\n  if isinstance(other,tuple):\n   return (self. major,self. minor,self. micro)<other\n   \n  raise Error(\"Error! I don't know how to compare!\")\n  \n def __ne__(self,other):\n  if isinstance(other,tuple):\n   return (self. major,self. minor,self. micro)!=other\n   \n  raise Error(\"Error! I don't know how to compare!\")\n  \n  \n  \nversion_info=_version_info(__BRYTHON__. version_info)\n\nclass _implementation:\n def __init__(self):\n  self. name='brython'\n  self. version=_version_info(__BRYTHON__. implementation)\n  self. hexversion=self. version. hexversion()\n  self. cache_tag=None\n  \n def __repr__(self):\n  return\"namespace(name='%s' version=%s hexversion='%s')\"%(self. name,self. version,self. hexversion)\n  \n def __str__(self):\n  return\"namespace(name='%s' version=%s hexversion='%s')\"%(self. name,self. version,self. hexversion)\n  \nimplementation=_implementation()\n\nclass _hash_info:\n def __init__(self):\n  self. width=32,\n  self. modulus=2147483647\n  self. inf=314159\n  self. nan=0\n  self. imag=1000003\n  self. algorithm='siphash24'\n  self. hash_bits=64\n  self. seed_bits=128\n  cutoff=0\n  \n def __repr__(self):\n \n  return\"sys.hash_info(width=32, modulus=2147483647, inf=314159, nan=0, imag=1000003, algorithm='siphash24', hash_bits=64, seed_bits=128, cutoff=0)\"\n  \nhash_info=_hash_info()\n\nclass _float_info:\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n def __init__(self):\n  _number=window. Number\n  self. dig=15\n  self. epsilon=2 **-52\n  self. mant_dig=53\n  self. max=_number. MAX_VALUE\n  self. max_exp=2 **10\n  self. max_10_exp=308\n  self. min=2 **(-1022)\n  self. min_exp=-1021\n  self. min_10_exp=-307\n  self. radix=2\n  self. rounds=1\n  self. _tuple=(self. max,self. max_exp,self. max_10_exp,self. min,self. min_exp,self. min_10_exp,self. dig,self. mant_dig,self. epsilon,self. radix,self. rounds)\n  \n def __getitem__(self,k):\n  return self. _tuple[k]\n  \n def __iter__(self):\n  return iter(self. _tuple)\n  \nfloat_info=_float_info()\n\nwarnoptions=[]\n\ndef getfilesystemencoding():\n return'utf-8'\n \n \n__stdout__=__BRYTHON__. stdout\n__stderr__=__BRYTHON__. stderr\n__stdin__=__BRYTHON__. stdin\n\n", ["_sys", "browser", "javascript"]], "importlib.basehook": [".py", "from javascript import JSObject\nfrom browser import window\nimport urllib. request\n\nclass TempMod:\n def __init__(self,name):\n  self. name=name\n  \n  \nclass BaseHook:\n def __init__(self,fullname=None ,path=None ):\n  self. _fullname=fullname\n  self. _path=path\n  self. _modpath=''\n  self. _module=''\n  \n def find_module(self,name=None ,path=None ):\n  if name is None :\n   name=self. _fullname\n   \n  for _i in ('libs/%s.js'%name,'Lib/%s.py'%name,\n  'Lib/%s/__init__.py'%name):\n   _path=\"%s%s\"%(__BRYTHON__. brython_path,_i)\n   try :\n    _fp,_,_headers=urllib. request. urlopen(_path)\n    if _headers['status']!=200:\n     continue\n    self. _module=_fp. read()\n    self. _modpath=_path\n    return self\n   except urllib. error. HTTPError as e:\n    self. _modpath=''\n    self. _module=''\n    \n  raise ImportError\n  \n def is_package(self):\n  return'.'in self. _fullname\n  \n def load_module(self,name):\n  if name is None :\n   name=self. _fullname\n  window. eval('__BRYTHON__.imported[\"%s\"]={}'%name)\n  return JSObject(__BRYTHON__. run_py)(self. _module,\n  self. _modpath,TempMod(name))\n", ["browser", "javascript", "urllib.request"]], "contextlib": [".py", "''\n\nimport sys\nfrom collections import deque\nfrom functools import wraps\n\n__all__=[\"contextmanager\",\"closing\",\"ContextDecorator\",\"ExitStack\"]\n\n\nclass ContextDecorator(object):\n ''\n \n def _recreate_cm(self):\n  ''\n\n\n\n\n\n\n\n  \n  return self\n  \n def __call__(self,func):\n  @wraps(func)\n  def inner(*args,**kwds):\n   with self. _recreate_cm():\n    return func(*args,**kwds)\n  return inner\n  \n  \nclass _GeneratorContextManager(ContextDecorator):\n ''\n \n def __init__(self,func,*args,**kwds):\n  self. gen=func(*args,**kwds)\n  self. func,self. args,self. kwds=func,args,kwds\n  \n def _recreate_cm(self):\n \n \n \n  return self. __class__(self. func,*self. args,**self. kwds)\n  \n def __enter__(self):\n  try :\n   return next(self. gen)\n  except StopIteration:\n   raise RuntimeError(\"generator didn't yield\")\n   \n def __exit__(self,type,value,traceback):\n  if type is None :\n   try :\n    next(self. gen)\n   except StopIteration:\n    return\n   else :\n    raise RuntimeError(\"generator didn't stop\")\n  else :\n   if value is None :\n   \n   \n    value=type()\n   try :\n    self. gen. throw(type,value,traceback)\n    raise RuntimeError(\"generator didn't stop after throw()\")\n   except StopIteration as exc:\n   \n   \n   \n    return exc is not value\n   except :\n   \n   \n   \n   \n   \n   \n   \n    if sys. exc_info()[1]is not value:\n     raise\n     \n     \ndef contextmanager(func):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n @wraps(func)\n def helper(*args,**kwds):\n  return _GeneratorContextManager(func,*args,**kwds)\n return helper\n \n \nclass closing(object):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n def __init__(self,thing):\n  self. thing=thing\n def __enter__(self):\n  return self. thing\n def __exit__(self,*exc_info):\n  self. thing. close()\n  \n  \n  \nclass ExitStack(object):\n ''\n\n\n\n\n\n\n\n\n\n \n def __init__(self):\n  self. _exit_callbacks=deque()\n  \n def pop_all(self):\n  ''\n  new_stack=type(self)()\n  new_stack. _exit_callbacks=self. _exit_callbacks\n  self. _exit_callbacks=deque()\n  return new_stack\n  \n def _push_cm_exit(self,cm,cm_exit):\n  ''\n  def _exit_wrapper(*exc_details):\n   return cm_exit(cm,*exc_details)\n  _exit_wrapper. __self__=cm\n  self. push(_exit_wrapper)\n  \n def push(self,exit):\n  ''\n\n\n\n\n\n  \n  \n  \n  _cb_type=type(exit)\n  try :\n   exit_method=_cb_type. __exit__\n  except AttributeError:\n  \n   self. _exit_callbacks. append(exit)\n  else :\n   self. _push_cm_exit(exit,exit_method)\n  return exit\n  \n def callback(self,callback,*args,**kwds):\n  ''\n\n\n  \n  def _exit_wrapper(exc_type,exc,tb):\n   callback(*args,**kwds)\n   \n   \n  _exit_wrapper. __wrapped__=callback\n  self. push(_exit_wrapper)\n  return callback\n  \n def enter_context(self,cm):\n  ''\n\n\n\n  \n  \n  _cm_type=type(cm)\n  _exit=_cm_type. __exit__\n  result=_cm_type. __enter__(cm)\n  self. _push_cm_exit(cm,_exit)\n  return result\n  \n def close(self):\n  ''\n  self. __exit__(None ,None ,None )\n  \n def __enter__(self):\n  return self\n  \n def __exit__(self,*exc_details):\n  received_exc=exc_details[0]is not None\n  \n  \n  \n  frame_exc=sys. exc_info()[1]\n  def _fix_exception_context(new_exc,old_exc):\n   while 1:\n    exc_context=new_exc. __context__\n    if exc_context in (None ,frame_exc):\n     break\n    new_exc=exc_context\n   new_exc. __context__=old_exc\n   \n   \n   \n  suppressed_exc=False\n  pending_raise=False\n  while self. _exit_callbacks:\n   cb=self. _exit_callbacks. pop()\n   try :\n    if cb(*exc_details):\n     suppressed_exc=True\n     pending_raise=False\n     exc_details=(None ,None ,None )\n   except :\n    new_exc_details=sys. exc_info()\n    \n    _fix_exception_context(new_exc_details[1],exc_details[1])\n    pending_raise=True\n    exc_details=new_exc_details\n  if pending_raise:\n   try :\n   \n   \n    fixed_ctx=exc_details[1]. __context__\n    raise exc_details[1]\n   except BaseException:\n    exc_details[1]. __context__=fixed_ctx\n    raise\n  return received_exc and suppressed_exc\n", ["collections", "functools", "sys"]], "pydoc": [".py", "#!/usr/bin/env python3\n''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n__all__=['help']\n__author__=\"Ka-Ping Yee <ping@lfw.org>\"\n__date__=\"26 February 2001\"\n\n__credits__=\"\"\"Guido van Rossum, for an excellent programming language.\nTommy Burnette, the original creator of manpy.\nPaul Prescod, for all his work on onlinehelp.\nRichard Chamberlain, for the first implementation of textdoc.\n\"\"\"\n\n\n\n\n\n\n\n\n\nimport builtins\nimport imp\nimport importlib. machinery\n\nimport inspect\nimport io\nimport os\n\n\nimport platform\nimport re\nimport sys\nimport time\nimport tokenize\nimport warnings\nfrom collections import deque\nfrom reprlib import Repr\n\n\n\n\n\n\ndef pathdirs():\n ''\n dirs=[]\n normdirs=[]\n for dir in sys. path:\n  dir=os. path. abspath(dir or'.')\n  normdir=os. path. normcase(dir)\n  if normdir not in normdirs and os. path. isdir(dir):\n   dirs. append(dir)\n   normdirs. append(normdir)\n return dirs\n \ndef getdoc(object):\n ''\n result=inspect. getdoc(object)or inspect. getcomments(object)\n return result and re. sub('^ *\\n','',result. rstrip())or''\n \ndef splitdoc(doc):\n ''\n lines=doc. strip(). split('\\n')\n if len(lines)==1:\n  return lines[0],''\n elif len(lines)>=2 and not lines[1]. rstrip():\n  return lines[0],'\\n'. join(lines[2:])\n return'','\\n'. join(lines)\n \ndef classname(object,modname):\n ''\n name=object. __name__\n if object. __module__ !=modname:\n  name=object. __module__+'.'+name\n return name\n \ndef isdata(object):\n ''\n return not (inspect. ismodule(object)or inspect. isclass(object)or\n inspect. isroutine(object)or inspect. isframe(object)or\n inspect. istraceback(object)or inspect. iscode(object))\n \ndef replace(text,*pairs):\n ''\n while pairs:\n  text=pairs[1]. join(text. split(pairs[0]))\n  pairs=pairs[2:]\n return text\n \ndef cram(text,maxlen):\n ''\n if len(text)>maxlen:\n  pre=max(0,(maxlen -3)//2)\n  post=max(0,maxlen -3 -pre)\n  return text[:pre]+'...'+text[len(text)-post:]\n return text\n \n_re_stripid=re. compile(r' at 0x[0-9a-f]{6,16}(>+)$',re. IGNORECASE)\ndef stripid(text):\n ''\n \n \n \n return text\n \ndef _is_some_method(obj):\n return (inspect. isfunction(obj)or\n inspect. ismethod(obj)or\n inspect. isbuiltin(obj)or\n inspect. ismethoddescriptor(obj))\n \ndef allmethods(cl):\n methods={}\n for key,value in inspect. getmembers(cl,_is_some_method):\n  methods[key]=1\n for base in cl. __bases__:\n  methods. update(allmethods(base))\n for key in methods. keys():\n  methods[key]=getattr(cl,key)\n return methods\n \ndef _split_list(s,predicate):\n ''\n\n\n\n\n \n \n yes=[]\n no=[]\n for x in s:\n  if predicate(x):\n   yes. append(x)\n  else :\n   no. append(x)\n return yes,no\n \ndef visiblename(name,all=None ,obj=None ):\n ''\n \n if name in {'__author__','__builtins__','__cached__','__credits__',\n '__date__','__doc__','__file__','__initializing__',\n '__loader__','__module__','__name__','__package__',\n '__path__','__qualname__','__slots__','__version__'}:\n  return 0\n  \n if name. startswith('__')and name. endswith('__'):return 1\n \n if name. startswith('_')and hasattr(obj,'_fields'):\n  return True\n if all is not None :\n \n  return name in all\n else :\n  return not name. startswith('_')\n  \ndef classify_class_attrs(object):\n ''\n results=[]\n for (name,kind,cls,value)in inspect. classify_class_attrs(object):\n  if inspect. isdatadescriptor(value):\n   kind='data descriptor'\n  results. append((name,kind,cls,value))\n return results\n \n \n \ndef ispackage(path):\n ''\n if os. path. isdir(path):\n  for ext in ('.py','.pyc','.pyo'):\n   if os. path. isfile(os. path. join(path,'__init__'+ext)):\n    return True\n return False\n \ndef source_synopsis(file):\n line=file. readline()\n while line[:1]=='#'or not line. strip():\n  line=file. readline()\n  if not line:break\n line=line. strip()\n if line[:4]=='r\"\"\"':line=line[1:]\n if line[:3]=='\"\"\"':\n  line=line[3:]\n  if line[-1:]=='\\\\':line=line[:-1]\n  while not line. strip():\n   line=file. readline()\n   if not line:break\n  result=line. split('\"\"\"')[0]. strip()\n else :result=None\n return result\n \ndef synopsis(filename,cache={}):\n ''\n mtime=os. stat(filename). st_mtime\n lastupdate,result=cache. get(filename,(None ,None ))\n if lastupdate is None or lastupdate <mtime:\n  try :\n   file=tokenize. open(filename)\n  except IOError:\n  \n   return None\n  binary_suffixes=importlib. machinery. BYTECODE_SUFFIXES[:]\n  binary_suffixes +=importlib. machinery. EXTENSION_SUFFIXES[:]\n  if any(filename. endswith(x)for x in binary_suffixes):\n  \n   file. close()\n   if any(filename. endswith(x)for x in\n   importlib. machinery. BYTECODE_SUFFIXES):\n    loader=importlib. machinery. SourcelessFileLoader('__temp__',\n    filename)\n   else :\n    loader=importlib. machinery. ExtensionFileLoader('__temp__',\n    filename)\n   try :\n    module=loader. load_module('__temp__')\n   except :\n    return None\n   result=(module. __doc__ or''). splitlines()[0]\n   del sys. modules['__temp__']\n  else :\n  \n   result=source_synopsis(file)\n   file. close()\n   \n  cache[filename]=(mtime,result)\n return result\n \nclass ErrorDuringImport(Exception):\n ''\n def __init__(self,filename,exc_info):\n  self. filename=filename\n  self. exc,self. value,self. tb=exc_info\n  \n def __str__(self):\n  exc=self. exc. __name__\n  return'problem in %s - %s: %s'%(self. filename,exc,self. value)\n  \ndef importfile(path):\n ''\n magic=imp. get_magic()\n with open(path,'rb')as file:\n  if file. read(len(magic))==magic:\n   kind=imp. PY_COMPILED\n  else :\n   kind=imp. PY_SOURCE\n  file. seek(0)\n  filename=os. path. basename(path)\n  name,ext=os. path. splitext(filename)\n  try :\n   module=imp. load_module(name,file,path,(ext,'r',kind))\n  except :\n   raise ErrorDuringImport(path,sys. exc_info())\n return module\n \ndef safeimport(path,forceload=0,cache={}):\n ''\n\n\n\n\n\n \n try :\n \n \n \n \n  if forceload and path in sys. modules:\n   if path not in sys. builtin_module_names:\n   \n   \n   \n   \n   \n    subs=[m for m in sys. modules if m. startswith(path+'.')]\n    for key in [path]+subs:\n    \n     cache[key]=sys. modules[key]\n     del sys. modules[key]\n  module=__import__(path)\n except :\n \n  (exc,value,tb)=info=sys. exc_info()\n  if path in sys. modules:\n  \n   raise ErrorDuringImport(sys. modules[path]. __file__,info)\n  elif exc is SyntaxError:\n  \n   raise ErrorDuringImport(value. filename,info)\n   \n   \n  elif exc is ImportError and str(value)==str(path):\n  \n   return None\n  else :\n  \n   raise ErrorDuringImport(path,sys. exc_info())\n for part in path. split('.')[1:]:\n  try :module=getattr(module,part)\n  except AttributeError:return None\n return module\n \n \n \nclass Doc:\n\n PYTHONDOCS=os. environ. get(\"PYTHONDOCS\",\n \"http://docs.python.org/%d.%d/library\"\n %sys. version_info[:2])\n \n def document(self,object,name=None ,*args):\n  ''\n  args=(object,name)+args\n  \n  \n  \n  \n  if inspect. isgetsetdescriptor(object):return self. docdata(*args)\n  if inspect. ismemberdescriptor(object):return self. docdata(*args)\n  try :\n   if inspect. ismodule(object):return self. docmodule(*args)\n   if inspect. isclass(object):return self. docclass(*args)\n   if inspect. isroutine(object):return self. docroutine(*args)\n  except AttributeError:\n   pass\n  if isinstance(object,property):return self. docproperty(*args)\n  return self. docother(*args)\n  \n def fail(self,object,name=None ,*args):\n  ''\n  message=\"don't know how to document object%s of type %s\"%(\n  name and' '+repr(name),type(object). __name__)\n  raise TypeError(message)\n  \n docmodule=docclass=docroutine=docother=docproperty=docdata=fail\n \n def getdocloc(self,object):\n  ''\n  \n  try :\n   file=inspect. getabsfile(object)\n  except TypeError:\n   file='(built-in)'\n   \n  docloc=os. environ. get(\"PYTHONDOCS\",self. PYTHONDOCS)\n  \n  basedir=os. path. join(sys. base_exec_prefix,\"lib\",\n  \"python%d.%d\"%sys. version_info[:2])\n  if (isinstance(object,type(os))and\n  (object. __name__ in ('errno','exceptions','gc','imp',\n  'marshal','posix','signal','sys',\n  '_thread','zipimport')or\n  (file. startswith(basedir)and\n  not file. startswith(os. path. join(basedir,'site-packages'))))and\n  object. __name__ not in ('xml.etree','test.pydoc_mod')):\n   if docloc. startswith(\"http://\"):\n    docloc=\"%s/%s\"%(docloc. rstrip(\"/\"),object. __name__)\n   else :\n    docloc=os. path. join(docloc,object. __name__+\".html\")\n  else :\n   docloc=None\n  return docloc\n  \n  \n  \nclass HTMLRepr(Repr):\n ''\n def __init__(self):\n  Repr. __init__(self)\n  self. maxlist=self. maxtuple=20\n  self. maxdict=10\n  self. maxstring=self. maxother=100\n  \n def escape(self,text):\n  return replace(text,'&','&amp;','<','&lt;','>','&gt;')\n  \n def repr(self,object):\n  return Repr. repr(self,object)\n  \n def repr1(self,x,level):\n  if hasattr(type(x),'__name__'):\n   methodname='repr_'+'_'. join(type(x). __name__. split())\n   if hasattr(self,methodname):\n    return getattr(self,methodname)(x,level)\n  return self. escape(cram(stripid(repr(x)),self. maxother))\n  \n def repr_string(self,x,level):\n  test=cram(x,self. maxstring)\n  testrepr=repr(test)\n  if'\\\\'in test and'\\\\'not in replace(testrepr,r'\\\\',''):\n  \n  \n   return'r'+testrepr[0]+self. escape(test)+testrepr[0]\n  return re. sub(r'((\\\\[\\\\abfnrtv\\'\"]|\\\\[0-9]..|\\\\x..|\\\\u....)+)',\n  r'<font color=\"#c040c0\">\\1</font>',\n  self. escape(testrepr))\n  \n repr_str=repr_string\n \n def repr_instance(self,x,level):\n  try :\n   return self. escape(cram(stripid(repr(x)),self. maxstring))\n  except :\n   return self. escape('<%s instance>'%x. __class__. __name__)\n   \n repr_unicode=repr_string\n \nclass HTMLDoc(Doc):\n ''\n \n \n \n _repr_instance=HTMLRepr()\n repr=_repr_instance. repr\n escape=_repr_instance. escape\n \n def page(self,title,contents):\n  ''\n  return'''\\\n<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n<html><head><title>Python: %s</title>\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n</head><body bgcolor=\"#f0f0f8\">\n%s\n</body></html>'''%(title,contents)\n  \n def heading(self,title,fgcol,bgcol,extras=''):\n  ''\n  return'''\n<table width=\"100%%\" cellspacing=0 cellpadding=2 border=0 summary=\"heading\">\n<tr bgcolor=\"%s\">\n<td valign=bottom>&nbsp;<br>\n<font color=\"%s\" face=\"helvetica, arial\">&nbsp;<br>%s</font></td\n><td align=right valign=bottom\n><font color=\"%s\" face=\"helvetica, arial\">%s</font></td></tr></table>\n    '''%(bgcol,fgcol,title,fgcol,extras or'&nbsp;')\n  \n def section(self,title,fgcol,bgcol,contents,width=6,\n prelude='',marginalia=None ,gap='&nbsp;'):\n  ''\n  if marginalia is None :\n   marginalia='<tt>'+'&nbsp;'*width+'</tt>'\n  result='''<p>\n<table width=\"100%%\" cellspacing=0 cellpadding=2 border=0 summary=\"section\">\n<tr bgcolor=\"%s\">\n<td colspan=3 valign=bottom>&nbsp;<br>\n<font color=\"%s\" face=\"helvetica, arial\">%s</font></td></tr>\n    '''%(bgcol,fgcol,title)\n  if prelude:\n   result=result+'''\n<tr bgcolor=\"%s\"><td rowspan=2>%s</td>\n<td colspan=2>%s</td></tr>\n<tr><td>%s</td>'''%(bgcol,marginalia,prelude,gap)\n  else :\n   result=result+'''\n<tr><td bgcolor=\"%s\">%s</td><td>%s</td>'''%(bgcol,marginalia,gap)\n   \n  return result+'\\n<td width=\"100%%\">%s</td></tr></table>'%contents\n  \n def bigsection(self,title,*args):\n  ''\n  title='<big><strong>%s</strong></big>'%title\n  return self. section(title,*args)\n  \n def preformat(self,text):\n  ''\n  text=self. escape(text. expandtabs())\n  return replace(text,'\\n\\n','\\n \\n','\\n\\n','\\n \\n',\n  ' ','&nbsp;','\\n','<br>\\n')\n  \n def multicolumn(self,list,format,cols=4):\n  ''\n  result=''\n  rows=(len(list)+cols -1)//cols\n  for col in range(cols):\n   result=result+'<td width=\"%d%%\" valign=top>'%(100 //cols)\n   for i in range(rows *col,rows *col+rows):\n    if i <len(list):\n     result=result+format(list[i])+'<br>\\n'\n   result=result+'</td>'\n  return'<table width=\"100%%\" summary=\"list\"><tr>%s</tr></table>'%result\n  \n def grey(self,text):return'<font color=\"#909090\">%s</font>'%text\n \n def namelink(self,name,*dicts):\n  ''\n  for dict in dicts:\n   if name in dict:\n    return'<a href=\"%s\">%s</a>'%(dict[name],name)\n  return name\n  \n def classlink(self,object,modname):\n  ''\n  name,module=object. __name__,sys. modules. get(object. __module__)\n  if hasattr(module,name)and getattr(module,name)is object:\n   return'<a href=\"%s.html#%s\">%s</a>'%(\n   module. __name__,name,classname(object,modname))\n  return classname(object,modname)\n  \n def modulelink(self,object):\n  ''\n  return'<a href=\"%s.html\">%s</a>'%(object. __name__,object. __name__)\n  \n def modpkglink(self,modpkginfo):\n  ''\n  name,path,ispackage,shadowed=modpkginfo\n  if shadowed:\n   return self. grey(name)\n  if path:\n   url='%s.%s.html'%(path,name)\n  else :\n   url='%s.html'%name\n  if ispackage:\n   text='<strong>%s</strong>&nbsp;(package)'%name\n  else :\n   text=name\n  return'<a href=\"%s\">%s</a>'%(url,text)\n  \n def filelink(self,url,path):\n  ''\n  return'<a href=\"file:%s\">%s</a>'%(url,path)\n  \n def markup(self,text,escape=None ,funcs={},classes={},methods={}):\n  ''\n  \n  escape=escape or self. escape\n  results=[]\n  here=0\n  pattern=re. compile(r'\\b((http|ftp)://\\S+[\\w/]|'\n  r'RFC[- ]?(\\d+)|'\n  r'PEP[- ]?(\\d+)|'\n  r'(self\\.)?(\\w+))')\n  while True :\n   match=pattern. search(text,here)\n   if not match:break\n   start,end=match. span()\n   results. append(escape(text[here:start]))\n   \n   all,scheme,rfc,pep,selfdot,name=match. groups()\n   if scheme:\n    url=escape(all). replace('\"','&quot;')\n    results. append('<a href=\"%s\">%s</a>'%(url,url))\n   elif rfc:\n    url='http://www.rfc-editor.org/rfc/rfc%d.txt'%int(rfc)\n    results. append('<a href=\"%s\">%s</a>'%(url,escape(all)))\n   elif pep:\n    url='http://www.python.org/dev/peps/pep-%04d/'%int(pep)\n    results. append('<a href=\"%s\">%s</a>'%(url,escape(all)))\n   elif text[end:end+1]=='(':\n    results. append(self. namelink(name,methods,funcs,classes))\n   elif selfdot:\n    results. append('self.<strong>%s</strong>'%name)\n   else :\n    results. append(self. namelink(name,classes))\n   here=end\n  results. append(escape(text[here:]))\n  return''. join(results)\n  \n  \n  \n def formattree(self,tree,modname,parent=None ):\n  ''\n  result=''\n  for entry in tree:\n   if type(entry)is type(()):\n    c,bases=entry\n    result=result+'<dt><font face=\"helvetica, arial\">'\n    result=result+self. classlink(c,modname)\n    if bases and bases !=(parent,):\n     parents=[]\n     for base in bases:\n      parents. append(self. classlink(base,modname))\n     result=result+'('+', '. join(parents)+')'\n    result=result+'\\n</font></dt>'\n   elif type(entry)is type([]):\n    result=result+'<dd>\\n%s</dd>\\n'%self. formattree(\n    entry,modname,c)\n  return'<dl>\\n%s</dl>\\n'%result\n  \n def docmodule(self,object,name=None ,mod=None ,*ignored):\n  ''\n  name=object. __name__\n  try :\n   all=object. __all__\n  except AttributeError:\n   all=None\n  parts=name. split('.')\n  links=[]\n  for i in range(len(parts)-1):\n   links. append(\n   '<a href=\"%s.html\"><font color=\"#ffffff\">%s</font></a>'%\n   ('.'. join(parts[:i+1]),parts[i]))\n  linkedname='.'. join(links+parts[-1:])\n  head='<big><big><strong>%s</strong></big></big>'%linkedname\n  try :\n   path=inspect. getabsfile(object)\n   url=path\n   if sys. platform =='win32':\n    import nturl2path\n    url=nturl2path. pathname2url(path)\n   filelink=self. filelink(url,path)\n  except TypeError:\n   filelink='(built-in)'\n  info=[]\n  if hasattr(object,'__version__'):\n   version=str(object. __version__)\n   if version[:11]=='$'+'Revision: 'and version[-1:]=='$':\n    version=version[11:-1]. strip()\n   info. append('version %s'%self. escape(version))\n  if hasattr(object,'__date__'):\n   info. append(self. escape(str(object. __date__)))\n  if info:\n   head=head+' (%s)'%', '. join(info)\n  docloc=self. getdocloc(object)\n  if docloc is not None :\n   docloc='<br><a href=\"%(docloc)s\">Module Reference</a>'%locals()\n  else :\n   docloc=''\n  result=self. heading(\n  head,'#ffffff','#7799ee',\n  '<a href=\".\">index</a><br>'+filelink+docloc)\n  \n  modules=inspect. getmembers(object,inspect. ismodule)\n  \n  classes,cdict=[],{}\n  for key,value in inspect. getmembers(object,inspect. isclass):\n  \n   if (all is not None or\n   (inspect. getmodule(value)or object)is object):\n    if visiblename(key,all,object):\n     classes. append((key,value))\n     cdict[key]=cdict[value]='#'+key\n  for key,value in classes:\n   for base in value. __bases__:\n    key,modname=base. __name__,base. __module__\n    module=sys. modules. get(modname)\n    if modname !=name and module and hasattr(module,key):\n     if getattr(module,key)is base:\n      if not key in cdict:\n       cdict[key]=cdict[base]=modname+'.html#'+key\n  funcs,fdict=[],{}\n  for key,value in inspect. getmembers(object,inspect. isroutine):\n  \n   if (all is not None or\n   inspect. isbuiltin(value)or inspect. getmodule(value)is object):\n    if visiblename(key,all,object):\n     funcs. append((key,value))\n     fdict[key]='#-'+key\n     if inspect. isfunction(value):fdict[value]=fdict[key]\n  data=[]\n  for key,value in inspect. getmembers(object,isdata):\n   if visiblename(key,all,object):\n    data. append((key,value))\n    \n  doc=self. markup(getdoc(object),self. preformat,fdict,cdict)\n  doc=doc and'<tt>%s</tt>'%doc\n  result=result+'<p>%s</p>\\n'%doc\n  \n  if hasattr(object,'__path__'):\n   modpkgs=[]\n   for importer,modname,ispkg in pkgutil. iter_modules(object. __path__):\n    modpkgs. append((modname,name,ispkg,0))\n   modpkgs. sort()\n   contents=self. multicolumn(modpkgs,self. modpkglink)\n   result=result+self. bigsection(\n   'Package Contents','#ffffff','#aa55cc',contents)\n  elif modules:\n   contents=self. multicolumn(\n   modules,lambda t:self. modulelink(t[1]))\n   result=result+self. bigsection(\n   'Modules','#ffffff','#aa55cc',contents)\n   \n  if classes:\n   classlist=[value for (key,value)in classes]\n   contents=[\n   self. formattree(inspect. getclasstree(classlist,1),name)]\n   for key,value in classes:\n    contents. append(self. document(value,key,name,fdict,cdict))\n   result=result+self. bigsection(\n   'Classes','#ffffff','#ee77aa',' '. join(contents))\n  if funcs:\n   contents=[]\n   for key,value in funcs:\n    contents. append(self. document(value,key,name,fdict,cdict))\n   result=result+self. bigsection(\n   'Functions','#ffffff','#eeaa77',' '. join(contents))\n  if data:\n   contents=[]\n   for key,value in data:\n    contents. append(self. document(value,key))\n   result=result+self. bigsection(\n   'Data','#ffffff','#55aa55','<br>\\n'. join(contents))\n  if hasattr(object,'__author__'):\n   contents=self. markup(str(object. __author__),self. preformat)\n   result=result+self. bigsection(\n   'Author','#ffffff','#7799ee',contents)\n  if hasattr(object,'__credits__'):\n   contents=self. markup(str(object. __credits__),self. preformat)\n   result=result+self. bigsection(\n   'Credits','#ffffff','#7799ee',contents)\n   \n  return result\n  \n def docclass(self,object,name=None ,mod=None ,funcs={},classes={},\n *ignored):\n  ''\n  print('docclass')\n  realname=object. __name__\n  name=name or realname\n  bases=object. __bases__\n  \n  contents=[]\n  push=contents. append\n  \n  \n  class HorizontalRule:\n   def __init__(self):\n    self. needone=0\n   def maybe(self):\n    if self. needone:\n     push('<hr>\\n')\n    self. needone=1\n  hr=HorizontalRule()\n  \n  \n  mro=deque(inspect. getmro(object))\n  if len(mro)>2:\n   hr. maybe()\n   push('<dl><dt>Method resolution order:</dt>\\n')\n   for base in mro:\n    push('<dd>%s</dd>\\n'%self. classlink(base,\n    object. __module__))\n   push('</dl>\\n')\n   \n  def spill(msg,attrs,predicate):\n   ok,attrs=_split_list(attrs,predicate)\n   if ok:\n    hr. maybe()\n    push(msg)\n    for name,kind,homecls,value in ok:\n     try :\n      value=getattr(object,name)\n     except Exception:\n     \n     \n      push(self. _docdescriptor(name,value,mod))\n     else :\n      push(self. document(value,name,mod,\n      funcs,classes,mdict,object))\n     push('\\n')\n   return attrs\n   \n  def spilldescriptors(msg,attrs,predicate):\n   ok,attrs=_split_list(attrs,predicate)\n   if ok:\n    hr. maybe()\n    push(msg)\n    for name,kind,homecls,value in ok:\n     push(self. _docdescriptor(name,value,mod))\n   return attrs\n   \n  def spilldata(msg,attrs,predicate):\n   ok,attrs=_split_list(attrs,predicate)\n   if ok:\n    hr. maybe()\n    push(msg)\n    for name,kind,homecls,value in ok:\n     base=self. docother(getattr(object,name),name,mod)\n     if callable(value)or inspect. isdatadescriptor(value):\n      doc=getattr(value,\"__doc__\",None )\n     else :\n      doc=None\n     if doc is None :\n      push('<dl><dt>%s</dl>\\n'%base)\n     else :\n      doc=self. markup(getdoc(value),self. preformat,\n      funcs,classes,mdict)\n      doc='<dd><tt>%s</tt>'%doc\n      push('<dl><dt>%s%s</dl>\\n'%(base,doc))\n     push('\\n')\n   return attrs\n   \n  attrs=[(name,kind,cls,value)\n  for name,kind,cls,value in classify_class_attrs(object)\n  if visiblename(name,obj=object)]\n  \n  mdict={}\n  for key,kind,homecls,value in attrs:\n   mdict[key]=anchor='#'+name+'-'+key\n   try :\n    value=getattr(object,name)\n   except Exception:\n   \n   \n    pass\n   try :\n   \n   \n    mdict[value]=anchor\n   except TypeError:\n    pass\n    \n  while attrs:\n   if mro:\n    thisclass=mro. popleft()\n   else :\n    thisclass=attrs[0][2]\n   attrs,inherited=_split_list(attrs,lambda t:t[2]is thisclass)\n   \n   if thisclass is builtins. object:\n    attrs=inherited\n    continue\n   elif thisclass is object:\n    tag='defined here'\n   else :\n    tag='inherited from %s'%self. classlink(thisclass,\n    object. __module__)\n   tag +=':<br>\\n'\n   \n   \n   attrs. sort(key=lambda t:t[0])\n   \n   \n   attrs=spill('Methods %s'%tag,attrs,\n   lambda t:t[1]=='method')\n   attrs=spill('Class methods %s'%tag,attrs,\n   lambda t:t[1]=='class method')\n   attrs=spill('Static methods %s'%tag,attrs,\n   lambda t:t[1]=='static method')\n   attrs=spilldescriptors('Data descriptors %s'%tag,attrs,\n   lambda t:t[1]=='data descriptor')\n   attrs=spilldata('Data and other attributes %s'%tag,attrs,\n   lambda t:t[1]=='data')\n   assert attrs ==[]\n   attrs=inherited\n   \n  contents=''. join(contents)\n  \n  if name ==realname:\n   title='<a name=\"%s\">class <strong>%s</strong></a>'%(\n   name,realname)\n  else :\n   title='<strong>%s</strong> = <a name=\"%s\">class %s</a>'%(\n   name,name,realname)\n  if bases:\n   parents=[]\n   for base in bases:\n    parents. append(self. classlink(base,object. __module__))\n   title=title+'(%s)'%', '. join(parents)\n  doc=self. markup(getdoc(object),self. preformat,funcs,classes,mdict)\n  doc=doc and'<tt>%s<br>&nbsp;</tt>'%doc\n  \n  return self. section(title,'#000000','#ffc8d8',contents,3,doc)\n  \n def formatvalue(self,object):\n  ''\n  return self. grey('='+self. repr(object))\n  \n def docroutine(self,object,name=None ,mod=None ,\n funcs={},classes={},methods={},cl=None ):\n  ''\n  realname=object. __name__\n  name=name or realname\n  anchor=(cl and cl. __name__ or'')+'-'+name\n  note=''\n  skipdocs=0\n  if inspect. ismethod(object):\n   imclass=object. __self__. __class__\n   if cl:\n    if imclass is not cl:\n     note=' from '+self. classlink(imclass,mod)\n   else :\n    if object. __self__ is not None :\n     note=' method of %s instance'%self. classlink(\n     object. __self__. __class__,mod)\n    else :\n     note=' unbound %s method'%self. classlink(imclass,mod)\n   object=object. __func__\n   \n  if name ==realname:\n   title='<a name=\"%s\"><strong>%s</strong></a>'%(anchor,realname)\n  else :\n   if (cl and realname in cl. __dict__ and\n   cl. __dict__[realname]is object):\n    reallink='<a href=\"#%s\">%s</a>'%(\n    cl. __name__+'-'+realname,realname)\n    skipdocs=1\n   else :\n    reallink=realname\n   title='<a name=\"%s\"><strong>%s</strong></a> = %s'%(\n   anchor,name,reallink)\n  if inspect. isfunction(object):\n   args,varargs,kwonlyargs,kwdefaults,varkw,defaults,ann=   inspect. getfullargspec(object)\n   argspec=inspect. formatargspec(\n   args,varargs,kwonlyargs,kwdefaults,varkw,defaults,ann,\n   formatvalue=self. formatvalue,\n   formatannotation=inspect. formatannotationrelativeto(object))\n   if realname =='<lambda>':\n    title='<strong>%s</strong> <em>lambda</em> '%name\n    \n    \n    \n    argspec=argspec[1:-1]\n  else :\n   argspec='(...)'\n   \n  decl=title+argspec+(note and self. grey(\n  '<font face=\"helvetica, arial\">%s</font>'%note))\n  \n  if skipdocs:\n   return'<dl><dt>%s</dt></dl>\\n'%decl\n  else :\n   doc=self. markup(\n   getdoc(object),self. preformat,funcs,classes,methods)\n   doc=doc and'<dd><tt>%s</tt></dd>'%doc\n   return'<dl><dt>%s</dt>%s</dl>\\n'%(decl,doc)\n   \n def _docdescriptor(self,name,value,mod):\n  results=[]\n  push=results. append\n  \n  if name:\n   push('<dl><dt><strong>%s</strong></dt>\\n'%name)\n  if value. __doc__ is not None :\n   doc=self. markup(getdoc(value),self. preformat)\n   push('<dd><tt>%s</tt></dd>\\n'%doc)\n  push('</dl>\\n')\n  \n  return''. join(results)\n  \n def docproperty(self,object,name=None ,mod=None ,cl=None ):\n  ''\n  return self. _docdescriptor(name,object,mod)\n  \n def docother(self,object,name=None ,mod=None ,*ignored):\n  ''\n  lhs=name and'<strong>%s</strong> = '%name or''\n  return lhs+self. repr(object)\n  \n def docdata(self,object,name=None ,mod=None ,cl=None ):\n  ''\n  return self. _docdescriptor(name,object,mod)\n  \n def index(self,dir,shadowed=None ):\n  ''\n  modpkgs=[]\n  if shadowed is None :shadowed={}\n  for importer,name,ispkg in pkgutil. iter_modules([dir]):\n   if any((0xD800 <=ord(ch)<=0xDFFF)for ch in name):\n   \n    continue\n   modpkgs. append((name,'',ispkg,name in shadowed))\n   shadowed[name]=1\n   \n  modpkgs. sort()\n  contents=self. multicolumn(modpkgs,self. modpkglink)\n  return self. bigsection(dir,'#ffffff','#ee77aa',contents)\n  \n  \n  \nclass TextRepr(Repr):\n ''\n def __init__(self):\n  Repr. __init__(self)\n  self. maxlist=self. maxtuple=20\n  self. maxdict=10\n  self. maxstring=self. maxother=100\n  \n  \n  \n  \n  \n  \n  \n  \n def repr_string(self,x,level):\n  test=cram(x,self. maxstring)\n  testrepr=repr(test)\n  if'\\\\'in test and'\\\\'not in replace(testrepr,r'\\\\',''):\n  \n  \n   return'r'+testrepr[0]+test+testrepr[0]\n  return testrepr\n  \n repr_str=repr_string\n \n def repr_instance(self,x,level):\n  try :\n   return cram(stripid(repr(x)),self. maxstring)\n  except :\n   return'<%s instance>'%x. __class__. __name__\n   \nclass TextDoc(Doc):\n ''\n \n \n \n _repr_instance=TextRepr()\n repr=_repr_instance. repr\n \n def bold(self,text):\n  ''\n  return''. join(ch+'\\b'+ch for ch in text)\n  \n def indent(self,text,prefix='    '):\n  ''\n  if not text:return''\n  lines=[prefix+line for line in text. split('\\n')]\n  if lines:lines[-1]=lines[-1]. rstrip()\n  return'\\n'. join(lines)\n  \n def section(self,title,contents):\n  ''\n  clean_contents=self. indent(contents). rstrip()\n  return self. bold(title)+'\\n'+clean_contents+'\\n\\n'\n  \n  \n  \n def formattree(self,tree,modname,parent=None ,prefix=''):\n  ''\n  result=''\n  for entry in tree:\n   if type(entry)is type(()):\n    c,bases=entry\n    result=result+prefix+classname(c,modname)\n    if bases and bases !=(parent,):\n     parents=(classname(c,modname)for c in bases)\n     result=result+'(%s)'%', '. join(parents)\n    result=result+'\\n'\n   elif type(entry)is type([]):\n    result=result+self. formattree(\n    entry,modname,c,prefix+'    ')\n  return result\n  \n def docmodule(self,object,name=None ,mod=None ):\n  ''\n  name=object. __name__\n  synop,desc=splitdoc(getdoc(object))\n  result=self. section('NAME',name+(synop and' - '+synop))\n  all=getattr(object,'__all__',None )\n  docloc=self. getdocloc(object)\n  if docloc is not None :\n   result=result+self. section('MODULE REFERENCE',docloc+\"\"\"\n\nThe following documentation is automatically generated from the Python\nsource files.  It may be incomplete, incorrect or include features that\nare considered implementation detail and may vary between Python\nimplementations.  When in doubt, consult the module reference at the\nlocation listed above.\n\"\"\")\n   \n  if desc:\n   result=result+self. section('DESCRIPTION',desc)\n   \n  classes=[]\n  for key,value in inspect. getmembers(object,inspect. isclass):\n  \n   if (all is not None\n   or (inspect. getmodule(value)or object)is object):\n    if visiblename(key,all,object):\n     classes. append((key,value))\n  funcs=[]\n  for key,value in inspect. getmembers(object,inspect. isroutine):\n  \n   if (all is not None or\n   inspect. isbuiltin(value)or inspect. getmodule(value)is object):\n    if visiblename(key,all,object):\n     funcs. append((key,value))\n  data=[]\n  for key,value in inspect. getmembers(object,isdata):\n   if visiblename(key,all,object):\n    data. append((key,value))\n    \n  modpkgs=[]\n  modpkgs_names=set()\n  if hasattr(object,'__path__'):\n   for importer,modname,ispkg in pkgutil. iter_modules(object. __path__):\n    modpkgs_names. add(modname)\n    if ispkg:\n     modpkgs. append(modname+' (package)')\n    else :\n     modpkgs. append(modname)\n     \n   modpkgs. sort()\n   result=result+self. section(\n   'PACKAGE CONTENTS','\\n'. join(modpkgs))\n   \n   \n  submodules=[]\n  for key,value in inspect. getmembers(object,inspect. ismodule):\n   if value. __name__. startswith(name+'.')and key not in modpkgs_names:\n    submodules. append(key)\n  if submodules:\n   submodules. sort()\n   result=result+self. section(\n   'SUBMODULES','\\n'. join(submodules))\n   \n  if classes:\n   classlist=[value for key,value in classes]\n   contents=[self. formattree(\n   inspect. getclasstree(classlist,1),name)]\n   for key,value in classes:\n    contents. append(self. document(value,key,name))\n   result=result+self. section('CLASSES','\\n'. join(contents))\n   \n  if funcs:\n   contents=[]\n   for key,value in funcs:\n    contents. append(self. document(value,key,name))\n   result=result+self. section('FUNCTIONS','\\n'. join(contents))\n   \n  if data:\n   contents=[]\n   for key,value in data:\n    contents. append(self. docother(value,key,name,maxlen=70))\n   result=result+self. section('DATA','\\n'. join(contents))\n   \n  if hasattr(object,'__version__'):\n   version=str(object. __version__)\n   if version[:11]=='$'+'Revision: 'and version[-1:]=='$':\n    version=version[11:-1]. strip()\n   result=result+self. section('VERSION',version)\n  if hasattr(object,'__date__'):\n   result=result+self. section('DATE',str(object. __date__))\n  if hasattr(object,'__author__'):\n   result=result+self. section('AUTHOR',str(object. __author__))\n  if hasattr(object,'__credits__'):\n   result=result+self. section('CREDITS',str(object. __credits__))\n  try :\n   file=inspect. getabsfile(object)\n  except TypeError:\n   file='(built-in)'\n  result=result+self. section('FILE',file)\n  return result\n  \n def docclass(self,object,name=None ,mod=None ,*ignored):\n  ''\n  realname=object. __name__\n  name=name or realname\n  bases=object. __bases__\n  \n  def makename(c,m=object. __module__):\n   return classname(c,m)\n   \n  if name ==realname:\n   title='class '+self. bold(realname)\n  else :\n   title=self. bold(name)+' = class '+realname\n  if bases:\n   parents=map(makename,bases)\n   title=title+'(%s)'%', '. join(parents)\n   \n  doc=getdoc(object)\n  contents=doc and [doc+'\\n']or []\n  push=contents. append\n  \n  \n  mro=deque(inspect. getmro(object))\n  if len(mro)>2:\n   push(\"Method resolution order:\")\n   for base in mro:\n    push('    '+makename(base))\n   push('')\n   \n   \n  class HorizontalRule:\n   def __init__(self):\n    self. needone=0\n   def maybe(self):\n    if self. needone:\n     push('-'*70)\n    self. needone=1\n  hr=HorizontalRule()\n  \n  def spill(msg,attrs,predicate):\n   ok,attrs=_split_list(attrs,predicate)\n   if ok:\n    hr. maybe()\n    push(msg)\n    for name,kind,homecls,value in ok:\n     try :\n      value=getattr(object,name)\n     except Exception:\n     \n     \n      push(self. _docdescriptor(name,value,mod))\n     else :\n      push(self. document(value,\n      name,mod,object))\n   return attrs\n   \n  def spilldescriptors(msg,attrs,predicate):\n   ok,attrs=_split_list(attrs,predicate)\n   if ok:\n    hr. maybe()\n    push(msg)\n    for name,kind,homecls,value in ok:\n     push(self. _docdescriptor(name,value,mod))\n   return attrs\n   \n  def spilldata(msg,attrs,predicate):\n   ok,attrs=_split_list(attrs,predicate)\n   if ok:\n    hr. maybe()\n    push(msg)\n    for name,kind,homecls,value in ok:\n     if callable(value)or inspect. isdatadescriptor(value):\n      doc=getdoc(value)\n     else :\n      doc=None\n     push(self. docother(getattr(object,name),\n     name,mod,maxlen=70,doc=doc)+'\\n')\n   return attrs\n   \n  attrs=[(name,kind,cls,value)\n  for name,kind,cls,value in classify_class_attrs(object)\n  if visiblename(name,obj=object)]\n  \n  while attrs:\n   if mro:\n    thisclass=mro. popleft()\n   else :\n    thisclass=attrs[0][2]\n   attrs,inherited=_split_list(attrs,lambda t:t[2]is thisclass)\n   \n   if thisclass is builtins. object:\n    attrs=inherited\n    continue\n   elif thisclass is object:\n    tag=\"defined here\"\n   else :\n    tag=\"inherited from %s\"%classname(thisclass,\n    object. __module__)\n    \n    \n   attrs. sort()\n   \n   \n   attrs=spill(\"Methods %s:\\n\"%tag,attrs,\n   lambda t:t[1]=='method')\n   attrs=spill(\"Class methods %s:\\n\"%tag,attrs,\n   lambda t:t[1]=='class method')\n   attrs=spill(\"Static methods %s:\\n\"%tag,attrs,\n   lambda t:t[1]=='static method')\n   attrs=spilldescriptors(\"Data descriptors %s:\\n\"%tag,attrs,\n   lambda t:t[1]=='data descriptor')\n   attrs=spilldata(\"Data and other attributes %s:\\n\"%tag,attrs,\n   lambda t:t[1]=='data')\n   assert attrs ==[]\n   attrs=inherited\n   \n  contents='\\n'. join(contents)\n  if not contents:\n   return title+'\\n'\n  return title+'\\n'+self. indent(contents. rstrip(),' |  ')+'\\n'\n  \n def formatvalue(self,object):\n  ''\n  return'='+self. repr(object)\n  \n def docroutine(self,object,name=None ,mod=None ,cl=None ):\n  ''\n  realname=object. __name__\n  name=name or realname\n  note=''\n  skipdocs=0\n  if inspect. ismethod(object):\n   imclass=object. __self__. __class__\n   if cl:\n    if imclass is not cl:\n     note=' from '+classname(imclass,mod)\n   else :\n    if object. __self__ is not None :\n     note=' method of %s instance'%classname(\n     object. __self__. __class__,mod)\n    else :\n     note=' unbound %s method'%classname(imclass,mod)\n   object=object. __func__\n   \n  if name ==realname:\n   title=self. bold(realname)\n  else :\n   if (cl and realname in cl. __dict__ and\n   cl. __dict__[realname]is object):\n    skipdocs=1\n   title=self. bold(name)+' = '+realname\n  if inspect. isfunction(object):\n   args,varargs,varkw,defaults,kwonlyargs,kwdefaults,ann=   inspect. getfullargspec(object)\n   argspec=inspect. formatargspec(\n   args,varargs,varkw,defaults,kwonlyargs,kwdefaults,ann,\n   formatvalue=self. formatvalue,\n   formatannotation=inspect. formatannotationrelativeto(object))\n   if realname =='<lambda>':\n    title=self. bold(name)+' lambda '\n    \n    \n    \n    argspec=argspec[1:-1]\n  else :\n   argspec='(...)'\n  decl=title+argspec+note\n  \n  if skipdocs:\n   return decl+'\\n'\n  else :\n   doc=getdoc(object)or''\n   return decl+'\\n'+(doc and self. indent(doc). rstrip()+'\\n')\n   \n def _docdescriptor(self,name,value,mod):\n  results=[]\n  push=results. append\n  \n  if name:\n   push(self. bold(name))\n   push('\\n')\n  doc=getdoc(value)or''\n  if doc:\n   push(self. indent(doc))\n   push('\\n')\n  return''. join(results)\n  \n def docproperty(self,object,name=None ,mod=None ,cl=None ):\n  ''\n  return self. _docdescriptor(name,object,mod)\n  \n def docdata(self,object,name=None ,mod=None ,cl=None ):\n  ''\n  return self. _docdescriptor(name,object,mod)\n  \n def docother(self,object,name=None ,mod=None ,parent=None ,maxlen=None ,doc=None ):\n  ''\n  repr=self. repr(object)\n  if maxlen:\n   line=(name and name+' = 'or'')+repr\n   chop=maxlen -len(line)\n   if chop <0:repr=repr[:chop]+'...'\n  line=(name and self. bold(name)+' = 'or'')+repr\n  if doc is not None :\n   line +='\\n'+self. indent(str(doc))\n  return line\n  \nclass _PlainTextDoc(TextDoc):\n ''\n def bold(self,text):\n  return text\n  \n  \n  \ndef pager(text):\n ''\n global pager\n pager=getpager()\n pager(text)\n \ndef getpager():\n ''\n if not hasattr(sys. stdout,\"isatty\"):\n  return plainpager\n if not sys. stdin. isatty()or not sys. stdout. isatty():\n  return plainpager\n if'PAGER'in os. environ:\n  if sys. platform =='win32':\n   return lambda text:tempfilepager(plain(text),os. environ['PAGER'])\n  elif os. environ. get('TERM')in ('dumb','emacs'):\n   return lambda text:pipepager(plain(text),os. environ['PAGER'])\n  else :\n   return lambda text:pipepager(text,os. environ['PAGER'])\n if os. environ. get('TERM')in ('dumb','emacs'):\n  return plainpager\n if sys. platform =='win32'or sys. platform. startswith('os2'):\n  return lambda text:tempfilepager(plain(text),'more <')\n if hasattr(os,'system')and os. system('(less) 2>/dev/null')==0:\n  return lambda text:pipepager(text,'less')\n  \n import tempfile\n (fd,filename)=tempfile. mkstemp()\n os. close(fd)\n try :\n  if hasattr(os,'system')and os. system('more \"%s\"'%filename)==0:\n   return lambda text:pipepager(text,'more')\n  else :\n   return ttypager\n finally :\n  os. unlink(filename)\n  \ndef plain(text):\n ''\n return re. sub('.\\b','',text)\n \ndef pipepager(text,cmd):\n ''\n pipe=os. popen(cmd,'w')\n try :\n  pipe. write(text)\n  pipe. close()\n except IOError:\n  pass\n  \ndef tempfilepager(text,cmd):\n ''\n import tempfile\n filename=tempfile. mktemp()\n file=open(filename,'w')\n file. write(text)\n file. close()\n try :\n  os. system(cmd+' \"'+filename+'\"')\n finally :\n  os. unlink(filename)\n  \ndef ttypager(text):\n ''\n lines=plain(text). split('\\n')\n try :\n  import tty\n  fd=sys. stdin. fileno()\n  old=tty. tcgetattr(fd)\n  tty. setcbreak(fd)\n  getchar=lambda :sys. stdin. read(1)\n except (ImportError,AttributeError):\n  tty=None\n  getchar=lambda :sys. stdin. readline()[:-1][:1]\n  \n try :\n  r=inc=os. environ. get('LINES',25)-1\n  sys. stdout. write('\\n'. join(lines[:inc])+'\\n')\n  while lines[r:]:\n   sys. stdout. write('-- more --')\n   sys. stdout. flush()\n   c=getchar()\n   \n   if c in ('q','Q'):\n    sys. stdout. write('\\r          \\r')\n    break\n   elif c in ('\\r','\\n'):\n    sys. stdout. write('\\r          \\r'+lines[r]+'\\n')\n    r=r+1\n    continue\n   if c in ('b','B','\\x1b'):\n    r=r -inc -inc\n    if r <0:r=0\n   sys. stdout. write('\\n'+'\\n'. join(lines[r:r+inc])+'\\n')\n   r=r+inc\n   \n finally :\n  if tty:\n   tty. tcsetattr(fd,tty. TCSAFLUSH,old)\n   \ndef plainpager(text):\n ''\n sys. stdout. write(plain(text))\n \ndef describe(thing):\n ''\n if inspect. ismodule(thing):\n  if thing. __name__ in sys. builtin_module_names:\n   return'built-in module '+thing. __name__\n  if hasattr(thing,'__path__'):\n   return'package '+thing. __name__\n  else :\n   return'module '+thing. __name__\n if inspect. isbuiltin(thing):\n  return'built-in function '+thing. __name__\n if inspect. isgetsetdescriptor(thing):\n  return'getset descriptor %s.%s.%s'%(\n  thing. __objclass__. __module__,thing. __objclass__. __name__,\n  thing. __name__)\n if inspect. ismemberdescriptor(thing):\n  return'member descriptor %s.%s.%s'%(\n  thing. __objclass__. __module__,thing. __objclass__. __name__,\n  thing. __name__)\n if inspect. isclass(thing):\n  return'class '+thing. __name__\n if inspect. isfunction(thing):\n  return'function '+thing. __name__\n if inspect. ismethod(thing):\n  return'method '+thing. __name__\n return type(thing). __name__\n \ndef locate(path,forceload=0):\n ''\n parts=[part for part in path. split('.')if part]\n module,n=None ,0\n while n <len(parts):\n  nextmodule=safeimport('.'. join(parts[:n+1]),forceload)\n  if nextmodule:module,n=nextmodule,n+1\n  else :break\n if module:\n  object=module\n else :\n  object=builtins\n for part in parts[n:]:\n  try :\n   object=getattr(object,part)\n  except AttributeError:\n   return None\n return object\n \n \n \ntext=TextDoc()\nplaintext=_PlainTextDoc()\nhtml=HTMLDoc()\n\ndef resolve(thing,forceload=0):\n ''\n if isinstance(thing,str):\n  object=locate(thing,forceload)\n  if not object:\n   raise ImportError('no Python documentation found for %r'%thing)\n  return object,thing\n else :\n  name=getattr(thing,'__name__',None )\n  return thing,name if isinstance(name,str)else None\n  \ndef render_doc(thing,title='Python Library Documentation: %s',forceload=0,\nrenderer=None ):\n ''\n if renderer is None :\n  renderer=text\n object,name=resolve(thing,forceload)\n desc=describe(object)\n module=inspect. getmodule(object)\n if name and'.'in name:\n  desc +=' in '+name[:name. rfind('.')]\n elif module and module is not object:\n  desc +=' in module '+module. __name__\n  \n if not (inspect. ismodule(object)or\n inspect. isclass(object)or\n inspect. isroutine(object)or\n inspect. isgetsetdescriptor(object)or\n inspect. ismemberdescriptor(object)or\n isinstance(object,property)):\n \n \n  object=type(object)\n  desc +=' object'\n return title %desc+'\\n\\n'+renderer. document(object,name)\n \ndef doc(thing,title='Python Library Documentation: %s',forceload=0,\noutput=None ):\n ''\n try :\n  if output is None :\n   pager(render_doc(thing,title,forceload))\n  else :\n   output. write(render_doc(thing,title,forceload,plaintext))\n except (ImportError,ErrorDuringImport)as value:\n  print(value)\n  \ndef writedoc(thing,forceload=0):\n ''\n try :\n  object,name=resolve(thing,forceload)\n  page=html. page(describe(object),html. document(object,name))\n  file=open(name+'.html','w',encoding='utf-8')\n  file. write(page)\n  file. close()\n  print('wrote',name+'.html')\n except (ImportError,ErrorDuringImport)as value:\n  print(value)\n  \ndef writedocs(dir,pkgpath='',done=None ):\n ''\n if done is None :done={}\n for importer,modname,ispkg in pkgutil. walk_packages([dir],pkgpath):\n  writedoc(modname)\n return\n \nclass Helper:\n\n\n\n\n\n\n\n\n\n\n\n\n keywords={\n 'False':'',\n 'None':'',\n 'True':'',\n 'and':'BOOLEAN',\n 'as':'with',\n 'assert':('assert',''),\n 'break':('break','while for'),\n 'class':('class','CLASSES SPECIALMETHODS'),\n 'continue':('continue','while for'),\n 'def':('function',''),\n 'del':('del','BASICMETHODS'),\n 'elif':'if',\n 'else':('else','while for'),\n 'except':'try',\n 'finally':'try',\n 'for':('for','break continue while'),\n 'from':'import',\n 'global':('global','nonlocal NAMESPACES'),\n 'if':('if','TRUTHVALUE'),\n 'import':('import','MODULES'),\n 'in':('in','SEQUENCEMETHODS'),\n 'is':'COMPARISON',\n 'lambda':('lambda','FUNCTIONS'),\n 'nonlocal':('nonlocal','global NAMESPACES'),\n 'not':'BOOLEAN',\n 'or':'BOOLEAN',\n 'pass':('pass',''),\n 'raise':('raise','EXCEPTIONS'),\n 'return':('return','FUNCTIONS'),\n 'try':('try','EXCEPTIONS'),\n 'while':('while','break continue if TRUTHVALUE'),\n 'with':('with','CONTEXTMANAGERS EXCEPTIONS yield'),\n 'yield':('yield',''),\n }\n \n \n _symbols_inverse={\n 'STRINGS':(\"'\",\"'''\",\"r'\",\"b'\",'\"\"\"','\"','r\"','b\"'),\n 'OPERATORS':('+','-','*','**','/','//','%','<<','>>','&',\n '|','^','~','<','>','<=','>=','==','!=','<>'),\n 'COMPARISON':('<','>','<=','>=','==','!=','<>'),\n 'UNARY':('-','~'),\n 'AUGMENTEDASSIGNMENT':('+=','-=','*=','/=','%=','&=','|=',\n '^=','<<=','>>=','**=','//='),\n 'BITWISE':('<<','>>','&','|','^','~'),\n 'COMPLEX':('j','J')\n }\n symbols={\n '%':'OPERATORS FORMATTING',\n '**':'POWER',\n ',':'TUPLES LISTS FUNCTIONS',\n '.':'ATTRIBUTES FLOAT MODULES OBJECTS',\n '...':'ELLIPSIS',\n ':':'SLICINGS DICTIONARYLITERALS',\n '@':'def class',\n '\\\\':'STRINGS',\n '_':'PRIVATENAMES',\n '__':'PRIVATENAMES SPECIALMETHODS',\n '`':'BACKQUOTES',\n '(':'TUPLES FUNCTIONS CALLS',\n ')':'TUPLES FUNCTIONS CALLS',\n '[':'LISTS SUBSCRIPTS SLICINGS',\n ']':'LISTS SUBSCRIPTS SLICINGS'\n }\n for topic,symbols_ in _symbols_inverse. items():\n  for symbol in symbols_:\n   topics=symbols. get(symbol,topic)\n   if topic not in topics:\n    topics=topics+' '+topic\n   symbols[symbol]=topics\n   \n topics={\n 'TYPES':('types','STRINGS UNICODE NUMBERS SEQUENCES MAPPINGS '\n 'FUNCTIONS CLASSES MODULES FILES inspect'),\n 'STRINGS':('strings','str UNICODE SEQUENCES STRINGMETHODS '\n 'FORMATTING TYPES'),\n 'STRINGMETHODS':('string-methods','STRINGS FORMATTING'),\n 'FORMATTING':('formatstrings','OPERATORS'),\n 'UNICODE':('strings','encodings unicode SEQUENCES STRINGMETHODS '\n 'FORMATTING TYPES'),\n 'NUMBERS':('numbers','INTEGER FLOAT COMPLEX TYPES'),\n 'INTEGER':('integers','int range'),\n 'FLOAT':('floating','float math'),\n 'COMPLEX':('imaginary','complex cmath'),\n 'SEQUENCES':('typesseq','STRINGMETHODS FORMATTING range LISTS'),\n 'MAPPINGS':'DICTIONARIES',\n 'FUNCTIONS':('typesfunctions','def TYPES'),\n 'METHODS':('typesmethods','class def CLASSES TYPES'),\n 'CODEOBJECTS':('bltin-code-objects','compile FUNCTIONS TYPES'),\n 'TYPEOBJECTS':('bltin-type-objects','types TYPES'),\n 'FRAMEOBJECTS':'TYPES',\n 'TRACEBACKS':'TYPES',\n 'NONE':('bltin-null-object',''),\n 'ELLIPSIS':('bltin-ellipsis-object','SLICINGS'),\n 'FILES':('bltin-file-objects',''),\n 'SPECIALATTRIBUTES':('specialattrs',''),\n 'CLASSES':('types','class SPECIALMETHODS PRIVATENAMES'),\n 'MODULES':('typesmodules','import'),\n 'PACKAGES':'import',\n 'EXPRESSIONS':('operator-summary','lambda or and not in is BOOLEAN '\n 'COMPARISON BITWISE SHIFTING BINARY FORMATTING POWER '\n 'UNARY ATTRIBUTES SUBSCRIPTS SLICINGS CALLS TUPLES '\n 'LISTS DICTIONARIES'),\n 'OPERATORS':'EXPRESSIONS',\n 'PRECEDENCE':'EXPRESSIONS',\n 'OBJECTS':('objects','TYPES'),\n 'SPECIALMETHODS':('specialnames','BASICMETHODS ATTRIBUTEMETHODS '\n 'CALLABLEMETHODS SEQUENCEMETHODS MAPPINGMETHODS '\n 'NUMBERMETHODS CLASSES'),\n 'BASICMETHODS':('customization','hash repr str SPECIALMETHODS'),\n 'ATTRIBUTEMETHODS':('attribute-access','ATTRIBUTES SPECIALMETHODS'),\n 'CALLABLEMETHODS':('callable-types','CALLS SPECIALMETHODS'),\n 'SEQUENCEMETHODS':('sequence-types','SEQUENCES SEQUENCEMETHODS '\n 'SPECIALMETHODS'),\n 'MAPPINGMETHODS':('sequence-types','MAPPINGS SPECIALMETHODS'),\n 'NUMBERMETHODS':('numeric-types','NUMBERS AUGMENTEDASSIGNMENT '\n 'SPECIALMETHODS'),\n 'EXECUTION':('execmodel','NAMESPACES DYNAMICFEATURES EXCEPTIONS'),\n 'NAMESPACES':('naming','global nonlocal ASSIGNMENT DELETION DYNAMICFEATURES'),\n 'DYNAMICFEATURES':('dynamic-features',''),\n 'SCOPING':'NAMESPACES',\n 'FRAMES':'NAMESPACES',\n 'EXCEPTIONS':('exceptions','try except finally raise'),\n 'CONVERSIONS':('conversions',''),\n 'IDENTIFIERS':('identifiers','keywords SPECIALIDENTIFIERS'),\n 'SPECIALIDENTIFIERS':('id-classes',''),\n 'PRIVATENAMES':('atom-identifiers',''),\n 'LITERALS':('atom-literals','STRINGS NUMBERS TUPLELITERALS '\n 'LISTLITERALS DICTIONARYLITERALS'),\n 'TUPLES':'SEQUENCES',\n 'TUPLELITERALS':('exprlists','TUPLES LITERALS'),\n 'LISTS':('typesseq-mutable','LISTLITERALS'),\n 'LISTLITERALS':('lists','LISTS LITERALS'),\n 'DICTIONARIES':('typesmapping','DICTIONARYLITERALS'),\n 'DICTIONARYLITERALS':('dict','DICTIONARIES LITERALS'),\n 'ATTRIBUTES':('attribute-references','getattr hasattr setattr ATTRIBUTEMETHODS'),\n 'SUBSCRIPTS':('subscriptions','SEQUENCEMETHODS'),\n 'SLICINGS':('slicings','SEQUENCEMETHODS'),\n 'CALLS':('calls','EXPRESSIONS'),\n 'POWER':('power','EXPRESSIONS'),\n 'UNARY':('unary','EXPRESSIONS'),\n 'BINARY':('binary','EXPRESSIONS'),\n 'SHIFTING':('shifting','EXPRESSIONS'),\n 'BITWISE':('bitwise','EXPRESSIONS'),\n 'COMPARISON':('comparisons','EXPRESSIONS BASICMETHODS'),\n 'BOOLEAN':('booleans','EXPRESSIONS TRUTHVALUE'),\n 'ASSERTION':'assert',\n 'ASSIGNMENT':('assignment','AUGMENTEDASSIGNMENT'),\n 'AUGMENTEDASSIGNMENT':('augassign','NUMBERMETHODS'),\n 'DELETION':'del',\n 'RETURNING':'return',\n 'IMPORTING':'import',\n 'CONDITIONAL':'if',\n 'LOOPING':('compound','for while break continue'),\n 'TRUTHVALUE':('truth','if while and or not BASICMETHODS'),\n 'DEBUGGING':('debugger','pdb'),\n 'CONTEXTMANAGERS':('context-managers','with'),\n }\n \n def __init__(self,input=None ,output=None ):\n  self. _input=input\n  self. _output=output\n  \n  \n  self. input=self. _input or sys. stdin\n  self. output=self. _output or sys. stdout\n  \n  \n  \n  \n  \n def __repr__(self):\n  if inspect. stack()[1][3]=='?':\n   self()\n   return''\n  return'<pydoc.Helper instance>'\n  \n _GoInteractive=object()\n def __call__(self,request=_GoInteractive):\n  if request is not self. _GoInteractive:\n   self. help(request)\n  else :\n   self. intro()\n   self. interact()\n   self. output. write('''\nYou are now leaving help and returning to the Python interpreter.\nIf you want to ask for help on a particular object directly from the\ninterpreter, you can type \"help(object)\".  Executing \"help('string')\"\nhas the same effect as typing a particular string at the help> prompt.\n''')\n   \n def interact(self):\n  self. output. write('\\n')\n  while True :\n   try :\n    request=self. getline('help> ')\n    if not request:break\n   except (KeyboardInterrupt,EOFError):\n    break\n   request=replace(request,'\"','',\"'\",''). strip()\n   if request. lower()in ('q','quit'):break\n   self. help(request)\n   \n def getline(self,prompt):\n  ''\n  if self. input is sys. stdin:\n   return input(prompt)\n  else :\n   self. output. write(prompt)\n   self. output. flush()\n   return self. input. readline()\n   \n def help(self,request):\n  if type(request)is type(''):\n   request=request. strip()\n   if request =='help':self. intro()\n   elif request =='keywords':self. listkeywords()\n   elif request =='symbols':self. listsymbols()\n   elif request =='topics':self. listtopics()\n   elif request =='modules':self. listmodules()\n   elif request[:8]=='modules ':\n    self. listmodules(request. split()[1])\n   elif request in self. symbols:self. showsymbol(request)\n   elif request in ['True','False','None']:\n   \n    doc(eval(request),'Help on %s:')\n   elif request in self. keywords:self. showtopic(request)\n   elif request in self. topics:self. showtopic(request)\n   elif request:doc(request,'Help on %s:',output=self. _output)\n  elif isinstance(request,Helper):self()\n  else :doc(request,'Help on %s:',output=self. _output)\n  self. output. write('\\n')\n  \n def intro(self):\n  self. output. write('''\nWelcome to Python %s!  This is the interactive help utility.\n\nIf this is your first time using Python, you should definitely check out\nthe tutorial on the Internet at http://docs.python.org/%s/tutorial/.\n\nEnter the name of any module, keyword, or topic to get help on writing\nPython programs and using Python modules.  To quit this help utility and\nreturn to the interpreter, just type \"quit\".\n\nTo get a list of available modules, keywords, or topics, type \"modules\",\n\"keywords\", or \"topics\".  Each module also comes with a one-line summary\nof what it does; to list the modules whose summaries contain a given word\nsuch as \"spam\", type \"modules spam\".\n'''%tuple([sys. version[:3]]*2))\n  \n def list(self,items,columns=4,width=80):\n  items=list(sorted(items))\n  colw=width //columns\n  rows=(len(items)+columns -1)//columns\n  for row in range(rows):\n   for col in range(columns):\n    i=col *rows+row\n    if i <len(items):\n     self. output. write(items[i])\n     if col <columns -1:\n      self. output. write(' '+' '*(colw -1 -len(items[i])))\n   self. output. write('\\n')\n   \n def listkeywords(self):\n  self. output. write('''\nHere is a list of the Python keywords.  Enter any keyword to get more help.\n\n''')\n  self. list(self. keywords. keys())\n  \n def listsymbols(self):\n  self. output. write('''\nHere is a list of the punctuation symbols which Python assigns special meaning\nto. Enter any symbol to get more help.\n\n''')\n  self. list(self. symbols. keys())\n  \n def listtopics(self):\n  self. output. write('''\nHere is a list of available topics.  Enter any topic name to get more help.\n\n''')\n  self. list(self. topics. keys())\n  \n def showtopic(self,topic,more_xrefs=''):\n  try :\n   import pydoc_data. topics\n  except ImportError:\n   self. output. write('''\nSorry, topic and keyword documentation is not available because the\nmodule \"pydoc_data.topics\" could not be found.\n''')\n   return\n  target=self. topics. get(topic,self. keywords. get(topic))\n  if not target:\n   self. output. write('no documentation found for %s\\n'%repr(topic))\n   return\n  if type(target)is type(''):\n   return self. showtopic(target,more_xrefs)\n   \n  label,xrefs=target\n  try :\n   doc=pydoc_data. topics. topics[label]\n  except KeyError:\n   self. output. write('no documentation found for %s\\n'%repr(topic))\n   return\n  pager(doc. strip()+'\\n')\n  if more_xrefs:\n   xrefs=(xrefs or'')+' '+more_xrefs\n  if xrefs:\n   import formatter\n   buffer=io. StringIO()\n   formatter. DumbWriter(buffer). send_flowing_data(\n   'Related help topics: '+', '. join(xrefs. split())+'\\n')\n   self. output. write('\\n%s\\n'%buffer. getvalue())\n   \n def _gettopic(self,topic,more_xrefs=''):\n  ''\n\n\n\n\n\n\n  \n  try :\n   import pydoc_data. topics\n  except ImportError:\n   return ('''\nSorry, topic and keyword documentation is not available because the\nmodule \"pydoc_data.topics\" could not be found.\n''','')\n  target=self. topics. get(topic,self. keywords. get(topic))\n  if not target:\n   raise ValueError('could not find topic')\n  if isinstance(target,str):\n   return self. _gettopic(target,more_xrefs)\n  label,xrefs=target\n  doc=pydoc_data. topics. topics[label]\n  if more_xrefs:\n   xrefs=(xrefs or'')+' '+more_xrefs\n  return doc,xrefs\n  \n def showsymbol(self,symbol):\n  target=self. symbols[symbol]\n  topic,_,xrefs=target. partition(' ')\n  self. showtopic(topic,xrefs)\n  \n def listmodules(self,key=''):\n  if key:\n   self. output. write('''\nHere is a list of matching modules.  Enter any module name to get more help.\n\n''')\n   apropos(key)\n  else :\n   self. output. write('''\nPlease wait a moment while I gather a list of all available modules...\n\n''')\n   modules={}\n   def callback(path,modname,desc,modules=modules):\n    if modname and modname[-9:]=='.__init__':\n     modname=modname[:-9]+' (package)'\n    if modname. find('.')<0:\n     modules[modname]=1\n   def onerror(modname):\n    callback(None ,modname,None )\n   ModuleScanner(). run(callback,onerror=onerror)\n   self. list(modules. keys())\n   self. output. write('''\nEnter any module name to get more help.  Or, type \"modules spam\" to search\nfor modules whose descriptions contain the word \"spam\".\n''')\n   \nhelp=Helper()\n\nclass Scanner:\n ''\n def __init__(self,roots,children,descendp):\n  self. roots=roots[:]\n  self. state=[]\n  self. children=children\n  self. descendp=descendp\n  \n def next(self):\n  if not self. state:\n   if not self. roots:\n    return None\n   root=self. roots. pop(0)\n   self. state=[(root,self. children(root))]\n  node,children=self. state[-1]\n  if not children:\n   self. state. pop()\n   return self. next()\n  child=children. pop(0)\n  if self. descendp(child):\n   self. state. append((child,self. children(child)))\n  return child\n  \n  \nclass ModuleScanner:\n ''\n \n def run(self,callback,key=None ,completer=None ,onerror=None ):\n  if key:key=key. lower()\n  self. quit=False\n  seen={}\n  \n  for modname in sys. builtin_module_names:\n   if modname !='__main__':\n    seen[modname]=1\n    if key is None :\n     callback(None ,modname,'')\n    else :\n     name=__import__(modname). __doc__ or''\n     desc=name. split('\\n')[0]\n     name=modname+' - '+desc\n     if name. lower(). find(key)>=0:\n      callback(None ,modname,desc)\n      \n  for importer,modname,ispkg in pkgutil. walk_packages(onerror=onerror):\n   if self. quit:\n    break\n    \n   if key is None :\n    callback(None ,modname,'')\n   else :\n    try :\n     loader=importer. find_module(modname)\n    except SyntaxError:\n    \n     continue\n    if hasattr(loader,'get_source'):\n     try :\n      source=loader. get_source(modname)\n     except Exception:\n      if onerror:\n       onerror(modname)\n      continue\n     desc=source_synopsis(io. StringIO(source))or''\n     if hasattr(loader,'get_filename'):\n      path=loader. get_filename(modname)\n     else :\n      path=None\n    else :\n     try :\n      module=loader. load_module(modname)\n     except ImportError:\n      if onerror:\n       onerror(modname)\n      continue\n     desc=(module. __doc__ or''). splitlines()[0]\n     path=getattr(module,'__file__',None )\n    name=modname+' - '+desc\n    if name. lower(). find(key)>=0:\n     callback(path,modname,desc)\n     \n  if completer:\n   completer()\n   \ndef apropos(key):\n ''\n def callback(path,modname,desc):\n  if modname[-9:]=='.__init__':\n   modname=modname[:-9]+' (package)'\n  print(modname,desc and'- '+desc)\n def onerror(modname):\n  pass\n with warnings. catch_warnings():\n  warnings. filterwarnings('ignore')\n  ModuleScanner(). run(callback,key,onerror=onerror)\n  \n  \n  \ndef _start_server(urlhandler,port):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n import http. server\n import email. message\n import select\n import threading\n \n class DocHandler(http. server. BaseHTTPRequestHandler):\n \n  def do_GET(self):\n   ''\n\n\n\n   \n   if self. path. endswith('.css'):\n    content_type='text/css'\n   else :\n    content_type='text/html'\n   self. send_response(200)\n   self. send_header('Content-Type','%s; charset=UTF-8'%content_type)\n   self. end_headers()\n   self. wfile. write(self. urlhandler(\n   self. path,content_type). encode('utf-8'))\n   \n  def log_message(self,*args):\n  \n   pass\n   \n class DocServer(http. server. HTTPServer):\n \n  def __init__(self,port,callback):\n   self. host=(sys. platform =='mac')and'127.0.0.1'or'localhost'\n   self. address=('',port)\n   self. callback=callback\n   self. base. __init__(self,self. address,self. handler)\n   self. quit=False\n   \n  def serve_until_quit(self):\n   while not self. quit:\n    rd,wr,ex=select. select([self. socket. fileno()],[],[],1)\n    if rd:\n     self. handle_request()\n   self. server_close()\n   \n  def server_activate(self):\n   self. base. server_activate(self)\n   if self. callback:\n    self. callback(self)\n    \n class ServerThread(threading. Thread):\n \n  def __init__(self,urlhandler,port):\n   self. urlhandler=urlhandler\n   self. port=int(port)\n   threading. Thread. __init__(self)\n   self. serving=False\n   self. error=None\n   \n  def run(self):\n   ''\n   try :\n    DocServer. base=http. server. HTTPServer\n    DocServer. handler=DocHandler\n    DocHandler. MessageClass=email. message. Message\n    DocHandler. urlhandler=staticmethod(self. urlhandler)\n    docsvr=DocServer(self. port,self. ready)\n    self. docserver=docsvr\n    docsvr. serve_until_quit()\n   except Exception as e:\n    self. error=e\n    \n  def ready(self,server):\n   self. serving=True\n   self. host=server. host\n   self. port=server. server_port\n   self. url='http://%s:%d/'%(self. host,self. port)\n   \n  def stop(self):\n   ''\n   self. docserver. quit=True\n   self. serving=False\n   self. url=None\n   \n thread=ServerThread(urlhandler,port)\n thread. start()\n \n \n while not thread. error and not thread. serving:\n  time. sleep(.01)\n return thread\n \n \ndef _url_handler(url,content_type=\"text/html\"):\n ''\n\n\n\n\n\n\n \n class _HTMLDoc(HTMLDoc):\n \n  def page(self,title,contents):\n   ''\n   css_path=\"pydoc_data/_pydoc.css\"\n   css_link=(\n   '<link rel=\"stylesheet\" type=\"text/css\" href=\"%s\">'%\n   css_path)\n   return'''\\\n<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n<html><head><title>Pydoc: %s</title>\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n%s</head><body bgcolor=\"#f0f0f8\">%s<div style=\"clear:both;padding-top:.5em;\">%s</div>\n</body></html>'''%(title,css_link,html_navbar(),contents)\n   \n  def filelink(self,url,path):\n   return'<a href=\"getfile?key=%s\">%s</a>'%(url,path)\n   \n   \n html=_HTMLDoc()\n \n def html_navbar():\n  version=html. escape(\"%s [%s, %s]\"%(platform. python_version(),\n  platform. python_build()[0],\n  platform. python_compiler()))\n  return\"\"\"\n            <div style='float:left'>\n                Python %s<br>%s\n            </div>\n            <div style='float:right'>\n                <div style='text-align:center'>\n                  <a href=\"index.html\">Module Index</a>\n                  : <a href=\"topics.html\">Topics</a>\n                  : <a href=\"keywords.html\">Keywords</a>\n                </div>\n                <div>\n                    <form action=\"get\" style='display:inline;'>\n                      <input type=text name=key size=15>\n                      <input type=submit value=\"Get\">\n                    </form>&nbsp;\n                    <form action=\"search\" style='display:inline;'>\n                      <input type=text name=key size=15>\n                      <input type=submit value=\"Search\">\n                    </form>\n                </div>\n            </div>\n            \"\"\"%(version,html. escape(platform. platform(terse=True )))\n  \n def html_index():\n  ''\n  \n  def bltinlink(name):\n   return'<a href=\"%s.html\">%s</a>'%(name,name)\n   \n  heading=html. heading(\n  '<big><big><strong>Index of Modules</strong></big></big>',\n  '#ffffff','#7799ee')\n  names=[name for name in sys. builtin_module_names\n  if name !='__main__']\n  contents=html. multicolumn(names,bltinlink)\n  contents=[heading,'<p>'+html. bigsection(\n  'Built-in Modules','#ffffff','#ee77aa',contents)]\n  \n  seen={}\n  for dir in sys. path:\n   contents. append(html. index(dir,seen))\n   \n  contents. append(\n  '<p align=right><font color=\"#909090\" face=\"helvetica,'\n  'arial\"><strong>pydoc</strong> by Ka-Ping Yee'\n  '&lt;ping@lfw.org&gt;</font>')\n  return'Index of Modules',''. join(contents)\n  \n def html_search(key):\n  ''\n  \n  search_result=[]\n  \n  def callback(path,modname,desc):\n   if modname[-9:]=='.__init__':\n    modname=modname[:-9]+' (package)'\n   search_result. append((modname,desc and'- '+desc))\n   \n  with warnings. catch_warnings():\n   warnings. filterwarnings('ignore')\n   ModuleScanner(). run(callback,key)\n   \n   \n  def bltinlink(name):\n   return'<a href=\"%s.html\">%s</a>'%(name,name)\n   \n  results=[]\n  heading=html. heading(\n  '<big><big><strong>Search Results</strong></big></big>',\n  '#ffffff','#7799ee')\n  for name,desc in search_result:\n   results. append(bltinlink(name)+desc)\n  contents=heading+html. bigsection(\n  'key = %s'%key,'#ffffff','#ee77aa','<br>'. join(results))\n  return'Search Results',contents\n  \n def html_getfile(path):\n  ''\n  path=path. replace('%20',' ')\n  with tokenize. open(path)as fp:\n   lines=html. escape(fp. read())\n  body='<pre>%s</pre>'%lines\n  heading=html. heading(\n  '<big><big><strong>File Listing</strong></big></big>',\n  '#ffffff','#7799ee')\n  contents=heading+html. bigsection(\n  'File: %s'%path,'#ffffff','#ee77aa',body)\n  return'getfile %s'%path,contents\n  \n def html_topics():\n  ''\n  \n  def bltinlink(name):\n   return'<a href=\"topic?key=%s\">%s</a>'%(name,name)\n   \n  heading=html. heading(\n  '<big><big><strong>INDEX</strong></big></big>',\n  '#ffffff','#7799ee')\n  names=sorted(Helper. topics. keys())\n  \n  contents=html. multicolumn(names,bltinlink)\n  contents=heading+html. bigsection(\n  'Topics','#ffffff','#ee77aa',contents)\n  return'Topics',contents\n  \n def html_keywords():\n  ''\n  heading=html. heading(\n  '<big><big><strong>INDEX</strong></big></big>',\n  '#ffffff','#7799ee')\n  names=sorted(Helper. keywords. keys())\n  \n  def bltinlink(name):\n   return'<a href=\"topic?key=%s\">%s</a>'%(name,name)\n   \n  contents=html. multicolumn(names,bltinlink)\n  contents=heading+html. bigsection(\n  'Keywords','#ffffff','#ee77aa',contents)\n  return'Keywords',contents\n  \n def html_topicpage(topic):\n  ''\n  buf=io. StringIO()\n  htmlhelp=Helper(buf,buf)\n  contents,xrefs=htmlhelp. _gettopic(topic)\n  if topic in htmlhelp. keywords:\n   title='KEYWORD'\n  else :\n   title='TOPIC'\n  heading=html. heading(\n  '<big><big><strong>%s</strong></big></big>'%title,\n  '#ffffff','#7799ee')\n  contents='<pre>%s</pre>'%html. markup(contents)\n  contents=html. bigsection(topic,'#ffffff','#ee77aa',contents)\n  if xrefs:\n   xrefs=sorted(xrefs. split())\n   \n   def bltinlink(name):\n    return'<a href=\"topic?key=%s\">%s</a>'%(name,name)\n    \n   xrefs=html. multicolumn(xrefs,bltinlink)\n   xrefs=html. section('Related help topics: ',\n   '#ffffff','#ee77aa',xrefs)\n  return ('%s %s'%(title,topic),\n  ''. join((heading,contents,xrefs)))\n  \n def html_getobj(url):\n  obj=locate(url,forceload=1)\n  if obj is None and url !='None':\n   raise ValueError('could not find object')\n  title=describe(obj)\n  content=html. document(obj,url)\n  return title,content\n  \n def html_error(url,exc):\n  heading=html. heading(\n  '<big><big><strong>Error</strong></big></big>',\n  '#ffffff','#7799ee')\n  contents='<br>'. join(html. escape(line)for line in\n  format_exception_only(type(exc),exc))\n  contents=heading+html. bigsection(url,'#ffffff','#bb0000',\n  contents)\n  return\"Error - %s\"%url,contents\n  \n def get_html_page(url):\n  ''\n  complete_url=url\n  if url. endswith('.html'):\n   url=url[:-5]\n  try :\n   if url in (\"\",\"index\"):\n    title,content=html_index()\n   elif url ==\"topics\":\n    title,content=html_topics()\n   elif url ==\"keywords\":\n    title,content=html_keywords()\n   elif'='in url:\n    op,_,url=url. partition('=')\n    if op ==\"search?key\":\n     title,content=html_search(url)\n    elif op ==\"getfile?key\":\n     title,content=html_getfile(url)\n    elif op ==\"topic?key\":\n    \n     try :\n      title,content=html_topicpage(url)\n     except ValueError:\n      title,content=html_getobj(url)\n    elif op ==\"get?key\":\n    \n     if url in (\"\",\"index\"):\n      title,content=html_index()\n     else :\n      try :\n       title,content=html_getobj(url)\n      except ValueError:\n       title,content=html_topicpage(url)\n    else :\n     raise ValueError('bad pydoc url')\n   else :\n    title,content=html_getobj(url)\n  except Exception as exc:\n  \n   title,content=html_error(complete_url,exc)\n  return html. page(title,content)\n  \n if url. startswith('/'):\n  url=url[1:]\n if content_type =='text/css':\n  path_here=os. path. dirname(os. path. realpath(__file__))\n  css_path=os. path. join(path_here,url)\n  with open(css_path)as fp:\n   return''. join(fp. readlines())\n elif content_type =='text/html':\n  return get_html_page(url)\n  \n raise TypeError('unknown content type %r for url %s'%(content_type,url))\n \n \ndef browse(port=0,*,open_browser=True ):\n ''\n\n\n\n \n import webbrowser\n serverthread=_start_server(_url_handler,port)\n if serverthread. error:\n  print(serverthread. error)\n  return\n if serverthread. serving:\n  server_help_msg='Server commands: [b]rowser, [q]uit'\n  if open_browser:\n   webbrowser. open(serverthread. url)\n  try :\n   print('Server ready at',serverthread. url)\n   print(server_help_msg)\n   while serverthread. serving:\n    cmd=input('server> ')\n    cmd=cmd. lower()\n    if cmd =='q':\n     break\n    elif cmd =='b':\n     webbrowser. open(serverthread. url)\n    else :\n     print(server_help_msg)\n  except (KeyboardInterrupt,EOFError):\n   print()\n  finally :\n   if serverthread. serving:\n    serverthread. stop()\n    print('Server stopped')\n    \n    \n    \n    \ndef ispath(x):\n return isinstance(x,str)and x. find(os. sep)>=0\n \ndef cli():\n ''\n import getopt\n class BadUsage(Exception):pass\n \n \n \n if''not in sys. path:\n  scriptdir=os. path. dirname(sys. argv[0])\n  if scriptdir in sys. path:\n   sys. path. remove(scriptdir)\n  sys. path. insert(0,'.')\n  \n try :\n  opts,args=getopt. getopt(sys. argv[1:],'bk:p:w')\n  writing=False\n  start_server=False\n  open_browser=False\n  port=None\n  for opt,val in opts:\n   if opt =='-b':\n    start_server=True\n    open_browser=True\n   if opt =='-k':\n    apropos(val)\n    return\n   if opt =='-p':\n    start_server=True\n    port=val\n   if opt =='-w':\n    writing=True\n    \n  if start_server:\n   if port is None :\n    port=0\n   browse(port,open_browser=open_browser)\n   return\n   \n  if not args:raise BadUsage\n  for arg in args:\n   if ispath(arg)and not os. path. exists(arg):\n    print('file %r does not exist'%arg)\n    break\n   try :\n    if ispath(arg)and os. path. isfile(arg):\n     arg=importfile(arg)\n    if writing:\n     if ispath(arg)and os. path. isdir(arg):\n      writedocs(arg)\n     else :\n      writedoc(arg)\n    else :\n     help. help(arg)\n   except ErrorDuringImport as value:\n    print(value)\n    \n except (getopt. error,BadUsage):\n  cmd=os. path. splitext(os. path. basename(sys. argv[0]))[0]\n  print(\"\"\"pydoc - the Python documentation tool\n\n{cmd} <name> ...\n    Show text documentation on something.  <name> may be the name of a\n    Python keyword, topic, function, module, or package, or a dotted\n    reference to a class or function within a module or module in a\n    package.  If <name> contains a '{sep}', it is used as the path to a\n    Python source file to document. If name is 'keywords', 'topics',\n    or 'modules', a listing of these things is displayed.\n\n{cmd} -k <keyword>\n    Search for a keyword in the synopsis lines of all available modules.\n\n{cmd} -p <port>\n    Start an HTTP server on the given port on the local machine.  Port\n    number 0 can be used to get an arbitrary unused port.\n\n{cmd} -b\n    Start an HTTP server on an arbitrary unused port and open a Web browser\n    to interactively browse documentation.  The -p option can be used with\n    the -b option to explicitly specify the server port.\n\n{cmd} -w <name> ...\n    Write out the HTML documentation for a module to a file in the current\n    directory.  If <name> contains a '{sep}', it is treated as a filename; if\n    it names a directory, documentation is written for all the contents.\n\"\"\". format(cmd=cmd,sep=os. sep))\n  \nif __name__ =='__main__':\n cli()\n", ["builtins", "collections", "email.message", "formatter", "getopt", "http.server", "imp", "importlib.machinery", "inspect", "io", "nturl2path", "os", "platform", "pydoc_data.topics", "re", "reprlib", "select", "sys", "tempfile", "threading", "time", "tokenize", "tty", "warnings", "webbrowser"]], "struct": [".py", "__all__=[\n\n'calcsize','pack','pack_into','unpack','unpack_from',\n\n\n'Struct',\n\n\n'error'\n]\n\nfrom _struct import *\nfrom _struct import _clearcache\nfrom _struct import __doc__\n", ["_struct"]], "_weakrefset": [".py", "\n\n\n\nfrom _weakref import ref\n\n__all__=['WeakSet']\n\n\nclass _IterationGuard:\n\n\n\n\n\n def __init__(self,weakcontainer):\n \n  self. weakcontainer=ref(weakcontainer)\n  \n def __enter__(self):\n  w=self. weakcontainer()\n  if w is not None :\n   w. _iterating. add(self)\n  return self\n  \n def __exit__(self,e,t,b):\n  w=self. weakcontainer()\n  if w is not None :\n   s=w. _iterating\n   s. remove(self)\n   if not s:\n    w. _commit_removals()\n    \n    \nclass WeakSet:\n def __init__(self,data=None ):\n  self. data=set()\n  def _remove(item,selfref=ref(self)):\n   self=selfref()\n   if self is not None :\n    if self. _iterating:\n     self. _pending_removals. append(item)\n    else :\n     self. data. discard(item)\n  self. _remove=_remove\n  \n  self. _pending_removals=[]\n  self. _iterating=set()\n  if data is not None :\n   self. update(data)\n   \n def _commit_removals(self):\n  l=self. _pending_removals\n  discard=self. data. discard\n  while l:\n   discard(l. pop())\n   \n def __iter__(self):\n  with _IterationGuard(self):\n   for itemref in self. data:\n    item=itemref()\n    if item is not None :\n     yield item\n     \n def __len__(self):\n  return len(self. data)-len(self. _pending_removals)\n  \n def __contains__(self,item):\n  try :\n   wr=ref(item)\n  except TypeError:\n   return False\n  return wr in self. data\n  \n def __reduce__(self):\n  return (self. __class__,(list(self),),\n  getattr(self,'__dict__',None ))\n  \n def add(self,item):\n  if self. _pending_removals:\n   self. _commit_removals()\n  self. data. add(ref(item,self. _remove))\n  \n def clear(self):\n  if self. _pending_removals:\n   self. _commit_removals()\n  self. data. clear()\n  \n def copy(self):\n  return self. __class__(self)\n  \n def pop(self):\n  if self. _pending_removals:\n   self. _commit_removals()\n  while True :\n   try :\n    itemref=self. data. pop()\n   except KeyError:\n    raise KeyError('pop from empty WeakSet')\n   item=itemref()\n   if item is not None :\n    return item\n    \n def remove(self,item):\n  if self. _pending_removals:\n   self. _commit_removals()\n  self. data. remove(ref(item))\n  \n def discard(self,item):\n  if self. _pending_removals:\n   self. _commit_removals()\n  self. data. discard(ref(item))\n  \n def update(self,other):\n  if self. _pending_removals:\n   self. _commit_removals()\n  for element in other:\n   self. add(element)\n   \n def __ior__(self,other):\n  self. update(other)\n  return self\n  \n def difference(self,other):\n  newset=self. copy()\n  newset. difference_update(other)\n  return newset\n __sub__=difference\n \n def difference_update(self,other):\n  self. __isub__(other)\n def __isub__(self,other):\n  if self. _pending_removals:\n   self. _commit_removals()\n  if self is other:\n   self. data. clear()\n  else :\n   self. data. difference_update(ref(item)for item in other)\n  return self\n  \n def intersection(self,other):\n  return self. __class__(item for item in other if item in self)\n __and__=intersection\n \n def intersection_update(self,other):\n  self. __iand__(other)\n def __iand__(self,other):\n  if self. _pending_removals:\n   self. _commit_removals()\n  self. data. intersection_update(ref(item)for item in other)\n  return self\n  \n def issubset(self,other):\n  return self. data. issubset(ref(item)for item in other)\n __le__=issubset\n \n def __lt__(self,other):\n  return self. data <set(ref(item)for item in other)\n  \n def issuperset(self,other):\n  return self. data. issuperset(ref(item)for item in other)\n __ge__=issuperset\n \n def __gt__(self,other):\n  return self. data >set(ref(item)for item in other)\n  \n def __eq__(self,other):\n  if not isinstance(other,self. __class__):\n   return NotImplemented\n  return self. data ==set(ref(item)for item in other)\n  \n def symmetric_difference(self,other):\n  newset=self. copy()\n  newset. symmetric_difference_update(other)\n  return newset\n __xor__=symmetric_difference\n \n def symmetric_difference_update(self,other):\n  self. __ixor__(other)\n def __ixor__(self,other):\n  if self. _pending_removals:\n   self. _commit_removals()\n  if self is other:\n   self. data. clear()\n  else :\n   self. data. symmetric_difference_update(ref(item,self. _remove)for item in other)\n  return self\n  \n def union(self,other):\n  return self. __class__(e for s in (self,other)for e in s)\n __or__=union\n \n def isdisjoint(self,other):\n  return len(self. intersection(other))==0\n", ["_weakref"]], "posix": [".py", "''\n\n\n\n\nfrom browser import window\n\ndef _randint(a,b):\n return int(window. Math. random()*(b -a+1)+a)\n \nF_OK=0\n\nO_APPEND=8\n\nO_BINARY=32768\n\nO_CREAT=256\n\nO_EXCL=1024\n\nO_NOINHERIT=128\n\nO_RANDOM=16\n\nO_RDONLY=0\n\nO_RDWR=2\n\nO_SEQUENTIAL=32\n\nO_SHORT_LIVED=4096\n\nO_TEMPORARY=64\n\nO_TEXT=16384\n\nO_TRUNC=512\n\nO_WRONLY=1\n\nP_DETACH=4\n\nP_NOWAIT=1\n\nP_NOWAITO=3\n\nP_OVERLAY=2\n\nP_WAIT=0\n\nR_OK=4\n\nTMP_MAX=32767\n\nW_OK=2\n\nX_OK=1\n\nclass __loader__:\n pass\n \ndef _exit(*args,**kw):\n ''\n \n pass\n \ndef _getdiskusage(*args,**kw):\n ''\n \n pass\n \ndef _getfileinformation(*args,**kw):\n pass\n \ndef _getfinalpathname(*args,**kw):\n pass\n \ndef _getfullpathname(*args,**kw):\n pass\n \n_have_functions=['MS_WINDOWS']\n\ndef _isdir(*args,**kw):\n ''\n pass\n \ndef abort(*args,**kw):\n ''\n\n \n pass\n \ndef access(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef chdir(*args,**kw):\n ''\n\n\n\n\n \n pass\n \ndef chmod(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef close(*args,**kw):\n ''\n \n pass\n \ndef closerange(*args,**kw):\n ''\n \n pass\n \ndef device_encoding(*args,**kw):\n ''\n\n \n pass\n \ndef dup(*args,**kw):\n ''\n \n pass\n \ndef dup2(*args,**kw):\n ''\n \n pass\n \nenviron={'PYTHONUSERBASE':' '}\n\nerror=OSError\n\ndef execv(*args,**kw):\n ''\n\n\n\n \n pass\n \ndef execve(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n \n pass\n \ndef fstat(*args,**kw):\n ''\n\n \n pass\n \ndef fsync(*args,**kw):\n ''\n \n pass\n \ndef get_terminal_size(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef getcwd(*args,**kw):\n ''\n \n return __BRYTHON__. brython_path\n \ndef getcwdb(*args,**kw):\n ''\n \n pass\n \ndef getlogin(*args,**kw):\n ''\n \n pass\n \ndef getpid(*args,**kw):\n ''\n \n return 0\n \ndef getppid(*args,**kw):\n ''\n\n\n \n pass\n \ndef isatty(*args,**kw):\n ''\n\n \n pass\n \ndef kill(*args,**kw):\n ''\n \n pass\n \ndef link(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef listdir(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n \n raise NotImplementedError(\"browser can't list files in a directory\")\n \ndef lseek(*args,**kw):\n ''\n\n \n pass\n \ndef lstat(*args,**kw):\n ''\n\n \n return stat_result()\n \ndef mkdir(*args,**kw):\n ''\n\n\n\n\n\n\n\n \n pass\n \ndef open(path,flags,mode=0o777,*args,dir_fd=None ):\n ''\n\n\n\n\n\n \n \n \n from browser. local_storage import storage\n \n class mystorage:\n  def __init__(self,path,flags):\n   self. _path=path\n   self. _pos=0\n   self. _flags=flags\n   \n   if self. _flags&O_RDONLY ==O_RDONLY:\n    self. _data=storage. get(self. _path,None )\n    if self. _data is None :\n     raise FileNotFoundError(\"%s not found\"%self. _path)\n   elif self. _flags&O_WRONLY ==O_WRONLY:\n    storage[self. _path]=''\n    \n  def seek(self,pos):\n   self. _pos=pos\n   \n  def read(self,size=None ):\n   if size is None :\n    _result=self. _data[self. _pos:]\n    self. _pos=len(self. _data)\n    return _result\n    \n   assert size <=len(self. _data)-self. _pos\n   _result=self. _data[self. _pos:self. _pos+size]\n   self. _pos +=size\n   return _result\n   \n  def write(self,data):\n   storage[self. _path]+=str(data)\n   \n  def close(self):\n   pass\n   \n return mystorage(path,flags)\n \ndef pipe(*args,**kw):\n ''\n \n pass\n \ndef putenv(*args,**kw):\n ''\n \n pass\n \ndef read(*args,**kw):\n ''\n \n pass\n \ndef readlink(*args,**kw):\n ''\n\n\n\n\n\n \n pass\n \ndef remove(*args,**kw):\n ''\n\n\n\n\n\n \n pass\n \ndef rename(*args,**kw):\n ''\n\n\n\n\n\n\n \n pass\n \ndef replace(*args,**kw):\n ''\n\n\n\n\n\n\n \n pass\n \ndef rmdir(*args,**kw):\n ''\n\n\n\n\n\n \n pass\n \ndef spawnv(*args,**kw):\n ''\n\n\n\n\n \n pass\n \ndef spawnve(*args,**kw):\n ''\n\n\n\n\n\n \n pass\n \ndef startfile(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef stat(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n \n return stat_result()\n \ndef stat_float_times(*args,**kw):\n ''\n\n\n\n\n \n pass\n \nclass stat_result:\n\n def __init__(self):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  self. st_atime=window. Date. new()\n  self. st_mtime=self. st_ctime=self. st_atime_ns=  self. st_mtime_ns=self. st_ctime_ns=self. st_atime\n  self. st_uid=self. st_gid=self. st_ino=-1\n  self. st_mode=0\n  self. st_size=1\n  \nclass statvfs_result:\n pass\n \ndef strerror(*args,**kw):\n ''\n \n pass\n \ndef symlink(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef system(*args,**kw):\n ''\n \n pass\n \nclass terminal_size:\n pass\n \ndef times(*args,**kw):\n ''\n\n\n \n pass\n \nclass times_result:\n pass\n \ndef umask(*args,**kw):\n ''\n \n pass\n \nclass uname_result:\n pass\n \ndef unlink(path,*args,dir_fd=None ):\n ''\n\n\n\n\n\n \n pass\n \ndef urandom(n):\n ''\n \n randbytes=[_randint(0,255)for i in range(n)]\n return bytes(randbytes)\n \ndef utime(*args,**kw):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n pass\n \ndef waitpid(*args,**kw):\n ''\n \n pass\n \ndef write(*args,**kw):\n ''\n \n pass\n \n \n \ndef WIFSIGNALED(a):\n return False\n \ndef WTERMSIG(status):\n return 0\n \ndef WIFSIGNALED(status):\n ''\n return False\n \ndef WIFEXITED(status):\n return False\n \ndef WEXITSTATUS(status):\n pass\n \ndef WNOHANG():\n return (0,0)\n", ["browser", "browser.local_storage"]], "gettext": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nimport locale,copy,io,os,re,struct,sys\nfrom errno import ENOENT\n\n\n__all__=['NullTranslations','GNUTranslations','Catalog',\n'find','translation','install','textdomain','bindtextdomain',\n'dgettext','dngettext','gettext','ngettext',\n]\n\n_default_localedir=os. path. join(sys. base_prefix,'share','locale')\n\n\ndef c2py(plural):\n ''\n\n \n \n import token,tokenize\n tokens=tokenize. generate_tokens(io. StringIO(plural). readline)\n try :\n  danger=[x for x in tokens if x[0]==token. NAME and x[1]!='n']\n except tokenize. TokenError:\n  raise ValueError('plural forms expression error, maybe unbalanced parenthesis')\n else :\n  if danger:\n   raise ValueError('plural forms expression could be dangerous')\n   \n   \n plural=plural. replace('&&',' and ')\n plural=plural. replace('||',' or ')\n \n expr=re. compile(r'\\!([^=])')\n plural=expr. sub(' not \\\\1',plural)\n \n \n \n expr=re. compile(r'(.*?)\\?(.*?):(.*)')\n def repl(x):\n  return\"(%s if %s else %s)\"%(x. group(2),x. group(1),\n  expr. sub(repl,x. group(3)))\n  \n  \n stack=['']\n for c in plural:\n  if c =='(':\n   stack. append('')\n  elif c ==')':\n   if len(stack)==1:\n   \n   \n   \n    raise ValueError('unbalanced parenthesis in plural form')\n   s=expr. sub(repl,stack. pop())\n   stack[-1]+='(%s)'%s\n  else :\n   stack[-1]+=c\n plural=expr. sub(repl,stack. pop())\n \n return eval('lambda n: int(%s)'%plural)\n \n \n \ndef _expand_lang(loc):\n loc=locale. normalize(loc)\n COMPONENT_CODESET=1 <<0\n COMPONENT_TERRITORY=1 <<1\n COMPONENT_MODIFIER=1 <<2\n \n mask=0\n pos=loc. find('@')\n if pos >=0:\n  modifier=loc[pos:]\n  loc=loc[:pos]\n  mask |=COMPONENT_MODIFIER\n else :\n  modifier=''\n pos=loc. find('.')\n if pos >=0:\n  codeset=loc[pos:]\n  loc=loc[:pos]\n  mask |=COMPONENT_CODESET\n else :\n  codeset=''\n pos=loc. find('_')\n if pos >=0:\n  territory=loc[pos:]\n  loc=loc[:pos]\n  mask |=COMPONENT_TERRITORY\n else :\n  territory=''\n language=loc\n ret=[]\n for i in range(mask+1):\n  if not (i&~mask):\n   val=language\n   if i&COMPONENT_TERRITORY:val +=territory\n   if i&COMPONENT_CODESET:val +=codeset\n   if i&COMPONENT_MODIFIER:val +=modifier\n   ret. append(val)\n ret. reverse()\n return ret\n \n \n \nclass NullTranslations:\n def __init__(self,fp=None ):\n  self. _info={}\n  self. _charset=None\n  self. _output_charset=None\n  self. _fallback=None\n  if fp is not None :\n   self. _parse(fp)\n   \n def _parse(self,fp):\n  pass\n  \n def add_fallback(self,fallback):\n  if self. _fallback:\n   self. _fallback. add_fallback(fallback)\n  else :\n   self. _fallback=fallback\n   \n def gettext(self,message):\n  if self. _fallback:\n   return self. _fallback. gettext(message)\n  return message\n  \n def lgettext(self,message):\n  if self. _fallback:\n   return self. _fallback. lgettext(message)\n  return message\n  \n def ngettext(self,msgid1,msgid2,n):\n  if self. _fallback:\n   return self. _fallback. ngettext(msgid1,msgid2,n)\n  if n ==1:\n   return msgid1\n  else :\n   return msgid2\n   \n def lngettext(self,msgid1,msgid2,n):\n  if self. _fallback:\n   return self. _fallback. lngettext(msgid1,msgid2,n)\n  if n ==1:\n   return msgid1\n  else :\n   return msgid2\n   \n def info(self):\n  return self. _info\n  \n def charset(self):\n  return self. _charset\n  \n def output_charset(self):\n  return self. _output_charset\n  \n def set_output_charset(self,charset):\n  self. _output_charset=charset\n  \n def install(self,names=None ):\n  import builtins\n  builtins. __dict__['_']=self. gettext\n  if hasattr(names,\"__contains__\"):\n   if\"gettext\"in names:\n    builtins. __dict__['gettext']=builtins. __dict__['_']\n   if\"ngettext\"in names:\n    builtins. __dict__['ngettext']=self. ngettext\n   if\"lgettext\"in names:\n    builtins. __dict__['lgettext']=self. lgettext\n   if\"lngettext\"in names:\n    builtins. __dict__['lngettext']=self. lngettext\n    \n    \nclass GNUTranslations(NullTranslations):\n\n LE_MAGIC=0x950412de\n BE_MAGIC=0xde120495\n \n def _parse(self,fp):\n  ''\n  unpack=struct. unpack\n  filename=getattr(fp,'name','')\n  \n  \n  self. _catalog=catalog={}\n  self. plural=lambda n:int(n !=1)\n  buf=fp. read()\n  buflen=len(buf)\n  \n  magic=unpack('<I',buf[:4])[0]\n  if magic ==self. LE_MAGIC:\n   version,msgcount,masteridx,transidx=unpack('<4I',buf[4:20])\n   ii='<II'\n  elif magic ==self. BE_MAGIC:\n   version,msgcount,masteridx,transidx=unpack('>4I',buf[4:20])\n   ii='>II'\n  else :\n   raise OSError(0,'Bad magic number',filename)\n   \n   \n  for i in range(0,msgcount):\n   mlen,moff=unpack(ii,buf[masteridx:masteridx+8])\n   mend=moff+mlen\n   tlen,toff=unpack(ii,buf[transidx:transidx+8])\n   tend=toff+tlen\n   if mend <buflen and tend <buflen:\n    msg=buf[moff:mend]\n    tmsg=buf[toff:tend]\n   else :\n    raise OSError(0,'File is corrupt',filename)\n    \n   if mlen ==0:\n   \n    lastk=k=None\n    for b_item in tmsg. split('\\n'. encode(\"ascii\")):\n     item=b_item. decode(). strip()\n     if not item:\n      continue\n     if':'in item:\n      k,v=item. split(':',1)\n      k=k. strip(). lower()\n      v=v. strip()\n      self. _info[k]=v\n      lastk=k\n     elif lastk:\n      self. _info[lastk]+='\\n'+item\n     if k =='content-type':\n      self. _charset=v. split('charset=')[1]\n     elif k =='plural-forms':\n      v=v. split(';')\n      plural=v[1]. split('plural=')[1]\n      self. plural=c2py(plural)\n      \n      \n      \n      \n      \n      \n      \n      \n      \n   charset=self. _charset or'ascii'\n   if b'\\x00'in msg:\n   \n    msgid1,msgid2=msg. split(b'\\x00')\n    tmsg=tmsg. split(b'\\x00')\n    msgid1=str(msgid1,charset)\n    for i,x in enumerate(tmsg):\n     catalog[(msgid1,i)]=str(x,charset)\n   else :\n    catalog[str(msg,charset)]=str(tmsg,charset)\n    \n   masteridx +=8\n   transidx +=8\n   \n def lgettext(self,message):\n  missing=object()\n  tmsg=self. _catalog. get(message,missing)\n  if tmsg is missing:\n   if self. _fallback:\n    return self. _fallback. lgettext(message)\n   return message\n  if self. _output_charset:\n   return tmsg. encode(self. _output_charset)\n  return tmsg. encode(locale. getpreferredencoding())\n  \n def lngettext(self,msgid1,msgid2,n):\n  try :\n   tmsg=self. _catalog[(msgid1,self. plural(n))]\n   if self. _output_charset:\n    return tmsg. encode(self. _output_charset)\n   return tmsg. encode(locale. getpreferredencoding())\n  except KeyError:\n   if self. _fallback:\n    return self. _fallback. lngettext(msgid1,msgid2,n)\n   if n ==1:\n    return msgid1\n   else :\n    return msgid2\n    \n def gettext(self,message):\n  missing=object()\n  tmsg=self. _catalog. get(message,missing)\n  if tmsg is missing:\n   if self. _fallback:\n    return self. _fallback. gettext(message)\n   return message\n  return tmsg\n  \n def ngettext(self,msgid1,msgid2,n):\n  try :\n   tmsg=self. _catalog[(msgid1,self. plural(n))]\n  except KeyError:\n   if self. _fallback:\n    return self. _fallback. ngettext(msgid1,msgid2,n)\n   if n ==1:\n    tmsg=msgid1\n   else :\n    tmsg=msgid2\n  return tmsg\n  \n  \n  \ndef find(domain,localedir=None ,languages=None ,all=False ):\n\n if localedir is None :\n  localedir=_default_localedir\n if languages is None :\n  languages=[]\n  for envar in ('LANGUAGE','LC_ALL','LC_MESSAGES','LANG'):\n   val=os. environ. get(envar)\n   if val:\n    languages=val. split(':')\n    break\n  if'C'not in languages:\n   languages. append('C')\n   \n nelangs=[]\n for lang in languages:\n  for nelang in _expand_lang(lang):\n   if nelang not in nelangs:\n    nelangs. append(nelang)\n    \n if all:\n  result=[]\n else :\n  result=None\n for lang in nelangs:\n  if lang =='C':\n   break\n  mofile=os. path. join(localedir,lang,'LC_MESSAGES','%s.mo'%domain)\n  if os. path. exists(mofile):\n   if all:\n    result. append(mofile)\n   else :\n    return mofile\n return result\n \n \n \n \n_translations={}\n\ndef translation(domain,localedir=None ,languages=None ,\nclass_=None ,fallback=False ,codeset=None ):\n if class_ is None :\n  class_=GNUTranslations\n mofiles=find(domain,localedir,languages,all=True )\n if not mofiles:\n  if fallback:\n   return NullTranslations()\n  raise OSError(ENOENT,'No translation file found for domain',domain)\n  \n  \n result=None\n for mofile in mofiles:\n  key=(class_,os. path. abspath(mofile))\n  t=_translations. get(key)\n  if t is None :\n   with open(mofile,'rb')as fp:\n    t=_translations. setdefault(key,class_(fp))\n    \n    \n    \n  t=copy. copy(t)\n  if codeset:\n   t. set_output_charset(codeset)\n  if result is None :\n   result=t\n  else :\n   result. add_fallback(t)\n return result\n \n \ndef install(domain,localedir=None ,codeset=None ,names=None ):\n t=translation(domain,localedir,fallback=True ,codeset=codeset)\n t. install(names)\n \n \n \n \n_localedirs={}\n\n_localecodesets={}\n\n_current_domain='messages'\n\n\ndef textdomain(domain=None ):\n global _current_domain\n if domain is not None :\n  _current_domain=domain\n return _current_domain\n \n \ndef bindtextdomain(domain,localedir=None ):\n global _localedirs\n if localedir is not None :\n  _localedirs[domain]=localedir\n return _localedirs. get(domain,_default_localedir)\n \n \ndef bind_textdomain_codeset(domain,codeset=None ):\n global _localecodesets\n if codeset is not None :\n  _localecodesets[domain]=codeset\n return _localecodesets. get(domain)\n \n \ndef dgettext(domain,message):\n try :\n  t=translation(domain,_localedirs. get(domain,None ),\n  codeset=_localecodesets. get(domain))\n except OSError:\n  return message\n return t. gettext(message)\n \ndef ldgettext(domain,message):\n try :\n  t=translation(domain,_localedirs. get(domain,None ),\n  codeset=_localecodesets. get(domain))\n except OSError:\n  return message\n return t. lgettext(message)\n \ndef dngettext(domain,msgid1,msgid2,n):\n try :\n  t=translation(domain,_localedirs. get(domain,None ),\n  codeset=_localecodesets. get(domain))\n except OSError:\n  if n ==1:\n   return msgid1\n  else :\n   return msgid2\n return t. ngettext(msgid1,msgid2,n)\n \ndef ldngettext(domain,msgid1,msgid2,n):\n try :\n  t=translation(domain,_localedirs. get(domain,None ),\n  codeset=_localecodesets. get(domain))\n except OSError:\n  if n ==1:\n   return msgid1\n  else :\n   return msgid2\n return t. lngettext(msgid1,msgid2,n)\n \ndef gettext(message):\n return dgettext(_current_domain,message)\n \ndef lgettext(message):\n return ldgettext(_current_domain,message)\n \ndef ngettext(msgid1,msgid2,n):\n return dngettext(_current_domain,msgid1,msgid2,n)\n \ndef lngettext(msgid1,msgid2,n):\n return ldngettext(_current_domain,msgid1,msgid2,n)\n \n \n \n \n \n \n \n \n \n \n \n \n \n \n \nCatalog=translation\n", ["builtins", "copy", "errno", "io", "locale", "os", "re", "struct", "sys", "token", "tokenize"]], "calendar": [".py", "''\n\n\n\n\n\n\nimport sys\nimport datetime\nimport locale as _locale\n\n__all__=[\"IllegalMonthError\",\"IllegalWeekdayError\",\"setfirstweekday\",\n\"firstweekday\",\"isleap\",\"leapdays\",\"weekday\",\"monthrange\",\n\"monthcalendar\",\"prmonth\",\"month\",\"prcal\",\"calendar\",\n\"timegm\",\"month_name\",\"month_abbr\",\"day_name\",\"day_abbr\"]\n\n\nerror=ValueError\n\n\nclass IllegalMonthError(ValueError):\n def __init__(self,month):\n  self. month=month\n def __str__(self):\n  return\"bad month number %r; must be 1-12\"%self. month\n  \n  \nclass IllegalWeekdayError(ValueError):\n def __init__(self,weekday):\n  self. weekday=weekday\n def __str__(self):\n  return\"bad weekday number %r; must be 0 (Monday) to 6 (Sunday)\"%self. weekday\n  \n  \n  \nJanuary=1\nFebruary=2\n\n\nmdays=[0,31,28,31,30,31,30,31,31,30,31,30,31]\n\n\n\n\n\n\nclass _localized_month:\n\n _months=[datetime. date(2001,i+1,1). strftime for i in range(12)]\n _months. insert(0,lambda x:\"\")\n \n def __init__(self,format):\n  self. format=format\n  \n def __getitem__(self,i):\n  funcs=self. _months[i]\n  if isinstance(i,slice):\n   return [f(self. format)for f in funcs]\n  else :\n   return funcs(self. format)\n   \n def __len__(self):\n  return 13\n  \n  \nclass _localized_day:\n\n\n _days=[datetime. date(2001,1,i+1). strftime for i in range(7)]\n \n def __init__(self,format):\n  self. format=format\n  \n def __getitem__(self,i):\n  funcs=self. _days[i]\n  if isinstance(i,slice):\n   return [f(self. format)for f in funcs]\n  else :\n   return funcs(self. format)\n   \n def __len__(self):\n  return 7\n  \n  \n  \nday_name=_localized_day('%A')\nday_abbr=_localized_day('%a')\n\n\nmonth_name=_localized_month('%B')\nmonth_abbr=_localized_month('%b')\n\n\n(MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY,SATURDAY,SUNDAY)=range(7)\n\n\ndef isleap(year):\n ''\n return year %4 ==0 and (year %100 !=0 or year %400 ==0)\n \n \ndef leapdays(y1,y2):\n ''\n \n y1 -=1\n y2 -=1\n return (y2 //4 -y1 //4)-(y2 //100 -y1 //100)+(y2 //400 -y1 //400)\n \n \ndef weekday(year,month,day):\n ''\n \n return datetime. date(year,month,day). weekday()\n \n \ndef monthrange(year,month):\n ''\n \n if not 1 <=month <=12:\n  raise IllegalMonthError(month)\n day1=weekday(year,month,1)\n ndays=mdays[month]+(month ==February and isleap(year))\n return day1,ndays\n \n \nclass Calendar(object):\n ''\n\n\n \n \n def __init__(self,firstweekday=0):\n  self. firstweekday=firstweekday\n  \n def getfirstweekday(self):\n  return self. _firstweekday %7\n  \n def setfirstweekday(self,firstweekday):\n  self. _firstweekday=firstweekday\n  \n firstweekday=property(getfirstweekday,setfirstweekday)\n \n def iterweekdays(self):\n  ''\n\n\n  \n  for i in range(self. firstweekday,self. firstweekday+7):\n   yield i %7\n   \n def itermonthdates(self,year,month):\n  ''\n\n\n\n  \n  date=datetime. date(year,month,1)\n  \n  days=(date. weekday()-self. firstweekday)%7\n  date -=datetime. timedelta(days=days)\n  oneday=datetime. timedelta(days=1)\n  while True :\n   yield date\n   try :\n    date +=oneday\n   except OverflowError:\n   \n    break\n   if date. month !=month and date. weekday()==self. firstweekday:\n    break\n    \n def itermonthdays2(self,year,month):\n  ''\n\n\n  \n  for date in self. itermonthdates(year,month):\n   if date. month !=month:\n    yield (0,date. weekday())\n   else :\n    yield (date. day,date. weekday())\n    \n def itermonthdays(self,year,month):\n  ''\n\n\n  \n  for date in self. itermonthdates(year,month):\n   if date. month !=month:\n    yield 0\n   else :\n    yield date. day\n    \n def monthdatescalendar(self,year,month):\n  ''\n\n\n  \n  dates=list(self. itermonthdates(year,month))\n  return [dates[i:i+7]for i in range(0,len(dates),7)]\n  \n def monthdays2calendar(self,year,month):\n  ''\n\n\n\n\n  \n  days=list(self. itermonthdays2(year,month))\n  return [days[i:i+7]for i in range(0,len(days),7)]\n  \n def monthdayscalendar(self,year,month):\n  ''\n\n\n  \n  days=list(self. itermonthdays(year,month))\n  return [days[i:i+7]for i in range(0,len(days),7)]\n  \n def yeardatescalendar(self,year,width=3):\n  ''\n\n\n\n\n  \n  months=[\n  self. monthdatescalendar(year,i)\n  for i in range(January,January+12)\n  ]\n  return [months[i:i+width]for i in range(0,len(months),width)]\n  \n def yeardays2calendar(self,year,width=3):\n  ''\n\n\n\n\n  \n  months=[\n  self. monthdays2calendar(year,i)\n  for i in range(January,January+12)\n  ]\n  return [months[i:i+width]for i in range(0,len(months),width)]\n  \n def yeardayscalendar(self,year,width=3):\n  ''\n\n\n\n  \n  months=[\n  self. monthdayscalendar(year,i)\n  for i in range(January,January+12)\n  ]\n  return [months[i:i+width]for i in range(0,len(months),width)]\n  \n  \nclass TextCalendar(Calendar):\n ''\n\n\n \n \n def prweek(self,theweek,width):\n  ''\n\n  \n  print(self. formatweek(theweek,width),end=' ')\n  \n def formatday(self,day,weekday,width):\n  ''\n\n  \n  if day ==0:\n   s=''\n  else :\n   s='%2i'%day\n  return s. center(width)\n  \n def formatweek(self,theweek,width):\n  ''\n\n  \n  return' '. join(self. formatday(d,wd,width)for (d,wd)in theweek)\n  \n def formatweekday(self,day,width):\n  ''\n\n  \n  if width >=9:\n   names=day_name\n  else :\n   names=day_abbr\n  return names[day][:width]. center(width)\n  \n def formatweekheader(self,width):\n  ''\n\n  \n  return' '. join(self. formatweekday(i,width)for i in self. iterweekdays())\n  \n def formatmonthname(self,theyear,themonth,width,withyear=True ):\n  ''\n\n  \n  s=month_name[themonth]\n  if withyear:\n   s=\"%s %r\"%(s,theyear)\n  return s. center(width)\n  \n def prmonth(self,theyear,themonth,w=0,l=0):\n  ''\n\n  \n  print(self. formatmonth(theyear,themonth,w,l),end=' ')\n  \n def formatmonth(self,theyear,themonth,w=0,l=0):\n  ''\n\n  \n  w=max(2,w)\n  l=max(1,l)\n  s=self. formatmonthname(theyear,themonth,7 *(w+1)-1)\n  s=s. rstrip()\n  s +='\\n'*l\n  s +=self. formatweekheader(w). rstrip()\n  s +='\\n'*l\n  for week in self. monthdays2calendar(theyear,themonth):\n   s +=self. formatweek(week,w). rstrip()\n   s +='\\n'*l\n  return s\n  \n def formatyear(self,theyear,w=2,l=1,c=6,m=3):\n  ''\n\n  \n  w=max(2,w)\n  l=max(1,l)\n  c=max(2,c)\n  colwidth=(w+1)*7 -1\n  v=[]\n  a=v. append\n  a(repr(theyear). center(colwidth *m+c *(m -1)). rstrip())\n  a('\\n'*l)\n  header=self. formatweekheader(w)\n  for (i,row)in enumerate(self. yeardays2calendar(theyear,m)):\n  \n   months=range(m *i+1,min(m *(i+1)+1,13))\n   a('\\n'*l)\n   names=(self. formatmonthname(theyear,k,colwidth,False )\n   for k in months)\n   a(formatstring(names,colwidth,c). rstrip())\n   a('\\n'*l)\n   headers=(header for k in months)\n   a(formatstring(headers,colwidth,c). rstrip())\n   a('\\n'*l)\n   \n   height=max(len(cal)for cal in row)\n   for j in range(height):\n    weeks=[]\n    for cal in row:\n     if j >=len(cal):\n      weeks. append('')\n     else :\n      weeks. append(self. formatweek(cal[j],w))\n    a(formatstring(weeks,colwidth,c). rstrip())\n    a('\\n'*l)\n  return''. join(v)\n  \n def pryear(self,theyear,w=0,l=0,c=6,m=3):\n  ''\n  print(self. formatyear(theyear,w,l,c,m))\n  \n  \nclass HTMLCalendar(Calendar):\n ''\n\n \n \n \n cssclasses=[\"mon\",\"tue\",\"wed\",\"thu\",\"fri\",\"sat\",\"sun\"]\n \n def formatday(self,day,weekday):\n  ''\n\n  \n  if day ==0:\n   return'<td class=\"noday\">&nbsp;</td>'\n  else :\n   return'<td class=\"%s\">%d</td>'%(self. cssclasses[weekday],day)\n   \n def formatweek(self,theweek):\n  ''\n\n  \n  s=''. join(self. formatday(d,wd)for (d,wd)in theweek)\n  return'<tr>%s</tr>'%s\n  \n def formatweekday(self,day):\n  ''\n\n  \n  return'<th class=\"%s\">%s</th>'%(self. cssclasses[day],day_abbr[day])\n  \n def formatweekheader(self):\n  ''\n\n  \n  s=''. join(self. formatweekday(i)for i in self. iterweekdays())\n  return'<tr>%s</tr>'%s\n  \n def formatmonthname(self,theyear,themonth,withyear=True ):\n  ''\n\n  \n  if withyear:\n   s='%s %s'%(month_name[themonth],theyear)\n  else :\n   s='%s'%month_name[themonth]\n  return'<tr><th colspan=\"7\" class=\"month\">%s</th></tr>'%s\n  \n def formatmonth(self,theyear,themonth,withyear=True ):\n  ''\n\n  \n  v=[]\n  a=v. append\n  a('<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" class=\"month\">')\n  a('\\n')\n  a(self. formatmonthname(theyear,themonth,withyear=withyear))\n  a('\\n')\n  a(self. formatweekheader())\n  a('\\n')\n  for week in self. monthdays2calendar(theyear,themonth):\n   a(self. formatweek(week))\n   a('\\n')\n  a('</table>')\n  a('\\n')\n  return''. join(v)\n  \n def formatyear(self,theyear,width=3):\n  ''\n\n  \n  v=[]\n  a=v. append\n  width=max(width,1)\n  a('<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" class=\"year\">')\n  a('\\n')\n  a('<tr><th colspan=\"%d\" class=\"year\">%s</th></tr>'%(width,theyear))\n  for i in range(January,January+12,width):\n  \n   months=range(i,min(i+width,13))\n   a('<tr>')\n   for m in months:\n    a('<td>')\n    a(self. formatmonth(theyear,m,withyear=False ))\n    a('</td>')\n   a('</tr>')\n  a('</table>')\n  return''. join(v)\n  \n def formatyearpage(self,theyear,width=3,css='calendar.css',encoding=None ):\n  ''\n\n  \n  if encoding is None :\n   encoding=sys. getdefaultencoding()\n  v=[]\n  a=v. append\n  a('<?xml version=\"1.0\" encoding=\"%s\"?>\\n'%encoding)\n  a('<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\\n')\n  a('<html>\\n')\n  a('<head>\\n')\n  a('<meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\" />\\n'%encoding)\n  if css is not None :\n   a('<link rel=\"stylesheet\" type=\"text/css\" href=\"%s\" />\\n'%css)\n  a('<title>Calendar for %d</title>\\n'%theyear)\n  a('</head>\\n')\n  a('<body>\\n')\n  a(self. formatyear(theyear,width))\n  a('</body>\\n')\n  a('</html>\\n')\n  return''. join(v). encode(encoding,\"xmlcharrefreplace\")\n  \n  \nclass different_locale:\n def __init__(self,locale):\n  self. locale=locale\n  \n def __enter__(self):\n  self. oldlocale=_locale. getlocale(_locale. LC_TIME)\n  _locale. setlocale(_locale. LC_TIME,self. locale)\n  \n def __exit__(self,*args):\n  _locale. setlocale(_locale. LC_TIME,self. oldlocale)\n  \n  \nclass LocaleTextCalendar(TextCalendar):\n ''\n\n\n\n\n \n \n def __init__(self,firstweekday=0,locale=None ):\n  TextCalendar. __init__(self,firstweekday)\n  if locale is None :\n   locale=_locale. getdefaultlocale()\n  self. locale=locale\n  \n def formatweekday(self,day,width):\n  with different_locale(self. locale):\n   if width >=9:\n    names=day_name\n   else :\n    names=day_abbr\n   name=names[day]\n   return name[:width]. center(width)\n   \n def formatmonthname(self,theyear,themonth,width,withyear=True ):\n  with different_locale(self. locale):\n   s=month_name[themonth]\n   if withyear:\n    s=\"%s %r\"%(s,theyear)\n   return s. center(width)\n   \n   \nclass LocaleHTMLCalendar(HTMLCalendar):\n ''\n\n\n\n\n \n def __init__(self,firstweekday=0,locale=None ):\n  HTMLCalendar. __init__(self,firstweekday)\n  if locale is None :\n   locale=_locale. getdefaultlocale()\n  self. locale=locale\n  \n def formatweekday(self,day):\n  with different_locale(self. locale):\n   s=day_abbr[day]\n   return'<th class=\"%s\">%s</th>'%(self. cssclasses[day],s)\n   \n def formatmonthname(self,theyear,themonth,withyear=True ):\n  with different_locale(self. locale):\n   s=month_name[themonth]\n   if withyear:\n    s='%s %s'%(s,theyear)\n   return'<tr><th colspan=\"7\" class=\"month\">%s</th></tr>'%s\n   \n   \n   \nc=TextCalendar()\n\nfirstweekday=c. getfirstweekday\n\ndef setfirstweekday(firstweekday):\n if not MONDAY <=firstweekday <=SUNDAY:\n  raise IllegalWeekdayError(firstweekday)\n c. firstweekday=firstweekday\n \nmonthcalendar=c. monthdayscalendar\nprweek=c. prweek\nweek=c. formatweek\nweekheader=c. formatweekheader\nprmonth=c. prmonth\nmonth=c. formatmonth\ncalendar=c. formatyear\nprcal=c. pryear\n\n\n\n_colwidth=7 *3 -1\n_spacing=6\n\n\ndef format(cols,colwidth=_colwidth,spacing=_spacing):\n ''\n print(formatstring(cols,colwidth,spacing))\n \n \ndef formatstring(cols,colwidth=_colwidth,spacing=_spacing):\n ''\n spacing *=' '\n return spacing. join(c. center(colwidth)for c in cols)\n \n \nEPOCH=1970\n_EPOCH_ORD=datetime. date(EPOCH,1,1). toordinal()\n\n\ndef timegm(tuple):\n ''\n year,month,day,hour,minute,second=tuple[:6]\n days=datetime. date(year,month,1). toordinal()-_EPOCH_ORD+day -1\n hours=days *24+hour\n minutes=hours *60+minute\n seconds=minutes *60+second\n return seconds\n \n \ndef main(args):\n import optparse\n parser=optparse. OptionParser(usage=\"usage: %prog [options] [year [month]]\")\n parser. add_option(\n \"-w\",\"--width\",\n dest=\"width\",type=\"int\",default=2,\n help=\"width of date column (default 2, text only)\"\n )\n parser. add_option(\n \"-l\",\"--lines\",\n dest=\"lines\",type=\"int\",default=1,\n help=\"number of lines for each week (default 1, text only)\"\n )\n parser. add_option(\n \"-s\",\"--spacing\",\n dest=\"spacing\",type=\"int\",default=6,\n help=\"spacing between months (default 6, text only)\"\n )\n parser. add_option(\n \"-m\",\"--months\",\n dest=\"months\",type=\"int\",default=3,\n help=\"months per row (default 3, text only)\"\n )\n parser. add_option(\n \"-c\",\"--css\",\n dest=\"css\",default=\"calendar.css\",\n help=\"CSS to use for page (html only)\"\n )\n parser. add_option(\n \"-L\",\"--locale\",\n dest=\"locale\",default=None ,\n help=\"locale to be used from month and weekday names\"\n )\n parser. add_option(\n \"-e\",\"--encoding\",\n dest=\"encoding\",default=None ,\n help=\"Encoding to use for output.\"\n )\n parser. add_option(\n \"-t\",\"--type\",\n dest=\"type\",default=\"text\",\n choices=(\"text\",\"html\"),\n help=\"output type (text or html)\"\n )\n \n (options,args)=parser. parse_args(args)\n \n if options. locale and not options. encoding:\n  parser. error(\"if --locale is specified --encoding is required\")\n  sys. exit(1)\n  \n locale=options. locale,options. encoding\n \n if options. type ==\"html\":\n  if options. locale:\n   cal=LocaleHTMLCalendar(locale=locale)\n  else :\n   cal=HTMLCalendar()\n  encoding=options. encoding\n  if encoding is None :\n   encoding=sys. getdefaultencoding()\n  optdict=dict(encoding=encoding,css=options. css)\n  write=sys. stdout. buffer. write\n  if len(args)==1:\n   write(cal. formatyearpage(datetime. date. today(). year,**optdict))\n  elif len(args)==2:\n   write(cal. formatyearpage(int(args[1]),**optdict))\n  else :\n   parser. error(\"incorrect number of arguments\")\n   sys. exit(1)\n else :\n  if options. locale:\n   cal=LocaleTextCalendar(locale=locale)\n  else :\n   cal=TextCalendar()\n  optdict=dict(w=options. width,l=options. lines)\n  if len(args)!=3:\n   optdict[\"c\"]=options. spacing\n   optdict[\"m\"]=options. months\n  if len(args)==1:\n   result=cal. formatyear(datetime. date. today(). year,**optdict)\n  elif len(args)==2:\n   result=cal. formatyear(int(args[1]),**optdict)\n  elif len(args)==3:\n   result=cal. formatmonth(int(args[1]),int(args[2]),**optdict)\n  else :\n   parser. error(\"incorrect number of arguments\")\n   sys. exit(1)\n  write=sys. stdout. write\n  if options. encoding:\n   result=result. encode(options. encoding)\n   write=sys. stdout. buffer. write\n  write(result)\n  \n  \nif __name__ ==\"__main__\":\n main(sys. argv)\n", ["datetime", "locale", "optparse", "sys"]], "functools": [".py", "''\n\n\n\n\n\n\n\n\n\n__all__=['update_wrapper','wraps','WRAPPER_ASSIGNMENTS','WRAPPER_UPDATES',\n'total_ordering','cmp_to_key','lru_cache','reduce','partial']\n\nfrom _functools import partial,reduce\nfrom collections import namedtuple\ntry :\n from _thread import RLock\nexcept :\n class RLock:\n  ''\n  def __enter__(self):pass\n  def __exit__(self,exctype,excinst,exctb):pass\n  \n  \n  \n  \n  \n  \n  \n  \n  \nWRAPPER_ASSIGNMENTS=('__module__','__name__','__qualname__','__doc__',\n'__annotations__')\nWRAPPER_UPDATES=('__dict__',)\ndef update_wrapper(wrapper,\nwrapped,\nassigned=WRAPPER_ASSIGNMENTS,\nupdated=WRAPPER_UPDATES):\n ''\n\n\n\n\n\n\n\n\n\n \n wrapper. __wrapped__=wrapped\n for attr in assigned:\n  try :\n   value=getattr(wrapped,attr)\n  except AttributeError:\n   pass\n  else :\n   setattr(wrapper,attr,value)\n for attr in updated:\n  getattr(wrapper,attr). update(getattr(wrapped,attr,{}))\n  \n return wrapper\n \ndef wraps(wrapped,\nassigned=WRAPPER_ASSIGNMENTS,\nupdated=WRAPPER_UPDATES):\n ''\n\n\n\n\n\n\n \n return partial(update_wrapper,wrapped=wrapped,\n assigned=assigned,updated=updated)\n \n \n \n \n \n \ndef total_ordering(cls):\n ''\n convert={\n '__lt__':[('__gt__',lambda self,other:not (self <other or self ==other)),\n ('__le__',lambda self,other:self <other or self ==other),\n ('__ge__',lambda self,other:not self <other)],\n '__le__':[('__ge__',lambda self,other:not self <=other or self ==other),\n ('__lt__',lambda self,other:self <=other and not self ==other),\n ('__gt__',lambda self,other:not self <=other)],\n '__gt__':[('__lt__',lambda self,other:not (self >other or self ==other)),\n ('__ge__',lambda self,other:self >other or self ==other),\n ('__le__',lambda self,other:not self >other)],\n '__ge__':[('__le__',lambda self,other:(not self >=other)or self ==other),\n ('__gt__',lambda self,other:self >=other and not self ==other),\n ('__lt__',lambda self,other:not self >=other)]\n }\n \n roots=[op for op in convert if getattr(cls,op,None )is not getattr(object,op,None )]\n if not roots:\n  raise ValueError('must define at least one ordering operation: < > <= >=')\n root=max(roots)\n for opname,opfunc in convert[root]:\n  if opname not in roots:\n   opfunc. __name__=opname\n   opfunc. __doc__=getattr(int,opname). __doc__\n   setattr(cls,opname,opfunc)\n return cls\n \n \n \n \n \n \ndef cmp_to_key(mycmp):\n ''\n class K(object):\n  __slots__=['obj']\n  def __init__(self,obj):\n   self. obj=obj\n  def __lt__(self,other):\n   return mycmp(self. obj,other. obj)<0\n  def __gt__(self,other):\n   return mycmp(self. obj,other. obj)>0\n  def __eq__(self,other):\n   return mycmp(self. obj,other. obj)==0\n  def __le__(self,other):\n   return mycmp(self. obj,other. obj)<=0\n  def __ge__(self,other):\n   return mycmp(self. obj,other. obj)>=0\n  def __ne__(self,other):\n   return mycmp(self. obj,other. obj)!=0\n  __hash__=None\n return K\n \ntry :\n from _functools import cmp_to_key\nexcept ImportError:\n pass\n \n \n \n \n \n \n_CacheInfo=namedtuple(\"CacheInfo\",[\"hits\",\"misses\",\"maxsize\",\"currsize\"])\n\nclass _HashedSeq(list):\n ''\n\n\n\n \n \n __slots__='hashvalue'\n \n def __init__(self,tup,hash=hash):\n  self[:]=tup\n  self. hashvalue=hash(tup)\n  \n def __hash__(self):\n  return self. hashvalue\n  \ndef _make_key(args,kwds,typed,\nkwd_mark=(object(),),\nfasttypes={int,str,frozenset,type(None )},\nsorted=sorted,tuple=tuple,type=type,len=len):\n ''\n\n\n\n\n\n\n\n\n \n key=args\n if kwds:\n  sorted_items=sorted(kwds. items())\n  key +=kwd_mark\n  for item in sorted_items:\n   key +=item\n if typed:\n  key +=tuple(type(v)for v in args)\n  if kwds:\n   key +=tuple(type(v)for k,v in sorted_items)\n elif len(key)==1 and type(key[0])in fasttypes:\n  return key[0]\n return _HashedSeq(key)\n \ndef lru_cache(maxsize=128,typed=False ):\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n \n \n \n \n \n \n sentinel=object()\n make_key=_make_key\n PREV,NEXT,KEY,RESULT=0,1,2,3\n \n def decorating_function(user_function):\n \n  cache={}\n  hits=misses=0\n  full=False\n  cache_get=cache. get\n  lock=RLock()\n  root=[]\n  root[:]=[root,root,None ,None ]\n  \n  if maxsize ==0:\n  \n   def wrapper(*args,**kwds):\n   \n    nonlocal misses\n    result=user_function(*args,**kwds)\n    misses +=1\n    return result\n    \n  elif maxsize is None :\n  \n   def wrapper(*args,**kwds):\n   \n    nonlocal hits,misses\n    key=make_key(args,kwds,typed)\n    result=cache_get(key,sentinel)\n    if result is not sentinel:\n     hits +=1\n     return result\n    result=user_function(*args,**kwds)\n    cache[key]=result\n    misses +=1\n    return result\n    \n  else :\n  \n   def wrapper(*args,**kwds):\n   \n    nonlocal root,hits,misses,full\n    key=make_key(args,kwds,typed)\n    with lock:\n     link=cache_get(key)\n     if link is not None :\n     \n      link_prev,link_next,_key,result=link\n      link_prev[NEXT]=link_next\n      link_next[PREV]=link_prev\n      last=root[PREV]\n      last[NEXT]=root[PREV]=link\n      link[PREV]=last\n      link[NEXT]=root\n      hits +=1\n      return result\n    result=user_function(*args,**kwds)\n    with lock:\n     if key in cache:\n     \n     \n     \n     \n      pass\n     elif full:\n     \n      oldroot=root\n      oldroot[KEY]=key\n      oldroot[RESULT]=result\n      \n      \n      \n      \n      \n      \n      root=oldroot[NEXT]\n      oldkey=root[KEY]\n      oldresult=root[RESULT]\n      root[KEY]=root[RESULT]=None\n      \n      del cache[oldkey]\n      \n      \n      \n      cache[key]=oldroot\n     else :\n     \n      last=root[PREV]\n      link=[last,root,key,result]\n      last[NEXT]=root[PREV]=cache[key]=link\n      full=(len(cache)>=maxsize)\n     misses +=1\n    return result\n    \n  def cache_info():\n   ''\n   with lock:\n    return _CacheInfo(hits,misses,maxsize,len(cache))\n    \n  def cache_clear():\n   ''\n   nonlocal hits,misses,full\n   with lock:\n    cache. clear()\n    root[:]=[root,root,None ,None ]\n    hits=misses=0\n    full=False\n    \n  wrapper. cache_info=cache_info\n  wrapper. cache_clear=cache_clear\n  return update_wrapper(wrapper,user_function)\n  \n return decorating_function\n", ["_functools", "_thread", "collections"]], "sre_parse": [".py", "\n\n\n\n\n\n\n\n\n\n\"\"\"Internal support module for sre\"\"\"\n\n\n\nimport sys\n\nfrom sre_constants import *\nfrom _sre import MAXREPEAT\n\nSPECIAL_CHARS=\".\\\\[{()*+?^$|\"\nREPEAT_CHARS=\"*+?{\"\n\nDIGITS=set(\"0123456789\")\n\nOCTDIGITS=set(\"01234567\")\nHEXDIGITS=set(\"0123456789abcdefABCDEF\")\n\nWHITESPACE=set(\" \\t\\n\\r\\v\\f\")\n\nESCAPES={\nr\"\\a\":(LITERAL,ord(\"\\a\")),\nr\"\\b\":(LITERAL,ord(\"\\b\")),\nr\"\\f\":(LITERAL,ord(\"\\f\")),\nr\"\\n\":(LITERAL,ord(\"\\n\")),\nr\"\\r\":(LITERAL,ord(\"\\r\")),\nr\"\\t\":(LITERAL,ord(\"\\t\")),\nr\"\\v\":(LITERAL,ord(\"\\v\")),\nr\"\\\\\":(LITERAL,ord(\"\\\\\"))\n}\n\nCATEGORIES={\nr\"\\A\":(AT,AT_BEGINNING_STRING),\nr\"\\b\":(AT,AT_BOUNDARY),\nr\"\\B\":(AT,AT_NON_BOUNDARY),\nr\"\\d\":(IN,[(CATEGORY,CATEGORY_DIGIT)]),\nr\"\\D\":(IN,[(CATEGORY,CATEGORY_NOT_DIGIT)]),\nr\"\\s\":(IN,[(CATEGORY,CATEGORY_SPACE)]),\nr\"\\S\":(IN,[(CATEGORY,CATEGORY_NOT_SPACE)]),\nr\"\\w\":(IN,[(CATEGORY,CATEGORY_WORD)]),\nr\"\\W\":(IN,[(CATEGORY,CATEGORY_NOT_WORD)]),\nr\"\\Z\":(AT,AT_END_STRING),\n}\n\nFLAGS={\n\n\"i\":SRE_FLAG_IGNORECASE,\n\"L\":SRE_FLAG_LOCALE,\n\"m\":SRE_FLAG_MULTILINE,\n\"s\":SRE_FLAG_DOTALL,\n\"x\":SRE_FLAG_VERBOSE,\n\n\"a\":SRE_FLAG_ASCII,\n\"t\":SRE_FLAG_TEMPLATE,\n\"u\":SRE_FLAG_UNICODE,\n}\n\nclass Pattern:\n\n def __init__(self):\n  self. flags=0\n  self. open=[]\n  self. groups=1\n  self. groupdict={}\n def opengroup(self,name=None ):\n  gid=self. groups\n  self. groups=gid+1\n  if name is not None :\n   ogid=self. groupdict. get(name,None )\n   if ogid is not None :\n    raise error(\"redefinition of group name %s as group %d; \"\n    \"was group %d\"%(repr(name),gid,ogid))\n   self. groupdict[name]=gid\n  self. open. append(gid)\n  return gid\n def closegroup(self,gid):\n  self. open. remove(gid)\n def checkgroup(self,gid):\n  return gid <self. groups and gid not in self. open\n  \nclass SubPattern:\n\n def __init__(self,pattern,data=None ):\n  self. pattern=pattern\n  if data is None :\n   data=[]\n  self. data=data\n  self. width=None\n def __iter__(self):\n  return iter(self. data)\n  \n def dump(self,level=0):\n  nl=1\n  seqtypes=(tuple,list)\n  for op,av in self. data:\n   print(level *\"  \"+op,end=' ');nl=0\n   if op ==\"in\":\n   \n    print();nl=1\n    for op,a in av:\n     print((level+1)*\"  \"+op,a)\n   elif op ==\"branch\":\n    print();nl=1\n    i=0\n    for a in av[1]:\n     if i >0:\n      print(level *\"  \"+\"or\")\n     a. dump(level+1);nl=1\n     i=i+1\n   elif isinstance(av,seqtypes):\n    for a in av:\n     if isinstance(a,SubPattern):\n      if not nl:print()\n      a. dump(level+1);nl=1\n     else :\n      print(a,end=' ');nl=0\n   else :\n    print(av,end=' ');nl=0\n   if not nl:print()\n def __repr__(self):\n  return repr(self. data)\n def __len__(self):\n  return len(self. data)\n def __delitem__(self,index):\n  del self. data[index]\n def __getitem__(self,index):\n  if isinstance(index,slice):\n   return SubPattern(self. pattern,self. data[index])\n  return self. data[index]\n def __setitem__(self,index,code):\n  self. data[index]=code\n def insert(self,index,code):\n  self. data. insert(index,code)\n def append(self,code):\n  self. data. append(code)\n def getwidth(self):\n \n  if self. width:\n   return self. width\n  lo=hi=0\n  UNITCODES=(ANY,RANGE,IN,LITERAL,NOT_LITERAL,CATEGORY)\n  REPEATCODES=(MIN_REPEAT,MAX_REPEAT)\n  for op,av in self. data:\n   if op is BRANCH:\n    i=sys. maxsize\n    j=0\n    for av in av[1]:\n     l,h=av. getwidth()\n     i=min(i,l)\n     j=max(j,h)\n    lo=lo+i\n    hi=hi+j\n   elif op is CALL:\n    i,j=av. getwidth()\n    lo=lo+i\n    hi=hi+j\n   elif op is SUBPATTERN:\n    i,j=av[1]. getwidth()\n    lo=lo+i\n    hi=hi+j\n   elif op in REPEATCODES:\n    i,j=av[2]. getwidth()\n    lo=lo+int(i)*av[0]\n    hi=hi+int(j)*av[1]\n   elif op in UNITCODES:\n    lo=lo+1\n    hi=hi+1\n   elif op ==SUCCESS:\n    break\n  self. width=int(min(lo,sys. maxsize)),int(min(hi,sys. maxsize))\n  return self. width\n  \nclass Tokenizer:\n def __init__(self,string):\n  self. istext=isinstance(string,str)\n  self. string=string\n  self. index=0\n  self. __next()\n def __next(self):\n  if self. index >=len(self. string):\n   self. next=None\n   return\n  char=self. string[self. index:self. index+1]\n  \n  \n  if char and not self. istext:\n   char=chr(char[0])\n  if char ==\"\\\\\":\n   try :\n    c=self. string[self. index+1]\n   except IndexError:\n    raise error(\"bogus escape (end of line)\")\n   if not self. istext:\n    c=chr(c)\n   char=char+c\n  self. index=self. index+len(char)\n  self. next=char\n def match(self,char,skip=1):\n  if char ==self. next:\n   if skip:\n    self. __next()\n   return 1\n  return 0\n def get(self):\n  this=self. next\n  self. __next()\n  return this\n def getwhile(self,n,charset):\n  result=''\n  for _ in range(n):\n   c=self. next\n   if c not in charset:\n    break\n   result +=c\n   self. __next()\n  return result\n def tell(self):\n  return self. index,self. next\n def seek(self,index):\n  self. index,self. next=index\n  \ndef isident(char):\n return\"a\"<=char <=\"z\"or\"A\"<=char <=\"Z\"or char ==\"_\"\n \ndef isdigit(char):\n return\"0\"<=char <=\"9\"\n \ndef isname(name):\n\n if not isident(name[0]):\n  return False\n for char in name[1:]:\n  if not isident(char)and not isdigit(char):\n   return False\n return True\n \ndef _class_escape(source,escape):\n\n code=ESCAPES. get(escape)\n if code:\n  return code\n code=CATEGORIES. get(escape)\n if code and code[0]==IN:\n  return code\n try :\n  c=escape[1:2]\n  if c ==\"x\":\n  \n   escape +=source. getwhile(2,HEXDIGITS)\n   if len(escape)!=4:\n    raise ValueError\n   return LITERAL,int(escape[2:],16)&0xff\n  elif c ==\"u\"and source. istext:\n  \n   escape +=source. getwhile(4,HEXDIGITS)\n   if len(escape)!=6:\n    raise ValueError\n   return LITERAL,int(escape[2:],16)\n  elif c ==\"U\"and source. istext:\n  \n   escape +=source. getwhile(8,HEXDIGITS)\n   if len(escape)!=10:\n    raise ValueError\n   c=int(escape[2:],16)\n   chr(c)\n   return LITERAL,c\n  elif c in OCTDIGITS:\n  \n   escape +=source. getwhile(2,OCTDIGITS)\n   return LITERAL,int(escape[1:],8)&0xff\n  elif c in DIGITS:\n   raise ValueError\n  if len(escape)==2:\n   return LITERAL,ord(escape[1])\n except ValueError:\n  pass\n raise error(\"bogus escape: %s\"%repr(escape))\n \ndef _escape(source,escape,state):\n\n code=CATEGORIES. get(escape)\n if code:\n  return code\n code=ESCAPES. get(escape)\n if code:\n  return code\n try :\n  c=escape[1:2]\n  if c ==\"x\":\n  \n   escape +=source. getwhile(2,HEXDIGITS)\n   if len(escape)!=4:\n    raise ValueError\n   return LITERAL,int(escape[2:],16)&0xff\n  elif c ==\"u\"and source. istext:\n  \n   escape +=source. getwhile(4,HEXDIGITS)\n   if len(escape)!=6:\n    raise ValueError\n   return LITERAL,int(escape[2:],16)\n  elif c ==\"U\"and source. istext:\n  \n   escape +=source. getwhile(8,HEXDIGITS)\n   if len(escape)!=10:\n    raise ValueError\n   c=int(escape[2:],16)\n   chr(c)\n   return LITERAL,c\n  elif c ==\"0\":\n  \n   escape +=source. getwhile(2,OCTDIGITS)\n   return LITERAL,int(escape[1:],8)&0xff\n  elif c in DIGITS:\n  \n   if source. next in DIGITS:\n    escape=escape+source. get()\n    if (escape[1]in OCTDIGITS and escape[2]in OCTDIGITS and\n    source. next in OCTDIGITS):\n    \n     escape=escape+source. get()\n     return LITERAL,int(escape[1:],8)&0xff\n     \n   group=int(escape[1:])\n   if group <state. groups:\n    if not state. checkgroup(group):\n     raise error(\"cannot refer to open group\")\n    return GROUPREF,group\n   raise ValueError\n  if len(escape)==2:\n   return LITERAL,ord(escape[1])\n except ValueError:\n  pass\n raise error(\"bogus escape: %s\"%repr(escape))\n \ndef _parse_sub(source,state,nested=1):\n\n\n items=[]\n itemsappend=items. append\n sourcematch=source. match\n while 1:\n  itemsappend(_parse(source,state))\n  if sourcematch(\"|\"):\n   continue\n  if not nested:\n   break\n  if not source. next or sourcematch(\")\",0):\n   break\n  else :\n   raise error(\"pattern not properly closed\")\n   \n if len(items)==1:\n  return items[0]\n  \n subpattern=SubPattern(state)\n subpatternappend=subpattern. append\n \n \n while 1:\n  prefix=None\n  for item in items:\n   if not item:\n    break\n   if prefix is None :\n    prefix=item[0]\n   elif item[0]!=prefix:\n    break\n  else :\n  \n  \n   for item in items:\n    del item[0]\n   subpatternappend(prefix)\n   continue\n  break\n  \n  \n for item in items:\n  if len(item)!=1 or item[0][0]!=LITERAL:\n   break\n else :\n \n \n  set=[]\n  setappend=set. append\n  for item in items:\n   setappend(item[0])\n  subpatternappend((IN,set))\n  return subpattern\n  \n subpattern. append((BRANCH,(None ,items)))\n return subpattern\n \ndef _parse_sub_cond(source,state,condgroup):\n item_yes=_parse(source,state)\n if source. match(\"|\"):\n  item_no=_parse(source,state)\n  if source. match(\"|\"):\n   raise error(\"conditional backref with more than two branches\")\n else :\n  item_no=None\n if source. next and not source. match(\")\",0):\n  raise error(\"pattern not properly closed\")\n subpattern=SubPattern(state)\n subpattern. append((GROUPREF_EXISTS,(condgroup,item_yes,item_no)))\n return subpattern\n \n_PATTERNENDERS=set(\"|)\")\n_ASSERTCHARS=set(\"=!<\")\n_LOOKBEHINDASSERTCHARS=set(\"=!\")\n_REPEATCODES=set([MIN_REPEAT,MAX_REPEAT])\n\ndef _parse(source,state):\n\n subpattern=SubPattern(state)\n \n \n subpatternappend=subpattern. append\n sourceget=source. get\n sourcematch=source. match\n _len=len\n PATTERNENDERS=_PATTERNENDERS\n ASSERTCHARS=_ASSERTCHARS\n LOOKBEHINDASSERTCHARS=_LOOKBEHINDASSERTCHARS\n REPEATCODES=_REPEATCODES\n \n while 1:\n \n  if source. next in PATTERNENDERS:\n   break\n  this=sourceget()\n  if this is None :\n   break\n   \n  if state. flags&SRE_FLAG_VERBOSE:\n  \n   if this in WHITESPACE:\n    continue\n   if this ==\"#\":\n    while 1:\n     this=sourceget()\n     if this in (None ,\"\\n\"):\n      break\n    continue\n    \n  if this and this[0]not in SPECIAL_CHARS:\n   subpatternappend((LITERAL,ord(this)))\n   \n  elif this ==\"[\":\n  \n   set=[]\n   setappend=set. append\n   \n   \n   if sourcematch(\"^\"):\n    setappend((NEGATE,None ))\n    \n   start=set[:]\n   while 1:\n    this=sourceget()\n    if this ==\"]\"and set !=start:\n     break\n    elif this and this[0]==\"\\\\\":\n     code1=_class_escape(source,this)\n    elif this:\n     code1=LITERAL,ord(this)\n    else :\n     raise error(\"unexpected end of regular expression\")\n    if sourcematch(\"-\"):\n    \n     this=sourceget()\n     if this ==\"]\":\n      if code1[0]is IN:\n       code1=code1[1][0]\n      setappend(code1)\n      setappend((LITERAL,ord(\"-\")))\n      break\n     elif this:\n      if this[0]==\"\\\\\":\n       code2=_class_escape(source,this)\n      else :\n       code2=LITERAL,ord(this)\n      if code1[0]!=LITERAL or code2[0]!=LITERAL:\n       raise error(\"bad character range\")\n      lo=code1[1]\n      hi=code2[1]\n      if hi <lo:\n       raise error(\"bad character range\")\n      setappend((RANGE,(lo,hi)))\n     else :\n      raise error(\"unexpected end of regular expression\")\n    else :\n     if code1[0]is IN:\n      code1=code1[1][0]\n     setappend(code1)\n     \n     \n   if _len(set)==1 and set[0][0]is LITERAL:\n    subpatternappend(set[0])\n   elif _len(set)==2 and set[0][0]is NEGATE and set[1][0]is LITERAL:\n    subpatternappend((NOT_LITERAL,set[1][1]))\n   else :\n   \n    subpatternappend((IN,set))\n    \n  elif this and this[0]in REPEAT_CHARS:\n  \n   if this ==\"?\":\n    min,max=0,1\n   elif this ==\"*\":\n    min,max=0,MAXREPEAT\n    \n   elif this ==\"+\":\n    min,max=1,MAXREPEAT\n   elif this ==\"{\":\n    if source. next ==\"}\":\n     subpatternappend((LITERAL,ord(this)))\n     continue\n    here=source. tell()\n    min,max=0,MAXREPEAT\n    lo=hi=\"\"\n    while source. next in DIGITS:\n     lo=lo+source. get()\n    if sourcematch(\",\"):\n     while source. next in DIGITS:\n      hi=hi+sourceget()\n    else :\n     hi=lo\n    if not sourcematch(\"}\"):\n     subpatternappend((LITERAL,ord(this)))\n     source. seek(here)\n     continue\n    if lo:\n     min=int(lo)\n     if min >=MAXREPEAT:\n      raise OverflowError(\"the repetition number is too large\")\n    if hi:\n     max=int(hi)\n     if max >=MAXREPEAT:\n      raise OverflowError(\"the repetition number is too large\")\n     if max <min:\n      raise error(\"bad repeat interval\")\n   else :\n    raise error(\"not supported\")\n    \n   if subpattern:\n    item=subpattern[-1:]\n   else :\n    item=None\n   if not item or (_len(item)==1 and item[0][0]==AT):\n    raise error(\"nothing to repeat\")\n   if item[0][0]in REPEATCODES:\n    raise error(\"multiple repeat\")\n   if sourcematch(\"?\"):\n    subpattern[-1]=(MIN_REPEAT,(min,max,item))\n   else :\n    subpattern[-1]=(MAX_REPEAT,(min,max,item))\n    \n  elif this ==\".\":\n   subpatternappend((ANY,None ))\n   \n  elif this ==\"(\":\n   group=1\n   name=None\n   condgroup=None\n   if sourcematch(\"?\"):\n    group=0\n    \n    if sourcematch(\"P\"):\n    \n     if sourcematch(\"<\"):\n     \n      name=\"\"\n      while 1:\n       char=sourceget()\n       if char is None :\n        raise error(\"unterminated name\")\n       if char ==\">\":\n        break\n       name=name+char\n      group=1\n      if not name:\n       raise error(\"missing group name\")\n      if not isname(name):\n       raise error(\"bad character in group name\")\n     elif sourcematch(\"=\"):\n     \n      name=\"\"\n      while 1:\n       char=sourceget()\n       if char is None :\n        raise error(\"unterminated name\")\n       if char ==\")\":\n        break\n       name=name+char\n      if not name:\n       raise error(\"missing group name\")\n      if not isname(name):\n       raise error(\"bad character in group name\")\n      gid=state. groupdict. get(name)\n      if gid is None :\n       raise error(\"unknown group name\")\n      subpatternappend((GROUPREF,gid))\n      continue\n     else :\n      char=sourceget()\n      if char is None :\n       raise error(\"unexpected end of pattern\")\n      raise error(\"unknown specifier: ?P%s\"%char)\n    elif sourcematch(\":\"):\n    \n     group=2\n    elif sourcematch(\"#\"):\n    \n     while 1:\n      if source. next is None or source. next ==\")\":\n       break\n      sourceget()\n     if not sourcematch(\")\"):\n      raise error(\"unbalanced parenthesis\")\n     continue\n    elif source. next in ASSERTCHARS:\n    \n     char=sourceget()\n     dir=1\n     if char ==\"<\":\n      if source. next not in LOOKBEHINDASSERTCHARS:\n       raise error(\"syntax error\")\n      dir=-1\n      char=sourceget()\n     p=_parse_sub(source,state)\n     if not sourcematch(\")\"):\n      raise error(\"unbalanced parenthesis\")\n     if char ==\"=\":\n      subpatternappend((ASSERT,(dir,p)))\n     else :\n      subpatternappend((ASSERT_NOT,(dir,p)))\n     continue\n    elif sourcematch(\"(\"):\n    \n     condname=\"\"\n     while 1:\n      char=sourceget()\n      if char is None :\n       raise error(\"unterminated name\")\n      if char ==\")\":\n       break\n      condname=condname+char\n     group=2\n     if not condname:\n      raise error(\"missing group name\")\n     if isname(condname):\n      condgroup=state. groupdict. get(condname)\n      if condgroup is None :\n       raise error(\"unknown group name\")\n     else :\n      try :\n       condgroup=int(condname)\n      except ValueError:\n       raise error(\"bad character in group name\")\n    else :\n    \n     if not source. next in FLAGS:\n      raise error(\"unexpected end of pattern\")\n     while source. next in FLAGS:\n      state. flags=state. flags |FLAGS[sourceget()]\n   if group:\n   \n    if group ==2:\n    \n     group=None\n    else :\n     group=state. opengroup(name)\n    if condgroup:\n     p=_parse_sub_cond(source,state,condgroup)\n    else :\n     p=_parse_sub(source,state)\n    if not sourcematch(\")\"):\n     raise error(\"unbalanced parenthesis\")\n    if group is not None :\n     state. closegroup(group)\n    subpatternappend((SUBPATTERN,(group,p)))\n   else :\n    while 1:\n     char=sourceget()\n     if char is None :\n      raise error(\"unexpected end of pattern\")\n     if char ==\")\":\n      break\n     raise error(\"unknown extension\")\n     \n  elif this ==\"^\":\n   subpatternappend((AT,AT_BEGINNING))\n   \n  elif this ==\"$\":\n   subpattern. append((AT,AT_END))\n   \n  elif this and this[0]==\"\\\\\":\n   code=_escape(source,this,state)\n   subpatternappend(code)\n   \n  else :\n   raise error(\"parser error\")\n   \n return subpattern\n \ndef fix_flags(src,flags):\n\n if isinstance(src,str):\n  if not flags&SRE_FLAG_ASCII:\n   flags |=SRE_FLAG_UNICODE\n  elif flags&SRE_FLAG_UNICODE:\n   raise ValueError(\"ASCII and UNICODE flags are incompatible\")\n else :\n  if flags&SRE_FLAG_UNICODE:\n   raise ValueError(\"can't use UNICODE flag with a bytes pattern\")\n return flags\n \ndef parse(str,flags=0,pattern=None ):\n\n source=Tokenizer(str)\n \n if pattern is None :\n  pattern=Pattern()\n pattern. flags=flags\n pattern. str=str\n p=_parse_sub(source,pattern,0)\n p. pattern. flags=fix_flags(str,p. pattern. flags)\n \n tail=source. get()\n if tail ==\")\":\n  raise error(\"unbalanced parenthesis\")\n elif tail:\n  raise error(\"bogus characters at end of regular expression\")\n  \n if flags&SRE_FLAG_DEBUG:\n  p. dump()\n  \n if not (flags&SRE_FLAG_VERBOSE)and p. pattern. flags&SRE_FLAG_VERBOSE:\n \n \n  return parse(str,p. pattern. flags)\n  \n return p\n \ndef parse_template(source,pattern):\n\n\n s=Tokenizer(source)\n sget=s. get\n p=[]\n a=p. append\n def literal(literal,p=p,pappend=a):\n  if p and p[-1][0]is LITERAL:\n   p[-1]=LITERAL,p[-1][1]+literal\n  else :\n   pappend((LITERAL,literal))\n sep=source[:0]\n if isinstance(sep,str):\n  makechar=chr\n else :\n  makechar=chr\n while 1:\n  this=sget()\n  if this is None :\n   break\n  if this and this[0]==\"\\\\\":\n  \n   c=this[1:2]\n   if c ==\"g\":\n    name=\"\"\n    if s. match(\"<\"):\n     while 1:\n      char=sget()\n      if char is None :\n       raise error(\"unterminated group name\")\n      if char ==\">\":\n       break\n      name=name+char\n    if not name:\n     raise error(\"missing group name\")\n    try :\n     index=int(name)\n     if index <0:\n      raise error(\"negative group number\")\n    except ValueError:\n     if not isname(name):\n      raise error(\"bad character in group name\")\n     try :\n      index=pattern. groupindex[name]\n     except KeyError:\n      raise IndexError(\"unknown group name\")\n    a((MARK,index))\n   elif c ==\"0\":\n    if s. next in OCTDIGITS:\n     this=this+sget()\n     if s. next in OCTDIGITS:\n      this=this+sget()\n    literal(makechar(int(this[1:],8)&0xff))\n   elif c in DIGITS:\n    isoctal=False\n    if s. next in DIGITS:\n     this=this+sget()\n     if (c in OCTDIGITS and this[2]in OCTDIGITS and\n     s. next in OCTDIGITS):\n      this=this+sget()\n      isoctal=True\n      literal(makechar(int(this[1:],8)&0xff))\n    if not isoctal:\n     a((MARK,int(this[1:])))\n   else :\n    try :\n     this=makechar(ESCAPES[this][1])\n    except KeyError:\n     pass\n    literal(this)\n  else :\n   literal(this)\n   \n i=0\n groups=[]\n groupsappend=groups. append\n literals=[None ]*len(p)\n if isinstance(source,str):\n  encode=lambda x:x\n else :\n \n \n  encode=lambda x:x. encode('latin-1')\n for c,s in p:\n  if c is MARK:\n   groupsappend((i,s))\n   \n  else :\n   literals[i]=encode(s)\n  i=i+1\n return groups,literals\n \ndef expand_template(template,match):\n g=match. group\n sep=match. string[:0]\n groups,literals=template\n literals=literals[:]\n try :\n  for index,group in groups:\n   literals[index]=s=g(group)\n   if s is None :\n    raise error(\"unmatched group\")\n except IndexError:\n  raise error(\"invalid group reference\")\n return sep. join(literals)\n \n \n", ["_sre", "sre_constants", "sys"]], "string": [".py", "''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nimport _string\n\n\nwhitespace=' \\t\\n\\r\\v\\f'\nascii_lowercase='abcdefghijklmnopqrstuvwxyz'\nascii_uppercase='ABCDEFGHIJKLMNOPQRSTUVWXYZ'\nascii_letters=ascii_lowercase+ascii_uppercase\ndigits='0123456789'\nhexdigits=digits+'abcdef'+'ABCDEF'\noctdigits='01234567'\npunctuation=\"\"\"!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~\"\"\"\nprintable=digits+ascii_letters+punctuation+whitespace\n\n\n\n\ndef capwords(s,sep=None ):\n ''\n\n\n\n\n\n\n\n\n \n return (sep or' '). join(x. capitalize()for x in s. split(sep))\n \n \n \nimport re as _re\nfrom collections import ChainMap\n\nclass _TemplateMetaclass(type):\n pattern=r\"\"\"\n    %(delim)s(?:\n      (?P<escaped>%(delim)s) |   # Escape sequence of two delimiters\n      (?P<named>%(id)s)      |   # delimiter and a Python identifier\n      {(?P<braced>%(id)s)}   |   # delimiter and a braced identifier\n      (?P<invalid>)              # Other ill-formed delimiter exprs\n    )\n    \"\"\"\n \n def __init__(cls,name,bases,dct):\n  super(_TemplateMetaclass,cls). __init__(name,bases,dct)\n  if'pattern'in dct:\n   pattern=cls. pattern\n  else :\n   pattern=_TemplateMetaclass. pattern %{\n   'delim':_re. escape(cls. delimiter),\n   'id':cls. idpattern,\n   }\n  cls. pattern=_re. compile(pattern,cls. flags |_re. VERBOSE)\n  \n  \nclass Template(metaclass=_TemplateMetaclass):\n ''\n \n delimiter='$'\n idpattern=r'[_a-z][_a-z0-9]*'\n flags=_re. IGNORECASE\n \n def __init__(self,template):\n  self. template=template\n  \n  \n  \n def _invalid(self,mo):\n  i=mo. start('invalid')\n  lines=self. template[:i]. splitlines(keepends=True )\n  if not lines:\n   colno=1\n   lineno=1\n  else :\n   colno=i -len(''. join(lines[:-1]))\n   lineno=len(lines)\n  raise ValueError('Invalid placeholder in string: line %d, col %d'%\n  (lineno,colno))\n  \n def substitute(self,*args,**kws):\n  if len(args)>1:\n   raise TypeError('Too many positional arguments')\n  if not args:\n   mapping=kws\n  elif kws:\n   mapping=ChainMap(kws,args[0])\n  else :\n   mapping=args[0]\n   \n  def convert(mo):\n  \n   named=mo. group('named')or mo. group('braced')\n   if named is not None :\n    val=mapping[named]\n    \n    \n    return'%s'%(val,)\n   if mo. group('escaped')is not None :\n    return self. delimiter\n   if mo. group('invalid')is not None :\n    self. _invalid(mo)\n   raise ValueError('Unrecognized named group in pattern',\n   self. pattern)\n  return self. pattern. sub(convert,self. template)\n  \n def safe_substitute(self,*args,**kws):\n  if len(args)>1:\n   raise TypeError('Too many positional arguments')\n  if not args:\n   mapping=kws\n  elif kws:\n   mapping=ChainMap(kws,args[0])\n  else :\n   mapping=args[0]\n   \n  def convert(mo):\n   named=mo. group('named')or mo. group('braced')\n   if named is not None :\n    try :\n    \n    \n     return'%s'%(mapping[named],)\n    except KeyError:\n     return mo. group()\n   if mo. group('escaped')is not None :\n    return self. delimiter\n   if mo. group('invalid')is not None :\n    return mo. group()\n   raise ValueError('Unrecognized named group in pattern',\n   self. pattern)\n  return self. pattern. sub(convert,self. template)\n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \n  \nclass Formatter:\n def format(self,format_string,*args,**kwargs):\n  return format_string. format(*args,**kwargs)\n", ["_string", "collections", "re"]], "pdb": [".py", "#! /usr/bin/env python3\n\n\"\"\"\nThe Python Debugger Pdb\n=======================\n\nTo use the debugger in its simplest form:\n\n        >>> import pdb\n        >>> pdb.run('<a statement>')\n\nThe debugger's prompt is '(Pdb) '.  This will stop in the first\nfunction call in <a statement>.\n\nAlternatively, if a statement terminated with an unhandled exception,\nyou can use pdb's post-mortem facility to inspect the contents of the\ntraceback:\n\n        >>> <a statement>\n        <exception traceback>\n        >>> import pdb\n        >>> pdb.pm()\n\nThe commands recognized by the debugger are listed in the next\nsection.  Most can be abbreviated as indicated; e.g., h(elp) means\nthat 'help' can be typed as 'h' or 'help' (but not as 'he' or 'hel',\nnor as 'H' or 'Help' or 'HELP').  Optional arguments are enclosed in\nsquare brackets.  Alternatives in the command syntax are separated\nby a vertical bar (|).\n\nA blank line repeats the previous command literally, except for\n'list', where it lists the next 11 lines.\n\nCommands that the debugger doesn't recognize are assumed to be Python\nstatements and are executed in the context of the program being\ndebugged.  Python statements can also be prefixed with an exclamation\npoint ('!').  This is a powerful way to inspect the program being\ndebugged; it is even possible to change variables or call functions.\nWhen an exception occurs in such a statement, the exception name is\nprinted but the debugger's state is not changed.\n\nThe debugger supports aliases, which can save typing.  And aliases can\nhave parameters (see the alias help entry) which allows one a certain\nlevel of adaptability to the context under examination.\n\nMultiple commands may be entered on a single line, separated by the\npair ';;'.  No intelligence is applied to separating the commands; the\ninput is split at the first ';;', even if it is in the middle of a\nquoted string.\n\nIf a file \".pdbrc\" exists in your home directory or in the current\ndirectory, it is read in and executed as if it had been typed at the\ndebugger prompt.  This is particularly useful for aliases.  If both\nfiles exist, the one in the home directory is read first and aliases\ndefined there can be overriden by the local file.\n\nAside from aliases, the debugger is not directly programmable; but it\nis implemented as a class from which you can derive your own debugger\nclass, which you can make as fancy as you like.\n\n\nDebugger commands\n=================\n\n\"\"\"\n\n\n\nimport os\nimport re\nimport sys\nimport cmd\nimport bdb\nimport dis\nimport code\nimport glob\nimport pprint\nimport signal\nimport inspect\nimport traceback\nimport linecache\n\n\nclass Restart(Exception):\n ''\n pass\n \n__all__=[\"run\",\"pm\",\"Pdb\",\"runeval\",\"runctx\",\"runcall\",\"set_trace\",\n\"post_mortem\",\"help\"]\n\ndef find_function(funcname,filename):\n cre=re. compile(r'def\\s+%s\\s*[(]'%re. escape(funcname))\n try :\n  fp=open(filename)\n except OSError:\n  return None\n  \n with fp:\n  for lineno,line in enumerate(fp,start=1):\n   if cre. match(line):\n    return funcname,filename,lineno\n return None\n \ndef getsourcelines(obj):\n lines,lineno=inspect. findsource(obj)\n if inspect. isframe(obj)and obj. f_globals is obj. f_locals:\n \n  return lines,1\n elif inspect. ismodule(obj):\n  return lines,1\n return inspect. getblock(lines[lineno:]),lineno+1\n \ndef lasti2lineno(code,lasti):\n linestarts=list(dis. findlinestarts(code))\n linestarts. reverse()\n for i,lineno in linestarts:\n  if lasti >=i:\n   return lineno\n return 0\n \n \nclass _rstr(str):\n ''\n def __repr__(self):\n  return self\n  \n  \n  \n  \n  \n  \n  \nline_prefix='\\n-> '\n\nclass Pdb(bdb. Bdb,cmd. Cmd):\n\n def __init__(self,completekey='tab',stdin=None ,stdout=None ,skip=None ,\n nosigint=False ):\n  bdb. Bdb. __init__(self,skip=skip)\n  cmd. Cmd. __init__(self,completekey,stdin,stdout)\n  if stdout:\n   self. use_rawinput=0\n  self. prompt='(Pdb) '\n  self. aliases={}\n  self. displaying={}\n  self. mainpyfile=''\n  self. _wait_for_mainpyfile=False\n  self. tb_lineno={}\n  \n  try :\n   import readline\n   \n   readline. set_completer_delims(' \\t\\n`@#$%^&*()=+[{]}\\\\|;:\\'\",<>?')\n  except ImportError:\n   pass\n  self. allow_kbdint=False\n  self. nosigint=nosigint\n  \n  \n  self. rcLines=[]\n  if'HOME'in os. environ:\n   envHome=os. environ['HOME']\n   try :\n    with open(os. path. join(envHome,\".pdbrc\"))as rcFile:\n     self. rcLines. extend(rcFile)\n   except OSError:\n    pass\n  try :\n   with open(\".pdbrc\")as rcFile:\n    self. rcLines. extend(rcFile)\n  except OSError:\n   pass\n   \n  self. commands={}\n  self. commands_doprompt={}\n  \n  self. commands_silent={}\n  \n  self. commands_defining=False\n  \n  self. commands_bnum=None\n  \n  \n def sigint_handler(self,signum,frame):\n  if self. allow_kbdint:\n   raise KeyboardInterrupt\n  self. message(\"\\nProgram interrupted. (Use 'cont' to resume).\")\n  self. set_step()\n  self. set_trace(frame)\n  \n  signal. signal(signal. SIGINT,self. _previous_sigint_handler)\n  \n def reset(self):\n  bdb. Bdb. reset(self)\n  self. forget()\n  \n def forget(self):\n  self. lineno=None\n  self. stack=[]\n  self. curindex=0\n  self. curframe=None\n  self. tb_lineno. clear()\n  \n def setup(self,f,tb):\n  self. forget()\n  self. stack,self. curindex=self. get_stack(f,tb)\n  while tb:\n  \n  \n  \n   lineno=lasti2lineno(tb. tb_frame. f_code,tb. tb_lasti)\n   self. tb_lineno[tb. tb_frame]=lineno\n   tb=tb. tb_next\n  self. curframe=self. stack[self. curindex][0]\n  \n  \n  \n  self. curframe_locals=self. curframe. f_locals\n  return self. execRcLines()\n  \n  \n def execRcLines(self):\n  if not self. rcLines:\n   return\n   \n  rcLines=self. rcLines\n  rcLines. reverse()\n  \n  self. rcLines=[]\n  while rcLines:\n   line=rcLines. pop(). strip()\n   if line and line[0]!='#':\n    if self. onecmd(line):\n    \n    \n    \n     self. rcLines +=reversed(rcLines)\n     return True\n     \n     \n     \n def user_call(self,frame,argument_list):\n  ''\n  \n  if self. _wait_for_mainpyfile:\n   return\n  if self. stop_here(frame):\n   self. message('--Call--')\n   self. interaction(frame,None )\n   \n def user_line(self,frame):\n  ''\n  if self. _wait_for_mainpyfile:\n   if (self. mainpyfile !=self. canonic(frame. f_code. co_filename)\n   or frame. f_lineno <=0):\n    return\n   self. _wait_for_mainpyfile=False\n  if self. bp_commands(frame):\n   self. interaction(frame,None )\n   \n def bp_commands(self,frame):\n  ''\n\n\n\n  \n  \n  if getattr(self,\"currentbp\",False )and  self. currentbp in self. commands:\n   currentbp=self. currentbp\n   self. currentbp=0\n   lastcmd_back=self. lastcmd\n   self. setup(frame,None )\n   for line in self. commands[currentbp]:\n    self. onecmd(line)\n   self. lastcmd=lastcmd_back\n   if not self. commands_silent[currentbp]:\n    self. print_stack_entry(self. stack[self. curindex])\n   if self. commands_doprompt[currentbp]:\n    self. _cmdloop()\n   self. forget()\n   return\n  return 1\n  \n def user_return(self,frame,return_value):\n  ''\n  if self. _wait_for_mainpyfile:\n   return\n  frame. f_locals['__return__']=return_value\n  self. message('--Return--')\n  self. interaction(frame,None )\n  \n def user_exception(self,frame,exc_info):\n  ''\n  \n  if self. _wait_for_mainpyfile:\n   return\n  exc_type,exc_value,exc_traceback=exc_info\n  frame. f_locals['__exception__']=exc_type,exc_value\n  \n  \n  \n  \n  \n  \n  prefix='Internal 'if (not exc_traceback\n  and exc_type is StopIteration)else''\n  self. message('%s%s'%(prefix,\n  traceback. format_exception_only(exc_type,exc_value)[-1]. strip()))\n  self. interaction(frame,exc_traceback)\n  \n  \n def _cmdloop(self):\n  while True :\n   try :\n   \n   \n    self. allow_kbdint=True\n    self. cmdloop()\n    self. allow_kbdint=False\n    break\n   except KeyboardInterrupt:\n    self. message('--KeyboardInterrupt--')\n    \n    \n def preloop(self):\n  displaying=self. displaying. get(self. curframe)\n  if displaying:\n   for expr,oldvalue in displaying. items():\n    newvalue=self. _getval_except(expr)\n    \n    \n    \n    if newvalue is not oldvalue and newvalue !=oldvalue:\n     displaying[expr]=newvalue\n     self. message('display %s: %r  [old: %r]'%\n     (expr,newvalue,oldvalue))\n     \n def interaction(self,frame,traceback):\n  if self. setup(frame,traceback):\n  \n  \n   self. forget()\n   return\n  self. print_stack_entry(self. stack[self. curindex])\n  self. _cmdloop()\n  self. forget()\n  \n def displayhook(self,obj):\n  ''\n\n  \n  \n  if obj is not None :\n   self. message(repr(obj))\n   \n def default(self,line):\n  if line[:1]=='!':line=line[1:]\n  locals=self. curframe_locals\n  globals=self. curframe. f_globals\n  try :\n   code=compile(line+'\\n','<stdin>','single')\n   save_stdout=sys. stdout\n   save_stdin=sys. stdin\n   save_displayhook=sys. displayhook\n   try :\n    sys. stdin=self. stdin\n    sys. stdout=self. stdout\n    sys. displayhook=self. displayhook\n    exec(code,globals,locals)\n   finally :\n    sys. stdout=save_stdout\n    sys. stdin=save_stdin\n    sys. displayhook=save_displayhook\n  except :\n   exc_info=sys. exc_info()[:2]\n   self. error(traceback. format_exception_only(*exc_info)[-1]. strip())\n   \n def precmd(self,line):\n  ''\n  if not line. strip():\n   return line\n  args=line. split()\n  while args[0]in self. aliases:\n   line=self. aliases[args[0]]\n   ii=1\n   for tmpArg in args[1:]:\n    line=line. replace(\"%\"+str(ii),\n    tmpArg)\n    ii +=1\n   line=line. replace(\"%*\",' '. join(args[1:]))\n   args=line. split()\n   \n   \n  if args[0]!='alias':\n   marker=line. find(';;')\n   if marker >=0:\n   \n    next=line[marker+2:]. lstrip()\n    self. cmdqueue. append(next)\n    line=line[:marker]. rstrip()\n  return line\n  \n def onecmd(self,line):\n  ''\n\n\n\n\n  \n  if not self. commands_defining:\n   return cmd. Cmd. onecmd(self,line)\n  else :\n   return self. handle_command_def(line)\n   \n def handle_command_def(self,line):\n  ''\n  cmd,arg,line=self. parseline(line)\n  if not cmd:\n   return\n  if cmd =='silent':\n   self. commands_silent[self. commands_bnum]=True\n   return\n  elif cmd =='end':\n   self. cmdqueue=[]\n   return 1\n  cmdlist=self. commands[self. commands_bnum]\n  if arg:\n   cmdlist. append(cmd+' '+arg)\n  else :\n   cmdlist. append(cmd)\n   \n  try :\n   func=getattr(self,'do_'+cmd)\n  except AttributeError:\n   func=self. default\n   \n  if func. __name__ in self. commands_resuming:\n   self. commands_doprompt[self. commands_bnum]=False\n   self. cmdqueue=[]\n   return 1\n  return\n  \n  \n  \n def message(self,msg):\n  print(msg,file=self. stdout)\n  \n def error(self,msg):\n  print('***',msg,file=self. stdout)\n  \n  \n  \n  \n def _complete_location(self,text,line,begidx,endidx):\n \n  if line. strip(). endswith((':',',')):\n  \n   return []\n   \n  try :\n   ret=self. _complete_expression(text,line,begidx,endidx)\n  except Exception:\n   ret=[]\n   \n  globs=glob. glob(text+'*')\n  for fn in globs:\n   if os. path. isdir(fn):\n    ret. append(fn+'/')\n   elif os. path. isfile(fn)and fn. lower(). endswith(('.py','.pyw')):\n    ret. append(fn+':')\n  return ret\n  \n def _complete_bpnumber(self,text,line,begidx,endidx):\n \n \n \n  return [str(i)for i,bp in enumerate(bdb. Breakpoint. bpbynumber)\n  if bp is not None and str(i). startswith(text)]\n  \n def _complete_expression(self,text,line,begidx,endidx):\n \n  if not self. curframe:\n   return []\n   \n   \n   \n  ns=self. curframe. f_globals. copy()\n  ns. update(self. curframe_locals)\n  if'.'in text:\n  \n  \n  \n   dotted=text. split('.')\n   try :\n    obj=ns[dotted[0]]\n    for part in dotted[1:-1]:\n     obj=getattr(obj,part)\n   except (KeyError,AttributeError):\n    return []\n   prefix='.'. join(dotted[:-1])+'.'\n   return [prefix+n for n in dir(obj)if n. startswith(dotted[-1])]\n  else :\n  \n   return [n for n in ns. keys()if n. startswith(text)]\n   \n   \n   \n   \n   \n def do_commands(self,arg):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if not arg:\n   bnum=len(bdb. Breakpoint. bpbynumber)-1\n  else :\n   try :\n    bnum=int(arg)\n   except :\n    self. error(\"Usage: commands [bnum]\\n        ...\\n        end\")\n    return\n  self. commands_bnum=bnum\n  \n  if bnum in self. commands:\n   old_command_defs=(self. commands[bnum],\n   self. commands_doprompt[bnum],\n   self. commands_silent[bnum])\n  else :\n   old_command_defs=None\n  self. commands[bnum]=[]\n  self. commands_doprompt[bnum]=True\n  self. commands_silent[bnum]=False\n  \n  prompt_back=self. prompt\n  self. prompt='(com) '\n  self. commands_defining=True\n  try :\n   self. cmdloop()\n  except KeyboardInterrupt:\n  \n   if old_command_defs:\n    self. commands[bnum]=old_command_defs[0]\n    self. commands_doprompt[bnum]=old_command_defs[1]\n    self. commands_silent[bnum]=old_command_defs[2]\n   else :\n    del self. commands[bnum]\n    del self. commands_doprompt[bnum]\n    del self. commands_silent[bnum]\n   self. error('command definition aborted, old commands restored')\n  finally :\n   self. commands_defining=False\n   self. prompt=prompt_back\n   \n complete_commands=_complete_bpnumber\n \n def do_break(self,arg,temporary=0):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  if not arg:\n   if self. breaks:\n    self. message(\"Num Type         Disp Enb   Where\")\n    for bp in bdb. Breakpoint. bpbynumber:\n     if bp:\n      self. message(bp. bpformat())\n   return\n   \n   \n  filename=None\n  lineno=None\n  cond=None\n  comma=arg. find(',')\n  if comma >0:\n  \n   cond=arg[comma+1:]. lstrip()\n   arg=arg[:comma]. rstrip()\n   \n  colon=arg. rfind(':')\n  funcname=None\n  if colon >=0:\n   filename=arg[:colon]. rstrip()\n   f=self. lookupmodule(filename)\n   if not f:\n    self. error('%r not found from sys.path'%filename)\n    return\n   else :\n    filename=f\n   arg=arg[colon+1:]. lstrip()\n   try :\n    lineno=int(arg)\n   except ValueError:\n    self. error('Bad lineno: %s'%arg)\n    return\n  else :\n  \n   try :\n    lineno=int(arg)\n   except ValueError:\n    try :\n     func=eval(arg,\n     self. curframe. f_globals,\n     self. curframe_locals)\n    except :\n     func=arg\n    try :\n     if hasattr(func,'__func__'):\n      func=func. __func__\n     code=func. __code__\n     \n     \n     funcname=code. co_name\n     lineno=code. co_firstlineno\n     filename=code. co_filename\n    except :\n    \n     (ok,filename,ln)=self. lineinfo(arg)\n     if not ok:\n      self. error('The specified object %r is not a function '\n      'or was not found along sys.path.'%arg)\n      return\n     funcname=ok\n     lineno=int(ln)\n  if not filename:\n   filename=self. defaultFile()\n   \n  line=self. checkline(filename,lineno)\n  if line:\n  \n   err=self. set_break(filename,line,temporary,cond,funcname)\n   if err:\n    self. error(err)\n   else :\n    bp=self. get_breaks(filename,line)[-1]\n    self. message(\"Breakpoint %d at %s:%d\"%\n    (bp. number,bp. file,bp. line))\n    \n    \n def defaultFile(self):\n  ''\n  filename=self. curframe. f_code. co_filename\n  if filename =='<string>'and self. mainpyfile:\n   filename=self. mainpyfile\n  return filename\n  \n do_b=do_break\n \n complete_break=_complete_location\n complete_b=_complete_location\n \n def do_tbreak(self,arg):\n  ''\n\n\n  \n  self. do_break(arg,1)\n  \n complete_tbreak=_complete_location\n \n def lineinfo(self,identifier):\n  failed=(None ,None ,None )\n  \n  idstring=identifier. split(\"'\")\n  if len(idstring)==1:\n  \n   id=idstring[0]. strip()\n  elif len(idstring)==3:\n  \n   id=idstring[1]. strip()\n  else :\n   return failed\n  if id =='':return failed\n  parts=id. split('.')\n  \n  if parts[0]=='self':\n   del parts[0]\n   if len(parts)==0:\n    return failed\n    \n  fname=self. defaultFile()\n  if len(parts)==1:\n   item=parts[0]\n  else :\n  \n  \n   f=self. lookupmodule(parts[0])\n   if f:\n    fname=f\n   item=parts[1]\n  answer=find_function(item,fname)\n  return answer or failed\n  \n def checkline(self,filename,lineno):\n  ''\n\n\n\n  \n  \n  \n  globs=self. curframe. f_globals if hasattr(self,'curframe')else None\n  line=linecache. getline(filename,lineno,globs)\n  if not line:\n   self. message('End of file')\n   return 0\n  line=line. strip()\n  \n  if (not line or (line[0]=='#')or\n  (line[:3]=='\"\"\"')or line[:3]==\"'''\"):\n   self. error('Blank or comment')\n   return 0\n  return lineno\n  \n def do_enable(self,arg):\n  ''\n\n\n  \n  args=arg. split()\n  for i in args:\n   try :\n    bp=self. get_bpbynumber(i)\n   except ValueError as err:\n    self. error(err)\n   else :\n    bp. enable()\n    self. message('Enabled %s'%bp)\n    \n complete_enable=_complete_bpnumber\n \n def do_disable(self,arg):\n  ''\n\n\n\n\n\n  \n  args=arg. split()\n  for i in args:\n   try :\n    bp=self. get_bpbynumber(i)\n   except ValueError as err:\n    self. error(err)\n   else :\n    bp. disable()\n    self. message('Disabled %s'%bp)\n    \n complete_disable=_complete_bpnumber\n \n def do_condition(self,arg):\n  ''\n\n\n\n\n  \n  args=arg. split(' ',1)\n  try :\n   cond=args[1]\n  except IndexError:\n   cond=None\n  try :\n   bp=self. get_bpbynumber(args[0]. strip())\n  except IndexError:\n   self. error('Breakpoint number expected')\n  except ValueError as err:\n   self. error(err)\n  else :\n   bp. cond=cond\n   if not cond:\n    self. message('Breakpoint %d is now unconditional.'%bp. number)\n   else :\n    self. message('New condition set for breakpoint %d.'%bp. number)\n    \n complete_condition=_complete_bpnumber\n \n def do_ignore(self,arg):\n  ''\n\n\n\n\n\n\n  \n  args=arg. split()\n  try :\n   count=int(args[1]. strip())\n  except :\n   count=0\n  try :\n   bp=self. get_bpbynumber(args[0]. strip())\n  except IndexError:\n   self. error('Breakpoint number expected')\n  except ValueError as err:\n   self. error(err)\n  else :\n   bp. ignore=count\n   if count >0:\n    if count >1:\n     countstr='%d crossings'%count\n    else :\n     countstr='1 crossing'\n    self. message('Will ignore next %s of breakpoint %d.'%\n    (countstr,bp. number))\n   else :\n    self. message('Will stop next time breakpoint %d is reached.'\n    %bp. number)\n    \n complete_ignore=_complete_bpnumber\n \n def do_clear(self,arg):\n  ''\n\n\n\n\n  \n  if not arg:\n   try :\n    reply=input('Clear all breaks? ')\n   except EOFError:\n    reply='no'\n   reply=reply. strip(). lower()\n   if reply in ('y','yes'):\n    bplist=[bp for bp in bdb. Breakpoint. bpbynumber if bp]\n    self. clear_all_breaks()\n    for bp in bplist:\n     self. message('Deleted %s'%bp)\n   return\n  if':'in arg:\n  \n   i=arg. rfind(':')\n   filename=arg[:i]\n   arg=arg[i+1:]\n   try :\n    lineno=int(arg)\n   except ValueError:\n    err=\"Invalid line number (%s)\"%arg\n   else :\n    bplist=self. get_breaks(filename,lineno)\n    err=self. clear_break(filename,lineno)\n   if err:\n    self. error(err)\n   else :\n    for bp in bplist:\n     self. message('Deleted %s'%bp)\n   return\n  numberlist=arg. split()\n  for i in numberlist:\n   try :\n    bp=self. get_bpbynumber(i)\n   except ValueError as err:\n    self. error(err)\n   else :\n    self. clear_bpbynumber(i)\n    self. message('Deleted %s'%bp)\n do_cl=do_clear\n \n complete_clear=_complete_location\n complete_cl=_complete_location\n \n def do_where(self,arg):\n  ''\n\n\n\n  \n  self. print_stack_trace()\n do_w=do_where\n do_bt=do_where\n \n def _select_frame(self,number):\n  assert 0 <=number <len(self. stack)\n  self. curindex=number\n  self. curframe=self. stack[self. curindex][0]\n  self. curframe_locals=self. curframe. f_locals\n  self. print_stack_entry(self. stack[self. curindex])\n  self. lineno=None\n  \n def do_up(self,arg):\n  ''\n\n\n  \n  if self. curindex ==0:\n   self. error('Oldest frame')\n   return\n  try :\n   count=int(arg or 1)\n  except ValueError:\n   self. error('Invalid frame count (%s)'%arg)\n   return\n  if count <0:\n   newframe=0\n  else :\n   newframe=max(0,self. curindex -count)\n  self. _select_frame(newframe)\n do_u=do_up\n \n def do_down(self,arg):\n  ''\n\n\n  \n  if self. curindex+1 ==len(self. stack):\n   self. error('Newest frame')\n   return\n  try :\n   count=int(arg or 1)\n  except ValueError:\n   self. error('Invalid frame count (%s)'%arg)\n   return\n  if count <0:\n   newframe=len(self. stack)-1\n  else :\n   newframe=min(len(self. stack)-1,self. curindex+count)\n  self. _select_frame(newframe)\n do_d=do_down\n \n def do_until(self,arg):\n  ''\n\n\n\n\n\n  \n  if arg:\n   try :\n    lineno=int(arg)\n   except ValueError:\n    self. error('Error in argument: %r'%arg)\n    return\n   if lineno <=self. curframe. f_lineno:\n    self. error('\"until\" line number is smaller than current '\n    'line number')\n    return\n  else :\n   lineno=None\n  self. set_until(self. curframe,lineno)\n  return 1\n do_unt=do_until\n \n def do_step(self,arg):\n  ''\n\n\n\n  \n  self. set_step()\n  return 1\n do_s=do_step\n \n def do_next(self,arg):\n  ''\n\n\n  \n  self. set_next(self. curframe)\n  return 1\n do_n=do_next\n \n def do_run(self,arg):\n  ''\n\n\n\n\n  \n  if arg:\n   import shlex\n   argv0=sys. argv[0:1]\n   sys. argv=shlex. split(arg)\n   sys. argv[:0]=argv0\n   \n  raise Restart\n  \n do_restart=do_run\n \n def do_return(self,arg):\n  ''\n\n  \n  self. set_return(self. curframe)\n  return 1\n do_r=do_return\n \n def do_continue(self,arg):\n  ''\n\n  \n  if not self. nosigint:\n   try :\n    self. _previous_sigint_handler=    signal. signal(signal. SIGINT,self. sigint_handler)\n   except ValueError:\n   \n   \n   \n   \n    pass\n  self. set_continue()\n  return 1\n do_c=do_cont=do_continue\n \n def do_jump(self,arg):\n  ''\n\n\n\n\n\n\n\n\n  \n  if self. curindex+1 !=len(self. stack):\n   self. error('You can only jump within the bottom frame')\n   return\n  try :\n   arg=int(arg)\n  except ValueError:\n   self. error(\"The 'jump' command requires a line number\")\n  else :\n   try :\n   \n   \n    self. curframe. f_lineno=arg\n    self. stack[self. curindex]=self. stack[self. curindex][0],arg\n    self. print_stack_entry(self. stack[self. curindex])\n   except ValueError as e:\n    self. error('Jump failed: %s'%e)\n do_j=do_jump\n \n def do_debug(self,arg):\n  ''\n\n\n\n  \n  sys. settrace(None )\n  globals=self. curframe. f_globals\n  locals=self. curframe_locals\n  p=Pdb(self. completekey,self. stdin,self. stdout)\n  p. prompt=\"(%s) \"%self. prompt. strip()\n  self. message(\"ENTERING RECURSIVE DEBUGGER\")\n  sys. call_tracing(p. run,(arg,globals,locals))\n  self. message(\"LEAVING RECURSIVE DEBUGGER\")\n  sys. settrace(self. trace_dispatch)\n  self. lastcmd=p. lastcmd\n  \n complete_debug=_complete_expression\n \n def do_quit(self,arg):\n  ''\n\n  \n  self. _user_requested_quit=True\n  self. set_quit()\n  return 1\n  \n do_q=do_quit\n do_exit=do_quit\n \n def do_EOF(self,arg):\n  ''\n\n  \n  self. message('')\n  self. _user_requested_quit=True\n  self. set_quit()\n  return 1\n  \n def do_args(self,arg):\n  ''\n\n  \n  co=self. curframe. f_code\n  dict=self. curframe_locals\n  n=co. co_argcount\n  if co. co_flags&4:n=n+1\n  if co. co_flags&8:n=n+1\n  for i in range(n):\n   name=co. co_varnames[i]\n   if name in dict:\n    self. message('%s = %r'%(name,dict[name]))\n   else :\n    self. message('%s = *** undefined ***'%(name,))\n do_a=do_args\n \n def do_retval(self,arg):\n  ''\n\n  \n  if'__return__'in self. curframe_locals:\n   self. message(repr(self. curframe_locals['__return__']))\n  else :\n   self. error('Not yet returned!')\n do_rv=do_retval\n \n def _getval(self,arg):\n  try :\n   return eval(arg,self. curframe. f_globals,self. curframe_locals)\n  except :\n   exc_info=sys. exc_info()[:2]\n   self. error(traceback. format_exception_only(*exc_info)[-1]. strip())\n   raise\n   \n def _getval_except(self,arg,frame=None ):\n  try :\n   if frame is None :\n    return eval(arg,self. curframe. f_globals,self. curframe_locals)\n   else :\n    return eval(arg,frame. f_globals,frame. f_locals)\n  except :\n   exc_info=sys. exc_info()[:2]\n   err=traceback. format_exception_only(*exc_info)[-1]. strip()\n   return _rstr('** raised %s **'%err)\n   \n def do_p(self,arg):\n  ''\n\n  \n  try :\n   self. message(repr(self. _getval(arg)))\n  except :\n   pass\n   \n def do_pp(self,arg):\n  ''\n\n  \n  try :\n   self. message(pprint. pformat(self. _getval(arg)))\n  except :\n   pass\n   \n complete_print=_complete_expression\n complete_p=_complete_expression\n complete_pp=_complete_expression\n \n def do_list(self,arg):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. lastcmd='list'\n  last=None\n  if arg and arg !='.':\n   try :\n    if','in arg:\n     first,last=arg. split(',')\n     first=int(first. strip())\n     last=int(last. strip())\n     if last <first:\n     \n      last=first+last\n    else :\n     first=int(arg. strip())\n     first=max(1,first -5)\n   except ValueError:\n    self. error('Error in argument: %r'%arg)\n    return\n  elif self. lineno is None or arg =='.':\n   first=max(1,self. curframe. f_lineno -5)\n  else :\n   first=self. lineno+1\n  if last is None :\n   last=first+10\n  filename=self. curframe. f_code. co_filename\n  breaklist=self. get_file_breaks(filename)\n  try :\n   lines=linecache. getlines(filename,self. curframe. f_globals)\n   self. _print_lines(lines[first -1:last],first,breaklist,\n   self. curframe)\n   self. lineno=min(last,len(lines))\n   if len(lines)<last:\n    self. message('[EOF]')\n  except KeyboardInterrupt:\n   pass\n do_l=do_list\n \n def do_longlist(self,arg):\n  ''\n\n  \n  filename=self. curframe. f_code. co_filename\n  breaklist=self. get_file_breaks(filename)\n  try :\n   lines,lineno=getsourcelines(self. curframe)\n  except OSError as err:\n   self. error(err)\n   return\n  self. _print_lines(lines,lineno,breaklist,self. curframe)\n do_ll=do_longlist\n \n def do_source(self,arg):\n  ''\n\n  \n  try :\n   obj=self. _getval(arg)\n  except :\n   return\n  try :\n   lines,lineno=getsourcelines(obj)\n  except (OSError,TypeError)as err:\n   self. error(err)\n   return\n  self. _print_lines(lines,lineno)\n  \n complete_source=_complete_expression\n \n def _print_lines(self,lines,start,breaks=(),frame=None ):\n  ''\n  if frame:\n   current_lineno=frame. f_lineno\n   exc_lineno=self. tb_lineno. get(frame,-1)\n  else :\n   current_lineno=exc_lineno=-1\n  for lineno,line in enumerate(lines,start):\n   s=str(lineno). rjust(3)\n   if len(s)<4:\n    s +=' '\n   if lineno in breaks:\n    s +='B'\n   else :\n    s +=' '\n   if lineno ==current_lineno:\n    s +='->'\n   elif lineno ==exc_lineno:\n    s +='>>'\n   self. message(s+'\\t'+line. rstrip())\n   \n def do_whatis(self,arg):\n  ''\n\n  \n  try :\n   value=self. _getval(arg)\n  except :\n  \n   return\n  code=None\n  \n  try :\n   code=value. __code__\n  except Exception:\n   pass\n  if code:\n   self. message('Function %s'%code. co_name)\n   return\n   \n  try :\n   code=value. __func__. __code__\n  except Exception:\n   pass\n  if code:\n   self. message('Method %s'%code. co_name)\n   return\n   \n  if value. __class__ is type:\n   self. message('Class %s.%s'%(value. __module__,value. __name__))\n   return\n   \n  self. message(type(value))\n  \n complete_whatis=_complete_expression\n \n def do_display(self,arg):\n  ''\n\n\n\n\n\n  \n  if not arg:\n   self. message('Currently displaying:')\n   for item in self. displaying. get(self. curframe,{}). items():\n    self. message('%s: %r'%item)\n  else :\n   val=self. _getval_except(arg)\n   self. displaying. setdefault(self. curframe,{})[arg]=val\n   self. message('display %s: %r'%(arg,val))\n   \n complete_display=_complete_expression\n \n def do_undisplay(self,arg):\n  ''\n\n\n\n\n  \n  if arg:\n   try :\n    del self. displaying. get(self. curframe,{})[arg]\n   except KeyError:\n    self. error('not displaying %s'%arg)\n  else :\n   self. displaying. pop(self. curframe,None )\n   \n def complete_undisplay(self,text,line,begidx,endidx):\n  return [e for e in self. displaying. get(self. curframe,{})\n  if e. startswith(text)]\n  \n def do_interact(self,arg):\n  ''\n\n\n\n  \n  ns=self. curframe. f_globals. copy()\n  ns. update(self. curframe_locals)\n  code. interact(\"*interactive*\",local=ns)\n  \n def do_alias(self,arg):\n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  args=arg. split()\n  if len(args)==0:\n   keys=sorted(self. aliases. keys())\n   for alias in keys:\n    self. message(\"%s = %s\"%(alias,self. aliases[alias]))\n   return\n  if args[0]in self. aliases and len(args)==1:\n   self. message(\"%s = %s\"%(args[0],self. aliases[args[0]]))\n  else :\n   self. aliases[args[0]]=' '. join(args[1:])\n   \n def do_unalias(self,arg):\n  ''\n\n  \n  args=arg. split()\n  if len(args)==0:return\n  if args[0]in self. aliases:\n   del self. aliases[args[0]]\n   \n def complete_unalias(self,text,line,begidx,endidx):\n  return [a for a in self. aliases if a. startswith(text)]\n  \n  \n commands_resuming=['do_continue','do_step','do_next','do_return',\n 'do_quit','do_jump']\n \n \n \n \n \n \n \n \n \n def print_stack_trace(self):\n  try :\n   for frame_lineno in self. stack:\n    self. print_stack_entry(frame_lineno)\n  except KeyboardInterrupt:\n   pass\n   \n def print_stack_entry(self,frame_lineno,prompt_prefix=line_prefix):\n  frame,lineno=frame_lineno\n  if frame is self. curframe:\n   prefix='> '\n  else :\n   prefix='  '\n  self. message(prefix+\n  self. format_stack_entry(frame_lineno,prompt_prefix))\n  \n  \n  \n def do_help(self,arg):\n  ''\n\n\n\n\n  \n  if not arg:\n   return cmd. Cmd. do_help(self,arg)\n  try :\n   try :\n    topic=getattr(self,'help_'+arg)\n    return topic()\n   except AttributeError:\n    command=getattr(self,'do_'+arg)\n  except AttributeError:\n   self. error('No help for %r'%arg)\n  else :\n   if sys. flags. optimize >=2:\n    self. error('No help for %r; please do not run Python with -OO '\n    'if you need command help'%arg)\n    return\n   self. message(command. __doc__. rstrip())\n   \n do_h=do_help\n \n def help_exec(self):\n  ''\n\n\n\n\n\n\n\n  \n  self. message((self. help_exec. __doc__ or''). strip())\n  \n def help_pdb(self):\n  help()\n  \n  \n  \n def lookupmodule(self,filename):\n  ''\n\n\n\n  \n  if os. path. isabs(filename)and os. path. exists(filename):\n   return filename\n  f=os. path. join(sys. path[0],filename)\n  if os. path. exists(f)and self. canonic(f)==self. mainpyfile:\n   return f\n  root,ext=os. path. splitext(filename)\n  if ext =='':\n   filename=filename+'.py'\n  if os. path. isabs(filename):\n   return filename\n  for dirname in sys. path:\n   while os. path. islink(dirname):\n    dirname=os. readlink(dirname)\n   fullname=os. path. join(dirname,filename)\n   if os. path. exists(fullname):\n    return fullname\n  return None\n  \n def _runscript(self,filename):\n \n \n \n \n \n  import __main__\n  __main__. __dict__. clear()\n  __main__. __dict__. update({\"__name__\":\"__main__\",\n  \"__file__\":filename,\n  \"__builtins__\":__builtins__,\n  })\n  \n  \n  \n  \n  \n  \n  self. _wait_for_mainpyfile=True\n  self. mainpyfile=self. canonic(filename)\n  self. _user_requested_quit=False\n  with open(filename,\"rb\")as fp:\n   statement=\"exec(compile(%r, %r, 'exec'))\"%   (fp. read(),self. mainpyfile)\n  self. run(statement)\n  \n  \n  \nif __doc__ is not None :\n\n _help_order=[\n 'help','where','down','up','break','tbreak','clear','disable',\n 'enable','ignore','condition','commands','step','next','until',\n 'jump','return','retval','run','continue','list','longlist',\n 'args','p','pp','whatis','source','display','undisplay',\n 'interact','alias','unalias','debug','quit',\n ]\n \n for _command in _help_order:\n  __doc__ +=getattr(Pdb,'do_'+_command). __doc__. strip()+'\\n\\n'\n __doc__ +=Pdb. help_exec. __doc__\n \n del _help_order,_command\n \n \n \n \ndef run(statement,globals=None ,locals=None ):\n Pdb(). run(statement,globals,locals)\n \ndef runeval(expression,globals=None ,locals=None ):\n return Pdb(). runeval(expression,globals,locals)\n \ndef runctx(statement,globals,locals):\n\n run(statement,globals,locals)\n \ndef runcall(*args,**kwds):\n return Pdb(). runcall(*args,**kwds)\n \ndef set_trace():\n Pdb(). set_trace(sys. _getframe(). f_back)\n \n \n \ndef post_mortem(t=None ):\n\n if t is None :\n \n \n  t=sys. exc_info()[2]\n if t is None :\n  raise ValueError(\"A valid traceback must be passed if no \"\n  \"exception is being handled\")\n  \n p=Pdb()\n p. reset()\n p. interaction(None ,t)\n \ndef pm():\n post_mortem(sys. last_traceback)\n \n \n \n \nTESTCMD='import x; x.main()'\n\ndef test():\n run(TESTCMD)\n \n \ndef help():\n import pydoc\n pydoc. pager(__doc__)\n \n_usage=\"\"\"\\\nusage: pdb.py [-c command] ... pyfile [arg] ...\n\nDebug the Python program given by pyfile.\n\nInitial commands are read from .pdbrc files in your home directory\nand in the current directory, if they exist.  Commands supplied with\n-c are executed after commands from .pdbrc files.\n\nTo let the script run until an exception occurs, use \"-c continue\".\nTo let the script run up to a given line X in the debugged file, use\n\"-c 'until X'\".\"\"\"\n\ndef main():\n import getopt\n \n opts,args=getopt. getopt(sys. argv[1:],'hc:',['--help','--command='])\n \n if not args:\n  print(_usage)\n  sys. exit(2)\n  \n commands=[]\n for opt,optarg in opts:\n  if opt in ['-h','--help']:\n   print(_usage)\n   sys. exit()\n  elif opt in ['-c','--command']:\n   commands. append(optarg)\n   \n mainpyfile=args[0]\n if not os. path. exists(mainpyfile):\n  print('Error:',mainpyfile,'does not exist')\n  sys. exit(1)\n  \n sys. argv[:]=args\n \n \n sys. path[0]=os. path. dirname(mainpyfile)\n \n \n \n \n \n pdb=Pdb()\n pdb. rcLines. extend(commands)\n while True :\n  try :\n   pdb. _runscript(mainpyfile)\n   if pdb. _user_requested_quit:\n    break\n   print(\"The program finished and will be restarted\")\n  except Restart:\n   print(\"Restarting\",mainpyfile,\"with arguments:\")\n   print(\"\\t\"+\" \". join(args))\n  except SystemExit:\n  \n   print(\"The program exited via sys.exit(). Exit status:\",end=' ')\n   print(sys. exc_info()[1])\n  except :\n   traceback. print_exc()\n   print(\"Uncaught exception. Entering post mortem debugging\")\n   print(\"Running 'cont' or 'step' will restart the program\")\n   t=sys. exc_info()[2]\n   pdb. interaction(None ,t)\n   print(\"Post mortem debugger finished. The \"+mainpyfile+\n   \" will be restarted\")\n   \n   \n   \nif __name__ =='__main__':\n import pdb\n pdb. main()\n", ["__main__", "bdb", "cmd", "code", "dis", "getopt", "glob", "inspect", "linecache", "os", "pdb", "pprint", "pydoc", "re", "readline", "shlex", "signal", "sys", "traceback"]], "codecs": [".py", "''\n\n\n\n\n\n\n\n\nimport builtins,sys\n\n\n\ntry :\n from _codecs import *\nexcept ImportError as why:\n raise SystemError('Failed to load the builtin codecs: %s'%why)\n \n__all__=[\"register\",\"lookup\",\"open\",\"EncodedFile\",\"BOM\",\"BOM_BE\",\n\"BOM_LE\",\"BOM32_BE\",\"BOM32_LE\",\"BOM64_BE\",\"BOM64_LE\",\n\"BOM_UTF8\",\"BOM_UTF16\",\"BOM_UTF16_LE\",\"BOM_UTF16_BE\",\n\"BOM_UTF32\",\"BOM_UTF32_LE\",\"BOM_UTF32_BE\",\n\"strict_errors\",\"ignore_errors\",\"replace_errors\",\n\"xmlcharrefreplace_errors\",\n\"register_error\",\"lookup_error\"]\n\n\n\n\n\n\n\n\n\n\nBOM_UTF8=b'\\xef\\xbb\\xbf'\n\n\nBOM_LE=BOM_UTF16_LE=b'\\xff\\xfe'\n\n\nBOM_BE=BOM_UTF16_BE=b'\\xfe\\xff'\n\n\nBOM_UTF32_LE=b'\\xff\\xfe\\x00\\x00'\n\n\nBOM_UTF32_BE=b'\\x00\\x00\\xfe\\xff'\n\nif sys. byteorder =='little':\n\n\n BOM=BOM_UTF16=BOM_UTF16_LE\n \n \n BOM_UTF32=BOM_UTF32_LE\n \nelse :\n\n\n BOM=BOM_UTF16=BOM_UTF16_BE\n \n \n BOM_UTF32=BOM_UTF32_BE\n \n \nBOM32_LE=BOM_UTF16_LE\nBOM32_BE=BOM_UTF16_BE\nBOM64_LE=BOM_UTF32_LE\nBOM64_BE=BOM_UTF32_BE\n\n\n\n\nclass CodecInfo(tuple):\n\n def __new__(cls,encode,decode,streamreader=None ,streamwriter=None ,\n incrementalencoder=None ,incrementaldecoder=None ,name=None ):\n  self=tuple. __new__(cls,(encode,decode,streamreader,streamwriter))\n  self. name=name\n  self. encode=encode\n  self. decode=decode\n  self. incrementalencoder=incrementalencoder\n  self. incrementaldecoder=incrementaldecoder\n  self. streamwriter=streamwriter\n  self. streamreader=streamreader\n  return self\n  \n def __repr__(self):\n  return\"<%s.%s object for encoding %s at 0x%x>\"%  (self. __class__. __module__,self. __class__. __name__,\n  self. name,id(self))\n  \nclass Codec:\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n def encode(self,input,errors='strict'):\n \n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  raise NotImplementedError\n  \n def decode(self,input,errors='strict'):\n \n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  raise NotImplementedError\n  \nclass IncrementalEncoder(object):\n ''\n\n\n\n \n def __init__(self,errors='strict'):\n  ''\n\n\n\n\n\n  \n  self. errors=errors\n  self. buffer=\"\"\n  \n def encode(self,input,final=False ):\n  ''\n\n  \n  raise NotImplementedError\n  \n def reset(self):\n  ''\n\n  \n  \n def getstate(self):\n  ''\n\n  \n  return 0\n  \n def setstate(self,state):\n  ''\n\n\n  \n  \nclass BufferedIncrementalEncoder(IncrementalEncoder):\n ''\n\n\n\n \n def __init__(self,errors='strict'):\n  IncrementalEncoder. __init__(self,errors)\n  \n  self. buffer=\"\"\n  \n def _buffer_encode(self,input,errors,final):\n \n \n  raise NotImplementedError\n  \n def encode(self,input,final=False ):\n \n  data=self. buffer+input\n  (result,consumed)=self. _buffer_encode(data,self. errors,final)\n  \n  self. buffer=data[consumed:]\n  return result\n  \n def reset(self):\n  IncrementalEncoder. reset(self)\n  self. buffer=\"\"\n  \n def getstate(self):\n  return self. buffer or 0\n  \n def setstate(self,state):\n  self. buffer=state or\"\"\n  \nclass IncrementalDecoder(object):\n ''\n\n\n\n \n def __init__(self,errors='strict'):\n  ''\n\n\n\n\n\n  \n  self. errors=errors\n  \n def decode(self,input,final=False ):\n  ''\n\n  \n  raise NotImplementedError\n  \n def reset(self):\n  ''\n\n  \n  \n def getstate(self):\n  ''\n\n\n\n\n\n\n\n\n\n  \n  return (b\"\",0)\n  \n def setstate(self,state):\n  ''\n\n\n\n\n  \n  \nclass BufferedIncrementalDecoder(IncrementalDecoder):\n ''\n\n\n\n \n def __init__(self,errors='strict'):\n  IncrementalDecoder. __init__(self,errors)\n  \n  self. buffer=b\"\"\n  \n def _buffer_decode(self,input,errors,final):\n \n \n  raise NotImplementedError\n  \n def decode(self,input,final=False ):\n \n  data=self. buffer+input\n  (result,consumed)=self. _buffer_decode(data,self. errors,final)\n  \n  self. buffer=data[consumed:]\n  return result\n  \n def reset(self):\n  IncrementalDecoder. reset(self)\n  self. buffer=b\"\"\n  \n def getstate(self):\n \n  return (self. buffer,0)\n  \n def setstate(self,state):\n \n  self. buffer=state[0]\n  \n  \n  \n  \n  \n  \n  \n  \nclass StreamWriter(Codec):\n\n def __init__(self,stream,errors='strict'):\n \n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. stream=stream\n  self. errors=errors\n  \n def write(self,object):\n \n  ''\n  \n  data,consumed=self. encode(object,self. errors)\n  self. stream. write(data)\n  \n def writelines(self,list):\n \n  ''\n\n  \n  self. write(''. join(list))\n  \n def reset(self):\n \n  ''\n\n\n\n\n\n\n  \n  pass\n  \n def seek(self,offset,whence=0):\n  self. stream. seek(offset,whence)\n  if whence ==0 and offset ==0:\n   self. reset()\n   \n def __getattr__(self,name,\n getattr=getattr):\n \n  ''\n  \n  return getattr(self. stream,name)\n  \n def __enter__(self):\n  return self\n  \n def __exit__(self,type,value,tb):\n  self. stream. close()\n  \n  \n  \nclass StreamReader(Codec):\n\n charbuffertype=str\n \n def __init__(self,stream,errors='strict'):\n \n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. stream=stream\n  self. errors=errors\n  self. bytebuffer=b\"\"\n  self. _empty_charbuffer=self. charbuffertype()\n  self. charbuffer=self. _empty_charbuffer\n  self. linebuffer=None\n  \n def decode(self,input,errors='strict'):\n  raise NotImplementedError\n  \n def read(self,size=-1,chars=-1,firstline=False ):\n \n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  \n  if self. linebuffer:\n   self. charbuffer=self. _empty_charbuffer. join(self. linebuffer)\n   self. linebuffer=None\n   \n   \n  while True :\n  \n   if chars <0:\n    if size <0:\n     if self. charbuffer:\n      break\n    elif len(self. charbuffer)>=size:\n     break\n   else :\n    if len(self. charbuffer)>=chars:\n     break\n     \n   if size <0:\n    newdata=self. stream. read()\n   else :\n    newdata=self. stream. read(size)\n    \n   data=self. bytebuffer+newdata\n   try :\n    newchars,decodedbytes=self. decode(data,self. errors)\n   except UnicodeDecodeError as exc:\n    if firstline:\n     newchars,decodedbytes=     self. decode(data[:exc. start],self. errors)\n     lines=newchars. splitlines(keepends=True )\n     if len(lines)<=1:\n      raise\n    else :\n     raise\n     \n   self. bytebuffer=data[decodedbytes:]\n   \n   self. charbuffer +=newchars\n   \n   if not newdata:\n    break\n  if chars <0:\n  \n   result=self. charbuffer\n   self. charbuffer=self. _empty_charbuffer\n  else :\n  \n   result=self. charbuffer[:chars]\n   self. charbuffer=self. charbuffer[chars:]\n  return result\n  \n def readline(self,size=None ,keepends=True ):\n \n  ''\n\n\n\n\n\n  \n  \n  \n  if self. linebuffer:\n   line=self. linebuffer[0]\n   del self. linebuffer[0]\n   if len(self. linebuffer)==1:\n   \n   \n    self. charbuffer=self. linebuffer[0]\n    self. linebuffer=None\n   if not keepends:\n    line=line. splitlines(keepends=False )[0]\n   return line\n   \n  readsize=size or 72\n  line=self. _empty_charbuffer\n  \n  while True :\n   data=self. read(readsize,firstline=True )\n   if data:\n   \n   \n   \n    if (isinstance(data,str)and data. endswith(\"\\r\"))or    (isinstance(data,bytes)and data. endswith(b\"\\r\")):\n     data +=self. read(size=1,chars=1)\n     \n   line +=data\n   lines=line. splitlines(keepends=True )\n   if lines:\n    if len(lines)>1:\n    \n    \n     line=lines[0]\n     del lines[0]\n     if len(lines)>1:\n     \n      lines[-1]+=self. charbuffer\n      self. linebuffer=lines\n      self. charbuffer=None\n     else :\n     \n      self. charbuffer=lines[0]+self. charbuffer\n     if not keepends:\n      line=line. splitlines(keepends=False )[0]\n     break\n    line0withend=lines[0]\n    line0withoutend=lines[0]. splitlines(keepends=False )[0]\n    if line0withend !=line0withoutend:\n    \n     self. charbuffer=self. _empty_charbuffer. join(lines[1:])+     self. charbuffer\n     if keepends:\n      line=line0withend\n     else :\n      line=line0withoutend\n     break\n     \n   if not data or size is not None :\n    if line and not keepends:\n     line=line. splitlines(keepends=False )[0]\n    break\n   if readsize <8000:\n    readsize *=2\n  return line\n  \n def readlines(self,sizehint=None ,keepends=True ):\n \n  ''\n\n\n\n\n\n\n\n\n  \n  data=self. read()\n  return data. splitlines(keepends)\n  \n def reset(self):\n \n  ''\n\n\n\n\n\n  \n  self. bytebuffer=b\"\"\n  self. charbuffer=self. _empty_charbuffer\n  self. linebuffer=None\n  \n def seek(self,offset,whence=0):\n  ''\n\n\n  \n  self. stream. seek(offset,whence)\n  self. reset()\n  \n def __next__(self):\n \n  ''\n  line=self. readline()\n  if line:\n   return line\n  raise StopIteration\n  \n def __iter__(self):\n  return self\n  \n def __getattr__(self,name,\n getattr=getattr):\n \n  ''\n  \n  return getattr(self. stream,name)\n  \n def __enter__(self):\n  return self\n  \n def __exit__(self,type,value,tb):\n  self. stream. close()\n  \n  \n  \nclass StreamReaderWriter:\n\n ''\n\n\n\n\n\n\n \n \n encoding='unknown'\n \n def __init__(self,stream,Reader,Writer,errors='strict'):\n \n  ''\n\n\n\n\n\n\n\n\n\n  \n  self. stream=stream\n  self. reader=Reader(stream,errors)\n  self. writer=Writer(stream,errors)\n  self. errors=errors\n  \n def read(self,size=-1):\n \n  return self. reader. read(size)\n  \n def readline(self,size=None ):\n \n  return self. reader. readline(size)\n  \n def readlines(self,sizehint=None ):\n \n  return self. reader. readlines(sizehint)\n  \n def __next__(self):\n \n  ''\n  return next(self. reader)\n  \n def __iter__(self):\n  return self\n  \n def write(self,data):\n \n  return self. writer. write(data)\n  \n def writelines(self,list):\n \n  return self. writer. writelines(list)\n  \n def reset(self):\n \n  self. reader. reset()\n  self. writer. reset()\n  \n def seek(self,offset,whence=0):\n  self. stream. seek(offset,whence)\n  self. reader. reset()\n  if whence ==0 and offset ==0:\n   self. writer. reset()\n   \n def __getattr__(self,name,\n getattr=getattr):\n \n  ''\n  \n  return getattr(self. stream,name)\n  \n  \n  \n def __enter__(self):\n  return self\n  \n def __exit__(self,type,value,tb):\n  self. stream. close()\n  \n  \n  \nclass StreamRecoder:\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n \n data_encoding='unknown'\n file_encoding='unknown'\n \n def __init__(self,stream,encode,decode,Reader,Writer,\n errors='strict'):\n \n  ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  \n  self. stream=stream\n  self. encode=encode\n  self. decode=decode\n  self. reader=Reader(stream,errors)\n  self. writer=Writer(stream,errors)\n  self. errors=errors\n  \n def read(self,size=-1):\n \n  data=self. reader. read(size)\n  data,bytesencoded=self. encode(data,self. errors)\n  return data\n  \n def readline(self,size=None ):\n \n  if size is None :\n   data=self. reader. readline()\n  else :\n   data=self. reader. readline(size)\n  data,bytesencoded=self. encode(data,self. errors)\n  return data\n  \n def readlines(self,sizehint=None ):\n \n  data=self. reader. read()\n  data,bytesencoded=self. encode(data,self. errors)\n  return data. splitlines(keepends=True )\n  \n def __next__(self):\n \n  ''\n  data=next(self. reader)\n  data,bytesencoded=self. encode(data,self. errors)\n  return data\n  \n def __iter__(self):\n  return self\n  \n def write(self,data):\n \n  data,bytesdecoded=self. decode(data,self. errors)\n  return self. writer. write(data)\n  \n def writelines(self,list):\n \n  data=''. join(list)\n  data,bytesdecoded=self. decode(data,self. errors)\n  return self. writer. write(data)\n  \n def reset(self):\n \n  self. reader. reset()\n  self. writer. reset()\n  \n def __getattr__(self,name,\n getattr=getattr):\n \n  ''\n  \n  return getattr(self. stream,name)\n  \n def __enter__(self):\n  return self\n  \n def __exit__(self,type,value,tb):\n  self. stream. close()\n  \n  \n  \ndef open(filename,mode='rb',encoding=None ,errors='strict',buffering=1):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n if encoding is not None and 'b'not in mode:\n \n  mode=mode+'b'\n file=builtins. open(filename,mode,buffering)\n if encoding is None :\n  return file\n info=lookup(encoding)\n srw=StreamReaderWriter(file,info. streamreader,info. streamwriter,errors)\n \n srw. encoding=encoding\n return srw\n \ndef EncodedFile(file,data_encoding,file_encoding=None ,errors='strict'):\n\n ''\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n \n if file_encoding is None :\n  file_encoding=data_encoding\n data_info=lookup(data_encoding)\n file_info=lookup(file_encoding)\n sr=StreamRecoder(file,data_info. encode,data_info. decode,\n file_info. streamreader,file_info. streamwriter,errors)\n \n sr. data_encoding=data_encoding\n sr. file_encoding=file_encoding\n return sr\n \n \n \ndef getencoder(encoding):\n\n ''\n\n\n\n\n \n return lookup(encoding). encode\n \ndef getdecoder(encoding):\n\n ''\n\n\n\n\n \n return lookup(encoding). decode\n \ndef getincrementalencoder(encoding):\n\n ''\n\n\n\n\n\n \n encoder=lookup(encoding). incrementalencoder\n if encoder is None :\n  raise LookupError(encoding)\n return encoder\n \ndef getincrementaldecoder(encoding):\n\n ''\n\n\n\n\n\n \n decoder=lookup(encoding). incrementaldecoder\n if decoder is None :\n  raise LookupError(encoding)\n return decoder\n \ndef getreader(encoding):\n\n ''\n\n\n\n\n \n return lookup(encoding). streamreader\n \ndef getwriter(encoding):\n\n ''\n\n\n\n\n \n return lookup(encoding). streamwriter\n \ndef iterencode(iterator,encoding,errors='strict',**kwargs):\n ''\n\n\n\n\n\n\n \n encoder=getincrementalencoder(encoding)(errors,**kwargs)\n for input in iterator:\n  output=encoder. encode(input)\n  if output:\n   yield output\n output=encoder. encode(\"\",True )\n if output:\n  yield output\n  \ndef iterdecode(iterator,encoding,errors='strict',**kwargs):\n ''\n\n\n\n\n\n\n \n decoder=getincrementaldecoder(encoding)(errors,**kwargs)\n for input in iterator:\n  output=decoder. decode(input)\n  if output:\n   yield output\n output=decoder. decode(b\"\",True )\n if output:\n  yield output\n  \n  \n  \ndef make_identity_dict(rng):\n\n ''\n\n\n\n\n \n return {i:i for i in rng}\n \ndef make_encoding_map(decoding_map):\n\n ''\n\n\n\n\n\n\n\n\n\n \n m={}\n for k,v in decoding_map. items():\n  if not v in m:\n   m[v]=k\n  else :\n   m[v]=None\n return m\n \n \n \ntry :\n strict_errors=lookup_error(\"strict\")\n ignore_errors=lookup_error(\"ignore\")\n replace_errors=lookup_error(\"replace\")\n xmlcharrefreplace_errors=lookup_error(\"xmlcharrefreplace\")\n backslashreplace_errors=lookup_error(\"backslashreplace\")\nexcept LookupError:\n\n strict_errors=None\n ignore_errors=None\n replace_errors=None\n xmlcharrefreplace_errors=None\n backslashreplace_errors=None\n \n \n \n_false=0\nif _false:\n import encodings\n \n \n \nif __name__ =='__main__':\n\n\n sys. stdout=EncodedFile(sys. stdout,'latin-1','utf-8')\n \n \n sys. stdin=EncodedFile(sys. stdin,'utf-8','latin-1')\n", ["_codecs", "builtins", "encodings", "sys"]], "_jsre": [".js", "var $module=(function($B){\n\n    var _b_ = $B.builtins\n    var $s=[]\n    for(var $b in _b_) $s.push('var ' + $b +'=_b_[\"'+$b+'\"]')\n    eval($s.join(';'))\n\n    var JSObject = $B.JSObject\n\n    var obj = {__class__:$module,\n        __str__: function(){return \"<module 're'>\"}\n    }\n    obj.A = obj.ASCII = 256\n    obj.I = obj.IGNORECASE = 2 // 'i'\n    obj.L = obj.LOCALE = 4\n    obj.M = obj.MULTILINE = 8 // 'm'\n    obj.S = obj.DOTALL = 16\n    obj.U = obj.UNICODE = 32\n    obj.X = obj.VERBOSE = 64\n    obj._is_valid = function(pattern) {\n        if ($B.$options.re=='pyre') return false  //force use of python's re module\n        if ($B.$options.re=='jsre') return true   //force use of brythons re module\n        // FIXME: Improve\n\n        if (!isinstance(pattern, str)) {\n           // this is probably a SRE_PATTERN, so return false, and let\n           // python's re module handle this.\n           return false\n        }\n        var is_valid = false;\n        try {\n            new RegExp(pattern);\n            is_valid = true;\n        }\n        catch(e) {}\n        if (!is_valid) return false  //if js won't parse the pattern return false\n\n        // using reference http://www.regular-expressions.info/\n        // to compare python re and javascript regex libraries\n\n        // look for things javascript does not support\n        // check for name capturing group\n        var mylist=['?P=', '?P<', '(?#', '(?<=', '(?<!', '(?(']\n        for(var i=0, _len_i = mylist.length; i < _len_i; i++) {\n           if (pattern.indexOf(mylist[i]) > -1) return false\n        }\n\n        var re_list=['\\{,\\d+\\}']\n        for(var i=0, _len_i = re_list.length; i < _len_i; i++) {\n           var _re=new RegExp(re_list[i])\n           if (_re.test(pattern)) return false\n        }\n\n        // it looks like the pattern has passed all our tests so lets assume\n        // javascript can handle this pattern.\n        return true\n    }\n    var $SRE_PatternDict = {\n        __class__:_b_.type,\n        __name__:'SRE_Pattern'\n    }\n    $SRE_PatternDict.__mro__ = [object]\n    $SRE_PatternDict.findall = function(self,string){\n        return obj.findall(self.pattern,string,self.flags)\n    }\n    $SRE_PatternDict.finditer = function(self,string){\n        return obj.finditer(self.pattern,string,self.flags)\n    }\n    $SRE_PatternDict.match = function(self,string){\n        return obj.match(self.pattern,string,self.flags)\n    }\n    $SRE_PatternDict.search = function(self,string){\n        return obj.search(self.pattern,string,self.flags)\n    }\n    function normflags(flags) {\n        return ((flags & obj.I)? 'i' : '') + ((flags & obj.M)? 'm' : '');\n    }\n    obj.compile = function(pattern,flags){\n        return {\n            __class__:$SRE_PatternDict,\n            pattern:pattern,\n            flags:normflags(flags)\n        }\n    }\n    obj.escape = function(string){\n        // Escape all the characters in pattern except ASCII letters, numbers \n        // and '_'. This is useful if you want to match an arbitrary literal \n        // string that may have regular expression metacharacters in it.\n        var res = ''\n        var ok = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_'\n        for(var i=0, _len_i = string.length; i < _len_i;i++){\n            if(ok.search(string.charAt(i))>-1){res += string.charAt(i)}\n        }\n        return res\n    }\n    obj.findall = function(pattern,string,flags){\n        var $ns=$B.args('re.findall',2,\n            {pattern:null, string:null}, ['pattern', 'string'],\n            arguments,{},'args','kw') ,\n            args = $ns['args'] ,\n            _flags = 0;\n        if(args.length>0){var flags=args[0]}\n        else{var _flags = getattr($ns['kw'], 'get')('flags',0)}\n        \n        var flags = normflags();\n        flags += 'gm'\n        var jsp = new RegExp(pattern,flags) ,\n            jsmatch = string.match(jsp);\n        if(jsmatch===null){return []}\n        return jsmatch\n    }\n    obj.finditer = function(pattern,string,flags){\n        var $ns=$B.args('re.finditer',2,\n            {pattern:null, sring:null}, ['pattern','string'],\n            arguments,{},'args','kw'),\n            args = $ns['args'],\n            _flags = 0;\n        if(args.length>0){var flags=args[0]}\n        else{var _flags = getattr($ns['kw'], 'get')('flags',0)}\n        \n        var flags = normflags();\n        flags += 'gm'\n        var jsp = new RegExp(pattern,flags),\n            jsmatch = string.match(jsp);\n        if(jsmatch===null){return []}\n        \n        var _list=[]\n        for (var j=0, _len_j = jsmatch.length; j < _len_j; j++) {\n            var mo = {}\n            mo._match=jsmatch[j]\n            mo.group = function(){\n               var res = []\n               for(var i=0, _len_i = arguments.length; i < _len_i;i++){\n                   if(jsmatch[arguments[i]]===undefined){res.push(None)}\n                   else{res.push(jsmatch[arguments[i]])}\n               }\n               if(arguments.length===1){return res[0]}\n               return tuple(res)\n            }\n            mo.groups = function(_default){\n               if(_default===undefined){_default=None}\n               var res = []\n               for(var i=1, _len_i = jsmatch.length; i < _len_i;i++){\n                  if(jsmatch[i]===undefined){res.push(_default)}\n                  else{res.push(jsmatch[i])}\n               }\n               return tuple(res)\n            }\n            mo.start = function(){return mo._match.index}\n            mo.end = function(){return mo._match.length-mo._match.index}\n            mo.string = string\n            _list.push(JSObject.$factory(mo))\n        }\n        return _list\n    }\n    obj.search = function(pattern,string){\n        var $ns=$B.args('re.search', 2,\n            {pattern:null, string:null},['pattern','string'],\n            arguments,{},'args','kw')\n        var args = $ns['args']\n        if(args.length>0){var flags=args[0]}\n        else{var flags = getattr($ns['kw'],'get')('flags','')}\n        flags = normflags(flags);\n        var jsp = new RegExp(pattern,flags)\n        var jsmatch = string.match(jsp)\n        if(jsmatch===null){return None}\n        var mo = new Object()\n        mo.group = function(){\n            var res = []\n            for(var i=0, _len_i = arguments.length; i < _len_i;i++){\n                if(jsmatch[arguments[i]]===undefined){res.push(None)}\n                else{res.push(jsmatch[arguments[i]])}\n            }\n            if(arguments.length===1){return res[0]}\n            return tuple(res)\n        }\n        mo.groups = function(_default){\n            if(_default===undefined){_default=None}\n            var res = []\n            for(var i=1, _len_i = jsmatch.length; i < _len_i;i++){\n                if(jsmatch[i]===undefined){res.push(_default)}\n                else{res.push(jsmatch[i])}\n            }\n            return tuple(res)\n        }\n        mo.start = function(){return jsmatch.index}\n        mo.end = function(){return jsmatch.length-jsmatch.index}\n        mo.string = string\n        return JSObject.$factory(mo)\n    }\n    obj.sub = function(pattern,repl,string){\n        var $ns=$B.args('re.search', 3,\n            {pattern:null, repl:null, string:null}, \n            ['pattern','repl','string'],\n            arguments,{},'args','kw')\n        for($var in $ns){eval(\"var \"+$var+\"=$ns[$var]\")}\n        var args = $ns['args']\n        var count = _b_.dict.get($ns['kw'],'count',0)\n        var flags = _b_.dict.get($ns['kw'],'flags','')\n        if(args.length>0){var count=args[0]}\n        if(args.length>1){var flags=args[1]}\n        flags = normflags(flags);\n        if(typeof repl===\"string\"){\n            // backreferences are \\1, \\2... in Python but $1,$2... in Javascript\n            repl = repl.replace(/\\\\(\\d+)/g,'$$$1')\n        }else if(typeof repl===\"function\"){\n            // the argument passed to the Python function is the match object\n            // the arguments passed to the Javascript function are :\n            // - the matched substring\n            // - the matched groups\n            // - the offset of the matched substring inside the string\n            // - the string being examined\n            var $repl1 = function(){\n                var mo = Object()\n                mo.string = arguments[arguments.length-1]\n                var start = arguments[arguments.length-2]\n                var end = start + arguments[0].length\n                mo.start = function(){return start}\n                mo.end = function(){return end}\n                groups = []\n                for(var i=1, _len_i = arguments.length-2; i < _len_i;i++){groups.push(arguments[i])}\n                mo.groups = function(_default){\n                    if(_default===undefined){_default=None}\n                    var res = []\n                    for(var i=0, _len_i = groups.length; i < _len_i;i++){\n                        if(groups[i]===undefined){res.push(_default)}\n                        else{res.push(groups[i])}\n                    }\n                    return res\n                }\n                return repl(JSObject.$factory(mo))\n            }\n        }\n        if(count==0){flags+='g'}\n        var jsp = new RegExp(pattern,flags)\n        if(typeof repl==='function'){return string.replace(jsp,$repl1)}\n        else{return string.replace(jsp,repl)}\n    }\n    obj.match = (function(search_func){\n        return function(){\n            // match is like search but pattern must start with ^\n            var pattern = arguments[0]\n            if(pattern.charAt(0)!=='^'){pattern = '^'+pattern}\n            var args = [pattern]\n            for(var i=1, _len_i = arguments.length; i < _len_i;i++){args.push(arguments[i])}\n            return search_func.apply(null,args)\n        }\n    })(obj.search)\n\n    return obj\n}\n)(__BRYTHON__)\n"], "importlib.machinery": [".py", "''\n\nimport _imp\n\nfrom . _bootstrap import (SOURCE_SUFFIXES,DEBUG_BYTECODE_SUFFIXES,\nOPTIMIZED_BYTECODE_SUFFIXES,\nEXTENSION_SUFFIXES)\nfrom . _bootstrap import BuiltinImporter\nfrom . _bootstrap import FrozenImporter\nfrom . _bootstrap import WindowsRegistryFinder\nfrom . _bootstrap import PathFinder\nfrom . _bootstrap import FileFinder\nfrom . _bootstrap import SourceFileLoader\nfrom . _bootstrap import SourcelessFileLoader\nfrom . _bootstrap import ExtensionFileLoader\n\n\n\n\n\n", ["_imp", "importlib._bootstrap"]]}